(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    939942,      24544]
NotebookOptionsPosition[    871169,      22629]
NotebookOutlinePosition[    895421,      23148]
CellTagsIndexPosition[    894163,      23105]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Graphs", "BookChapterTitle",
 CounterAssignments->{{"ChapterNumber", 10}}],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
 "In this chapter we consider ways in which ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can help you explore and understand graphs. In particular, we describe how \
to do computations on graphs using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be used to visualize graphs."
}], "Text"],

Cell[TextData[{
 "Throughout the first half of this chapter, pseudographs are a recurring \
theme. Recall that pseudographs are graphs that may contain loops and may \
contain multiple edges between vertices. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " includes numerous and powerful commands for representing, manipulating, \
and calculating with simple graphs, both undirected and directed. Each \
section in what follows will introduce you to these useful tools so that you \
can more easily explore the concepts described in the textbook. But many of \
these functions do not support graphs with multiple edges. So parts of this \
chapter are devoted to extending ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s existing functionality to pseudographs. This will give you tools that \
you can use to explore these kinds of graphs. More than that, seeing how to \
create the functions for pseudographs will help you to better understand how \
the functions work for simple graphs."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["10.1 Graphs and Graph Models", "Section",
 CellTags->"Section1"],

Cell[TextData[{
 "Recall that a simple graph, as defined in Section 10.1 of the text, is a \
set ",
 Cell[BoxData[
  FormBox["V", TraditionalForm]]],
 " of vertices and a set ",
 Cell[BoxData[
  FormBox["E", TraditionalForm]]],
 " of unordered pairs of elements of ",
 Cell[BoxData[
  FormBox["V", TraditionalForm]]],
 ", called the edges of the graph, and where each edge connects two different \
vertices and no two edges connect the same pair of vertices. That is, the \
edges are undirected, there are no loops, and there are no multiple edges."
}], "Text"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " represents a simple graph as a special raw object with head ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 ". You should think about ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " not as a function, but as a way to describe and represent an object. To \
explain this distinction, consider a fraction, such as ",
 Cell[BoxData[
  FormBox[
   FractionBox["5", "9"], TraditionalForm]]],
 ". We think about this as a single number, and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " treats it as a simple object, but if you delve down using ",
 StyleBox[ButtonBox["FullForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FullForm"], "FunctionLink"],
 ", you see that it\[CloseCurlyQuote]s a bit more complicated."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"5", "/", "9"}], " ", "//", "FullForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"Rational", "[", 
    RowBox[{"5", ",", "9"}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox[ButtonBox["FullForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FullForm"], "FunctionLink"],
 " reveals that, for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the fraction ",
 Cell[BoxData[
  FormBox[
   FractionBox["5", "9"], TraditionalForm]]],
 " is actually represented by ",
 StyleBox[ButtonBox["Rational",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rational"], "FunctionLink"],
 " applied to two integers. ",
 StyleBox[ButtonBox["Rational",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rational"], "FunctionLink"],
 " is not a function, in the usual sense. Rather, it is a head that tells ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " what the contents mean. ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " is exactly the same, if a bit more complicated. It is a head that tells ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " that the contents represent a graph object. Also, just like a ",
 StyleBox[ButtonBox["Rational",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rational"], "FunctionLink"],
 " is typically displayed in the usual fraction notation, a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object is displayed as a drawing of the graph. "
}], "Text"],

Cell[TextData[{
 "The simplest way to specify a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is by specifying the edges as a list of rules. You typically use positive \
integers or strings for the vertices (although other expressions can be \
used). An edge between the vertex represented by 1 and the vertex represented \
by \[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote] is given as the rule ",
 Cell[BoxData[
  RowBox[{"1", "->", "\"\<a\>\""}]], "myCode"],
 "."
}], "Text"],

Cell["\<\
As an example, the following defines a directed version of the graph shown in \
Exercise 3 in Section 10.1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exercise3directed", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], "]"}]}]], "Input",\

 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {{{1, 2}, {1, 3}, {2, 3}, {2, 4}}, Null}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Arrowheads[0.03384563758389261], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       ArrowBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       ArrowBox[
        BezierCurveBox[{
          DynamicLocation["VertexID$1", Automatic, Center], {0., 
          1.9012345679012346`}, {0., 1.8444444444444446`}, {0., 
          1.7827160493827163`}, {0., 1.7160493827160495`}, {0., 
          1.6444444444444444`}, {0., 1.567901234567901}, {0., 
          1.4864197530864198`}, {0., 1.4}, {0., 1.3111111111111107`}, {0., 
          1.222222222222222}, {0., 1.1333333333333335`}, {0., 
          1.0444444444444445`}, {0., 0.9555555555555556}, {0., 
          0.8666666666666667}, {0., 0.7777777777777778}, {0., 
          0.6888888888888889}, {0., 0.6}, {0., 0.5135802469135802}, {0., 
          0.4320987654320988}, {0., 0.35555555555555557`}, {0., 
          0.2839506172839506}, {0., 0.2172839506172839}, {0., 
          0.15555555555555556`}, {0., 0.09876543209876543}, 
          DynamicLocation["VertexID$3", Automatic, Center]}]], 
       ArrowBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0., 2.}, 0.02261146496815286], "DynamicName", BoxID -> 
        "VertexID$1"], 
       TagBox[
        DiskBox[{1., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
        "VertexID$2"], 
       TagBox[
        DiskBox[{0., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
        "VertexID$3"], 
       TagBox[
        DiskBox[{1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
        "VertexID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{3.4969274927974974`, 
       221.34944714707748`}, {-214.68294960691438`, 209.68294960691443`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To produce an undirected simple graph, you can set the option ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " to ",
 StyleBox[ButtonBox["False",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/False"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exercise3", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "False"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0.002089066523780936, 0.}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0.9175848200953383, 0.4241670904205272}, 
         0.022873923537282098`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0., 0.8473715512181632}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
         0.022873923537282098`], "DynamicName", BoxID -> 
        "VertexID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18, 352.82000000000016`}, {-78.1072, 
       72.00674296209056}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "You can also create (undirected) simple graphs using the symbol \
\[UndirectedEdge] in place of ",
 StyleBox[ButtonBox["Rule",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rule"], "FunctionLink"],
 " (",
 StyleBox["\[Rule]", "Input"],
 "). The undirected edge symbol is entered by typing \[EscapeKey]ue\
\[EscapeKey]. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\"\<a\>\"", "\[UndirectedEdge]", "\"\<b\>\""}], ",", 
    RowBox[{"\"\<a\>\"", "\[UndirectedEdge]", "\"\<c\>\""}], ",", 
    RowBox[{"\"\<b\>\"", "\[UndirectedEdge]", "\"\<c\>\""}], ",", 
    RowBox[{"\"\<b\>\"", "\[UndirectedEdge]", "\"\<d\>\""}]}], "}"}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0.002089066523780936, 0.}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0.9175848200953383, 0.4241670904205272}, 
         0.022873923537282098`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0., 0.8473715512181632}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
         0.022873923537282098`], "DynamicName", BoxID -> 
        "VertexID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18, 352.82000000000016`}, {-78.1072, 
       72.00674296209056}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "If you prefer, you can use the symbol \[DirectedEdge], entered as \
\[EscapeKey]de\[EscapeKey] in place of ",
 StyleBox[ButtonBox["Rule",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rule"], "FunctionLink"],
 " (",
 StyleBox["\[Rule]", "Input"],
 ") for a directed graph. Note, however, that ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " does not allow mixed graphs, that is, graphs with both directed an \
undirected edges. In this manual, we will generally use ",
 StyleBox[ButtonBox["Rule",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rule"], "FunctionLink"],
 " (",
 StyleBox["\[Rule]", "Input"],
 ") to specify all edges together with the ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " option, when needed. There are, however, certain functions that require \
the use of \[DirectedEdge] or \[UndirectedEdge], and you should pay special \
attention to those situations."
}], "Text"],

Cell[TextData[{
 "If you wish, you may give an explicit list of vertices as an optional first \
argument to ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 ". This is only required in the situation when a graph has a vertex not \
adjacent to any other, as in the example below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"2", "\[Rule]", "3"}], ",", 
     RowBox[{"3", "\[Rule]", "4"}], ",", 
     RowBox[{"4", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, {{1, 2}, {2, 3}, {3, 4}, {4, 1}}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{1.1570827321497008`, -1.1281685887629571`}, 
         0.016512279377655925`], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0.15768973023584465`, -1.154236031031331}, 
         0.016512279377655925`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0.12841548684339066`, -0.15485132588994366`}, 
         0.016512279377655925`], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{1.1283539266140916`, -0.12841548684339066`}, 
         0.016512279377655925`], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{0.12841548684339066`, -1.4110670047181124`}, 
         0.016512279377655925`], "DynamicName", BoxID -> 
        "VertexID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.019218448547162, 
       344.94170397881106`}, {-212.26155028939468`, 207.26155028939468`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["VertexList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexList"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["EdgeList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeList"], "FunctionLink"],
 " functions applied to a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object output the vertices and edges of the graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexList", "[", "exercise3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", ",", "\<\"d\"\>"}],
   "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EdgeList", "[", "exercise3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[UndirectedEdge]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[UndirectedEdge]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[UndirectedEdge]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[UndirectedEdge]", "\<\"d\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Observe that the output of ",
 StyleBox[ButtonBox["EdgeList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeList"], "FunctionLink"],
 " is a list of undirected edges, using the symbol \[UndirectedEdge], despite \
the fact that we defined the graph using rules. This is because the true \
effect of setting the ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " option to ",
 StyleBox[ButtonBox["False",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/False"], "FunctionLink"],
 " is for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to transform the rules into undirected edges. Using ",
 StyleBox[ButtonBox["FullForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FullForm"], "FunctionLink"],
 ", you can see that these are stored using the head ",
 StyleBox[ButtonBox["UndirectedEdge",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/UndirectedEdge"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"EdgeList", "[", "exercise3", "]"}], "//", "FullForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"List", "[", 
    RowBox[{
     RowBox[{"UndirectedEdge", "[", 
      RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "]"}], ",", 
     RowBox[{"UndirectedEdge", "[", 
      RowBox[{"\"\<a\>\"", ",", "\"\<c\>\""}], "]"}], ",", 
     RowBox[{"UndirectedEdge", "[", 
      RowBox[{"\"\<b\>\"", ",", "\"\<c\>\""}], "]"}], ",", 
     RowBox[{"UndirectedEdge", "[", 
      RowBox[{"\"\<b\>\"", ",", "\"\<d\>\""}], "]"}]}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that the same is true in the directed case, with the edges represented \
internally as ",
 StyleBox[ButtonBox["DirectedEdge",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdge"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EdgeList", "[", "exercise3directed", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[DirectedEdge]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[DirectedEdge]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[DirectedEdge]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[DirectedEdge]", "\<\"d\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"EdgeList", "[", "exercise3directed", "]"}], "//", 
  "FullForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"List", "[", 
    RowBox[{
     RowBox[{"DirectedEdge", "[", 
      RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "]"}], ",", 
     RowBox[{"DirectedEdge", "[", 
      RowBox[{"\"\<a\>\"", ",", "\"\<c\>\""}], "]"}], ",", 
     RowBox[{"DirectedEdge", "[", 
      RowBox[{"\"\<b\>\"", ",", "\"\<c\>\""}], "]"}], ",", 
     RowBox[{"DirectedEdge", "[", 
      RowBox[{"\"\<b\>\"", ",", "\"\<d\>\""}], "]"}]}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " objects may contain loops, as illustrated below with a replica of Exercise \
7 from Section 10.1. Loops are created simply by including an edge from a \
vertex to itself."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exercise7", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\"", ",", 
      "\"\<e\>\""}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
      RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<a\>\""}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<e\>\""}]}], "}"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "5"}], ",", 
    RowBox[{"VertexCoordinates", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "a", "b", "c", "d", "e"}, {{{1, 2}, {2, 5}, {3, 2}, {3, 3}, {3, 4}, {4, 
       3}, {5, 1}, {5, 4}, {5, 5}}, Null}, {
      ImagePadding -> 5, 
       VertexCoordinates -> {{1, 1}, {2, 2}, {3, 2}, {3, 1}, {2, 1}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.03384563758389261], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       ArrowBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       ArrowBox[
        BezierCurveBox[{
          DynamicLocation["VertexID$3", Automatic, Center], {
          2.9226652357765426`, 2.211102824883941}, {3.03037168156465, 
          2.404072374917325}, {3.1710710001067524`, 2.4556369686221933`}, {
          3.4556369686221933`, 2.1710710001067524`}, {3.404072374917325, 
          2.03037168156465}, {3.211102824883941, 1.9226652357765426`}, 
          DynamicLocation["VertexID$3", Automatic, Center]}, SplineDegree -> 
         7]], 
       ArrowBox[
        BezierCurveBox[{
          DynamicLocation["VertexID$3", Automatic, Center], {
          3.1552807082181697`, 1.5}, 
          DynamicLocation["VertexID$4", Automatic, Center]}]], 
       ArrowBox[
        BezierCurveBox[{
          DynamicLocation["VertexID$4", Automatic, Center], {
          2.8447192917818303`, 1.5000000000000004`}, 
          DynamicLocation["VertexID$3", Automatic, Center]}]], 
       ArrowBox[{
         DynamicLocation["VertexID$5", Automatic, Center], 
         DynamicLocation["VertexID$1", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$5", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       ArrowBox[
        BezierCurveBox[{
          DynamicLocation["VertexID$5", Automatic, Center], {
          2.2304450364563646`, 0.8476276972960466}, {2.250002442847489, 
          0.6526270006898856}, {2.1815918401357854`, 0.5391807550302723}, {
          1.8184081598642148`, 0.5391807550302722}, {1.7499975571525106`, 
          0.6526270006898856}, {1.7695549635436354`, 0.8476276972960466}, 
          DynamicLocation["VertexID$5", Automatic, Center]}, SplineDegree -> 
         7]]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 2.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 2.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{8.760693309010083, 
       351.2393066909899}, {-136.2393066909899, 131.2393066909899}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Options Affecting the Visual Output of ",
 StyleBox["Graph", "Input"]
}], "Subsection",
 CellTags->"Section1a"],

Cell[TextData[{
 "In this subsection, we will explain just a few of the options available \
when creating ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " objects to change their visual appearance. Readers interested in greater \
control over the visual display of ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " objects should refer to the help pages."
}], "Text"],

Cell[TextData[{
 "To have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " display the names of vertices, you use the ",
 StyleBox[ButtonBox["VertexLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabels"], "FunctionLink"],
 " option. Probably the most common value for this option is ",
 StyleBox["\"Name\"", "Input"],
 ", including the quotation marks, which causes each vertex to be labeled \
with its name. As an example, we repeat the definition of the graph from \
Exercise 3 used above, with this option invoked."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}, {
      VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0.002089066523780936, 0.}, 0.022873923537282098`], 
          "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9175848200953383, 0.4241670904205272}, 
           0.022873923537282098`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.8473715512181632}, 0.022873923537282098`], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
           0.022873923537282098`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18, 359.4160496194132}, {-89.70324961941132, 
       72.00674296209054}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Observe that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has cut off part of the string \[OpenCurlyDoubleQuote]c\
\[CloseCurlyDoubleQuote] which labels the top vertex. This is because it did \
not allocate room for the labels when it drew the graph. To correct for this, \
we apply the ",
 StyleBox[ButtonBox["ImagePadding",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ImagePadding"], "FunctionLink"],
 " option, which is available for all graphics objects. The valid values for ",
 StyleBox[ButtonBox["ImagePadding",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ImagePadding"], "FunctionLink"],
 " include: a single integer representing padding to be added to all sides of \
the image, measured in points; a list of the form ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", "{"}], 
   StyleBox["left", "CodeVar"], ",", 
   StyleBox["right", "CodeVar"], 
   RowBox[{"}", ",", "{"}], 
   StyleBox["bottom", "CodeVar"], ",", 
   StyleBox["top", "CodeVar"], 
   RowBox[{"}", "}"}]}]], "myCode"],
 " indicating specific lengths for each side; ",
 StyleBox[ButtonBox["None",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/None"], "FunctionLink"],
 ", for no padding, or ",
 StyleBox[ButtonBox["All",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/All"], "FunctionLink"],
 ", which ensures there is enough padding for all the objects in the graphic. \
Below, we see that 5 points on all sides is sufficient in this example."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}, {
      ImagePadding -> 5, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0.002089066523780936, 0.}, 0.022873923537282098`], 
          "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9175848200953383, 0.4241670904205272}, 
           0.022873923537282098`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.8473715512181632}, 0.022873923537282098`], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
           0.022873923537282098`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{10.999999999999996`, 
       355.62390342012617`}, {-86.90390342012718, 71.12078004660633}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Another use of the ",
 StyleBox[ButtonBox["VertexLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabels"], "FunctionLink"],
 " option is to specify labels for specific vertices. You do this by \
identifying the option with a list consisting of rules associating the name \
of the vertex with the desired label. The following illustrates this by \
labeling two of the vertices in the Exercise 3 graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<A\>\""}], ",", 
      RowBox[{"\"\<d\>\"", "\[Rule]", "4"}]}], "}"}]}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}, {
      ImagePadding -> 5, VertexLabels -> {"a" -> "A", "d" -> 4}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0.002089066523780936, 0.}, 0.022873923537282098`], 
          "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"A\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[
        DiskBox[{0.9175848200953383, 0.4241670904205272}, 
         0.022873923537282098`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0., 0.8473715512181632}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
           0.022873923537282098`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{10.999999999999996`, 
       355.62390342012617`}, {-75.28000000000002, 71.12078004660636}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Similarly, edges in a graph can be labeled using the ",
 StyleBox[ButtonBox["EdgeLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeLabels"], "FunctionLink"],
 " option. Once again, the value \[OpenCurlyDoubleQuote]Name\
\[CloseCurlyDoubleQuote] will cause all edges to be labeled."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
   RowBox[{"EdgeLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}, {
      EdgeLabels -> {"Name"}, ImagePadding -> 5}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          RowBox[{"\"a\"", "\[UndirectedEdge]", "\"b\""}], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          RowBox[{"\"a\"", "\[UndirectedEdge]", "\"c\""}], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          RowBox[{"\"b\"", "\[UndirectedEdge]", "\"c\""}], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          RowBox[{"\"b\"", "\[UndirectedEdge]", "\"d\""}], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0.002089066523780936, 0.}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0.9175848200953383, 0.4241670904205272}, 
         0.022873923537282098`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0., 0.8473715512181632}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
         0.022873923537282098`], "DynamicName", BoxID -> 
        "VertexID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{2.9529556267788664`, 
       349.4142135623731}, {-75.69421356237312, 71.53499360897946}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "As with vertices, you can also choose to label specific edges with \
arbitrary labels by giving a list of rules as the value to ",
 StyleBox[ButtonBox["EdgeLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeLabels"], "FunctionLink"],
 ". When doing this, the edges must be specified using either \
\[UndirectedEdge] (\[EscapeKey]ue\[EscapeKey]) or \[DirectedEdge] (\
\[EscapeKey]de\[EscapeKey])."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
   RowBox[{"EdgeLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[UndirectedEdge]", "\"\<b\>\""}], "\[Rule]", 
      SubscriptBox["e", "1"]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}, {
      EdgeLabels -> {
        UndirectedEdge["a", "b"] -> Subscript[$CellContext`e, 1]}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          SubscriptBox["e", "1"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0.002089066523780936, 0.}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0.9175848200953383, 0.4241670904205272}, 
         0.022873923537282098`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0., 0.8473715512181632}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
         0.022873923537282098`], "DynamicName", BoxID -> 
        "VertexID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18, 352.82000000000016`}, {-78.1072, 
       72.00674296209056}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "As an alternative to ",
 StyleBox[ButtonBox["VertexLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabels"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["EdgeLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeLabels"], "FunctionLink"],
 ", you can use the wrapper ",
 StyleBox[ButtonBox["Labeled",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Labeled"], "FunctionLink"],
 " around an edge in the list of edges or, in conjuncion with the optional \
list of vertices, around a vertex. The first element in ",
 StyleBox[ButtonBox["Labeled",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Labeled"], "FunctionLink"],
 " is the name of the vertex or the edge definition. The second element is \
the label to be used. Observe that, just as with the ",
 StyleBox[ButtonBox["EdgeLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeLabels"], "FunctionLink"],
 " option, edges within a ",
 StyleBox[ButtonBox["Labeled",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Labeled"], "FunctionLink"],
 " wrapper must be given using \[UndirectedEdge] or \[DirectedEdge]."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<a\>\"", ",", 
     RowBox[{"Labeled", "[", 
      RowBox[{"\"\<b\>\"", ",", "\"\<b\>\""}], "]"}], ",", "\"\<c\>\"", ",", 
     RowBox[{"Labeled", "[", 
      RowBox[{"\"\<d\>\"", ",", "4"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"Labeled", "[", 
      RowBox[{
       RowBox[{"\"\<b\>\"", "\[UndirectedEdge]", "\"\<d\>\""}], ",", 
       "\"\<edge\>\""}], "]"}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}, {
      EdgeLabels -> {UndirectedEdge["b", "d"] -> "edge"}, 
       VertexLabels -> {"b" -> "b", "d" -> 4}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox["\"edge\"", TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0.002089066523780936, 0.}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9175848200953383, 0.4241670904205272}, 
           0.022873923537282098`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[
        DiskBox[{0., 0.8473715512181632}, 0.022873923537282098`], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
           0.022873923537282098`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18, 359.4160496194132}, {-78.1072, 
       72.00674296209056}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "You can change the size of vertices with the ",
 StyleBox[ButtonBox["VertexSize",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexSize"], "FunctionLink"],
 " option. Valid values include ",
 StyleBox["Tiny", "Input"],
 ", ",
 StyleBox["Small", "Input"],
 ", ",
 StyleBox["Medium", "Input"],
 ", and ",
 StyleBox["Large", "Input"],
 ", or a number between 0 and 1. A numerical value indicates that the size of \
the vertex should be that proportion of the distance between the closest two \
vertices."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"VertexSize", "\[Rule]", "Medium"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}, {
      VertexLabels -> {"Name"}, VertexSize -> {Medium}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0.002089066523780936, 0.}, 0.08473741263531812], 
          "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9175848200953383, 0.4241670904205272}, 
           0.08473741263531812], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.8473715512181632}, 0.08473741263531812], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
           0.08473741263531812], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.179999999999998, 
       356.64242980839174`}, {-91.9296298083872, 78.04979861080588}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "You can further control the appearance, such as the color, of vertices and \
edges with the ",
 StyleBox[ButtonBox["VertexStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexStyle"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["EdgeStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeStyle"], "FunctionLink"],
 " options. Multiple styles can be combined with the ",
 StyleBox[ButtonBox["Directive",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Directive"], "FunctionLink"],
 " wrapper. For example, the following illustrates how to create red vertices \
and thick green edges. Readers interested in exploring the various options \
available should consult the ",
 ButtonBox["Graphics Directives",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/GraphicsDirectives"],
 " guide."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
   RowBox[{"VertexStyle", "\[Rule]", "Red"}], ",", 
   RowBox[{"EdgeStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Green", ",", "Thick"}], "]"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}, {
      EdgeStyle -> {
         Directive[
          RGBColor[0, 1, 0], 
          Thickness[Large]]}, VertexStyle -> {
         RGBColor[1, 0, 0]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}], 
        Directive[
         RGBColor[0, 1, 0], 
         Thickness[Large]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}], 
        Directive[
         RGBColor[0, 1, 0], 
         Thickness[Large]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}], 
        Directive[
         RGBColor[0, 1, 0], 
         Thickness[Large]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}], 
        Directive[
         RGBColor[0, 1, 0], 
         Thickness[Large]], StripOnInput -> False]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        StyleBox[
         DiskBox[{0.002089066523780936, 0.}, 0.022873923537282098`], 
         RGBColor[1, 0, 0], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$1"], 
       TagBox[
        StyleBox[
         DiskBox[{0.9175848200953383, 0.4241670904205272}, 
          0.022873923537282098`], 
         RGBColor[1, 0, 0], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$2"], 
       TagBox[
        StyleBox[
         DiskBox[{0., 0.8473715512181632}, 0.022873923537282098`], 
         RGBColor[1, 0, 0], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$3"], 
       TagBox[
        StyleBox[
         DiskBox[{2.0324134878538267`, 0.42430280790670055`}, 
          0.022873923537282098`], 
         RGBColor[1, 0, 0], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18, 352.82000000000016`}, {-78.1072, 
       72.00674296209056}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["VertexCoordinates",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexCoordinates"], "FunctionLink"],
 " option is used to specify the locations of vertices. The value for the ",
 StyleBox[ButtonBox["VertexCoordinates",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexCoordinates"], "FunctionLink"],
 " option is a list of pairs of the form ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      StyleBox[
       SubscriptBox["x", "1"], "CodeVar"], ",", 
      StyleBox[
       SubscriptBox[
        StyleBox["y", "CodeVar"], "1"], "CodeVar"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      StyleBox[
       SubscriptBox[
        StyleBox["x", "CodeVar"], "2"], "CodeVar"], ",", 
      StyleBox[
       SubscriptBox[
        StyleBox["y", "CodeVar"], "2"], "CodeVar"]}], "}"}], ",", "..."}], 
   "}"}]], "myCode"],
 ", with the pairs specifying the coordinates of a vertex. The order of the \
locations must correspond to the order of the vertices in the graph. When an \
explicit list of vertices is given as the optional first element of ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 ", that list specifies the order. Otherwise, the order is determined by when \
the vertex is first encountered in the list of edges, and is the same as the \
output of ",
 StyleBox[ButtonBox["VertexList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexList"], "FunctionLink"],
 ". Below, we use ",
 StyleBox[ButtonBox["VertexCoordinates",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexCoordinates"], "FunctionLink"],
 " to redraw the Exercise 3 graph with the vertices in the same positions as \
in the image in the textbook."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\""}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"VertexCoordinates", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, {{1, 2}, {1, 3}, {2, 3}, {2, 4}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{1, 2}, {2, 2}, {1, 1}, {2, 1}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{1., 2.}, 0.01273], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 2.}, 0.01273], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.01273], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.01273], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.80000000000003, 
       350.72032971286444`}, {-177.9923297128641, 161.92799999999983`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "You can also exert control over the layout of the vertices of a graph, but \
without specifying each coordinate, by using the ",
 StyleBox[ButtonBox["GraphLayout",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphLayout"], "FunctionLink"],
 " option to specify the algorithm that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " uses to choose the vertex location. Common choices include: ",
 StyleBox["\"SpringEmbedding\"", "Input"],
 ", which treats edges as springs and minimizes the mechanical energy of the \
system; ",
 StyleBox["\"SpringElectricalEmbedding\"", "Input"],
 ", which treats edges as springs and vertices as electrical charges and \
minimizes mechanical and electrical energy; ",
 StyleBox["\"HighDimensionalEmbedding\"", "Input"],
 ", which is like the spring-electrical method but computes in high \
dimensions and then projects down to two; ",
 StyleBox["\"CircularEmbedding\"", "Input"],
 ", which places the vertices on a circle; and ",
 StyleBox["\"LayeredDrawing\"", "Input"],
 ", which places vertices in layers and attempts to reduce the number of \
edges between non-adjacent layers."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Modifying Graphs", "Subsection",
 CellTags->"Section1b"],

Cell[TextData[{
 "You can modify existing graphs by adding and deleting edges and vertices \
using the functions ",
 StyleBox[ButtonBox["VertexAdd",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexAdd"], "FunctionLink"],
 ", ",
 StyleBox[ButtonBox["VertexDelete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexDelete"], "FunctionLink"],
 ", ",
 StyleBox[ButtonBox["EdgeAdd",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeAdd"], "FunctionLink"],
 ", and ",
 StyleBox[ButtonBox["EdgeDelete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeDelete"], "FunctionLink"],
 ". Each of these functions requires a graph as the first argument. The \
second argument is usually either a vertex, an edge, or a list of vertices or \
edges. The deletion functions can, in place of a vertex, edge, or list, \
accept a pattern as the second argument in order to delete all of the \
vertices or edges that match the pattern."
}], "Text"],

Cell["\<\
First, we create an example graph to illustrate the functions with.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"modifyExample", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {
      Null, {{1, 2}, {1, 3}, {1, 4}, {2, 3}, {2, 4}}}, {
      ImagePadding -> 10, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.933811463554344, 0.869482848690875}, 
           0.021528196942231848`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{0.9341177427775514, 0.}, 0.021528196942231848`], 
          "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.43502688266879386`}, 0.021528196942231848`], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.8676183598099563`, 0.43516953249600193`}, 
           0.021528196942231848`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 350.8299464294225}, {-93.10194642942345, 
       76.41680744913377}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Now we use ",
 StyleBox[ButtonBox["VertexAdd",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexAdd"], "FunctionLink"],
 " to add two new vertices to the graph. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"modifyExampleB", "=", 
  RowBox[{"VertexAdd", "[", 
   RowBox[{"modifyExample", ",", 
    RowBox[{"{", 
     RowBox[{"\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "y", "z"}, {
      Null, {{1, 2}, {1, 3}, {1, 4}, {2, 3}, {2, 4}}}, {
      ImagePadding -> 10, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.0478673472418787`, -0.11405588368753461`}, 
           0.021528196942231848`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.0481736264650863`, -0.9835387323784096}, 
           0.021528196942231848`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.11405588368753472`, -0.5485118497096158}, 
           0.021528196942231848`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.981674243497491, -0.5483691998824076}, 
           0.021528196942231848`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.11405588368753464`, -1.211650499753479}, 
           0.021528196942231848`], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["\"y\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.1619209472800476`, -1.211650499753479}, 
           0.021528196942231848`], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999994`, 
       350.82994642942236`}, {-112.10194642942406`, 96.38507283666635}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Now we add edges to connect the new vertices with the rest of the graph. \
Note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will interpret rules as undirected edges since the original graph is not \
directed."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"modifyExampleB", "=", 
  RowBox[{"EdgeAdd", "[", 
   RowBox[{"modifyExampleB", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<z\>\""}], ",", 
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<y\>\""}], ",", 
      RowBox[{"\"\<y\>\"", "\[Rule]", "\"\<z\>\""}]}], "}"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "y", "z"}, {
      Null, {{1, 2}, {1, 3}, {1, 4}, {2, 3}, {2, 4}, {1, 6}, {1, 5}, {5, 
       6}}}, {ImagePadding -> 10, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.0676007538230274`, 0.7933100758731038}, 
           0.023294242675072352`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.0846023908064906`, 0.7938850610645942}, 
           0.023294242675072352`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1.838459398305044, 0.}, 0.023294242675072352`], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.8376933287596289`, 1.585597019420473}, 
           0.023294242675072352`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.0004657148894082752, 1.1725672959493358`}, 
           0.023294242675072352`], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["\"y\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.41352335879263663`}, 0.023294242675072352`], 
          "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.800000000000004`, 
       350.86218035112427`}, {-140.13418035112497`, 123.50342675195591`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell["\<\
Now we delete one of the old edges. Note that to delete an edge from an \
undirected graph, you must use \[UndirectedEdge] \
(\[EscapeKey]ue\[EscapeKey]). Likewise, deleting an edge from a directed \
graph must use \[DirectedEdge] (\[EscapeKey]de\[EscapeKey]).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"modifyExampleB", "=", 
  RowBox[{"EdgeDelete", "[", 
   RowBox[{"modifyExampleB", ",", 
    RowBox[{"\"\<b\>\"", "\[UndirectedEdge]", "\"\<c\>\""}]}], 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "y", "z"}, {
      Null, {{1, 2}, {1, 3}, {1, 4}, {2, 4}, {1, 6}, {1, 5}, {5, 6}}}, {
      ImagePadding -> 10, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.0782041042622732`, 0.674002682331695}, 
           0.023867660434571475`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.156361714138678, 0.6802926891493504}, 
           0.023867660434571475`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.0771215938230145`, 1.8193553429415705`}, 
           0.023867660434571475`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.9227559548012003`, 0.0017383942209355796`}, 
           0.023867660434571475`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{0.23476133946233557`, 0.}, 0.023867660434571475`], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["\"y\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.6798102775084007}, 0.023867660434571475`], 
          "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 350.87187259034596`}, {-153.1438725903498, 
       137.0214496931777}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell["\<\
Finally, note that deleting a vertex also deletes all the edges incident with \
that vertex. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"modifyExampleB", "=", 
  RowBox[{"VertexDelete", "[", 
   RowBox[{"modifyExampleB", ",", "\"\<y\>\""}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "z"}, {
      Null, {{1, 2}, {1, 3}, {1, 4}, {2, 4}, {1, 5}}}, {
      ImagePadding -> 10, VertexLabels -> {"Name", "y" -> None}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.7371789453155361, 0.8059778623701405}, 
           0.019961725034986444`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.6800871361765972`, 0.43232437440949273`}, 
           0.019961725034986444`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{0.0006249958503357078, 0.}, 0.019961725034986444`], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.6800704750705713`, 1.1796403948693213`}, 
           0.019961725034986444`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 1.611343010753724}, 0.019961725034986444`], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.800000000000004`, 
       350.79760905614273`}, {-171.06960905614474`, 155.88268346680914`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexList", "[", "modifyExampleB", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"z\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EdgeList", "[", "modifyExampleB", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[UndirectedEdge]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[UndirectedEdge]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[UndirectedEdge]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[UndirectedEdge]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[UndirectedEdge]", "\<\"z\"\>"}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Multiple edges and ",
 StyleBox["GraphPlot", "Input"]
}], "Subsection",
 CellTags->"Section1c"],

Cell[TextData[{
 "We saw that loops are allowed, but ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " objects may not contain multiple edges. The following is the list of edges \
for Exercise 4 from Section 10.1."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"exercise4edges", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
     RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}]}], "}"}]}], ";"}]], "Input",\

 InitializationCell->True],

Cell[TextData[{
 "This cannot be used to form a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", "exercise4edges", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Graph", "::", "supp"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Mixed graphs and multigraphs are not supported. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/Graph\\\", ButtonNote -> \
\\\"Graph::supp\\\"]\\)\"\>"}]], "Message", "MSG"],

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
    RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
    RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
    RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
    RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
    RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
    RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}]}], "}"}], "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "As mentioned above, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " includes many functions that can be applied to ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " objects in order to check graph properties and do other computations with \
them. In order to work with multigraphs, that is, graphs with multiple edges, \
we will build our own functions to do computations. Fortunately, we do not \
need to develop a new function for drawing images of multigraphs."
}], "Text"],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " function, having been introduced in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " version 6, is older than and partially superceded by the ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object. However, it has some benefits, in particular the ability to draw \
multigraphs."
}], "Text"],

Cell[TextData[{
 "The basic input for ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " is a list of rules representing the edges of the graph. In this regard, ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " are similar. However, ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " does not allow the use of the symbols \[UndirectedEdge] or \
\[DirectedEdge], nor does it allow a list of vertices as a first argument."
}], "Text"],

Cell[TextData[{
 "You can draw a plot of Exercise 4 by applying ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " to ",
 StyleBox["exercise4edges", "Input"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", "exercise4edges", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw1j3sw1AkAx39cQuS84jqyHrVRmUpdEe5LIdLhSBnOowcxlIq70NXRzXUn
Ou9Hpaz1PGvXLhnXuvy2az1qi9jKcW1nzIV9tL/f1nhU1HV/9Jn5zmfm+9/H
7lBqaLw2QRA+H/a/P2J7X2Sk3Xwd/p2NOrEEjY+/aCYwwXy8Gmsv6uTKsmiY
/iA9bXGGBqd3eUrKPIX9N/16kgqFeGiitV1INePF27yfzMZEYL1ZLIqXcNHP
OB5996QYD7m6B6LM+LgjlpluM+pHv3uLSwYhwFiJ8aPtPAn0BEd0yBYBTtYI
Wzkhg0iURt9/bdkGfqP9/LasITTpJ8qX7mxD9dMad+e9Ujj+mOM8uq4NIVMO
qRvTJjG+6zeNYAsPv8+XWqqiphD3vDyEOs9FNfNQsJ3PNPh8Fb0Q3ILbKS0B
F9bLQXTrG7lfbUahzrOsYRMFCE9pmUt8E96OJbbemlXgRGXvYimvHpPRSfbE
mBLZN/YbeGSwweMwS0O7VBBlBDLCLlzDDku/m1HrhSBcwufUO0Jxe2dl7dwV
EYj0NsZfKzPJ40FXUrUcxSDuVY4GJ+SSVnU93ryuPtjynlsfti0mI3Tzl/6z
T4Lx1tDl6fnl5N+MDurUywHElX0mnZu5THYp06dqA4bAepdS/DSqiswzOuC6
ykoKVlfRo4O3rpH+2eeONUZOwovFDhMQ9aTo8y8L2Lum4MVNlRhurCfde+MY
JRs+9HtFFb0cqyNrAgItNq340L+Q+MnZJXVkwmLFhU2LcmSbzEdTHDZZP/mq
PfBfBQpneA0dQyyyKlXl5HZPCcLJfcVdVRWZUtEwzOep4HXAO/bUFxXktdyq
zL27KXy94cWlslwh8v+o9mWtpFDQ1RnQ/VgEnwhx3dwrNWzbcm1+ThGjvCEn
PuaJGhbTQa46ev1gM5MGZSI1gooNjC0bJXDo82R9365G+Fzz+8v+g+gbfaIP
nhphMQVBHd8OIShpkM8UqHF0WHbRZbcU3ew1hmFmFEaT0z1jjk0irSxCN9aG
gnlAWuSz8Cl49DiN522mwO+kTEY8p3Fo9mqJdC+FtnPaze9Xy7EYvqXU+QQF
x61Lmj81UKBmuvb+r1cpnOn21XRTCmw2DayVD1A47M190DOsxGyB23sLHRqZ
sZtMZe0qHG3wPhfzHQ3STTmQtVoIH+5jDlFKw23F+cwr5SIY7nSy5HFpjNna
KjvsxYjJO9gec4fGuj1MvbSOPqx357YbPKbxjuGs1/6VBN1hCZdaJ2joemQk
hisGwFYOvPZV0fB4u9XB2ncIi0cS5yQaGoIOl2hrCylu5JitmbDX4KzsOlO6
bxKn7xbMh6/W4BfLXnGR5xT6Q79x7rTT4Kmeg8qXOQ392t6ypVYa2Ewsa2ow
ksP4sHCPn7EGLYZvViXPyuG6bCUnU0sDp8jkuj0yBcwjOJH1ahoPRqpHF/5U
Ik/T4jU4QmOtXYjQrVGF/wC+ph1B
    "], {
     {RGBColor[0.5, 0., 0.], 
      LineBox[{{1, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
        2}, {1, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 2}, {1, 3}, {2, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
        49, 50, 51, 52, 4}, {2, 4}, {2, 53, 54, 55, 56, 57, 58, 59, 60, 61, 
        62, 63, 64, 65, 66, 67, 68, 4}, {3, 4}}]}, 
     {RGBColor[0, 0, 0.7], 
      TagBox[
       TooltipBox[PointBox[1],
        "\"a\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "a", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[2],
        "\"b\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "b", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[3],
        "\"c\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "c", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[4],
        "\"d\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "d", "Tooltip"]& ]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.029945404196222936`}, {
     1.0000906201270983`, 0.}, {0.031128233665176586`, 1.0299964287193093`}, {
     1.0300507240971837`, 0.999075137178996}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Right away, you can see another important difference between ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 ". Specifically, where ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 "\[CloseCurlyQuote]s default behavior is to interpret rules as directed \
edges, ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " assumes that rules are not directed. To draw a directed graph, you must \
use the ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " option."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"exercise4edges", ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJw1j3sw1AkAx39cQuS84jqyHrVRmUpdEe5LIdLhSBnOowcxlIq70NXRzXUn
Ou9Hpaz1PGvXLhnXuvy2az1qi9jKcW1nzIV9tL/f1nhU1HV/9Jn5zmfm+9/H
7lBqaLw2QRA+H/a/P2J7X2Sk3Xwd/p2NOrEEjY+/aCYwwXy8Gmsv6uTKsmiY
/iA9bXGGBqd3eUrKPIX9N/16kgqFeGiitV1INePF27yfzMZEYL1ZLIqXcNHP
OB5996QYD7m6B6LM+LgjlpluM+pHv3uLSwYhwFiJ8aPtPAn0BEd0yBYBTtYI
Wzkhg0iURt9/bdkGfqP9/LasITTpJ8qX7mxD9dMad+e9Ujj+mOM8uq4NIVMO
qRvTJjG+6zeNYAsPv8+XWqqiphD3vDyEOs9FNfNQsJ3PNPh8Fb0Q3ILbKS0B
F9bLQXTrG7lfbUahzrOsYRMFCE9pmUt8E96OJbbemlXgRGXvYimvHpPRSfbE
mBLZN/YbeGSwweMwS0O7VBBlBDLCLlzDDku/m1HrhSBcwufUO0Jxe2dl7dwV
EYj0NsZfKzPJ40FXUrUcxSDuVY4GJ+SSVnU93ryuPtjynlsfti0mI3Tzl/6z
T4Lx1tDl6fnl5N+MDurUywHElX0mnZu5THYp06dqA4bAepdS/DSqiswzOuC6
ykoKVlfRo4O3rpH+2eeONUZOwovFDhMQ9aTo8y8L2Lum4MVNlRhurCfde+MY
JRs+9HtFFb0cqyNrAgItNq340L+Q+MnZJXVkwmLFhU2LcmSbzEdTHDZZP/mq
PfBfBQpneA0dQyyyKlXl5HZPCcLJfcVdVRWZUtEwzOep4HXAO/bUFxXktdyq
zL27KXy94cWlslwh8v+o9mWtpFDQ1RnQ/VgEnwhx3dwrNWzbcm1+ThGjvCEn
PuaJGhbTQa46ev1gM5MGZSI1gooNjC0bJXDo82R9365G+Fzz+8v+g+gbfaIP
nhphMQVBHd8OIShpkM8UqHF0WHbRZbcU3ew1hmFmFEaT0z1jjk0irSxCN9aG
gnlAWuSz8Cl49DiN522mwO+kTEY8p3Fo9mqJdC+FtnPaze9Xy7EYvqXU+QQF
x61Lmj81UKBmuvb+r1cpnOn21XRTCmw2DayVD1A47M190DOsxGyB23sLHRqZ
sZtMZe0qHG3wPhfzHQ3STTmQtVoIH+5jDlFKw23F+cwr5SIY7nSy5HFpjNna
KjvsxYjJO9gec4fGuj1MvbSOPqx357YbPKbxjuGs1/6VBN1hCZdaJ2joemQk
hisGwFYOvPZV0fB4u9XB2ncIi0cS5yQaGoIOl2hrCylu5JitmbDX4KzsOlO6
bxKn7xbMh6/W4BfLXnGR5xT6Q79x7rTT4Kmeg8qXOQ392t6ypVYa2Ewsa2ow
ksP4sHCPn7EGLYZvViXPyuG6bCUnU0sDp8jkuj0yBcwjOJH1ahoPRqpHF/5U
Ik/T4jU4QmOtXYjQrVGF/wC+ph1B
    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.041285217403800124`, 0.8}}], 
      ArrowBox[{1, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
       2}], ArrowBox[{1, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
       34, 35, 36, 2}], ArrowBox[{1, 3}], 
      ArrowBox[{2, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
        52, 4}], ArrowBox[{2, 4}], 
      ArrowBox[{2, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
        68, 4}], ArrowBox[{3, 4}]}, 
     {RGBColor[0, 0, 0.7], 
      TagBox[
       TooltipBox[PointBox[1],
        "\"a\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "a", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[2],
        "\"b\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "b", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[3],
        "\"c\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "c", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[4],
        "\"d\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "d", "Tooltip"]& ]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.029945404196222936`}, {
     1.0000906201270983`, 0.}, {0.031128233665176586`, 1.0299964287193093`}, {
     1.0300507240971837`, 0.999075137178996}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The most important difference between ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " is the fact that where ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " produces a graph object, which can be computed with and manipulated, ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " only produces a graphics object, just like ",
 StyleBox[ButtonBox["Plot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Plot"], "FunctionLink"],
 " or ",
 StyleBox[ButtonBox["Plot3D",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Plot3D"], "FunctionLink"],
 ". For this reason, we can not assign a symbol to the result of ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " and use it to do computations on the graph. Instead, when dealing with \
multigraphs, we will treat the list of rules representing the graph\
\[CloseCurlyQuote]s edges, such as ",
 StyleBox["exercise4edges", "Input"],
 ", as the representation of the graph."
}], "Text"],

Cell[TextData[{
 "One final comment about the relationship between ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 ": ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " can often be given a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object as its argument in order to create a plot of the graph. For \
example, we can apply ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " to ",
 StyleBox["exercise7.", "Input"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", "exercise7", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[{{1., 1.}, {2., 2.}, {3., 2.}, {3., 1.}, {2., 
    1.}}, {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03384563758389261, 0.8}}], 
      ArrowBox[{1, 2}], ArrowBox[{2, 5}], ArrowBox[{3, 2}], ArrowBox[{3, 4}], 
      ArrowBox[{4, 3}], ArrowBox[{5, 1}], ArrowBox[{5, 4}]}, 
     {RGBColor[0, 0, 0.7], 
      TagBox[
       TooltipBox[PointBox[1],
        "1"],
       Annotation[#, 1, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[2],
        "2"],
       Annotation[#, 2, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[3],
        "3"],
       Annotation[#, 3, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[4],
        "4"],
       Annotation[#, 4, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[5],
        "5"],
       Annotation[#, 5, "Tooltip"]& ]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{1., 1.}, {2., 2.}, {3., 2.}, {3., 1.}, {2., 
     1.}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  ImagePadding->5,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This preserves some of the options from the ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object, such as the vertex positions, but discards options that ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " does not implement or are implemented differently, such as the vertex \
labels. You may also observe that the ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " version has removed the loops. These can be displayed by explicitly \
setting the ",
 StyleBox[ButtonBox["SelfLoopStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SelfLoopStyle"], "FunctionLink"],
 " option to ",
 StyleBox[ButtonBox["All",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/All"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"exercise7", ",", 
   RowBox[{"SelfLoopStyle", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEf7FFpBgdUmgMHH139B/uUhy12LL/YHUI/Wi/T
YWNw2K4zuebfPHaH6pTsH0uaGRzOK4RNPZPF7nAqtIt5liijw6f2Zf7zEtkd
OA61rw3bwOhwJdHNwKCF3eHk/ZzJhe5MDp9/XYjac57dQWij3rPT55gcuqMl
moztOBx8nkr7dFkzO+gE7A/beYzDYa95zIXPLcwOaqzfKqLiOB3WLd3xT2Up
s8PlJR6hb39wOoQfuna2Yyazg+py1cfcXVwOIXmsS3mTmR3+/rtiI8TGDaWZ
oeLcUHVMUH3cDlfA5jBCzeWG2sMItZcb6g4GqLu4oe5kgLqby+H514VbK+b/
t4f4i8thxeGehASO//YQf3M6POH3nW9z+J89JFw4HeY5rtGaefWfPSTcOBzy
ItV+/rH9bw8JVw6HE4c4azm+/LdfmPvx8tMlwHCdETN1veZ7ezvDaRb1CowO
B8udbQPs39k/auu/o9zJ6BC0/cfRL/fe2PvcsJj4+Tqjwzf7R3JH5F/blx66
ueoAO5PDdJ+oRAX5l/aNhY3S6aJMDvNNH03Y8e+Z/cGZ990ZGZgcopL5WIMe
PbEP1SiQ/X6C0WHFn9nb894+sve+YpLzrJjRoWrW+v/fHR7az004JZjGxuiw
waL/o+an+/YFS8S+Lm9ncDDX3vRqYdg9eHpZs93eNOnUXXvF7ZdEN3z4Zw+T
P2qXfcf48197mP7s8GnqxhJ/7Suh5oetlz8qmPfHfjnU/tozDgV///+2h7nv
n8zfE4ZXf9vPg7pfrNpnVd2H3/Yw/2X4992VCPhjD/O/zacHbjve/rEPhIZP
69zLfYz7/9rDwm+fimyEybZ/9rDwBQDwEl6k
    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03384563758389261, 0.8}}], 
      ArrowBox[{1, 2}], ArrowBox[{2, 5}], ArrowBox[{3, 2}], 
      ArrowBox[{3, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
        22, 23, 24, 25, 26, 27, 28, 3}], ArrowBox[{3, 4}], ArrowBox[{4, 3}], 
      ArrowBox[{5, 1}], ArrowBox[{5, 4}], 
      ArrowBox[{5, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43,
        44, 45, 46, 47, 48, 49, 50, 51, 5}]}, 
     {RGBColor[0, 0, 0.7], 
      TagBox[
       TooltipBox[PointBox[1],
        "1"],
       Annotation[#, 1, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[2],
        "2"],
       Annotation[#, 2, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[3],
        "3"],
       Annotation[#, 3, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[4],
        "4"],
       Annotation[#, 4, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[5],
        "5"],
       Annotation[#, 5, "Tooltip"]& ]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{1., 1.}, {2., 2.}, {3., 2.}, {3., 1.}, {2., 
     1.}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  ImagePadding->5,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We now focus on some of the options you can use with ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " to control the plot\[CloseCurlyQuote]s appearance. Note that many of these \
are different from and incompatible with the corresponding option for ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 ". We will illustrate with Exercise 8 from Section 10.1, whose edge list we \
produce below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exercise8edges", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
    RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
    RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
    RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
    RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
    RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
    RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
    RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
    RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
    RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
    RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<a\>\""}], ",", 
    RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
    RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<e\>\""}]}], "}"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"d\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"e\"\>", "\[Rule]", "\<\"a\"\>"}], ",", 
   RowBox[{"\<\"e\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"e\"\>", "\[Rule]", "\<\"e\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We have already mentioned the ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " option. By default, ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " draws edges as undirected. We set ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " to ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 " to draw the edges as arrows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"exercise8edges", ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJxl1nk4VG0fB/BB2RKSNkU1ElLyqAdtviOkFM8gydM2b1GKitAmy9vmoWKE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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03418866180821335, 0.8}}], 
      ArrowBox[{1, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
        2}], ArrowBox[{1, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
       35, 36, 37, 2}], 
      ArrowBox[{1, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
        53, 3}], 
      ArrowBox[{2, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68,
        69, 4}], 
      ArrowBox[{2, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84,
        85, 4}], 
      ArrowBox[{3, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
       100, 101, 1}], ArrowBox[{3, 5}], 
      ArrowBox[{3, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
        114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 3}], 
      ArrowBox[{4, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136,
        137, 138, 139, 140, 5}], ArrowBox[{4, 5}], 
      ArrowBox[{4, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152,
        153, 154, 155, 156, 5}], ArrowBox[{4, 3}], 
      ArrowBox[{5, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168,
        169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 5}]}, 
     {RGBColor[0, 0, 0.7], 
      TagBox[
       TooltipBox[PointBox[1],
        "\"a\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "a", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[2],
        "\"b\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "b", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[3],
        "\"e\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "e", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[4],
        "\"c\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "c", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[5],
        "\"d\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "d", "Tooltip"]& ]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.}, {0.0000844631970533527, 
     0.9749570119768911}, {1.0801664942437248`, 0.036058820258936475`}, {
     1.0800501615876983`, 0.9388386710835143}, {1.9436044961120342`, 
     0.48750235009092924`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We have also already mentioned the ",
 StyleBox[ButtonBox["SelfLoopStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SelfLoopStyle"], "FunctionLink"],
 " option. The value ",
 StyleBox[ButtonBox["All",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/All"], "FunctionLink"],
 " ensures that all self-loops are drawn, while ",
 StyleBox[ButtonBox["None",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/None"], "FunctionLink"],
 " will cause the loops to not be drawn. You can also specify a value between \
0 and 1, which will scale the loops relative to the average length of edges \
in the graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"exercise8edges", ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
   RowBox[{"SelfLoopStyle", "\[Rule]", "0.2"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJxl1nk4VPsfB/BJZY+uJVdFNYhUcvHT7j0kUnHHUuom+RWptBBKSbTf3OwK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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03418866180821335, 0.8}}], 
      ArrowBox[{1, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
        2}], ArrowBox[{1, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
       35, 36, 37, 2}], 
      ArrowBox[{1, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
        53, 3}], 
      ArrowBox[{2, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68,
        69, 4}], 
      ArrowBox[{2, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84,
        85, 4}], 
      ArrowBox[{3, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
       100, 101, 1}], ArrowBox[{3, 5}], 
      ArrowBox[{3, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
        114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 3}], 
      ArrowBox[{4, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136,
        137, 138, 139, 140, 5}], ArrowBox[{4, 5}], 
      ArrowBox[{4, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152,
        153, 154, 155, 156, 5}], ArrowBox[{4, 3}], 
      ArrowBox[{5, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168,
        169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 5}]}, 
     {RGBColor[0, 0, 0.7], 
      TagBox[
       TooltipBox[PointBox[1],
        "\"a\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "a", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[2],
        "\"b\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "b", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[3],
        "\"e\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "e", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[4],
        "\"c\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "c", "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[5],
        "\"d\"",
        TooltipStyle->"TextStyling"],
       Annotation[#, "d", "Tooltip"]& ]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.}, {0.0000844631970533527, 
     0.9749570119768911}, {1.0801664942437248`, 0.036058820258936475`}, {
     1.0800501615876983`, 0.9388386710835143}, {1.9436044961120342`, 
     0.48750235009092924`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To display the names of vertices, you use the ",
 StyleBox[ButtonBox["VertexLabeling",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabeling"], "FunctionLink"],
 " option. The default behavior, provided the number of vertices is not too \
large, is for the names of vertices to appear in a tooltip when you move the \
mouse pointer over the vertex. This option can be explicitly given with value \
",
 StyleBox[ButtonBox["Tooltip",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Tooltip"], "FunctionLink"],
 ". By setting the ",
 StyleBox[ButtonBox["VertexLabeling",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabeling"], "FunctionLink"],
 " option to ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 ", the names will be displayed on the graph itself."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"exercise8edges", ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
   RowBox[{"SelfLoopStyle", "\[Rule]", "0.2"}], ",", 
   RowBox[{"VertexLabeling", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJxl1nk4VPsfB/BJZY+uJVdFNYhUcvHT7j0kUnHHUuom+RWptBBKSbTf3OwK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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03418866180821335, 0.7}}], 
      ArrowBox[{1, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
        2}], ArrowBox[{1, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
       35, 36, 37, 2}], 
      ArrowBox[{1, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
        53, 3}], 
      ArrowBox[{2, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68,
        69, 4}], 
      ArrowBox[{2, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84,
        85, 4}], 
      ArrowBox[{3, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
       100, 101, 1}], ArrowBox[{3, 5}], 
      ArrowBox[{3, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
        114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 3}], 
      ArrowBox[{4, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136,
        137, 138, 139, 140, 5}], ArrowBox[{4, 5}], 
      ArrowBox[{4, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152,
        153, 154, 155, 156, 5}], ArrowBox[{4, 3}], 
      ArrowBox[{5, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168,
        169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 5}]}, {InsetBox[
       FrameBox["\<\"a\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox["\<\"b\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox["\<\"e\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox["\<\"c\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox["\<\"d\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.}, {0.0000844631970533527, 
     0.9749570119768911}, {1.0801664942437248`, 0.036058820258936475`}, {
     1.0800501615876983`, 0.9388386710835143}, {1.9436044961120342`, 
     0.48750235009092924`}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell["\<\
To display labels for edges, you must explicitly provide the labels. This is \
done by replacing the rule defining an edge by a list consisting of the rule \
and an expression for the label. We illustrate with the following simple \
example.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1", "\[Rule]", "2"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "\[Rule]", "3"}], ",", "\"\<2-3\>\""}], "}"}], ",", 
    RowBox[{"3", "\[Rule]", "4"}], ",", 
    RowBox[{"4", "\[Rule]", "1"}]}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[{{0., 0.9997532360813219}, {0.9993931236462025, 
    1.0258160108662502`}, {1.0286626995939243`, 0.026431169015734945`}, {
    0.02872413637035287, 0.}}, {
     {RGBColor[0.5, 0., 0.], LineBox[{1, 2}], 
      {Arrowheads[{{0.5, 0.5, 
          GraphicsBox[{
            GrayLevel[0], 
            InsetBox[
             BoxData[
              FormBox[
               StyleBox["\"2-3\"", StripOnInput -> False], 
               TraditionalForm]], {0, 0}, 
             ImageScaled[{0.5, 0.5}], Automatic, None, Background -> 
             GrayLevel[1]]}]}, {0, 0}}], ArrowBox[{2, 3}]}, LineBox[{3, 4}], 
      LineBox[{4, 1}]}, 
     {RGBColor[0, 0, 0.7], 
      TagBox[
       TooltipBox[PointBox[1],
        "1"],
       Annotation[#, 1, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[2],
        "2"],
       Annotation[#, 2, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[3],
        "3"],
       Annotation[#, 3, "Tooltip"]& ], 
      TagBox[
       TooltipBox[PointBox[4],
        "4"],
       Annotation[#, 4, "Tooltip"]& ]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.9997532360813219}, {0.9993931236462025, 
     1.0258160108662502`}, {1.0286626995939243`, 0.026431169015734945`}, {
     0.02872413637035287, 0.}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The option ",
 StyleBox[ButtonBox["EdgeLabeling",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeLabeling"], "FunctionLink"],
 " can be set to ",
 StyleBox[ButtonBox["Automatic",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Automatic"], "FunctionLink"],
 " to instead display the label only as a tooltip, or to ",
 StyleBox[ButtonBox["False",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/False"], "FunctionLink"],
 " to suppress display of the labels."
}], "Text"],

Cell[TextData[{
 "To explicitly control the placement of vertices, you use the ",
 StyleBox[ButtonBox["VertexCoordinateRules",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexCoordinateRules"], "FunctionLink"],
 " option. The value of this option is a list of rules identifying the name \
of a vertex with a pair representing ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " coordinates. You can use the symbol ",
 StyleBox[ButtonBox["Automatic",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Automatic"], "FunctionLink"],
 " in place of the coordinate pair to indicate that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " should determine the location for that vertex automatically. This is the \
default if vertices are omitted from the rules. You can also use ",
 StyleBox[ButtonBox["Automatic",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Automatic"], "FunctionLink"],
 " in place of either the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " value within a pair if you wish to specify one value but leave the other \
to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to determine. We use ",
 StyleBox[ButtonBox["VertexCoordinateRules",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexCoordinateRules"], "FunctionLink"],
 " to rearrange the vertices in the Exercise 8 example to match the locations \
in the textbook."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"exercise8edges", ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
   RowBox[{"SelfLoopStyle", "\[Rule]", "0.2"}], ",", 
   RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
   RowBox[{"VertexCoordinateRules", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], ",", 
      RowBox[{"\"\<d\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"2", ",", "0.5"}], "}"}]}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJxl1g84lWcfB/Bz5KoXYyqN/g3T2oSyFM30fp8wV7RGLRVbS6yMt5e8hEqm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    "], {
     {RGBColor[0.5, 0., 0.], Arrowheads[{{0.03384563758389261, 0.7}}], 
      ArrowBox[{1, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
        2}], ArrowBox[{1, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 
       35, 36, 37, 2}], 
      ArrowBox[{1, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52,
        53, 3}], 
      ArrowBox[{2, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68,
        69, 4}], 
      ArrowBox[{2, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84,
        85, 4}], 
      ArrowBox[{3, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
       100, 101, 1}], ArrowBox[{3, 5}], 
      ArrowBox[{3, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
        114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 3}], 
      ArrowBox[{4, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136,
        137, 138, 139, 140, 5}], ArrowBox[{4, 5}], 
      ArrowBox[{4, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152,
        153, 154, 155, 156, 5}], ArrowBox[{4, 3}], 
      ArrowBox[{5, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168,
        169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 5}]}, {InsetBox[
       FrameBox["\<\"a\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox["\<\"b\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox["\<\"e\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox["\<\"c\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox["\<\"d\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 1.}, {0., 0.}, {1., 1.}, {1., 0.}, {2., 
     0.5}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Finally, the ",
 StyleBox[ButtonBox["Method",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Method"], "FunctionLink"],
 " option can be used to specify the algorithm used to lay out the vertices. \
The values are very similar to ",
 StyleBox[ButtonBox["GraphLayout",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphLayout"], "FunctionLink"],
 " including ",
 StyleBox["\[OpenCurlyDoubleQuote]SpringEmbedding\[CloseCurlyDoubleQuote]", 
  "Input"],
 ", ",
 StyleBox["\[OpenCurlyDoubleQuote]SpringElectricalEmbedding\
\[CloseCurlyDoubleQuote]", "Input"],
 ", ",
 StyleBox["\[OpenCurlyDoubleQuote]HighDimensionalEmbedding\
\[CloseCurlyDoubleQuote]", "Input"],
 ", and ",
 StyleBox["\[OpenCurlyDoubleQuote]CircularEmbedding\[CloseCurlyDoubleQuote]", 
  "Input"],
 "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["10.2 Graph Terminology and Special Types of Graphs", "Section",
 CellTags->"Section2"],

Cell[TextData[{
 "In this section we will see how to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to perform computations related to some of the basic terminology of \
graphs, such as calculating degree. We will also look at some of the special \
families of graphs that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has built-in support for. And we discuss subgraphs and unions of graphs in \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell["Degree", "Subsection",
 CellTags->"Section2a"],

Cell[TextData[{
 "For a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " includes the function ",
 StyleBox[ButtonBox["VertexDegree",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexDegree"], "FunctionLink"],
 " for determining the degree of a vertex. Given a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object and one of the graph\[CloseCurlyQuote]s vertices, the function \
returns the number of edges incident to that vertex. For example, we can \
check the degrees of vertices ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 " of ",
 StyleBox["exercise7", "Input"],
 " from the previous section."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData["exercise7"], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "a", "b", "c", "d", "e"}, {{{1, 2}, {2, 5}, {3, 2}, {3, 3}, {3, 4}, {4, 
       3}, {5, 1}, {5, 4}, {5, 5}}, Null}, {
      ImagePadding -> 5, 
       VertexCoordinates -> {{1, 1}, {2, 2}, {3, 2}, {3, 1}, {2, 1}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.03384563758389261], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       ArrowBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       ArrowBox[
        BezierCurveBox[{
          DynamicLocation["VertexID$3", Automatic, Center], {
          2.9226652357765426`, 2.211102824883941}, {3.03037168156465, 
          2.404072374917325}, {3.1710710001067524`, 2.4556369686221933`}, {
          3.4556369686221933`, 2.1710710001067524`}, {3.404072374917325, 
          2.03037168156465}, {3.211102824883941, 1.9226652357765426`}, 
          DynamicLocation["VertexID$3", Automatic, Center]}, SplineDegree -> 
         7]], 
       ArrowBox[
        BezierCurveBox[{
          DynamicLocation["VertexID$3", Automatic, Center], {
          3.1552807082181697`, 1.5}, 
          DynamicLocation["VertexID$4", Automatic, Center]}]], 
       ArrowBox[
        BezierCurveBox[{
          DynamicLocation["VertexID$4", Automatic, Center], {
          2.8447192917818303`, 1.5000000000000004`}, 
          DynamicLocation["VertexID$3", Automatic, Center]}]], 
       ArrowBox[{
         DynamicLocation["VertexID$5", Automatic, Center], 
         DynamicLocation["VertexID$1", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$5", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       ArrowBox[
        BezierCurveBox[{
          DynamicLocation["VertexID$5", Automatic, Center], {
          2.2304450364563646`, 0.8476276972960466}, {2.250002442847489, 
          0.6526270006898856}, {2.1815918401357854`, 0.5391807550302723}, {
          1.8184081598642148`, 0.5391807550302722}, {1.7499975571525106`, 
          0.6526270006898856}, {1.7695549635436354`, 0.8476276972960466}, 
          DynamicLocation["VertexID$5", Automatic, Center]}, SplineDegree -> 
         7]]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 2.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 2.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{8.760693309010083, 
       351.2393066909899}, {-136.2393066909899, 131.2393066909899}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexDegree", "[", 
  RowBox[{"exercise7", ",", "\"\<a\>\""}], "]"}]], "Input"],

Cell[BoxData["2"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexDegree", "[", 
  RowBox[{"exercise7", ",", "\"\<e\>\""}], "]"}]], "Input"],

Cell[BoxData["5"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Observe that the loop at the vertex ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 " counts as 2 towards the degree of that vertex. Also note that with this \
directed graph, ",
 StyleBox[ButtonBox["VertexDegree",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexDegree"], "FunctionLink"],
 " calculates the number of edges incident to the given vertex without regard \
for their direction. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides ",
 StyleBox[ButtonBox["VertexInDegree",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexInDegree"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["VertexOutDegree",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexOutDegree"], "FunctionLink"],
 " functions for calculating the directed values. As an example, consider \
vertex ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 " from above."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexInDegree", "[", 
  RowBox[{"exercise7", ",", "\"\<d\>\""}], "]"}]], "Input"],

Cell[BoxData["2"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexOutDegree", "[", 
  RowBox[{"exercise7", ",", "\"\<d\>\""}], "]"}]], "Input"],

Cell[BoxData["1"], "Output"]
}, Open  ]],

Cell[TextData[{
 "All three of these functions can be used without a second argument. If they \
are passed only the graph as the sole argument, they will return a list of \
the degrees of the vertices. Note that the output is in the same order as the \
output from ",
 StyleBox[ButtonBox["VertexList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexList"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexList", "[", "exercise7", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexDegree", "[", "exercise7", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "3", ",", "5", ",", "3", ",", "5"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexInDegree", "[", "exercise7", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "2", ",", "2", ",", "2"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexOutDegree", "[", "exercise7", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "3", ",", "1", ",", "3"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Degree in Pseudographs", "Subsubsection"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s built-in functions for degree cannot take into account multiple edges. \
We will write a function to rectify this, at least for the undirected degree. \
The in-degree and out-degree functions for directed graphs are left to the \
reader."
}], "Text"],

Cell[TextData[{
 "We reproduce Exercise 2 from Section 10.2 to use as an example. Recall that \
the presence of multiple edges means that we cannot create a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object. Instead, we model the graph as a list of edges, with multiple \
edges repeated. We will use ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " to display an image of the graph, but our function for computing degree \
will take the list of edges as the input."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"exercise2edges", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<a\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
     RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
     RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
     RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
     RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<e\>\""}]}], "}"}]}], ";"}]], "Input",\

 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"exercise2edges", ",", 
   RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
   RowBox[{"VertexCoordinateRules", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"2", ",", "0"}], "}"}]}], ",", 
      RowBox[{"\"\<d\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJxt1As01FkcB/AxY2t7IKWi5+RU6/Qw04tM6nc3ZVersG2hTR55ZLYy0Y7D
prSEFqFtbdTIZr1iI68y6CI0apKS12L2ZIUG0zQGLTMszsz/nP1vv3P+5557
zv3f3/fzP/d/V7n5fO1BpVAofpPP1PjfksLHx/8V+vh7FErwHzk/0zezcYHv
jza87nfgciSsw+jsPTxvx/GDHHcJXKKxQNurEkcJzK+Ohw1AxoyffGdmCnEa
T7ZtjssAhMX4Ttw93IB1iq/qFMkGgLM0rozZ0Iz/Vtb57NjyDkSch65vT7Xh
/IO322UhUhDzL2Y0tnfgorvaaVdS30Opha7n+IAIiyK+MTPpkYGLce6lwEgR
3h6gl7eMIYfWXuYgs6wdZ+2n9cvdhgCZzHMwyWjFMVqa8VrsYcg10cptiGzE
JiyhuTVjBLq67AS+pfX41zknfxPdHoFhy9+f3DN7jCW2oQkXSkaA3Sd2ETvw
Mf80nb3NfwTOcvdd+/Z8Mja96eMQ2DYMJyzoM65eT4B2S3eGUD4EgabsEBt2
LrxOmczQKIea+d/Zpk0UQCOyk9B/GYTEEoPTcwT5wEE9j19by+DVAWHt6INM
SPVoid69+D2gr6KDct28oanZap6BlhSK0OoNlk58oMXl6n/vLYX1dkE7Dfnl
8FJD/+z9ye+jZxHXetK6CvTyZl1XJkhh7SXhXveux6C3siECZUuhtGDLot7g
p9C7UxgVyJfCB+2HZ5roz4GlMDROr5JCDCvRJMz1BSxjfW7+6IkUYMtUNcAz
4VRJwctzqrqJeXlnXpe5TQ+x3upc7PEnpr3Efi3z/UarV74l+j0URUm6Z4hh
gSrP7pwbtV39YiJvaVYyx/9FH+GR+v/Asi/oB6rKq/aPdiTVLdz4jvAfVTxf
HPdBQvibb/Q/1xRKCH9rhaPkfLqE8DNDvbpnR0oIf+RMfso9roTwCyKDwgPY
EsI/zfaUEH71XO1Xr1f7o1T7qf3qfmr/n6o8an+LKq/a76TyqP0KlbevPnnj
LRoFSfda71hXxoF4QXFgsiMFNT8VGFfE5EGP6dpK/wYKSjMN9KAbl8MuPm+F
s5cGMnLWdVbcqYLR2siggFlUtCiAU7jfrQYYOhmsmmwq6s0PPdHMrIZ2cdaK
DXtoaGv2qg4DRgUEjKUcDntEQ6mJvUH3jxXCtpTOeh5dE8mrX1mFPogDe0/6
xOhBTWSZCfo+jLu4MDt+3QVHTbQrREL9UF+Bswt4WsVMTTR3kbjYtfopHirl
vR1op6E1tRqV9gde4ovmlcea3GkoK99me1Z9I46o8zuh95KK1rQl9d1c1YK3
OsXHnmJSEXtBlSVPtxXvO880bY3SQPZi7vyT0S3Yz2DcjiunoDZDUUXKrSYc
fmjDRJAfBR02K7v/l08DHinKCf9Sj4K0r1gPL79Qh8eURt3vSyeg1GOA4V1b
hReecz9Vnj0BXt59VZ/MLcSJsgwjq38mIDb8U33rIQ4eLtnJW39kHMqnz10i
bj9k+6CkVwmIRQmRcJNxUvMzd1+uEmJ3m2jkQwo+6mPp70dTAqfz+BLdiFTM
vmym7IxRAKUsPMHOJh0b7hJserNUAbbhzlVvrmVgpzOOvknpYxBs8VmEl0Mm
3jR93sYgOWGqMnHd9H8mJ+a3r6RFuzrIifUdFaZ1S7oGAan2i+fWUJdzBol+
KbHFEVGKyXtRlcfVaPON6MsyCFblXX0n54s9i2XAVHlm76l0ezV5rwarvCQ/
kPxA8gPJDyQ/kPxA8gPJDyQ/kPxA8gPJDyQ/kPxA8gPJD/8CXVWIPw==
    "], {
     {RGBColor[0.5, 0., 0.], 
      LineBox[{{1, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
         22, 23, 24, 25, 26, 27, 28, 1}, {1, 29, 30, 31, 32, 33, 34, 35, 36, 
        37, 38, 39, 40, 41, 42, 43, 44, 2}, {1, 2}, {1, 45, 46, 47, 48, 49, 
        50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 2}, {1, 3}, {2, 4}, {2, 
        5}, {2, 3}, {4, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 
        74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 4}, {4, 84, 85, 86, 87, 88, 
        89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 5}, {4, 5}, {4, 100, 101, 
        102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 
        5}, {5, 3}}]}, {InsetBox[
       FrameBox["\<\"a\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox["\<\"b\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox["\<\"e\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox["\<\"c\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox["\<\"d\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 1.}, {1., 1.}, {0., 0.}, {2., 0.}, {1., 
     0.}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that we use the ",
 StyleBox[ButtonBox["VertexLabeling",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabeling"], "FunctionLink"],
 " option to display the names of the vertices and the ",
 StyleBox[ButtonBox["VertexCoordinateRules",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexCoordinateRules"], "FunctionLink"],
 " option to ensure that the position of vertices corresponds to the image in \
the textbook. Using the ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " option is unnecessary since ",
 StyleBox[ButtonBox["GraphPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphPlot"], "FunctionLink"],
 " defaults to undirected edges."
}], "Text"],

Cell["\<\
To calculate the degree of a specified vertex, given the list of edges, we \
must count the number of edges in which the vertex is an endpoint. Keep in \
mind that a loop contributes twice to the degree of the vertex. This means \
that the degree of a vertex is the number of times that the vertex name \
appears in the list of edges as either endpoint.\
\>", "Text"],

Cell[TextData[{
 "We will use the built-in function ",
 StyleBox[ButtonBox["Count",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Count"], "FunctionLink"],
 " to count the number of times the vertex appears. ",
 StyleBox[ButtonBox["Count",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Count"], "FunctionLink"],
 " requires two arguments: a list (or other expression) within which to count \
and a pattern being sought. It returns the number of times the pattern \
matches an element of the list. A third argument allows you to specify the \
level at which to search. By default, ",
 StyleBox[ButtonBox["Count",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Count"], "FunctionLink"],
 " will only count the elements of the list that match the pattern. In this \
case, we want to count elements of ",
 StyleBox[ButtonBox["Rule",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rule"], "FunctionLink"],
 "s that are members of the list. That is, we want ",
 StyleBox[ButtonBox["Count",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Count"], "FunctionLink"],
 " to look at level 2. To specify this, we give ",
 StyleBox[ButtonBox["Count",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Count"], "FunctionLink"],
 " the third argument ",
 StyleBox["{2}", "Input"],
 ", indicating that it should only count expressions at the second level that \
match the pattern."
}], "Text"],

Cell[TextData[{
 "So to find the degree of ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 ", we apply ",
 StyleBox[ButtonBox["Count",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Count"], "FunctionLink"],
 " to the edge list, the name of the vertex ",
 StyleBox["\"a\"", "Input"],
 ", and ",
 StyleBox["{2}", "Input"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Count", "[", 
  RowBox[{"exercise2edges", ",", "\"\<a\>\"", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input"],

Cell[BoxData["6"], "Output"]
}, Open  ]],

Cell["We use this approach to create a function as shown below.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"undirectedDegree", "[", 
   RowBox[{
    RowBox[{"edgeList", ":", 
     RowBox[{"{", "___Rule", "}"}]}], ",", "vertex_"}], "]"}], ":=", 
  RowBox[{"Count", "[", 
   RowBox[{"edgeList", ",", "vertex", ",", 
    RowBox[{"{", "2", "}"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[TextData[{
 "We check the function by applying it to the vertex ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"undirectedDegree", "[", 
  RowBox[{"exercise2edges", ",", "\"\<d\>\""}], "]"}]], "Input"],

Cell[BoxData["5"], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Some Special Simple Graphs", "Subsection",
 CellTags->"Section2b"],

Cell[TextData[{
 "The textbook discusses several families of graphs, including complete \
graphs, cycles, and wheels. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides functions for easily creating these and other special graphs. "
}], "Text"],

Cell[TextData[{
 "We begin with complete graphs. Recall that a complete graph is a simple, \
undirected graph on a given number of vertices that has all possible edges \
between those vertices. The complete graph on ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices is denoted ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "n"], TraditionalForm]]],
 ". The complete graph on ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices can be obtained with the function ",
 StyleBox[ButtonBox["CompleteGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CompleteGraph"], "FunctionLink"],
 " applied to ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ". For example, we can generate and display ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "5"], TraditionalForm]]],
 ", the complete graph on 5 vertices."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompleteGraph", "[", "5", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 4, 8, 12, 16, 20}, {{2}, {3}, {4}, {5}, {1}, {3}, {4}, {5}, {
          1}, {2}, {4}, {5}, {1}, {2}, {3}, {5}, {1}, {2}, {3}, {4}}}, 
         Pattern}]}, {GraphLayout -> "CircularEmbedding"}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0.5877852522924738, -0.8090169943749481}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
        "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18000000000001, 352.82}, {-168.10719999999998`, 
       162.04310466848688`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Similarly, the cycle ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "n"], TraditionalForm]]],
 " is obtained with the function ",
 StyleBox[ButtonBox["CycleGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CycleGraph"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CycleGraph", "[", "9", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9}, {Null, 
       SparseArray[
       Automatic, {9, 9}, 0, {
        1, {{0, 2, 4, 6, 8, 10, 12, 14, 16, 18}, {{2}, {9}, {1}, {3}, {2}, {
          4}, {3}, {5}, {4}, {6}, {5}, {7}, {6}, {8}, {7}, {9}, {1}, {8}}}, 
         Pattern}]}, {GraphLayout -> "CircularEmbedding"}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{-0.6427876096865398, 0.7660444431189786}, 
         0.022364449578799767`], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{-0.9848077530122081, 0.17364817766693114`}, 
         0.022364449578799767`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
         0.022364449578799767`], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{-0.3420201433256684, -0.9396926207859079}, 
         0.022364449578799767`], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{0.3420201433256691, -0.9396926207859085}, 
         0.022364449578799767`], "DynamicName", BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{0.8660254037844389, -0.5000000000000012}, 
         0.022364449578799767`], "DynamicName", BoxID -> "VertexID$6"], 
       TagBox[
        DiskBox[{0.984807753012208, 0.17364817766692903`}, 
         0.022364449578799767`], "DynamicName", BoxID -> "VertexID$7"], 
       TagBox[
        DiskBox[{0.6427876096865388, 0.7660444431189772}, 
         0.022364449578799767`], "DynamicName", BoxID -> "VertexID$8"], 
       TagBox[
        DiskBox[{-7.044813998280222*^-16, 1.}, 0.022364449578799767`], 
        "DynamicName", BoxID -> "VertexID$9"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.179999999999977, 
       352.8200000000001}, {-173.10720000000006`, 168.4132071726418}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A wheel ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["W", "n"], TraditionalForm]]],
 " is obtained from the cycle graph ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "n"], TraditionalForm]]],
 " by adding one additional vertex adjacent to all ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " of the original vertices. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", wheel graphs are obtained by ",
 StyleBox[ButtonBox["WheelGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WheelGraph"], "FunctionLink"],
 " applied to the value ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "+", "1"}], TraditionalForm]]],
 ", the total number of vertices in the wheel, not just the outside ring."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WheelGraph", "[", "6", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6}, {Null, 
       SparseArray[
       Automatic, {6, 6}, 0, {
        1, {{0, 5, 8, 11, 14, 17, 20}, {{2}, {3}, {4}, {5}, {6}, {1}, {3}, {
          6}, {1}, {2}, {4}, {1}, {3}, {5}, {1}, {4}, {6}, {1}, {2}, {5}}}, 
         Pattern}]}, {GraphLayout -> "StarEmbedding"}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0., 0.}, 0.021812234931106983`], "DynamicName", BoxID -> 
        "VertexID$1"], 
       TagBox[
        DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0.5877852522924738, -0.8090169943749481}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
        "DynamicName", BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{-0.9510565162951538, 0.30901699437494945`}, 
         0.021812234931106983`], "DynamicName", BoxID -> 
        "VertexID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18000000000001, 352.82}, {-168.10719999999998`, 
       162.04310466848688`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hypercubes", "Subsection",
 CellTags->"Section2c"],

Cell[TextData[{
 "To construct the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 "-cube ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Q", "n"], TraditionalForm]]],
 ", we use the ",
 StyleBox[ButtonBox["HypercubeGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HypercubeGraph"], "FunctionLink"],
 " function applied to the dimension ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ". Recall the definition of the hypercube graph given in Example 8 of \
Section 10.2. There are ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "n"], TraditionalForm]]],
 " vertices labeled with the binary representations of the numbers 0 through ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["2", "n"], "-", "1"}], TraditionalForm]]],
 ". Two vertices are adjacent if their binary representations differ in only \
one digit. Here is the presentation of the three dimensional cube."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypercubeGraph", "[", "3", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 3, 6, 9, 12, 15, 18, 21, 24}, {{2}, {3}, {5}, {1}, {4}, {6}, {
          1}, {4}, {7}, {2}, {3}, {8}, {1}, {6}, {7}, {2}, {5}, {8}, {3}, {
          5}, {8}, {4}, {6}, {7}}}, Pattern}]}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0.6411318907234969, 1.6256350616332038`}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{1.5431761475992014`, 1.6258514889129208`}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{1.3641521541128723`, 0.8124188351574709}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{2.186420636755495, 0.814439144539747}, 0.02410631722965237], 
        "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{0., 0.8116524116085829}, 0.02410631722965237], "DynamicName",
         BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{0.8207122623609914, 0.8136876580070856}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$6"], 
       TagBox[
        DiskBox[{0.6431241846256299, 0.}, 0.02410631722965237], "DynamicName",
         BoxID -> "VertexID$7"], 
       TagBox[
        DiskBox[{1.5449243126722068`, 0.0005338415834358345}, 
         0.02410631722965237], "DynamicName", BoxID -> 
        "VertexID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.179999999999999, 352.82}, {-133.10719999999998`, 
       127.0780990872907}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "By default, the vertices are not labeled. To have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " label the vertices, we can use the ",
 StyleBox[ButtonBox["VertexLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabels"], "FunctionLink"],
 " option. In fact, ",
 StyleBox[ButtonBox["HypercubeGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HypercubeGraph"], "FunctionLink"],
 " accepts all the options that ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " does."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypercubeGraph", "[", 
  RowBox[{"3", ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 3, 6, 9, 12, 15, 18, 21, 24}, {{2}, {3}, {5}, {1}, {4}, {6}, {
          1}, {4}, {7}, {2}, {3}, {8}, {1}, {6}, {7}, {2}, {5}, {8}, {3}, {
          5}, {8}, {4}, {6}, {7}}}, Pattern}]}, {
      ImagePadding -> 10, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.6411318907234969, 1.6256350616332038`}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5431761475992014`, 1.6258514889129208`}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.3641521541128723`, 0.8124188351574709}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.186420636755495, 0.814439144539747}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.8116524116085829}, 0.02410631722965237], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8207122623609914, 0.8136876580070856}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{0.6431241846256299, 0.}, 0.02410631722965237], 
          "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5449243126722068`, 0.0005338415834358345}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       350.8758090230311}, {-137.147809023033, 121.0488960715287}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "One more modification will allow us to see the connection between this \
image and the definition. Instead of using ",
 StyleBox["\[OpenCurlyDoubleQuote]Name\[CloseCurlyDoubleQuote]", "Input"],
 " as the argument to ",
 StyleBox[ButtonBox["VertexLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabels"], "FunctionLink"],
 ", we can specify the labels explicitly by setting the option to a list of \
rules identifying the integers with the binary expression."
}], "Text"],

Cell[TextData[{
 "The definition of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Q", "n"], TraditionalForm]]],
 " tells us that the vertices should be considered to be the binary \
representations of the integers from 0 to 7. So we will apply labels by \
subtracting 1 from the integer vertex names and using the ",
 StyleBox[ButtonBox["IntegerString",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IntegerString"], "FunctionLink"],
 " function to obtain the binary representation. The ",
 StyleBox[ButtonBox["IntegerString",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IntegerString"], "FunctionLink"],
 " function requires two arguments, an integer and a base, and produces a \
string representing the integer in that base. A third optional argument \
allows you to specify a minimal length for the string."
}], "Text"],

Cell[TextData[{
 "The following ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 " produces the list of rules identifying the vertex names with the \
appropriate label."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"v", "\[Rule]", 
    RowBox[{"IntegerString", "[", 
     RowBox[{
      RowBox[{"v", "-", "1"}], ",", "2", ",", "3"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "8"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "\[Rule]", "\<\"000\"\>"}], ",", 
   RowBox[{"2", "\[Rule]", "\<\"001\"\>"}], ",", 
   RowBox[{"3", "\[Rule]", "\<\"010\"\>"}], ",", 
   RowBox[{"4", "\[Rule]", "\<\"011\"\>"}], ",", 
   RowBox[{"5", "\[Rule]", "\<\"100\"\>"}], ",", 
   RowBox[{"6", "\[Rule]", "\<\"101\"\>"}], ",", 
   RowBox[{"7", "\[Rule]", "\<\"110\"\>"}], ",", 
   RowBox[{"8", "\[Rule]", "\<\"111\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Using this as the value for ",
 StyleBox[ButtonBox["VertexLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabels"], "FunctionLink"],
 " produces a graph similar to the one shown in Figure 6 of Section 10.2 of \
the textbook."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypercubeGraph", "[", 
  RowBox[{"3", ",", 
   RowBox[{"VertexLabels", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"v", "\[Rule]", 
       RowBox[{"IntegerString", "[", 
        RowBox[{
         RowBox[{"v", "-", "1"}], ",", "2", ",", "3"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"v", ",", "8"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 3, 6, 9, 12, 15, 18, 21, 24}, {{2}, {3}, {5}, {1}, {4}, {6}, {
          1}, {4}, {7}, {2}, {3}, {8}, {1}, {6}, {7}, {2}, {5}, {8}, {3}, {
          5}, {8}, {4}, {6}, {7}}}, Pattern}]}, {
      ImagePadding -> 10, 
       VertexLabels -> {
        1 -> "000", 6 -> "101", 2 -> "001", 8 -> "111", 7 -> "110", 3 -> 
         "010", 4 -> "011", 5 -> "100"}}]], Typeset`boxes, Typeset`boxes$s2d =
     GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.6411318907234969, 1.6256350616332038`}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"000\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5431761475992014`, 1.6258514889129208`}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"001\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.3641521541128723`, 0.8124188351574709}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"010\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.186420636755495, 0.814439144539747}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"011\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.8116524116085829}, 0.02410631722965237], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["\"100\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8207122623609914, 0.8136876580070856}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["\"101\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{0.6431241846256299, 0.}, 0.02410631722965237], 
          "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["\"110\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5449243126722068`, 0.0005338415834358345}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["\"111\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       360.8758090230311}, {-137.14780902303363`, 121.0488960715287}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bipartite Graphs", "Subsection",
 CellTags->"Section2d"],

Cell[TextData[{
 "Another important class of graphs is the bipartite graphs. A bipartite \
graph is one whose vertex set can be partitioned into two disjoint sets such \
that every edge has one vertex in each of the partitioning sets. In other \
words, no two vertices in the same partitioning set are adjacent. We write ",
 Cell[BoxData[
  FormBox[
   RowBox[{"V", "=", 
    RowBox[{"(", 
     RowBox[{"A", ",", "B"}], ")"}]}], TraditionalForm]]],
 " to indicate that the vertex set ",
 Cell[BoxData[
  FormBox["V", TraditionalForm]]],
 " is partitioned into the sets ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "The complete bipartite graph ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    RowBox[{"m", ",", "n"}]], TraditionalForm]]],
 " is a bipartite graph with bipartition ",
 Cell[BoxData[
  FormBox[
   RowBox[{"V", "=", 
    RowBox[{"(", 
     RowBox[{"A", ",", "B"}], ")"}]}], TraditionalForm]]],
 " such that there are ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 " vertices in ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " in ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]]],
 " and such that there is an edge for every pair of vertices ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "\[Element]", "A"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "\[Element]", "B"}], TraditionalForm]]],
 ". The ",
 StyleBox[ButtonBox["CompleteGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CompleteGraph"], "FunctionLink"],
 " function can be used to create complete bipartite graphs. The argument is \
the list consisting of the pair of ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompleteGraph", "[", 
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7}, {Null, 
       SparseArray[
       Automatic, {7, 7}, 0, {
        1, {{0, 4, 8, 12, 15, 18, 21, 24}, {{4}, {5}, {6}, {7}, {4}, {5}, {
          6}, {7}, {4}, {5}, {6}, {7}, {1}, {2}, {3}, {1}, {2}, {3}, {1}, {
          2}, {3}, {1}, {2}, {3}}}, Pattern}]}, {
      GraphLayout -> {"MultipartiteLayout", "VertexPartition" -> {3, 4}}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0., -0.2560113295832984}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$1"], 
       TagBox[
        DiskBox[{0., 0.}, 0.01273], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0., 0.2560113295832984}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$3"], 
       TagBox[
        DiskBox[{1., -0.38401699437494763`}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$4"], 
       TagBox[
        DiskBox[{1., -0.1280056647916492}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$5"], 
       TagBox[
        DiskBox[{1., 0.1280056647916492}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$6"], 
       TagBox[
        DiskBox[{1., 0.38401699437494763`}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$7"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.180000000000001, 
       352.8200000000001}, {-137.10719999999998`, 131.57289311212918`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Notice that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " draws the complete bipartite graph with the two partitioning sets along \
the left and right to make the partition visually clear. As with the other \
functions in this section, the usual options for ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " apply. We illustrate how to label the vertices in a meaningful way. To \
enter a subscript in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", press \[ControlKey] and -."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompleteGraph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", 
    RowBox[{"Union", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"i", "\[Rule]", 
         SubscriptBox["a", "i"]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"i", "\[Rule]", 
         SubscriptBox["b", 
          RowBox[{"i", "-", "3"}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "4", ",", "7"}], "}"}]}], "]"}]}], "]"}]}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7}, {Null, 
       SparseArray[
       Automatic, {7, 7}, 0, {
        1, {{0, 4, 8, 12, 15, 18, 21, 24}, {{4}, {5}, {6}, {7}, {4}, {5}, {
          6}, {7}, {4}, {5}, {6}, {7}, {1}, {2}, {3}, {1}, {2}, {3}, {1}, {
          2}, {3}, {1}, {2}, {3}}}, Pattern}]}, {
      GraphLayout -> {"MultipartiteLayout", "VertexPartition" -> {3, 4}}, 
       ImagePadding -> 10, 
       VertexLabels -> {
        1 -> Subscript[$CellContext`a, 1], 6 -> Subscript[$CellContext`b, 3], 
         2 -> Subscript[$CellContext`a, 2], 7 -> Subscript[$CellContext`b, 4],
          3 -> Subscript[$CellContext`a, 3], 4 -> 
         Subscript[$CellContext`b, 1], 5 -> Subscript[$CellContext`b, 2]}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., -0.2560113295832984}, 0.01273], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox[
           SubscriptBox["a", "1"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.01273], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox[
           SubscriptBox["a", "2"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.2560113295832984}, 0.01273], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox[
           SubscriptBox["a", "3"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{1., -0.38401699437494763`}, 0.01273], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox[
           SubscriptBox["b", "1"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{1., -0.1280056647916492}, 0.01273], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox[
           SubscriptBox["b", "2"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.1280056647916492}, 0.01273], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox[
           SubscriptBox["b", "3"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.38401699437494763`}, 0.01273], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox[
           SubscriptBox["b", "4"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 356.72032971286444`}, {-142.99232971286338`, 
       125.09410489728108`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can also produce complete multipartite graphs. A ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 "-partite graph is a graph in which the vertices can be partitioned into ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 " disjoint sets so that no two vertices in any one of the partitioning sets \
are adjacent."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompleteGraph", "[", 
  RowBox[{"{", 
   RowBox[{"2", ",", "3", ",", "4"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9}, {Null, 
       SparseArray[
       Automatic, {9, 9}, 0, {
        1, {{0, 7, 14, 20, 26, 32, 37, 42, 47, 52}, {{3}, {4}, {5}, {6}, {
          7}, {8}, {9}, {3}, {4}, {5}, {6}, {7}, {8}, {9}, {1}, {2}, {6}, {
          7}, {8}, {9}, {1}, {2}, {6}, {7}, {8}, {9}, {1}, {2}, {6}, {7}, {
          8}, {9}, {1}, {2}, {3}, {4}, {5}, {1}, {2}, {3}, {4}, {5}, {1}, {
          2}, {3}, {4}, {5}, {1}, {2}, {3}, {4}, {5}}}, Pattern}]}, {
      GraphLayout -> {
        "MultipartiteLayout", "VertexPartition" -> {2, 3, 4}}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0., -0.2310113295832984}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0., 0.2310113295832984}, 0.02261146496815286], "DynamicName",
         BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{1., -0.4620226591665968}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
        "VertexID$4"], 
       TagBox[
        DiskBox[{1., 0.4620226591665968}, 0.02261146496815286], "DynamicName",
         BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{2., -0.6930339887498952}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$6"], 
       TagBox[
        DiskBox[{2., -0.2310113295832984}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$7"], 
       TagBox[
        DiskBox[{2., 0.2310113295832984}, 0.02261146496815286], "DynamicName",
         BoxID -> "VertexID$8"], 
       TagBox[
        DiskBox[{2., 0.6930339887498952}, 0.02261146496815286], "DynamicName",
         BoxID -> "VertexID$9"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.179999999999998, 
       352.82000000000005`}, {-124.10719999999992`, 119.07926975767009`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a function for determining whether a given graph is bipartite: ",
 StyleBox[ButtonBox["BipartiteGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/BipartiteGraphQ"], "FunctionLink"],
 ". This function accepts a graph as its sole argument and returns ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 " if the graph is bipartite."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BipartiteGraphQ", "[", 
  RowBox[{"HypercubeGraph", "[", "3", "]"}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bipartite Pseudographs", "Subsubsection"],

Cell[TextData[{
 "It is worthwhile, however, to recreate a version of ",
 StyleBox["BipartiteGraphQ", "Input"],
 " from scratch in order to better understand the algorithm that determines \
whether the graph is bipartite and finds a bipartition. Our function will \
apply to edge lists, so as to be applicable to pseudographs. Also, instead of \
just returning true, our function will, if the graph is bipartite, display \
the graph with the vertices colored red and green to represent the \
partitioning. Of course, if the graph is not bipartite, the function will \
return false."
}], "Text"],

Cell[TextData[{
 "For ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " objects, the color of vertices can be changed by setting the ",
 StyleBox[ButtonBox["VertexStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexStyle"], "FunctionLink"],
 " option to a single style for global changes or to a list of rules to set \
options for individual vertices as is shown below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypercubeGraph", "[", 
  RowBox[{"2", ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"VertexStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", "Red"}], ",", 
      RowBox[{"2", "\[Rule]", "Green"}], ",", 
      RowBox[{"3", "\[Rule]", "Blue"}], ",", 
      RowBox[{"4", "\[Rule]", "Black"}]}], "}"}]}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4}, {Null, 
       SparseArray[
       Automatic, {4, 4}, 0, {
        1, {{0, 2, 4, 6, 8}, {{2}, {3}, {1}, {4}, {1}, {4}, {2}, {3}}}, 
         Pattern}]}, {
      GraphLayout -> "GridEmbedding", ImagePadding -> 10, 
       VertexLabels -> {"Name"}, 
       VertexStyle -> {
        2 -> RGBColor[0, 1, 0], 1 -> RGBColor[1, 0, 0], 4 -> GrayLevel[0], 3 -> 
         RGBColor[0, 0, 1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 1.}, 0.01273], 
           RGBColor[1, 0, 0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 2.}, 0.01273], 
           RGBColor[0, 1, 0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 1.}, 0.01273], 
           RGBColor[0, 0, 1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 2.}, 0.01273], 
           GrayLevel[0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.80000000000003, 
       350.72032971286444`}, {-177.9923297128684, 161.92799999999983`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["VertexStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexStyle"], "FunctionLink"],
 " option is not a possibility for graphs not stored as a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object. Instead, the ",
 StyleBox[ButtonBox["VertexRenderingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexRenderingFunction"], "FunctionLink"],
 " allows us to take complete control of the appearance of vertices. It is \
not quite so easy to use, however. The following shows how to display the \
vertices as blue circles with the vertex label inside of the disk."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"1", "\[Rule]", "3"}], ",", 
     RowBox[{"2", "\[Rule]", "4"}], ",", 
     RowBox[{"3", "\[Rule]", "4"}]}], "}"}], ",", 
   RowBox[{"VertexRenderingFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Blue", ",", 
        RowBox[{"EdgeForm", "[", "Black", "]"}], ",", 
        RowBox[{"Disk", "[", 
         RowBox[{"#1", ",", ".1"}], "]"}], ",", "Green", ",", 
        RowBox[{"Text", "[", 
         RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsGroupBox[{
     GraphicsComplexBox[{{0., 0.029945404196222936`}, {1.0000906201270983`, 
      0.}, {0.031128233665176586`, 1.0299964287193093`}, {1.0300507240971837`,
       0.999075137178996}}, 
      {RGBColor[0.5, 0., 0.], LineBox[{{1, 2}, {1, 3}, {2, 4}, {3, 4}}]}], {
      {RGBColor[0, 0, 1], EdgeForm[GrayLevel[0]], 
       DiskBox[{0., 0.029945404196222936`}, 0.1], 
       {RGBColor[0, 1, 0], InsetBox["1", {0., 0.029945404196222936`}]}}, 
      {RGBColor[0, 0, 1], EdgeForm[GrayLevel[0]], 
       DiskBox[{1.0000906201270983`, 0.}, 0.1], 
       {RGBColor[0, 1, 0], InsetBox["2", {1.0000906201270983`, 0.}]}}, 
      {RGBColor[0, 0, 1], EdgeForm[GrayLevel[0]], 
       DiskBox[{0.031128233665176586`, 1.0299964287193093`}, 0.1], 
       {RGBColor[0, 1, 0], 
        InsetBox["3", {0.031128233665176586`, 1.0299964287193093`}]}}, 
      {RGBColor[0, 0, 1], EdgeForm[GrayLevel[0]], 
       DiskBox[{1.0300507240971837`, 0.999075137178996}, 0.1], 
       {RGBColor[0, 1, 0], 
        InsetBox["4", {1.0300507240971837`, 0.999075137178996}]}}}},
    ContentSelectable->True],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.029945404196222936`}, {
     1.0000906201270983`, 0.}, {0.031128233665176586`, 1.0299964287193093`}, {
     1.0300507240971837`, 0.999075137178996}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Notice that the ",
 StyleBox[ButtonBox["VertexRenderingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexRenderingFunction"], "FunctionLink"],
 " is set to a pure ",
 StyleBox[ButtonBox["Function",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Function"], "FunctionLink"],
 " (&). Each time a vertex needs to be drawn, this function is called with \
two arguments: the location of the center of the vertex (",
 StyleBox["#1", "Input"],
 ") and the name of the vertex (",
 StyleBox["#2", "Input"],
 "). The body of the function is a list of graphics directives. ",
 StyleBox["Blue", "Input"],
 " and ",
 StyleBox["EdgeForm[Black]", "Input"],
 " cause the shape to be filled with blue and to have a black border. The \
shape ",
 StyleBox["Disk[#1,.1]", "Input"],
 " causes a disk to be drawn at the location of the vertex (",
 StyleBox["#1", "Input"],
 ") with radius .1. Then ",
 StyleBox["Green", "Input"],
 " changes the prevailing color and ",
 StyleBox["Text[#2,#1]", "Input"],
 " causes the name of the vertex (",
 StyleBox["#2", "Input"],
 ") to be displayed at the location (",
 StyleBox["#1", "Input"],
 ") of the vertex. The interested reader can explore the help page for ",
 StyleBox[ButtonBox["VertexRenderingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexRenderingFunction"], "FunctionLink"],
 " for more information."
}], "Text"],

Cell[TextData[{
 "Elements of the ",
 StyleBox[ButtonBox["VertexRenderingFunction",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexRenderingFunction"], "FunctionLink"],
 " can be made dependent on particular vertices by using expressions such as ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " or ",
 StyleBox[ButtonBox["Switch",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Switch"], "FunctionLink"],
 ". For example, the following will change the color for each vertex."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"1", "\[Rule]", "3"}], ",", 
     RowBox[{"2", "\[Rule]", "4"}], ",", 
     RowBox[{"3", "\[Rule]", "4"}]}], "}"}], ",", 
   RowBox[{"VertexRenderingFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Switch", "[", 
         RowBox[{
         "#2", ",", "1", ",", "Red", ",", "2", ",", "Green", ",", "3", ",", 
          "Blue", ",", "4", ",", "Black"}], "]"}], ",", 
        RowBox[{"EdgeForm", "[", "Black", "]"}], ",", 
        RowBox[{"Disk", "[", 
         RowBox[{"#1", ",", ".1"}], "]"}], ",", "White", ",", 
        RowBox[{"Text", "[", 
         RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsGroupBox[{
     GraphicsComplexBox[{{0., 0.029945404196222936`}, {1.0000906201270983`, 
      0.}, {0.031128233665176586`, 1.0299964287193093`}, {1.0300507240971837`,
       0.999075137178996}}, 
      {RGBColor[0.5, 0., 0.], LineBox[{{1, 2}, {1, 3}, {2, 4}, {3, 4}}]}], {
      {RGBColor[1, 0, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{0., 0.029945404196222936`}, 0.1], 
       {GrayLevel[1], InsetBox["1", {0., 0.029945404196222936`}]}}, 
      {RGBColor[0, 1, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{1.0000906201270983`, 0.}, 0.1], 
       {GrayLevel[1], InsetBox["2", {1.0000906201270983`, 0.}]}}, 
      {RGBColor[0, 0, 1], EdgeForm[GrayLevel[0]], 
       DiskBox[{0.031128233665176586`, 1.0299964287193093`}, 0.1], 
       {GrayLevel[1], 
        InsetBox["3", {0.031128233665176586`, 1.0299964287193093`}]}}, 
      {GrayLevel[0], EdgeForm[GrayLevel[0]], 
       DiskBox[{1.0300507240971837`, 0.999075137178996}, 0.1], 
       {GrayLevel[1], 
        InsetBox["4", {1.0300507240971837`, 0.999075137178996}]}}}},
    ContentSelectable->True],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.029945404196222936`}, {
     1.0000906201270983`, 0.}, {0.031128233665176586`, 1.0299964287193093`}, {
     1.0300507240971837`, 0.999075137178996}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We now turn to our version of ",
 StyleBox[ButtonBox["BipartiteGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/BipartiteGraphQ"], "FunctionLink"],
 ". The idea of the function is as follows. (Note that this method is based \
on forming a spanning tree of the graph, a concept discussed in Section 11.4 \
of the textbook)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "Pick a vertex ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " from the vertex set and place it in the set ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 "."
}], "Item1Numbered"],

Cell[TextData[{
 "Place all of ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 "'s neighbors in set ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]]],
 "."
}], "Item1Numbered"],

Cell[TextData[{
 "For each vertex ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " in the set ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]]],
 " that has not already been processed, place all of ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 "'s neighbors that are not already in either set into the set ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 "."
}], "Item1Numbered"],

Cell[TextData[{
 "Repeat step 3, reversing ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]]],
 " until no more vertices remain to be processed."
}], "Item1Numbered"],

Cell[TextData[{
 "Once step 4 is complete, we have formed a disjoint partition of the \
vertices. We then examine each edge of the graph and ensure that no edge has \
both ends in ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 " or both ends in ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]]],
 ". If some edge fails that test, then the graph is not bipartite. If all of \
the edges do pass the test, then the graph is bipartite and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"A", ",", "B"}], ")"}], TraditionalForm]]],
 " is a bipartition."
}], "Item1Numbered"]
}, Open  ]],

Cell[TextData[{
 "First we will need a function to determine the list of neighbors of a given \
vertex. For a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object, the built-in function ",
 StyleBox[ButtonBox["AdjacencyList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AdjacencyList"], "FunctionLink"],
 " applied to a graph and a vertex will return the list of vertices adjacent \
to it."
}], "Text"],

Cell[TextData[{
 "To find the neighbors of a vertex in a graph defined by a list of rules, \
rather than a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object, we need to find all of the edges containing the given vertex and \
output the other vertex in the rule. The ",
 StyleBox[ButtonBox["Cases",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Cases"], "FunctionLink"],
 " function can be used for this. The first argument to ",
 StyleBox[ButtonBox["Cases",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Cases"], "FunctionLink"],
 " is a list of expressions. The second argument is a pattern expressing \
which elements of the first argument should be output. In our case, we want \
to pick out those edges, that is, ",
 StyleBox[ButtonBox["Rule",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rule"], "FunctionLink"],
 "s, one of whose elements is the desired vertex. As an example, suppose we\
\[CloseCurlyQuote]re looking for edges involving the vertex ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 ". Those edges will either be of the form ",
 StyleBox["Rule[\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote],_]", "Input"],
 " or ",
 StyleBox["Rule[_,\[CloseCurlyDoubleQuote]a\[CloseCurlyDoubleQuote]]", 
  "Input"],
 ". In a pattern, we use the ",
 StyleBox[ButtonBox["Alternatives",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Alternatives"], "FunctionLink"],
 " (",
 StyleBox["|", "Input"],
 ") operator to combined two or more possibilities in a single pattern. The \
following picks out all of the edges incident to ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " in ",
 StyleBox["exercise2edges", "Input"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData["exercise2edges"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"a\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"d\"\>", "\[Rule]", "\<\"e\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"exercise2edges", ",", 
   RowBox[{
    RowBox[{"Rule", "[", 
     RowBox[{"\"\<a\>\"", ",", "_"}], "]"}], "|", 
    RowBox[{"Rule", "[", 
     RowBox[{"_", ",", "\"\<a\>\""}], "]"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"a\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"e\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that these edges form the neighborhood graph of \
\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote], that is, the subgraph \
consisting of \[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote] and all of its \
neighbors. But our interest is the neighbors, not the subgraph. To obtain the \
neighbors, we\[CloseCurlyQuote]ll take advantage of another feature of the ",
 StyleBox[ButtonBox["Cases",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Cases"], "FunctionLink"],
 " function: the second argument can be given as a rule. The left hand side \
of the rule is the pattern expressing which elements of the original list \
should match and the right hand side describes what to include in the output \
for that matching element. Since we want the other vertex in the output, not \
the entire rule, we\[CloseCurlyQuote]ll name the blanks in the rule and \
output the vertex."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{"exercise2edges", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Rule", "[", 
      RowBox[{"\"\<a\>\"", ",", "x_"}], "]"}], "|", 
     RowBox[{"Rule", "[", 
      RowBox[{"x_", ",", "\"\<a\>\""}], "]"}]}], "\[Rule]", "x"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"b\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"e\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Applying ",
 StyleBox[ButtonBox["Union",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Union"], "FunctionLink"],
 " will remove duplicates and sort the results. Replacing the example data \
with arguments allows us to create a function."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"neighbors", "[", 
   RowBox[{
    RowBox[{"E", ":", 
     RowBox[{"{", "__Rule", "}"}]}], ",", "v_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "x", "}"}], ",", 
    RowBox[{"Union", "[", 
     RowBox[{"Cases", "[", 
      RowBox[{"E", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Rule", "[", 
          RowBox[{"v", ",", "x_"}], "]"}], "|", 
         RowBox[{"Rule", "[", 
          RowBox[{"x_", ",", "v"}], "]"}]}], "\[Rule]", "x"}]}], "]"}], 
     "]"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[TextData[{
 "Here is the implementation of our function ",
 StyleBox["drawBipartite", "Input"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"drawBipartite", "[", 
   RowBox[{"E", ":", 
    RowBox[{"{", "__Rule", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"V", ",", "AB", ",", "i", ",", "T", ",", "w", ",", "e"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"V", "=", 
      RowBox[{"Union", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"E", ",", "2", ",", "Rule"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"w", "=", 
      RowBox[{"V", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"AB", "[", "0", "]"}], "=", 
      RowBox[{"{", "w", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"AB", "[", "1", "]"}], "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"i", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"V", "\[NotEqual]", 
        RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"T", "=", 
         RowBox[{"Intersection", "[", 
          RowBox[{"V", ",", 
           RowBox[{"AB", "[", "i", "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"i", "=", 
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"i", "+", "1"}], ",", "2"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"AB", "[", "i", "]"}], "=", 
           RowBox[{"Union", "[", 
            RowBox[{
             RowBox[{"AB", "[", "i", "]"}], ",", 
             RowBox[{"Complement", "[", 
              RowBox[{
               RowBox[{"neighbors", "[", 
                RowBox[{"E", ",", "w"}], "]"}], ",", 
               RowBox[{"Union", "[", 
                RowBox[{
                 RowBox[{"AB", "[", "0", "]"}], ",", 
                 RowBox[{"AB", "[", "1", "]"}]}], "]"}]}], "]"}]}], "]"}]}], 
          "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"w", ",", "T"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"V", "=", 
         RowBox[{"Complement", "[", 
          RowBox[{"V", ",", "T"}], "]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"Catch", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"MemberQ", "[", 
               RowBox[{
                RowBox[{"AB", "[", "0", "]"}], ",", 
                RowBox[{"e", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&&", 
              RowBox[{"MemberQ", "[", 
               RowBox[{
                RowBox[{"AB", "[", "0", "]"}], ",", 
                RowBox[{"e", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ")"}], "||", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"MemberQ", "[", 
               RowBox[{
                RowBox[{"AB", "[", "1", "]"}], ",", 
                RowBox[{"e", "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&&", 
              RowBox[{"MemberQ", "[", 
               RowBox[{
                RowBox[{"AB", "[", "1", "]"}], ",", 
                RowBox[{"e", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ")"}]}], ",", 
           RowBox[{"Throw", "[", "False", "]"}]}], "]"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"e", ",", "E"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"GraphPlot", "[", 
        RowBox[{"E", ",", 
         RowBox[{"VertexRenderingFunction", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"MemberQ", "[", 
                 RowBox[{
                  RowBox[{"AB", "[", "0", "]"}], ",", "#2"}], "]"}], ",", 
                "Red", ",", "Green"}], "]"}], ",", 
              RowBox[{"EdgeForm", "[", "Black", "]"}], ",", 
              RowBox[{"Disk", "[", 
               RowBox[{"#1", ",", ".1"}], "]"}], ",", "Black", ",", 
              RowBox[{"Text", "[", 
               RowBox[{"#2", ",", "#1"}], "]"}]}], "}"}], "&"}], ")"}]}]}], 
        "]"}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell["\<\
Note that if the graph is not bipartite, the function will output false.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"drawBipartite", "[", "exercise2edges", "]"}]], "Input"],

Cell[BoxData["False"], "Output"]
}, Open  ]],

Cell["\<\
But for bipartite graphs, such as Exercise 4 from Section 10.1, the function \
will draw the graph with the vertices colored to illustrate the bipartition.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"drawBipartite", "[", "exercise4edges", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsGroupBox[{GraphicsComplexBox[CompressedData["
1:eJw1j3sw1AkAx39cQuS84jqyHrVRmUpdEe5LIdLhSBnOowcxlIq70NXRzXUn
Ou9Hpaz1PGvXLhnXuvy2az1qi9jKcW1nzIV9tL/f1nhU1HV/9Jn5zmfm+9/H
7lBqaLw2QRA+H/a/P2J7X2Sk3Xwd/p2NOrEEjY+/aCYwwXy8Gmsv6uTKsmiY
/iA9bXGGBqd3eUrKPIX9N/16kgqFeGiitV1INePF27yfzMZEYL1ZLIqXcNHP
OB5996QYD7m6B6LM+LgjlpluM+pHv3uLSwYhwFiJ8aPtPAn0BEd0yBYBTtYI
Wzkhg0iURt9/bdkGfqP9/LasITTpJ8qX7mxD9dMad+e9Ujj+mOM8uq4NIVMO
qRvTJjG+6zeNYAsPv8+XWqqiphD3vDyEOs9FNfNQsJ3PNPh8Fb0Q3ILbKS0B
F9bLQXTrG7lfbUahzrOsYRMFCE9pmUt8E96OJbbemlXgRGXvYimvHpPRSfbE
mBLZN/YbeGSwweMwS0O7VBBlBDLCLlzDDku/m1HrhSBcwufUO0Jxe2dl7dwV
EYj0NsZfKzPJ40FXUrUcxSDuVY4GJ+SSVnU93ryuPtjynlsfti0mI3Tzl/6z
T4Lx1tDl6fnl5N+MDurUywHElX0mnZu5THYp06dqA4bAepdS/DSqiswzOuC6
ykoKVlfRo4O3rpH+2eeONUZOwovFDhMQ9aTo8y8L2Lum4MVNlRhurCfde+MY
JRs+9HtFFb0cqyNrAgItNq340L+Q+MnZJXVkwmLFhU2LcmSbzEdTHDZZP/mq
PfBfBQpneA0dQyyyKlXl5HZPCcLJfcVdVRWZUtEwzOep4HXAO/bUFxXktdyq
zL27KXy94cWlslwh8v+o9mWtpFDQ1RnQ/VgEnwhx3dwrNWzbcm1+ThGjvCEn
PuaJGhbTQa46ev1gM5MGZSI1gooNjC0bJXDo82R9365G+Fzz+8v+g+gbfaIP
nhphMQVBHd8OIShpkM8UqHF0WHbRZbcU3ew1hmFmFEaT0z1jjk0irSxCN9aG
gnlAWuSz8Cl49DiN522mwO+kTEY8p3Fo9mqJdC+FtnPaze9Xy7EYvqXU+QQF
x61Lmj81UKBmuvb+r1cpnOn21XRTCmw2DayVD1A47M190DOsxGyB23sLHRqZ
sZtMZe0qHG3wPhfzHQ3STTmQtVoIH+5jDlFKw23F+cwr5SIY7nSy5HFpjNna
KjvsxYjJO9gec4fGuj1MvbSOPqx357YbPKbxjuGs1/6VBN1hCZdaJ2joemQk
hisGwFYOvPZV0fB4u9XB2ncIi0cS5yQaGoIOl2hrCylu5JitmbDX4KzsOlO6
bxKn7xbMh6/W4BfLXnGR5xT6Q79x7rTT4Kmeg8qXOQ392t6ypVYa2Ewsa2ow
ksP4sHCPn7EGLYZvViXPyuG6bCUnU0sDp8jkuj0yBcwjOJH1ahoPRqpHF/5U
Ik/T4jU4QmOtXYjQrVGF/wC+ph1B
      "], 
      {RGBColor[0.5, 0., 0.], 
       LineBox[{{1, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
          2}, {1, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
         36, 2}, {1, 3}, {2, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
         49, 50, 51, 52, 4}, {2, 4}, {2, 53, 54, 55, 56, 57, 58, 59, 60, 61, 
         62, 63, 64, 65, 66, 67, 68, 4}, {3, 4}}]}], {
      {RGBColor[1, 0, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{0., 0.029945404196222936`}, 0.1], 
       {GrayLevel[0], InsetBox["\<\"a\"\>", {0., 0.029945404196222936`}]}}, 
      {RGBColor[0, 1, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{1.0000906201270983`, 0.}, 0.1], 
       {GrayLevel[0], InsetBox["\<\"b\"\>", {1.0000906201270983`, 0.}]}}, 
      {RGBColor[0, 1, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{0.031128233665176586`, 1.0299964287193093`}, 0.1], 
       {GrayLevel[0], 
        InsetBox["\<\"c\"\>", {0.031128233665176586`, 1.0299964287193093`}]}}, 
      {RGBColor[1, 0, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{1.0300507240971837`, 0.999075137178996}, 0.1], 
       {GrayLevel[0], 
        InsetBox["\<\"d\"\>", {1.0300507240971837`, 0.999075137178996}]}}}},
    ContentSelectable->True],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.029945404196222936`}, {
     1.0000906201270983`, 0.}, {0.031128233665176586`, 1.0299964287193093`}, {
     1.0300507240971837`, 0.999075137178996}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note also that our function can be applied to a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object by calling ",
 StyleBox[ButtonBox["EdgeList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeList"], "FunctionLink"],
 ". Then, since ",
 StyleBox[ButtonBox["EdgeList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeList"], "FunctionLink"],
 " always returns a list whose elements have head ",
 StyleBox[ButtonBox["UndirectedEdge",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/UndirectedEdge"], "FunctionLink"],
 " or ",
 StyleBox[ButtonBox["DirectedEdge",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdge"], "FunctionLink"],
 ", we must transform those heads into ",
 StyleBox[ButtonBox["Rule",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rule"], "FunctionLink"],
 ". For example, the following illustrates a bipartition for the three \
dimensional hypercube."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"drawBipartite", "[", 
  RowBox[{
   RowBox[{"EdgeList", "[", 
    RowBox[{"HypercubeGraph", "[", "3", "]"}], "]"}], "/.", 
   RowBox[{"UndirectedEdge", "\[Rule]", "Rule"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsGroupBox[{
     GraphicsComplexBox[{{0., 0.8100535547739974}, {0.638980383668265, 
      1.6244281947557233`}, {0.8219923795692097, 0.8110965215471371}, {
      0.6455817338392549, 0.}, {1.5415507259846923`, 1.6267159656670214`}, {
      1.3653153726545733`, 0.8156225549698262}, {1.5475752648505943`, 
      0.001848778784065419}, {2.18736743935368, 0.8166006810485757}}, 
      {RGBColor[0.5, 0., 0.], 
       LineBox[{{1, 2}, {1, 3}, {1, 4}, {2, 5}, {2, 6}, {3, 5}, {3, 7}, {4, 
        6}, {4, 7}, {5, 8}, {6, 8}, {7, 8}}]}], {
      {RGBColor[1, 0, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{0., 0.8100535547739974}, 0.1], 
       {GrayLevel[0], InsetBox["1", {0., 0.8100535547739974}]}}, 
      {RGBColor[0, 1, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{0.638980383668265, 1.6244281947557233`}, 0.1], 
       {GrayLevel[0], 
        InsetBox["2", {0.638980383668265, 1.6244281947557233`}]}}, 
      {RGBColor[0, 1, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{0.8219923795692097, 0.8110965215471371}, 0.1], 
       {GrayLevel[0], 
        InsetBox["3", {0.8219923795692097, 0.8110965215471371}]}}, 
      {RGBColor[0, 1, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{0.6455817338392549, 0.}, 0.1], 
       {GrayLevel[0], InsetBox["5", {0.6455817338392549, 0.}]}}, 
      {RGBColor[1, 0, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{1.5415507259846923`, 1.6267159656670214`}, 0.1], 
       {GrayLevel[0], 
        InsetBox["4", {1.5415507259846923`, 1.6267159656670214`}]}}, 
      {RGBColor[1, 0, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{1.3653153726545733`, 0.8156225549698262}, 0.1], 
       {GrayLevel[0], 
        InsetBox["6", {1.3653153726545733`, 0.8156225549698262}]}}, 
      {RGBColor[1, 0, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{1.5475752648505943`, 0.001848778784065419}, 0.1], 
       {GrayLevel[0], 
        InsetBox["7", {1.5475752648505943`, 0.001848778784065419}]}}, 
      {RGBColor[0, 1, 0], EdgeForm[GrayLevel[0]], 
       DiskBox[{2.18736743935368, 0.8166006810485757}, 0.1], 
       {GrayLevel[0], 
        InsetBox["8", {2.18736743935368, 0.8166006810485757}]}}}},
    ContentSelectable->True],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 0.8100535547739974}, {0.638980383668265, 
     1.6244281947557233`}, {0.8219923795692097, 0.8110965215471371}, {
     0.6455817338392549, 0.}, {1.5415507259846923`, 1.6267159656670214`}, {
     1.3653153726545733`, 0.8156225549698262}, {1.5475752648505943`, 
     0.001848778784065419}, {2.18736743935368, 0.8166006810485757}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "For convenience, we can define a version of ",
 StyleBox["drawBipartite", "Input"],
 " that accepts a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object argument and applies the transformation automatically."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"drawBipartite", "[", "G_Graph", "]"}], ":=", 
  RowBox[{"drawBipartite", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EdgeList", "[", "G", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"DirectedEdge", "\[Rule]", "Rule"}], ",", 
      RowBox[{"UndirectedEdge", "\[Rule]", "Rule"}]}], "}"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Bipartite Graphs and Matchings", "Subsection",
 CellTags->"Section2e"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can help us find maximal matchings in a bipartite graph. We will use \
Figure 10a from Section 10.2 of the text as an example. To improve \
readability, we have abbreviated the names to their first letter and \
shortened the descriptions of the jobs."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figure10aEdges", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\"\<A\>\"", "\[Rule]", "\"\<req\>\""}], ",", 
    RowBox[{"\"\<A\>\"", "\[Rule]", "\"\<test\>\""}], ",", 
    RowBox[{"\"\<B\>\"", "\[Rule]", "\"\<arch\>\""}], ",", 
    RowBox[{"\"\<B\>\"", "\[Rule]", "\"\<imp\>\""}], ",", 
    RowBox[{"\"\<B\>\"", "\[Rule]", "\"\<test\>\""}], ",", 
    RowBox[{"\"\<C\>\"", "\[Rule]", "\"\<req\>\""}], ",", 
    RowBox[{"\"\<C\>\"", "\[Rule]", "\"\<arch\>\""}], ",", 
    RowBox[{"\"\<C\>\"", "\[Rule]", "\"\<imp\>\""}], ",", 
    RowBox[{"\"\<D\>\"", "\[Rule]", "\"\<req\>\""}]}], "}"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"A\"\>", "\[Rule]", "\<\"req\"\>"}], ",", 
   RowBox[{"\<\"A\"\>", "\[Rule]", "\<\"test\"\>"}], ",", 
   RowBox[{"\<\"B\"\>", "\[Rule]", "\<\"arch\"\>"}], ",", 
   RowBox[{"\<\"B\"\>", "\[Rule]", "\<\"imp\"\>"}], ",", 
   RowBox[{"\<\"B\"\>", "\[Rule]", "\<\"test\"\>"}], ",", 
   RowBox[{"\<\"C\"\>", "\[Rule]", "\<\"req\"\>"}], ",", 
   RowBox[{"\<\"C\"\>", "\[Rule]", "\<\"arch\"\>"}], ",", 
   RowBox[{"\<\"C\"\>", "\[Rule]", "\<\"imp\"\>"}], ",", 
   RowBox[{"\<\"D\"\>", "\[Rule]", "\<\"req\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "In order to draw the graph meaningfully, in the same fashion as in the \
text, we will specify the coordinates of each vertex. This is done by setting \
the ",
 StyleBox[ButtonBox["VertexCoordinates",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexCoordinates"], "FunctionLink"],
 " option to a list of coordinates, with the order of the list matching the \
order of the vertices. To ensure that our order is correct, we will specify a \
vertex list when we create the ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figure10aVertices", "=", 
  RowBox[{"{", 
   RowBox[{
   "\"\<A\>\"", ",", "\"\<B\>\"", ",", "\"\<C\>\"", ",", "\"\<D\>\"", ",", 
    "\"\<req\>\"", ",", "\"\<test\>\"", ",", "\"\<arch\>\"", ",", 
    "\"\<imp\>\""}], "}"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A\"\>", ",", "\<\"B\"\>", ",", "\<\"C\"\>", ",", "\<\"D\"\>", 
   ",", "\<\"req\"\>", ",", "\<\"test\"\>", ",", "\<\"arch\"\>", 
   ",", "\<\"imp\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To create the list of coordinates, we use two ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 "s and specify that the names should have ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 "-coordinate 1 and the jobs should have ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 "-coordinate 0. ",
 StyleBox[ButtonBox["Join",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Join"], "FunctionLink"],
 " is used to combine the two lists."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figure10aCoordinates", "=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "4"}], "}"}]}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["We now create the graph.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figure10a", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{"figure10aVertices", ",", "figure10aEdges", ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"VertexCoordinates", "\[Rule]", "figure10aCoordinates"}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "5"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "A", "B", "C", "D", "req", "test", "arch", "imp"}, {{{1, 5}, {1, 6}, {2,
        7}, {2, 8}, {2, 6}, {3, 5}, {3, 7}, {3, 8}, {4, 5}}, Null}, {
      ImagePadding -> 5, 
       VertexCoordinates -> {{1, 1}, {2, 1}, {3, 1}, {4, 1}, {1, 0}, {2, 0}, {
        3, 0}, {4, 0}}, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Arrowheads[0.028937842778793414`], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       ArrowBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$6", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$6", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$7", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$8", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$7", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$8", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$4", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"A\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"B\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"C\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{4., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"D\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"req\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"test\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["\"arch\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          DiskBox[{4., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["\"imp\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{10.999999999999991`, 
       366.734731094075}, {-73.01473109407357, 57.146531011543715`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To find a maximal matching, we use the function ",
 StyleBox[ButtonBox["FindIndependentEdgeSet",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindIndependentEdgeSet"], "FunctionLink"],
 ". The term ",
 StyleBox["independent edge set",
  FontSlant->"Italic"],
 " is synonymous with matching. The only allowed argument to this function is \
the graph. It returns a list of edges in a matching."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figure10aMatching", "=", 
  RowBox[{"FindIndependentEdgeSet", "[", "figure10a", "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"A\"\>", "\[DirectedEdge]", "\<\"test\"\>"}], ",", 
   RowBox[{"\<\"B\"\>", "\[DirectedEdge]", "\<\"imp\"\>"}], ",", 
   RowBox[{"\<\"C\"\>", "\[DirectedEdge]", "\<\"arch\"\>"}], ",", 
   RowBox[{"\<\"D\"\>", "\[DirectedEdge]", "\<\"req\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The output indicates that one maximal matching has Alvarez assigned to \
testing, Berkowitz to implementation, Chen to architecture, and Davis to \
requirements.\
\>", "Text"],

Cell[TextData[{
 "We can visualize this matching by having ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " highlight the edges that form the matching using the function ",
 StyleBox[ButtonBox["HighlightGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HighlightGraph"], "FunctionLink"],
 ". This function requires two arguments. The first is a graph. The second is \
a list of the elements to highlight. In this case, the second argument will \
be the output from ",
 StyleBox[ButtonBox["FindIndependentEdgeSet",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindIndependentEdgeSet"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"figure10a", ",", "figure10aMatching"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "A", "B", "C", "D", "req", "test", "arch", "imp"}, {{{1, 5}, {1, 6}, {2,
        7}, {2, 8}, {2, 6}, {3, 5}, {3, 7}, {3, 8}, {4, 5}}, Null}, {
      GraphHighlight -> {
         DirectedEdge["D", "req"], 
         DirectedEdge["B", "imp"], 
         DirectedEdge["C", "arch"], 
         DirectedEdge["A", "test"]}, ImagePadding -> 5, 
       VertexCoordinates -> {{1, 1}, {2, 1}, {3, 1}, {4, 1}, {1, 0}, {2, 0}, {
        3, 0}, {4, 0}}, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Arrowheads[0.028937842778793414`], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       ArrowBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       StyleBox[
        ArrowBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       ArrowBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$6", Automatic, Center]}], 
       ArrowBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$7", Automatic, Center]}], 
       StyleBox[
        ArrowBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       ArrowBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       StyleBox[
        ArrowBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       ArrowBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$8", Automatic, Center]}], 
       StyleBox[
        ArrowBox[{
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"A\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"B\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"C\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{4., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"D\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"req\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"test\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["\"arch\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          DiskBox[{4., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["\"imp\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{10.999999999999991`, 
       366.734731094075}, {-73.01473109407357, 57.146531011543715`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Subgraphs and Induced Subgraphs", "Subsection",
 CellTags->"Section2f"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides the ",
 StyleBox[ButtonBox["Subgraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Subgraph"], "FunctionLink"],
 " function for producing a subgraph from an existing graph. Given a graph \
and a list of edges, ",
 StyleBox[ButtonBox["Subgraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Subgraph"], "FunctionLink"],
 " produces the ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " consisting of the edges and all the vertices that are an endpoint of one \
of the given edges."
}], "Text"],

Cell["\<\
For example, below we create the subgraph of the hypercube graph consisting \
of one of the faces of the cube.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hyper", "=", 
  RowBox[{"HypercubeGraph", "[", 
   RowBox[{"3", ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 3, 6, 9, 12, 15, 18, 21, 24}, {{2}, {3}, {5}, {1}, {4}, {6}, {
          1}, {4}, {7}, {2}, {3}, {8}, {1}, {6}, {7}, {2}, {5}, {8}, {3}, {
          5}, {8}, {4}, {6}, {7}}}, Pattern}]}, {
      ImagePadding -> 10, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.6411318907234969, 1.6256350616332038`}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5431761475992014`, 1.6258514889129208`}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.3641521541128723`, 0.8124188351574709}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.186420636755495, 0.814439144539747}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.8116524116085829}, 0.02410631722965237], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8207122623609914, 0.8136876580070856}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{0.6431241846256299, 0.}, 0.02410631722965237], 
          "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5449243126722068`, 0.0005338415834358345}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       350.8758090230311}, {-137.14780902303335`, 121.0488960715287}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subhyper", "=", 
  RowBox[{"Subgraph", "[", 
   RowBox[{"hyper", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", "3"}], ",", 
      RowBox[{"3", "\[Rule]", "7"}], ",", 
      RowBox[{"7", "\[Rule]", "5"}], ",", 
      RowBox[{"5", "\[Rule]", "1"}]}], "}"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 3, 7, 5}, {Null, 
       SparseArray[
       Automatic, {4, 4}, 0, {
        1, {{0, 2, 4, 6, 8}, {{2}, {4}, {1}, {3}, {2}, {4}, {1}, {3}}}, 
         Pattern}]}, {ImagePadding -> 10, VertexLabels -> {"Name"}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{-1., 1.0106430996148606`*^-15}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{6.049014748177263*^-16, -1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., -1.133107779529596*^-15}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{-7.044813998280222*^-16, 1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       350.8501736435237}, {-178.12217364352463`, 161.9279999999999}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Alternately, you can give a list of vertices as the second argument to ",
 StyleBox[ButtonBox["Subgraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Subgraph"], "FunctionLink"],
 ". The result is the graph induced by the given vertices, that is, the graph \
consisting of the vertices and all the edges from the original graph with \
both endpoints in the set of vertices. Below we consider a prism graph and \
one of its layers."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prism", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", "2"}], ",", 
      RowBox[{"2", "\[Rule]", "3"}], ",", 
      RowBox[{"3", "\[Rule]", "4"}], ",", 
      RowBox[{"4", "\[Rule]", "5"}], ",", 
      RowBox[{"5", "\[Rule]", "6"}], ",", 
      RowBox[{"6", "\[Rule]", "1"}], ",", 
      RowBox[{"7", "\[Rule]", "8"}], ",", 
      RowBox[{"8", "\[Rule]", "9"}], ",", 
      RowBox[{"9", "\[Rule]", "10"}], ",", 
      RowBox[{"10", "\[Rule]", "11"}], ",", 
      RowBox[{"11", "\[Rule]", "12"}], ",", 
      RowBox[{"12", "\[Rule]", "7"}], ",", 
      RowBox[{"1", "\[Rule]", "7"}], ",", 
      RowBox[{"2", "\[Rule]", "8"}], ",", 
      RowBox[{"3", "\[Rule]", "9"}], ",", 
      RowBox[{"4", "\[Rule]", "10"}], ",", 
      RowBox[{"5", "\[Rule]", "11"}], ",", 
      RowBox[{"6", "\[Rule]", "12"}]}], "}"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {
      Null, {{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 1}, {7, 8}, {8, 9}, {
       9, 10}, {10, 11}, {11, 12}, {12, 7}, {1, 7}, {2, 8}, {3, 9}, {4, 10}, {
       5, 11}, {6, 12}}}, {ImagePadding -> 10, VertexLabels -> {"Name"}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.131886240159202, 1.0679997479661056`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1.746253598844666, 0.}, 0.028272915525887662`], 
          "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{0.6304889130415254, 0.025024836593490196`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.9613735416148091}, 0.028272915525887662`], 
          "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.39633201912470273`, 2.005417270737875}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5310211335833706`, 1.962083942725086}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.7301971795384574`, 1.43946750611585}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.334320957296703, 0.3959398859272738}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.198833360397172, 0.4394995286124058}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$9"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5978338406037161, 1.3337455155333127`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$10"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9839991165643827, 2.4015105280929165`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$11"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.1003059044788586`, 2.375684659780954}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$12"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 350.937192973569}, {-159.20919297357213`, 
       142.43025455877185`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subprism", "=", 
  RowBox[{"Subgraph", "[", 
   RowBox[{"prism", ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "8", ",", "9", ",", "10", ",", "11", ",", "12"}], 
     "}"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{7, 8, 9, 10, 11, 12}, {
      Null, {{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 1}}}, {
      ImagePadding -> 10, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.8660254037844389, 0.5000000000000008}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{3.8285686989269494`*^-16, -1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8660254037844389, -0.5000000000000012}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8660254037844386, 0.4999999999999993}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{1.8369701987210297`*^-16, 1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.800000000000011`, 
       355.690826000719}, {-202.96282600072493`, 186.13742371673527`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["HighlightGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HighlightGraph"], "FunctionLink"],
 " function can be used to display a subgraph relative to the original by \
passing the original graph as the first argument and the subgraph as the \
second. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"hyper", ",", "subhyper"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 3, 6, 9, 12, 15, 18, 21, 24}, {{2}, {3}, {5}, {1}, {4}, {6}, {
          1}, {4}, {7}, {2}, {3}, {8}, {1}, {6}, {7}, {2}, {5}, {8}, {3}, {
          5}, {8}, {4}, {6}, {7}}}, Pattern}]}, {GraphHighlight -> {3, 1, 
         UndirectedEdge[3, 7], 5, 
         UndirectedEdge[1, 5], 7, 
         UndirectedEdge[1, 3], 
         UndirectedEdge[7, 5]}, ImagePadding -> 10, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$6", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$4", Automatic, Center], 
         DynamicLocation["VertexID$8", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$5", Automatic, Center], 
         DynamicLocation["VertexID$6", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$6", Automatic, Center], 
         DynamicLocation["VertexID$8", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$7", Automatic, Center], 
         DynamicLocation["VertexID$8", Automatic, Center]}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.6411318907234969, 1.6256350616332038`}, 
            0.02410631722965237], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5431761475992014`, 1.6258514889129208`}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.3641521541128723`, 0.8124188351574709}, 
            0.02410631722965237], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.186420636755495, 0.814439144539747}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.8116524116085829}, 0.02410631722965237], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8207122623609914, 0.8136876580070856}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0.6431241846256299, 0.}, 0.02410631722965237], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5449243126722068`, 0.0005338415834358345}, 
           0.02410631722965237], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       350.8758090230311}, {-137.1478090230351, 121.0488960715287}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"prism", ",", "subprism"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {
      Null, {{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 1}, {7, 8}, {8, 9}, {
       9, 10}, {10, 11}, {11, 12}, {12, 7}, {1, 7}, {2, 8}, {3, 9}, {4, 10}, {
       5, 11}, {6, 12}}}, {GraphHighlight -> {10, 
         UndirectedEdge[7, 8], 11, 
         UndirectedEdge[11, 12], 
         UndirectedEdge[8, 9], 
         UndirectedEdge[9, 10], 
         UndirectedEdge[12, 7], 
         UndirectedEdge[10, 11], 9, 12, 7, 8}, ImagePadding -> 10, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$6", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$7", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$8", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$9", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$4", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$4", Automatic, Center], 
         DynamicLocation["VertexID$10", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$5", Automatic, Center], 
         DynamicLocation["VertexID$6", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$5", Automatic, Center], 
         DynamicLocation["VertexID$11", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$6", Automatic, Center], 
         DynamicLocation["VertexID$12", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.131886240159202, 1.0679997479661056`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1.746253598844666, 0.}, 0.028272915525887662`], 
          "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.6304889130415254, 0.025024836593490196`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.9613735416148091}, 0.028272915525887662`], 
          "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.39633201912470273`, 2.005417270737875}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5310211335833706`, 1.962083942725086}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.7301971795384574`, 1.43946750611585}, 
            0.028272915525887662`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.334320957296703, 0.3959398859272738}, 
            0.028272915525887662`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.198833360397172, 0.4394995286124058}, 
            0.028272915525887662`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.5978338406037161, 1.3337455155333127`}, 
            0.028272915525887662`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$10"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.9839991165643827, 2.4015105280929165`}, 
            0.028272915525887662`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$11"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.1003059044788586`, 2.375684659780954}, 
            0.028272915525887662`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$12"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 350.937192973569}, {-159.20919297357213`, 
       142.43025455877185`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Deleting Vertices and Edges", "Subsection",
 PageBreakWithin->False,
 CellTags->"Section2g"],

Cell[TextData[{
 "Subgraphs can also be produced by deleting vertices or edges. The ",
 StyleBox[ButtonBox["VertexDelete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexDelete"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["EdgeDelete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeDelete"], "FunctionLink"],
 " functions were described in the previous section, but are worth \
revisiting. ",
 StyleBox[ButtonBox["VertexDelete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexDelete"], "FunctionLink"],
 " takes two arguments: a graph and a vertex or list of vertices. The \
function returns a new graph with the vertex or vertices and all incident \
edges removed. Here we highlight the subgraph of the complete graph ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "4"], TraditionalForm]]],
 " that is obtained by deleting a vertex."
}], "Text",
 PageBreakAbove->False,
 PageBreakWithin->False],

Cell[BoxData[
 RowBox[{
  RowBox[{"deleteVExStart", "=", 
   RowBox[{"CompleteGraph", "[", "5", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"deleteVExEnd", "=", 
   RowBox[{"VertexDelete", "[", 
    RowBox[{"deleteVExStart", ",", "1"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"deleteVExStart", ",", "deleteVExEnd", ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 4, 8, 12, 16, 20}, {{2}, {3}, {4}, {5}, {1}, {3}, {4}, {5}, {
          1}, {2}, {4}, {5}, {1}, {2}, {3}, {5}, {1}, {2}, {3}, {4}}}, 
         Pattern}]}, {GraphHighlight -> {
         UndirectedEdge[2, 5], 5, 
         UndirectedEdge[3, 5], 3, 4, 2, 
         UndirectedEdge[2, 3], 
         UndirectedEdge[3, 4], 
         UndirectedEdge[2, 4], 
         UndirectedEdge[4, 5]}, GraphLayout -> "CircularEmbedding", 
       ImagePadding -> 10, 
       VertexLabels -> {
        5 -> "Name", 4 -> "Name", 2 -> "Name", 3 -> "Name"}}]], Typeset`boxes,
     Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
            0.021812234931106983`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.5877852522924738, -0.8090169943749481}, 
            0.021812234931106983`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
            0.021812234931106983`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999994`, 
       350.8354014677217}, {-170.10740146772525`, 154.31101834898476`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox[ButtonBox["EdgeDelete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeDelete"], "FunctionLink"],
 " also takes two arguments, a name of an undirected graph and an edge or a \
list of edges. For example, we can remove the outer ring of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "5"], TraditionalForm]]],
 " as follows."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"deleteEexStart", "=", 
   RowBox[{"CompleteGraph", "[", "5", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"deleteEexEdges", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"i", "\[Rule]", 
        RowBox[{"i", "+", "1"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", "\[Rule]", "5"}], "}"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"deleteEexEnd", "=", 
   RowBox[{"EdgeDelete", "[", 
    RowBox[{"deleteEexStart", ",", "deleteEexEdges"}], "]"}]}], 
  ";"}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"deleteEexStart", ",", "deleteEexEnd"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 4, 8, 12, 16, 20}, {{2}, {3}, {4}, {5}, {1}, {3}, {4}, {5}, {
          1}, {2}, {4}, {5}, {1}, {2}, {3}, {5}, {1}, {2}, {3}, {4}}}, 
         Pattern}]}, {GraphHighlight -> {3, 1, 
         UndirectedEdge[2, 5], 5, 
         UndirectedEdge[2, 4], 4, 
         UndirectedEdge[3, 5], 2, 
         UndirectedEdge[1, 4], 
         UndirectedEdge[1, 3]}, GraphLayout -> "CircularEmbedding"}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$4", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        StyleBox[
         DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
          0.021812234931106983`], 
         Directive[
          Hue[1, 1, 0.7], 
          EdgeForm[{
            Hue[1, 1, 0.7], 
            Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$1"], 
       TagBox[
        StyleBox[
         DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
          0.021812234931106983`], 
         Directive[
          Hue[1, 1, 0.7], 
          EdgeForm[{
            Hue[1, 1, 0.7], 
            Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$2"], 
       TagBox[
        StyleBox[
         DiskBox[{0.5877852522924738, -0.8090169943749481}, 
          0.021812234931106983`], 
         Directive[
          Hue[1, 1, 0.7], 
          EdgeForm[{
            Hue[1, 1, 0.7], 
            Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$3"], 
       TagBox[
        StyleBox[
         DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
          0.021812234931106983`], 
         Directive[
          Hue[1, 1, 0.7], 
          EdgeForm[{
            Hue[1, 1, 0.7], 
            Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$4"], 
       TagBox[
        StyleBox[
         DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
         Directive[
          Hue[1, 1, 0.7], 
          EdgeForm[{
            Hue[1, 1, 0.7], 
            Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18000000000001, 352.82}, {-168.10719999999998`, 
       162.04310466848688`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Adding Vertices and Edges", "Subsection",
 PageBreakWithin->False,
 CellTags->"Section2h"],

Cell[TextData[{
 "The functions for adding vertices and edges are very similar. ",
 StyleBox[ButtonBox["VertexAdd",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexAdd"], "FunctionLink"],
 " accepts a graph and either a vertex or list of vertices to add to the \
graph."
}], "Text",
 PageBreakAbove->False,
 PageBreakWithin->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VertexAdd", "[", 
  RowBox[{
   RowBox[{"CompleteGraph", "[", 
    RowBox[{"5", ",", 
     RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
     RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}], ",", "\"\<a\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, "a"}, {Null, 
       SparseArray[
       Automatic, {6, 6}, 0, {
        1, {{0, 4, 8, 12, 16, 20, 20}, {{2}, {3}, {4}, {5}, {1}, {3}, {4}, {
          5}, {1}, {2}, {4}, {5}, {1}, {2}, {3}, {5}, {1}, {2}, {3}, {4}}}, 
         Pattern}]}, {
      GraphLayout -> "CircularEmbedding", ImagePadding -> 10, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.23195562668532854`, -0.9229386323103799}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5952268906880097, -2.040972621060275}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.770797395272956, -2.040972621060276}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.1340686592756355`, -0.9229386323103819}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.1830121429804816`, -0.2319556266853282}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.23195562668532846`, -2.5048838744309334`}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 350.69289964032333`}, {-208.96489964032594`, 
       192.94303744196327`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox[ButtonBox["EdgeAdd",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeAdd"], "FunctionLink"],
 " acts on a graph and adds an edge or a list of edges. Note that you can use \
rules to describe the edges and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will interpret them as directed or not depending on whether the original \
graph is directed."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EdgeAdd", "[", 
  RowBox[{
   RowBox[{"CycleGraph", "[", "6", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "3"}], ",", 
     RowBox[{"2", "\[Rule]", "4"}], ",", 
     RowBox[{"3", "\[Rule]", "5"}], ",", 
     RowBox[{"4", "\[Rule]", "6"}], ",", 
     RowBox[{"5", "\[Rule]", "1"}], ",", 
     RowBox[{"6", "\[Rule]", "2"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6}, {Null, 
       SparseArray[
       Automatic, {6, 6}, 0, {
        1, {{0, 4, 8, 12, 16, 20, 24}, {{2}, {6}, {3}, {5}, {1}, {3}, {4}, {
          6}, {2}, {4}, {1}, {5}, {3}, {5}, {2}, {6}, {4}, {6}, {3}, {1}, {
          1}, {5}, {4}, {2}}}, Pattern}]}, {
      GraphLayout -> "CircularEmbedding"}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{-0.8660254037844389, 0.5000000000000008}, 
         0.02261146496815286], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
         0.02261146496815286], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{3.8285686989269494`*^-16, -1.}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{0.8660254037844389, -0.5000000000000012}, 
         0.02261146496815286], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{0.8660254037844386, 0.4999999999999993}, 
         0.02261146496815286], "DynamicName", BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{1.8369701987210297`*^-16, 1.}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.180000000000004, 352.82}, {-202.10720000000003`, 
       196.49216210090572`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Edge Contraction", "Subsection",
 CellTags->"Section2i"],

Cell[TextData[{
 "Recall that an edge contraction for an edge ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 " with endpoints ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " consists of deleting the edge, merging ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " into a new vertex ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 ", and preserving all edges (other than ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 ") which had ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " as an endpoint by setting ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " as the new endpoint. As an illustration, consider the following graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exampleContraction", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7"}], "}"}],
     ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", "2"}], ",", 
      RowBox[{"1", "\[Rule]", "3"}], ",", 
      RowBox[{"2", "\[Rule]", "3"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"3", "\[Rule]", "4"}], ",", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Red"}], "}"}]}], "]"}], ",", 
      RowBox[{"4", "\[Rule]", "5"}], ",", 
      RowBox[{"4", "\[Rule]", "7"}], ",", 
      RowBox[{"5", "\[Rule]", "6"}], ",", 
      RowBox[{"6", "\[Rule]", "7"}]}], "}"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "5"}], ",", 
    RowBox[{"VertexCoordinates", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7}, {
      Null, {{1, 2}, {1, 3}, {2, 3}, {3, 4}, {4, 5}, {4, 7}, {5, 6}, {6, 
       7}}}, {EdgeStyle -> {UndirectedEdge[3, 4] -> {{
            Thickness[Large], 
            RGBColor[1, 0, 0]}}}, ImagePadding -> 5, 
       VertexCoordinates -> {{0, 1}, {0, 0}, {1, 0}, {2, 0}, {3, 0}, {3, 1}, {
        2, 1}}, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}], {{
          Thickness[Large], 
          RGBColor[1, 0, 0]}}, StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$4", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$4", Automatic, Center], 
         DynamicLocation["VertexID$7", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$5", Automatic, Center], 
         DynamicLocation["VertexID$6", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$6", Automatic, Center], 
         DynamicLocation["VertexID$7", Automatic, Center]}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{11.000000000000004`, 
       355.73473109407513`}, {-73.01473109407311, 57.14653101154374}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Observe the use of the ",
 StyleBox[ButtonBox["Style",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Style"], "FunctionLink"],
 " wrapper on the edge between vertices 3 and 4 to highlight that edge."
}], "Text"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not include a built-in function for performing an edge contraction, \
so we will create one. Our function will take as arguments a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object and a rule or a directed edge or an undirected edge representing \
the edge to be contracted. Since some of the ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " functions may cause an error if given an undirected graph and a rule, we \
begin the function by ensuring that if the graph is undirected then the edge \
is stored as an ",
 StyleBox[ButtonBox["UndirectedEdge",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/UndirectedEdge"], "FunctionLink"],
 " and a ",
 StyleBox[ButtonBox["DirectedEdge",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdge"], "FunctionLink"],
 " if not."
}], "Text"],

Cell[TextData[{
 "After ensuring the edge is represented properly, we execute a ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop over the vertices ",
 StyleBox["x", "Input"],
 " of the original graph. This loop sets values of an indexed variable ",
 StyleBox["vertLocs", "Input"],
 ", which stores the locations of the vertices from the display of the \
original graph. This will be used later to ensure that the vertex positions \
are preserved in the output. The positions are obtained using the function ",
 StyleBox[ButtonBox["PropertyValue",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PropertyValue"], "FunctionLink"],
 " which takes two arguments: a list consisting of the graph and an object \
(vertex or edge) of the graph, and the name of a property, in this case, ",
 StyleBox[ButtonBox["VertexCoordinates",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexCoordinates"], "FunctionLink"],
 ". Doing this is not necessary for performing the contraction, but then ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " would choose new positions for the vertices in the output graph, which may \
make the connection between the two graphs more difficult to see."
}], "Text"],

Cell["Next, the function deletes the edge being contracted.", "Text"],

Cell[TextData[{
 "We will need to create a new vertex. The function will automatically name \
this new vertex by combining the names of the original two vertices with a \
hyphen, as in 3-4. To do this, we use ",
 StyleBox[ButtonBox["ToString",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ToString"], "FunctionLink"],
 " on each of the original vertex names to ensure that they are string, and \
then combine them with the hyphen using the ",
 StyleBox[ButtonBox["StringJoin",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/StringJoin"], "FunctionLink"],
 " (",
 StyleBox["<>", "Input"],
 ") operator. This vertex is then added to the graph and its position is \
calculated as the average of the positions of the original vertices."
}], "Text"],

Cell[TextData[{
 "Once the new vertex has been established, it needs to be connected to the \
neighbors of the original vertices. To do this, we use ",
 StyleBox[ButtonBox["NeighborhoodGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/NeighborhoodGraph"], "FunctionLink"],
 " applied to the existing graph and the endpoints of the removed edge. The \
result of this function is the graph consisting of those two vertices and all \
of their neighbors. The edges of this graph are exactly the edges that need \
to be modified to create the contraction. Specifically, for each edge in the \
neighborhood graph, we need to replace ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " with the new vertex ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "To this end, we loop over all of the edges in the neighborhood graph, with \
loop variable ",
 StyleBox["modEdge", "Input"],
 ". First, the edge is deleted from the existing graph. Then we modify the \
edge by applying ",
 StyleBox[ButtonBox["ReplaceAll",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ReplaceAll"], "FunctionLink"],
 " (",
 StyleBox["/.", "Input"],
 ") to replace whichever of the contracted vertices are present with the new \
vertex. Provided this edge does not already exist, we add it to the graph."
}], "Text"],

Cell[TextData[{
 "Once the edges have been modified, the two vertices are deleted from the \
graph. And finally, looping over the vertices of the graph, we use ",
 StyleBox[ButtonBox["PropertyValue",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PropertyValue"], "FunctionLink"],
 ", to assign the original positions, which were stored in ",
 StyleBox["vertLocs", "Input"],
 "."
}], "Text"],

Cell["Here is the function.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"contractGraph", "[", 
   RowBox[{"G_Graph", ",", 
    RowBox[{"e", ":", 
     RowBox[{"_Rule", "|", "_DirectedEdge", "|", "_UndirectedEdge"}]}]}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "=", 
       RowBox[{"e", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"v", "=", 
       RowBox[{"e", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", "contractE", ",", "vertLocs", 
      ",", "x", ",", "w", ",", 
      RowBox[{"g", "=", "G"}], ",", "N", ",", "modEdge"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "ensure", " ", "the", " ", "edge", " ", "is", " ", "a", " ", 
      "DirectedEdge", " ", "or", " ", "UndirectedEdge"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"UndirectedGraphQ", "[", "G", "]"}], ",", 
       RowBox[{"contractE", "=", 
        RowBox[{"UndirectedEdge", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}], ",", 
       RowBox[{"contractE", "=", 
        RowBox[{"DirectedEdge", "[", 
         RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"store", " ", "vertex", " ", "locations"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"vertLocs", "[", "x", "]"}], "=", 
        RowBox[{"PropertyValue", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"G", ",", "x"}], "}"}], ",", "VertexCoordinates"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"VertexList", "[", "G", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "delete", " ", "the", " ", "edge", " ", "and", " ", "add", " ", "the", 
       " ", "new", " ", "vertex"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"g", "=", 
      RowBox[{"EdgeDelete", "[", 
       RowBox[{"g", ",", "contractE"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"w", "=", 
      RowBox[{
       RowBox[{"ToString", "[", "u", "]"}], "<>", "\"\<-\>\"", "<>", 
       RowBox[{"ToString", "[", "v", "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"g", "=", 
      RowBox[{"VertexAdd", "[", 
       RowBox[{"g", ",", "w"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vertLocs", "[", "w", "]"}], "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"vertLocs", "[", "u", "]"}], "+", 
         RowBox[{"vertLocs", "[", "v", "]"}]}], ")"}], "/", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"update", " ", "old", " ", "edges"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"N", "=", 
      RowBox[{"NeighborhoodGraph", "[", 
       RowBox[{"g", ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "v"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"g", "=", 
         RowBox[{"EdgeDelete", "[", 
          RowBox[{"g", ",", "modEdge"}], "]"}]}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"modEdge", "=", 
         RowBox[{"modEdge", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"u", "\[Rule]", "w"}], ",", 
            RowBox[{"v", "\[Rule]", "w"}]}], "}"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"EdgeQ", "[", 
            RowBox[{"g", ",", "modEdge"}], "]"}]}], ",", 
          RowBox[{"g", "=", 
           RowBox[{"EdgeAdd", "[", 
            RowBox[{"g", ",", "modEdge"}], "]"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"modEdge", ",", 
         RowBox[{"EdgeList", "[", "N", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "delete", " ", "the", " ", "old", " ", "vertices", " ", "and", " ", 
       "reset", " ", "vertex", " ", "positions"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"g", "=", 
      RowBox[{"VertexDelete", "[", 
       RowBox[{"g", ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", "v"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PropertyValue", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"g", ",", "x"}], "}"}], ",", "VertexCoordinates"}], "]"}], 
        "=", 
        RowBox[{"vertLocs", "[", "x", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"VertexList", "[", "g", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "g"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 InitializationCell->True],

Cell[TextData[{
 "We apply ",
 StyleBox["contractGraph", "Input"],
 " to the example."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"contractGraph", "[", 
  RowBox[{"exampleContraction", ",", 
   RowBox[{"3", "\[Rule]", "4"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 5, 6, 7, "3-4"}, {
      Null, {{3, 4}, {4, 5}, {1, 6}, {1, 2}, {2, 6}, {6, 3}, {6, 5}}}, {
      EdgeStyle -> {UndirectedEdge[3, 4] -> {{
            Thickness[Large], 
            RGBColor[1, 0, 0]}}}, ImagePadding -> 5, 
       VertexCoordinates -> {{0, 1}, {0, 0}, {3, 0}, {3, 1}, {2, 1}, {
          Rational[3, 2], 0}}, 
       VertexLabels -> {"Name", 4 -> None, 3 -> None}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{1.5, 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"3-4\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{11.000000000000004`, 
       355.73473109407513`}, {-73.01473109407266, 57.14653101154374}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Unions and Complements of Graphs", "Subsection",
 CellTags->"Section2j"],

Cell["\<\
Recall that the union of two graphs is the graph obtained by taking the union \
of the sets of vertices and the sets of edges from the two graphs. \
\>", "Text"],

Cell["\<\
As an example, we will \[OpenCurlyDoubleQuote]fill in\[CloseCurlyDoubleQuote] \
a prism graph by computing the union of the prism with the complete graph on \
the vertices in one ring. We begin with the prism we created above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"unionExampleA", "=", "prism"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {
      Null, {{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 1}, {7, 8}, {8, 9}, {
       9, 10}, {10, 11}, {11, 12}, {12, 7}, {1, 7}, {2, 8}, {3, 9}, {4, 10}, {
       5, 11}, {6, 12}}}, {ImagePadding -> 10, VertexLabels -> {"Name"}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.131886240159202, 1.0679997479661056`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1.746253598844666, 0.}, 0.028272915525887662`], 
          "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{0.6304889130415254, 0.025024836593490196`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.9613735416148091}, 0.028272915525887662`], 
          "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.39633201912470273`, 2.005417270737875}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5310211335833706`, 1.962083942725086}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.7301971795384574`, 1.43946750611585}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.334320957296703, 0.3959398859272738}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.198833360397172, 0.4394995286124058}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$9"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5978338406037161, 1.3337455155333127`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$10"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9839991165643827, 2.4015105280929165`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$11"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.1003059044788586`, 2.375684659780954}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$12"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 350.937192973569}, {-159.20919297356883`, 
       142.43025455877185`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We use the complete graph on 6 vertices as the second graph that will form \
part of the union. By default, ",
 StyleBox[ButtonBox["CompleteGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CompleteGraph"], "FunctionLink"],
 " with argument 6 will form the complete graph on the vertices from 1 \
through 6. Suppose instead that we want the complete graph on the vertices \
from 7 through 12. To do this, apply the ",
 StyleBox[ButtonBox["VertexReplace",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexReplace"], "FunctionLink"],
 " function. This function accepts two arguments: a graph and a list of rules \
specifying how to modify the names of the vertices. In this instance, we will \
replace vertex 1 with 7, 2 with 8, and so on, so we need to use the list of \
rules ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "7"}], ",", 
     RowBox[{"2", "\[Rule]", "6"}], ",", "\[Ellipsis]", ",", 
     RowBox[{"6", "\[Rule]", "12"}]}], "}"}], TraditionalForm]]],
 ", which we will create with a ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"unionExampleB", "=", 
  RowBox[{"VertexReplace", "[", 
   RowBox[{
    RowBox[{"CompleteGraph", "[", 
     RowBox[{"6", ",", 
      RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
      RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"i", "\[Rule]", 
       RowBox[{"i", "+", "6"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{7, 8, 9, 10, 11, 12}, {Null, 
       SparseArray[
       Automatic, {6, 6}, 0, {
        1, {{0, 5, 10, 15, 20, 25, 30}, {{2}, {3}, {4}, {5}, {6}, {1}, {3}, {
          4}, {5}, {6}, {1}, {2}, {4}, {5}, {6}, {1}, {2}, {3}, {5}, {6}, {
          1}, {2}, {3}, {4}, {6}, {1}, {2}, {3}, {4}, {5}}}, Pattern}]}, {
      GraphLayout -> "CircularEmbedding", ImagePadding -> 10, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.8660254037844389, 0.5000000000000008}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{3.8285686989269494`*^-16, -1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8660254037844389, -0.5000000000000012}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8660254037844386, 0.4999999999999993}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{1.8369701987210297`*^-16, 1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.800000000000011`, 
       355.690826000719}, {-202.96282600071973`, 186.13742371673524`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that the same effect can be obtained with the function ",
 StyleBox[ButtonBox["IndexGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IndexGraph"], "FunctionLink"],
 ", with first argument a graph and second argument the smallest integer to \
be used (defaulting to 1 if the second argument is omitted). ",
 StyleBox[ButtonBox["VertexReplace",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexReplace"], "FunctionLink"],
 " is the more general function."
}], "Text"],

Cell[TextData[{
 "To obtain the union of the graphs, we apply the ",
 StyleBox[ButtonBox["GraphUnion",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphUnion"], "FunctionLink"],
 " function, which simply takes the two (or more) graphs as arguments, along \
with the usual options."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"unionExample", "=", 
  RowBox[{"GraphUnion", "[", 
   RowBox[{"unionExampleA", ",", "unionExampleB", ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {
      Null, {{1, 2}, {1, 7}, {2, 3}, {2, 8}, {3, 4}, {3, 9}, {4, 5}, {4, 
       10}, {5, 6}, {5, 11}, {6, 1}, {6, 12}, {7, 8}, {7, 9}, {7, 10}, {7, 
       11}, {7, 12}, {8, 9}, {8, 10}, {8, 11}, {8, 12}, {9, 10}, {9, 11}, {9, 
       12}, {10, 11}, {10, 12}, {11, 12}}}, {
      ImagePadding -> 10, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.7071913354253746, 0.0017371171895790294`}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{2.123360656829433, 0.}, 0.029028898903187203`], 
          "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.8328742308413517`, 1.2265585699814128`}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.1249909704264685`, 2.452895534992326}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.7087043053910814, 2.4530810339704474`}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 1.2278301842640489`}, 0.029028898903187203`], 
          "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.1493073953353186`, 0.763001016404376}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.6836991600385602`, 0.7636387931506287}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.952934675305475, 1.2266188040854957`}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$9"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.6840025605623565`, 1.6898280281048312`}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$10"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.1488531370174286`, 1.690607776763056}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$11"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8815955604571679, 1.2262384437093572`}, 
           0.029028898903187203`], "DynamicName", BoxID -> "VertexID$12"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 350.94714896493167`}, {-157.21914896493004`, 
       140.04753853282065`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has rearranged the locations of the vertices. If you prefer the \
three-dimensional appearance of the prism, you can impose those locations as \
shown below. Note how the ",
 StyleBox[ButtonBox["PropertyValue",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PropertyValue"], "FunctionLink"],
 " function is being used to both access the values from ",
 StyleBox["unionExampleA", "Input"],
 " and assign those locations to ",
 StyleBox["unionExample", "Input"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PropertyValue", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"unionExample", ",", "v"}], "}"}], ",", "VertexCoordinates"}], 
     "]"}], "=", 
    RowBox[{"PropertyValue", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"unionExampleA", ",", "v"}], "}"}], ",", "VertexCoordinates"}],
      "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"VertexList", "[", "unionExample", "]"}]}], "}"}]}], 
  "]"}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData["unionExample"], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {
      Null, {{1, 2}, {1, 7}, {2, 3}, {2, 8}, {3, 4}, {3, 9}, {4, 5}, {4, 
       10}, {5, 6}, {5, 11}, {6, 1}, {6, 12}, {7, 8}, {7, 9}, {7, 10}, {7, 
       11}, {7, 12}, {8, 9}, {8, 10}, {8, 11}, {8, 12}, {9, 10}, {9, 11}, {9, 
       12}, {10, 11}, {10, 12}, {11, 12}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{2.131886240159202, 1.0679997479661056`}, {
        1.746253598844666, 0.}, {0.6304889130415254, 0.025024836593490196`}, {
        0., 0.9613735416148091}, {0.39633201912470273`, 2.005417270737875}, {
        1.5310211335833706`, 1.962083942725086}, {2.7301971795384574`, 
        1.43946750611585}, {2.334320957296703, 0.3959398859272738}, {
        1.198833360397172, 0.4394995286124058}, {0.5978338406037161, 
        1.3337455155333127`}, {0.9839991165643827, 2.4015105280929165`}, {
        2.1003059044788586`, 2.375684659780954}}, VertexLabels -> {"Name"}}]],
     Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$11", Automatic, Center]}, {
          DynamicLocation["VertexID$10", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}, {
          DynamicLocation["VertexID$11", Automatic, Center], 
          DynamicLocation["VertexID$12", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.131886240159202, 1.0679997479661056`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1.746253598844666, 0.}, 0.028272915525887662`], 
          "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.6304889130415254, 0.025024836593490196`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.9613735416148091}, 0.028272915525887662`], 
          "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.39633201912470273`, 2.005417270737875}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.5310211335833706`, 1.962083942725086}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.7301971795384574`, 1.43946750611585}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.334320957296703, 0.3959398859272738}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.198833360397172, 0.4394995286124058}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$9"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5978338406037161, 1.3337455155333127`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$10"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9839991165643827, 2.4015105280929165`}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$11"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.1003059044788586`, 2.375684659780954}, 
           0.028272915525887662`], "DynamicName", BoxID -> "VertexID$12"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 350.937192973569}, {-159.20919297357213`, 
       142.43025455877185`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Finally, we consider graph complements, described in Exercise 59 of Section \
10.2. The complement, ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["G", "_"], TraditionalForm]]],
 ", of a graph ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 " is the graph whose vertex set is the same as that of ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 ", but whose edge set is the set of all pairs of ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 " that have no edge between them. In other words, if ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 " has ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices, then the edge set of ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 " is the complement of the edge set of ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 " relative to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "n"], TraditionalForm]]],
 ", the complete graph on ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a function to compute the complement of a graph: ",
 StyleBox[ButtonBox["GraphComplement",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphComplement"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WheelGraph", "[", 
  RowBox[{"8", ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 7, 10, 13, 16, 19, 22, 25, 28}, {{2}, {3}, {4}, {5}, {6}, {
          7}, {8}, {1}, {3}, {8}, {1}, {2}, {4}, {1}, {3}, {5}, {1}, {4}, {
          6}, {1}, {5}, {7}, {1}, {6}, {8}, {1}, {2}, {7}}}, Pattern}]}, {
      GraphLayout -> "StarEmbedding", ImagePadding -> 10, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.02220329551621769], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9749279121818235, -0.22252093395631342`}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.43388373911755757`, -0.9009688679024187}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.43388373911755884`, -0.9009688679024196}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9749279121818237, -0.2225209339563155}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.7818314824680294, 0.6234898018587326}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{-7.044813998280222*^-16, 1.}, 0.02220329551621769], 
          "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.7818314824680302, 0.6234898018587351}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.800000000000018`, 
       350.8427319370911}, {-174.1147319370886, 157.92669462225433`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"complementExample", "=", 
  RowBox[{"GraphComplement", "[", 
   RowBox[{
    RowBox[{"WheelGraph", "[", "8", "]"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "7"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 0, 4, 8, 12, 16, 20, 24, 28}, {{4}, {5}, {6}, {7}, {5}, {6}, {
          7}, {8}, {2}, {6}, {7}, {8}, {2}, {3}, {7}, {8}, {2}, {3}, {4}, {
          8}, {2}, {3}, {4}, {5}, {3}, {4}, {5}, {6}}}, Pattern}]}, {
      ImagePadding -> 7, 
       VertexCoordinates -> {{0.7071067811865475, 0.7071067811865476}, {1., 
        6.123233995736766*^-17}, {0.7071067811865476, -0.7071067811865475}, {
        1.2246467991473532`*^-16, -1.}, {-0.7071067811865475, \
-0.7071067811865477}, {-1., -1.8369701987210297`*^-16}, {-0.7071067811865477, 
        0.7071067811865474}, {-2.4492935982947064`*^-16, 1.}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.7071067811865475, 0.7071067811865476}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 6.123233995736766*^-17}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.7071067811865476, -0.7071067811865475}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{1.2246467991473532`*^-16, -1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.7071067811865475, -0.7071067811865477}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{-1., -1.8369701987210297`*^-16}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.7071067811865477, 0.7071067811865474}, 
           0.02261146496815286], "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          DiskBox[{-2.4492935982947064`*^-16, 1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{12.920000000000002`, 
       353.7115218822708}, {-180.98832188227067`, 164.8032}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->7]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Again, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has rearranged the vertices. We can impose the original locations as \
follows."
}], "Text"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PropertyValue", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"complementExample", ",", "v"}], "}"}], ",", 
      "VertexCoordinates"}], "]"}], "=", 
    RowBox[{"PropertyValue", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"WheelGraph", "[", "8", "]"}], ",", "v"}], "}"}], ",", 
      "VertexCoordinates"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"VertexList", "[", "complementExample", "]"}]}], "}"}]}], 
  "]"}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData["complementExample"], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 0, 4, 8, 12, 16, 20, 24, 28}, {{4}, {5}, {6}, {7}, {5}, {6}, {
          7}, {8}, {2}, {6}, {7}, {8}, {2}, {3}, {7}, {8}, {2}, {3}, {4}, {
          8}, {2}, {3}, {4}, {5}, {3}, {4}, {5}, {6}}}, Pattern}]}, {
      ImagePadding -> 7, 
       VertexCoordinates -> {{0., 
        0.}, {-0.9749279121818235, -0.22252093395631342`}, \
{-0.43388373911755757`, -0.9009688679024187}, {
        0.43388373911755884`, -0.9009688679024196}, {
        0.9749279121818237, -0.2225209339563155}, {0.7818314824680294, 
        0.6234898018587326}, {-7.044813998280222*^-16, 
        1.}, {-0.7818314824680302, 0.6234898018587351}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.02220329551621769], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9749279121818235, -0.22252093395631342`}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.43388373911755757`, -0.9009688679024187}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.43388373911755884`, -0.9009688679024196}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9749279121818237, -0.2225209339563155}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.7818314824680294, 0.6234898018587326}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{-7.044813998280222*^-16, 1.}, 0.02220329551621769], 
          "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.7818314824680302, 0.6234898018587351}, 
           0.02220329551621769], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{12.92000000000004, 
       353.70394885160704`}, {-176.9807488516076, 160.66069511558817`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->7]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["10.3 Representing Graphs and Graph Isomorphism", "Section",
 CellTags->"Section3"],

Cell["\<\
In this section we will see how to represent graphs in terms of adjacency \
matrices, adjacency lists, and incidence matrices. We will then use the \
adjacency matrix representation to help determine whether two graphs are \
isomorphic. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Adjacency Matrices", "Subsection",
 CellTags->"Section3a"],

Cell[TextData[{
 "The adjacency matrix of a graph ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices is the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Times]", "n"}], TraditionalForm]]],
 " matrix whose ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"i", ",", "j"}], ")"}], TraditionalForm]]],
 " entry is 1 if there is an edge from vertex ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 " to vertex ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]]],
 " and 0 if not. You can define a graph by passing an adjacency matrix, \
represented as a list of lists, to the function ",
 StyleBox[ButtonBox["AdjacencyGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AdjacencyGraph"], "FunctionLink"],
 "."
}], "Text"],

Cell["As an example, we reproduce Example 4 from Section 10.3.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"exampleAdjM", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1", ",", "0"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"exampleAdjM", "//", "MatrixForm"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1", "1", "0"},
     {"1", "0", "0", "1"},
     {"1", "0", "0", "1"},
     {"0", "1", "1", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Recall that we must invoke ",
 StyleBox[ButtonBox["MatrixForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MatrixForm"], "FunctionLink"],
 " in an expression separate from the definition of the symbol in order to \
avoid having the ",
 StyleBox[ButtonBox["MatrixForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MatrixForm"], "FunctionLink"],
 " head permanently stored in the symbol."
}], "Text"],

Cell[TextData[{
 "We now invoke the ",
 StyleBox[ButtonBox["AdjacencyGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AdjacencyGraph"], "FunctionLink"],
 " function with this matrix."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdjacencyGraph", "[", "exampleAdjM", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4}, {Null, 
       SparseArray[
       Automatic, {4, 4}, 0, {
        1, {{0, 2, 4, 6, 8}, {{2}, {3}, {1}, {4}, {1}, {4}, {2}, {3}}}, 
         Pattern}]}]], Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{-1., 1.0106430996148606`*^-15}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{6.049014748177263*^-16, -1.}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{1., -1.133107779529596*^-15}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{-7.044813998280222*^-16, 1.}, 0.02261146496815286], 
        "DynamicName", BoxID -> "VertexID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.17999999999998, 
       352.82000000000005`}, {-176.10720000000003`, 170.53279999999995`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "In the textbook, the vertices for this graph were labeled as letters rather \
than numbers. The ",
 StyleBox[ButtonBox["AdjacencyGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AdjacencyGraph"], "FunctionLink"],
 " function accepts a list of names for the vertices as an optional first \
argument. It also accepts the usual graph options."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdjacencyGraph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\""}], 
    "}"}], ",", "exampleAdjM", ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d"}, {Null, 
       SparseArray[
       Automatic, {4, 4}, 0, {
        1, {{0, 2, 4, 6, 8}, {{2}, {3}, {1}, {4}, {1}, {4}, {2}, {3}}}, 
         Pattern}]}, {ImagePadding -> 10, VertexLabels -> {"Name"}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{-1., 1.0106430996148606`*^-15}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{6.049014748177263*^-16, -1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., -1.133107779529596*^-15}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{-7.044813998280222*^-16, 1.}, 0.02261146496815286], 
          "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       349.8501736435237}, {-178.12217364352463`, 161.9279999999999}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell["\<\
Notice that this is the same graph as is produced in the textbook, with the \
exception of the locations of the vertices. \
\>", "Text"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " also provides a function, ",
 StyleBox[ButtonBox["AdjacencyMatrix",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AdjacencyMatrix"], "FunctionLink"],
 ", for computing the adjacency matrix of a graph. The output of this \
function is always a ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 " object, which is more efficient at storing large arrays with many entries \
0. You can display a ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 " with ",
 StyleBox[ButtonBox["MatrixForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MatrixForm"], "FunctionLink"],
 ", as usual, and you can convert it into the usual list of lists \
representation with the function ",
 StyleBox[ButtonBox["Normal",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Normal"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wheelAdjacency", "=", 
  RowBox[{"AdjacencyMatrix", "[", 
   RowBox[{"WheelGraph", "[", "7", "]"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 TagBox[
  RowBox[{"SparseArray", "[", 
   RowBox[{
    InterpretationBox[
     RowBox[{"\<\"<\"\>", "\[InvisibleSpace]", "24", 
      "\[InvisibleSpace]", "\<\">\"\>"}],
     SequenceForm["<", 24, ">"],
     Editable->False], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "7"}], "}"}]}], "]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wheelAdjacency", "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1", "1", "1", "1", "1", "1"},
     {"1", "0", "1", "0", "0", "0", "1"},
     {"1", "1", "0", "1", "0", "0", "0"},
     {"1", "0", "1", "0", "1", "0", "0"},
     {"1", "0", "0", "1", "0", "1", "0"},
     {"1", "0", "0", "0", "1", "0", "1"},
     {"1", "1", "0", "0", "0", "1", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {7, 7}, 0, {
     1, {{0, 6, 9, 12, 15, 18, 21, 24}, {{2}, {3}, {4}, {5}, {6}, {7}, {1}, {
       3}, {7}, {1}, {2}, {4}, {1}, {3}, {5}, {1}, {4}, {6}, {1}, {5}, {7}, {
       1}, {2}, {6}}}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
      1, 1, 1, 1, 1, 1}}]]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wheelAdjacency", "//", "Normal"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "1"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "1", ",", "0", ",", "0"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "1", ",", "0", ",", "1", ",", "0"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "1"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0"}],
     "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Adjacency Lists", "Subsection",
 CellTags->"Section3b"],

Cell["\<\
Recall that a representation of a graph as an adjacency list consists of the \
lists of neighbors of each vertex.\
\>", "Text"],

Cell[TextData[{
 "Above, we saw the function ",
 StyleBox[ButtonBox["AdjacencyList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AdjacencyList"], "FunctionLink"],
 " used to determine the list of vertices adjacent to a given vertex. For \
example, the following determines the vertices adjacent to vertex 2 in the \
wheel graph on 7 vertices."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AdjacencyList", "[", 
  RowBox[{
   RowBox[{"WheelGraph", "[", "7", "]"}], ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "3", ",", "7"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
To obtain the complete adjacency list representation of a graph, it is only a \
matter of looping through the vertices of the graph.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"adjacencyList", "[", "G_Graph", "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"AdjacencyList", "[", 
     RowBox[{"G", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", 
      RowBox[{"VertexList", "[", "G", "]"}]}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"adjacencyList", "[", 
  RowBox[{"WheelGraph", "[", "7", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "5", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "6"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not include a function to create a graph from an adjacency list. \
However, it is not difficult to create a function that transforms an \
adjacency list into a graph object by using the adjacency matrix as an \
intermediate. We will create a function ",
 StyleBox["adjacencyListGraph", "Input"],
 " that accepts as its argument a list of lists. We will require that the \
vertices be represented by positive integers beginning with 1. For example, \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", "4", "}"}]}], "}"}], TraditionalForm]]],
 " will be used to represent the adjacency list for a graph in which vertex 1 \
is incident to vertices 2 and 3; vertex 2 is incident to vertices 1, 3, and \
4; vertex 3 is incident to vertices 1 and 2; and so on."
}], "Text"],

Cell[TextData[{
 "The main work of the function will be to transform the list into a matrix \
with 1s in the locations specified by the adjacency list. The first sublist \
in the adjacency list indicates the positions in the first row of the \
adjacency matrix that should be set to 1. In the example, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], TraditionalForm]]],
 " tells us that the first row should have 1s in the second and third \
columns. The second sublist specifies the second row, and so on."
}], "Text"],

Cell[TextData[{
 "We mentioned above that a ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 " is particularly suitable for matrices with few non-zero entries. To \
further explore this type of object, we will have our ",
 StyleBox["adjacencyListGraph", "Input"],
 " function create a ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 " as part of its operation. There are several different syntax options for \
creating a ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 ", but we will use the most descriptive: a list of rules identifying \
positions with values. For example, to create a ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "\[Times]", "4"}], TraditionalForm]]],
 " matrix is 1s in positions ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", ",", "3"}], ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"2", ",", "4"}], ")"}], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"4", ",", "1"}], ")"}], TraditionalForm]]],
 ", you enter the following."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SparseArray", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"4", ",", "1"}], "}"}], "\[Rule]", "1"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "1", "0"},
     {"0", "0", "0", "1"},
     {"0", "0", "0", "0"},
     {"1", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 2, 3}, {{3}, {4}, {1}}}, {1, 1, 1}}]]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Observe that the first argument is a list of rules with the positions \
within the matrix given as lists on the left hand of each rule, and the value \
that belongs in the position on the right. The second argument to ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 " is a list specifying the dimensions of the matrix. If the second argument \
is omitted, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will attempt to deduce the size of the matrix from the given entries."
}], "Text"],

Cell[TextData[{
 "The ",
 StyleBox["adjacencyListGraph", "Input"],
 " function will begin by determining the dimension of the matrix, which must \
be equal to the length of the adjacency list. The function must then create \
the list of rules from the adjacency list. "
}], "Text"],

Cell[TextData[{
 "Recall that the ",
 StyleBox[ButtonBox["Map",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Map"], "FunctionLink"],
 " function is used to apply a function to every member of a sequence. For \
example, the following can be used to add \"",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 "\" to each element of a list."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#", "+", "x"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "+", "x"}], ",", 
   RowBox[{"2", "+", "x"}], ",", 
   RowBox[{"3", "+", "x"}], ",", 
   RowBox[{"4", "+", "x"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "As you can see above, the function is applied to each element of the list \
with the ",
 StyleBox[ButtonBox["Slot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Slot"], "FunctionLink"],
 " (",
 StyleBox["#", "Input"],
 ") replaced by the elements of the list. There is a related function, ",
 StyleBox[ButtonBox["MapIndexed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MapIndexed"], "FunctionLink"],
 ", whose first argument should be a function on two arguments, which are \
taken as the element of the list together with a specification of the \
location of that element within the list as the second. For example, the \
following applies the function \[OpenCurlyDoubleQuote]f\
\[CloseCurlyDoubleQuote] to a list of letters."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\""}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"\<\"a\"\>", ",", 
     RowBox[{"{", "1", "}"}]}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"\<\"b\"\>", ",", 
     RowBox[{"{", "2", "}"}]}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"\<\"c\"\>", ",", 
     RowBox[{"{", "3", "}"}]}], "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "You see that \[OpenCurlyDoubleQuote]f\[CloseCurlyDoubleQuote] is applied to \
two arguments: the letter from the second argument and a list containing the \
position of the letter in the list of letters. The position is given as a \
list in case of nested structures requiring more complicated position \
specifications. The following makes use of ",
 StyleBox[ButtonBox["MapIndexed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MapIndexed"], "FunctionLink"],
 " to add ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " raised to a power determined by the index of the list element. We use ",
 StyleBox[ButtonBox["First",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/First"], "FunctionLink"],
 " to take the index out of the enclosing list."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"#1", "+", 
     RowBox[{"x", "^", 
      RowBox[{"First", "[", "#2", "]"}]}]}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "3", ",", "11", ",", "4"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"7", "+", "x"}], ",", 
   RowBox[{"3", "+", 
    SuperscriptBox["x", "2"]}], ",", 
   RowBox[{"11", "+", 
    SuperscriptBox["x", "3"]}], ",", 
   RowBox[{"4", "+", 
    SuperscriptBox["x", "4"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "For nested lists, ",
 StyleBox[ButtonBox["MapIndexed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MapIndexed"], "FunctionLink"],
 " requires a third argument specifying the level at which to apply the \
function. For example, the following function applies the function \
\[OpenCurlyDoubleQuote]f\[CloseCurlyDoubleQuote] at the second level."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "5"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"1", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"f", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"f", "[", 
      RowBox[{"4", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}]}], "]"}], ",", 
     RowBox[{"f", "[", 
      RowBox[{"5", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}]}], "]"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Without the level ",
 StyleBox["{2}", "Input"],
 ", which means that the function should be applied only to elements at the \
second level in the nested lists, ",
 StyleBox["f", "Input"],
 " would have been applied only to the two lists ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "5"}], "}"}], TraditionalForm]]],
 " instead of the five numbers 1 through 5. Note that the second arguments \
passed to f are lists consisting of two integers: the first indicating which \
sublist it is and the second indicating the position within the sublist."
}], "Text"],

Cell[TextData[{
 "If ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4", ",", "5"}], "}"}]}], "}"}], TraditionalForm]]],
 " were an adjacency list, the first element from the index information tells \
us which row in the adjacency matrix that sublist refers to. The values in \
the lists tell us which columns in that row should be 1s. The following \
application of ",
 StyleBox[ButtonBox["MapIndexed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MapIndexed"], "FunctionLink"],
 " uses this observation to print out the locations of 1s in the adjacency \
matrix."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MapIndexed", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"First", "[", "#2", "]"}], ",", "#1"}], "}"}], "]"}], "&"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", "2", "}"}]}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "3"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "4"}], "}"}]], "Print"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "5"}], "}"}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "To form a ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 ", we need to create a ",
 StyleBox[ButtonBox["Rule",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rule"], "FunctionLink"],
 " (",
 StyleBox["->", "Input"],
 ") rather than printing the list. And we must apply ",
 StyleBox[ButtonBox["Flatten",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Flatten"], "FunctionLink"],
 " since ",
 StyleBox[ButtonBox["MapIndexed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MapIndexed"], "FunctionLink"],
 " preserves the list structure and we need a simple list of rules."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
  RowBox[{"MapIndexed", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"First", "[", "#2", "]"}], ",", "#1"}], "}"}], "\[Rule]", 
      "1"}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "4", ",", "5"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", "2", "}"}]}], "]"}], "\[IndentingNewLine]", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "5"}], "}"}], "\[Rule]", "1"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We now build ",
 StyleBox["adjacencyListGraph", "Input"],
 ". We also illustrate how to use a ",
 StyleBox[ButtonBox["BlankNullSequence",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/BlankNullSequence"], "FunctionLink"],
 " (",
 StyleBox["___", "Input"],
 "), which matches any, including 0, number of arguments, to pass options \
from this function to ",
 StyleBox[ButtonBox["AdjacencyGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AdjacencyGraph"], "FunctionLink"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"adjacencyListGraph", "[", 
   RowBox[{"L_List", ",", "opts___"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "rules"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"n", "=", 
      RowBox[{"Length", "[", "L", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rules", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"MapIndexed", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Rule", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"First", "[", "#2", "]"}], ",", "#1"}], "}"}], ",", 
            "1"}], "]"}], "&"}], ",", "L", ",", 
         RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"AdjacencyGraph", "[", 
      RowBox[{
       RowBox[{"SparseArray", "[", 
        RowBox[{"rules", ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "n"}], "}"}]}], "]"}], ",", "opts"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True],

Cell["We apply this to an example.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exampleAL", "=", 
  RowBox[{"adjacencyListGraph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "5"}], "}"}], ",", 
      RowBox[{"{", "4", "}"}]}], "}"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "5"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 2, 5, 7, 9, 10}, {{2}, {3}, {1}, {3}, {4}, {1}, {2}, {2}, {
          5}, {4}}}, Pattern}]}, {
      ImagePadding -> 5, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.031216793513870522`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9035675208407604, 0.3783936291918627}, 
           0.031216793513870522`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.0016365078580331538`, 0.7567615788180366}, 
           0.031216793513870522`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.1100767471814814`, 0.3782410387236667}, 
           0.031216793513870522`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{3.1373969617796416`, 0.378122716930539}, 
           0.031216793513870522`], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{10.999999999999998`, 
       355.74702129230405`}, {-58.02702129230496, 41.740047476192224`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Incidence Matrices", "Subsection",
 CellTags->"Section3c"],

Cell[TextData[{
 "The third representation of graphs that we are considering is incidence \
matrices. For a graph ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices and ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 " edges, the associated incidence matrix is the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Times]", "m"}], TraditionalForm]]],
 " matrix whose ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"i", ",", "j"}], ")"}], TraditionalForm]]],
 " entry is 1 if vertex ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 " is an endpoint of edge ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " includes functions for working with incidence matrices. Given an incidence \
matrix ",
 Cell[BoxData[
  FormBox["M", TraditionalForm]]],
 ", the function ",
 StyleBox[ButtonBox["IncidenceGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IncidenceGraph"], "FunctionLink"],
 " will produce the associated graph. As an example, we reverse Example 6 \
from Section 10.3 and use the incidence matrix given in the solution in order \
to reproduce the graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exampleIncidenceM", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1", ",", "1", ",", "0", ",", "1"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "1", ",", "0"}], "}"}]}],
    "}"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "1", ",", "0", ",", "1"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "1", ",", "0"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exampleIncidenceG", "=", 
  RowBox[{"IncidenceGraph", "[", 
   RowBox[{"exampleIncidenceM", ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}], ",", 
    RowBox[{"VertexCoordinates", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.5", ",", "0"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {
      Null, {{1, 4}, {1, 5}, {2, 4}, {2, 5}, {3, 5}, {2, 3}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{0, 1}, {1, 1}, {2, 1}, {0.5, 0}, {1.5, 0}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{0.5, 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{1.5, 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       350.85017364352365`}, {-98.12217364352233, 82.33659545312992}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "For the reverse, the ",
 StyleBox[ButtonBox["IncidenceMatrix",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IncidenceMatrix"], "FunctionLink"],
 " function will produce the incidence matrix for a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object. We apply this function to the previous graph. Again, the output \
from this function is a ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 " object, so we apply ",
 StyleBox[ButtonBox["MatrixForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MatrixForm"], "FunctionLink"],
 " to view it."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"IncidenceMatrix", "[", "exampleIncidenceG", "]"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "0", "0", "0", "0"},
     {"0", "0", "1", "1", "0", "1"},
     {"0", "0", "0", "0", "1", "1"},
     {"1", "0", "1", "0", "0", "0"},
     {"0", "1", "0", "1", "1", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {5, 6}, 0, {
     1, {{0, 2, 5, 7, 9, 12}, {{1}, {2}, {3}, {4}, {6}, {5}, {6}, {1}, {3}, {
       2}, {4}, {5}}}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}]]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "For a directed graph, the ",
 StyleBox[ButtonBox["IncidenceMatrix",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IncidenceMatrix"], "FunctionLink"],
 " function returns a matrix with a 1 in position ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"i", ",", "j"}], ")"}], TraditionalForm]]],
 " indicating that the vertex ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 " is the head of edge ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]]],
 " and an entry of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]]],
 " indicating that the vertex is the tail of the edge."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"directedIncidenceG", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", "2"}], ",", 
      RowBox[{"2", "\[Rule]", "3"}], ",", 
      RowBox[{"3", "\[Rule]", "1"}], ",", 
      RowBox[{"2", "\[Rule]", "4"}], ",", 
      RowBox[{"4", "\[Rule]", "1"}]}], "}"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}], ",", 
    RowBox[{"VertexCoordinates", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4}, {{{1, 2}, {2, 3}, {3, 1}, {2, 4}, {4, 1}}, Null}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{0, 0}, {1, 1}, {0, 1}, {1, 0}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.041582132564841494`], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$1", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$1", Automatic, Center]}]]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.01273], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.01273], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 1.}, 0.01273], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.01273], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.800000000000004`, 
       350.7203297128645}, {-177.9923297128637, 161.928}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"IncidenceMatrix", "[", "directedIncidenceG", "]"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "1"}], "0", "1", "0", "1"},
     {"1", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], "0"},
     {"0", "1", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "1", 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 5}, 0, {
     1, {{0, 3, 6, 8, 10}, {{1}, {3}, {5}, {1}, {2}, {4}, {2}, {3}, {4}, {
       5}}}, {-1, 1, 1, 1, -1, -1, 1, -1, 1, -1}}]]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Isomorphism of Graphs", "Subsection",
 CellTags->"Section3d"],

Cell["\<\
We conclude this section with a brief discussion of isomorphism of graphs and \
graph invariants. Determining whether two graphs are isomorphic is a \
difficult problem. The naive approach (exhaustively checking each possible \
mapping) can require exponential time. \
\>", "Text"],

Cell["\<\
Graph invariants are useful tools for confirming that two graphs are not \
isomorphic. While there is no complete collection of graph invariants that \
will definitively conclude whether two graphs are or are not isomorphic, they \
can, for many pairs of graphs, quickly demonstrate the impossibility of an \
isomorphism. We will create a function that will check some of the basic \
invariants: number of vertices, number of edges, whether the graph is \
directed, and whether it is bipartite. We also introduce another invariant: \
the degree sequence.\
\>", "Text"],

Cell[TextData[{
 "For a graph ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 ", the ",
 StyleBox["degree sequence",
  FontSlant->"Italic"],
 " is the list of the degrees of the vertices of the graph sorted in \
ascending order. The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox[ButtonBox["VertexDegree",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexDegree"], "FunctionLink"],
 " applied to a graph and a vertex returns the degree of the vertex. Applied \
to the graph with no second argument, it produces a list of the degrees of \
the vertices of a graph, listed in order of the vertices. Since this depends \
on the order in which ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " stores the vertices, it is not an invariant. However, applying the ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " function to the result of ",
 StyleBox[ButtonBox["VertexDegree",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexDegree"], "FunctionLink"],
 " returns the degree sequence for the graph, which is an invariant."
}], "Text"],

Cell["\<\
The function defined below checks, one at a time, the invariants we have \
mentioned. If any of the invariants indicate that the graphs are not \
isomorphic, the procedure prints a statement to that effect.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkInvariants", "[", 
   RowBox[{"G1_Graph", ",", "G2_Graph"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"notIsomorphic", "=", "False"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"VertexCount", "[", "G1", "]"}], "\[NotEqual]", 
        RowBox[{"VertexCount", "[", "G2", "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"notIsomorphic", "=", "True"}], ";", "\[IndentingNewLine]", 
        RowBox[{
        "Print", "[", "\"\<Different numbers of vertices.\>\"", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"EdgeCount", "[", "G1", "]"}], "\[NotEqual]", 
          RowBox[{"EdgeCount", "[", "G2", "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"notIsomorphic", "=", "True"}], ";", "\[IndentingNewLine]", 
          
          RowBox[{
          "Print", "[", "\"\<Different numbers of edges.\>\"", "]"}]}]}], 
        "\[IndentingNewLine]", "]"}], "'"}], "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"Equivalent", "[", 
          RowBox[{
           RowBox[{"DirectedGraphQ", "[", "G1", "]"}], ",", 
           RowBox[{"DirectedGraphQ", "[", "G2", "]"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"notIsomorphic", "=", "True"}], ";", "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", "\"\<One is directed, one is undirected.\>\"", 
          "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"Equivalent", "[", 
         RowBox[{
          RowBox[{"BipartiteGraphQ", "[", "G1", "]"}], ",", 
          RowBox[{"BipartiteGraphQ", "[", "G2", "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"notIsomorphic", "=", "True"}], ";", "\[IndentingNewLine]", 
        RowBox[{
        "Print", "[", "\"\<One is bipartite, one is not.\>\"", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sort", "[", 
         RowBox[{"VertexDegree", "[", "G1", "]"}], "]"}], "\[NotEqual]", 
        RowBox[{"Sort", "[", 
         RowBox[{"VertexDegree", "[", "G2", "]"}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"notIsomorphic", "=", "True"}], ";", "\[IndentingNewLine]", 
        RowBox[{
        "Print", "[", "\"\<Degree sequences do not match.\>\"", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{"notIsomorphic", ",", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "\"\<The graphs are not isomorphic.\>\"", "]"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "\"\<The graphs MAY be isomorphic.\>\"", "]"}]}],
       "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"checkInvariants", "[", 
  RowBox[{"directedIncidenceG", ",", "exampleIncidenceG"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Different numbers of vertices.\"\>"], "Print"],

Cell[BoxData["\<\"Different numbers of edges.\"\>"], "Print"],

Cell[BoxData["\<\"One is directed, one is undirected.\"\>"], "Print"],

Cell[BoxData["\<\"Degree sequences do not match.\"\>"], "Print"],

Cell[BoxData["\<\"The graphs are not isomorphic.\"\>"], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"checkInvariants", "[", 
  RowBox[{
   RowBox[{"CompleteGraph", "[", "3", "]"}], ",", 
   RowBox[{"CycleGraph", "[", "3", "]"}]}], "]"}]], "Input"],

Cell[BoxData["\<\"The graphs MAY be isomorphic.\"\>"], "Print"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides a function, ",
 StyleBox[ButtonBox["IsomorphicGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsomorphicGraphQ"], "FunctionLink"],
 ", for definitively determining whether or not two graphs are isomorphic. \
This function applies to any ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object. The ",
 StyleBox[ButtonBox["IsomorphicGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsomorphicGraphQ"], "FunctionLink"],
 " function accepts two graphs as its arguments. It returns ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 " if the graphs are isomorphic."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IsomorphicGraphQ", "[", 
  RowBox[{
   RowBox[{"CompleteGraph", "[", "3", "]"}], ",", 
   RowBox[{"CycleGraph", "[", "3", "]"}]}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["FindGraphIsomorphism",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindGraphIsomorphism"], "FunctionLink"],
 " function can be used to determine an explicit isomorphism for a pair of \
graphs that are in fact isomorphic. Like ",
 StyleBox[ButtonBox["IsomorphicGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsomorphicGraphQ"], "FunctionLink"],
 ", the only arguments are the two graphs. If the two graphs are in fact \
isomorphic, the output is a list of rules of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"v", "\[Rule]", "w"}], TraditionalForm]]],
 " indicating that vertex ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " in the first graph is mapped to vertex ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " in the second graph. If the graphs are not isomorphic, ",
 StyleBox[ButtonBox["IsomorphicGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsomorphicGraphQ"], "FunctionLink"],
 " returns an empty list."
}], "Text"],

Cell["\<\
We illustrate by reproducing the graphs in Figure 12 of Section 10.3 of the \
textbook. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figure12G", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["u", "1"], ",", 
      SubscriptBox["u", "2"], ",", 
      SubscriptBox["u", "3"], ",", 
      SubscriptBox["u", "4"], ",", 
      SubscriptBox["u", "5"], ",", 
      SubscriptBox["u", "6"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["u", "1"], "\[Rule]", 
       SubscriptBox["u", "2"]}], ",", 
      RowBox[{
       SubscriptBox["u", "1"], "\[Rule]", 
       SubscriptBox["u", "4"]}], ",", 
      RowBox[{
       SubscriptBox["u", "2"], "\[Rule]", 
       SubscriptBox["u", "3"]}], ",", 
      RowBox[{
       SubscriptBox["u", "2"], "\[Rule]", 
       SubscriptBox["u", "6"]}], ",", 
      RowBox[{
       SubscriptBox["u", "3"], "\[Rule]", 
       SubscriptBox["u", "4"]}], ",", 
      RowBox[{
       SubscriptBox["u", "4"], "\[Rule]", 
       SubscriptBox["u", "5"]}], ",", 
      RowBox[{
       SubscriptBox["u", "5"], "\[Rule]", 
       SubscriptBox["u", "6"]}]}], "}"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}], ",", 
    RowBox[{"VertexCoordinates", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
       Subscript[$CellContext`u, 1], 
       Subscript[$CellContext`u, 2], 
       Subscript[$CellContext`u, 3], 
       Subscript[$CellContext`u, 4], 
       Subscript[$CellContext`u, 5], 
       Subscript[$CellContext`u, 6]}, {
      Null, {{1, 2}, {1, 4}, {2, 3}, {2, 6}, {3, 4}, {4, 5}, {5, 6}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{0, 2}, {3, 2}, {3, 0}, {0, 0}, {1, 1}, {2, 1}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 2.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox[
           SubscriptBox["u", "1"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 2.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox[
           SubscriptBox["u", "2"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox[
           SubscriptBox["u", "3"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox[
           SubscriptBox["u", "4"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox[
           SubscriptBox["u", "5"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox[
           SubscriptBox["u", "6"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       356.96251325656397`}, {-127.23451325656283`, 108.27802934846407`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"figure12H", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["v", "1"], ",", 
      SubscriptBox["v", "2"], ",", 
      SubscriptBox["v", "3"], ",", 
      SubscriptBox["v", "4"], ",", 
      SubscriptBox["v", "5"], ",", 
      SubscriptBox["v", "6"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["v", "1"], "\[Rule]", 
       SubscriptBox["v", "2"]}], ",", 
      RowBox[{
       SubscriptBox["v", "1"], "\[Rule]", 
       SubscriptBox["v", "5"]}], ",", 
      RowBox[{
       SubscriptBox["v", "2"], "\[Rule]", 
       SubscriptBox["v", "3"]}], ",", 
      RowBox[{
       SubscriptBox["v", "3"], "\[Rule]", 
       SubscriptBox["v", "4"]}], ",", 
      RowBox[{
       SubscriptBox["v", "3"], "\[Rule]", 
       SubscriptBox["v", "6"]}], ",", 
      RowBox[{
       SubscriptBox["v", "4"], "\[Rule]", 
       SubscriptBox["v", "5"]}], ",", 
      RowBox[{
       SubscriptBox["v", "5"], "\[Rule]", 
       SubscriptBox["v", "6"]}]}], "}"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}], ",", 
    RowBox[{"VertexCoordinates", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1.3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
       Subscript[$CellContext`v, 1], 
       Subscript[$CellContext`v, 2], 
       Subscript[$CellContext`v, 3], 
       Subscript[$CellContext`v, 4], 
       Subscript[$CellContext`v, 5], 
       Subscript[$CellContext`v, 6]}, {
      Null, {{1, 2}, {1, 5}, {2, 3}, {3, 4}, {3, 6}, {4, 5}, {5, 6}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{0, 2}, {1, 1.3}, {3, 2}, {3, 0}, {0, 0}, {2, 
         1}}, VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 2.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox[
           SubscriptBox["v", "1"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.3}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox[
           SubscriptBox["v", "2"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 2.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox[
           SubscriptBox["v", "3"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox[
           SubscriptBox["v", "4"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox[
           SubscriptBox["v", "5"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox[
           SubscriptBox["v", "6"], TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       355.96251325656397`}, {-127.23451325656434`, 108.2780293484641}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Applying ",
 StyleBox[ButtonBox["IsomorphicGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsomorphicGraphQ"], "FunctionLink"],
 " confirms that the graphs are isomorphic."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IsomorphicGraphQ", "[", 
  RowBox[{"figure12G", ",", "figure12H"}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox[ButtonBox["FindGraphIsomorphism",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindGraphIsomorphism"], "FunctionLink"],
 " determines the isomorphism."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindGraphIsomorphism", "[", 
  RowBox[{"figure12G", ",", "figure12H"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["u", "1"], "\[Rule]", 
    SubscriptBox["v", "4"]}], ",", 
   RowBox[{
    SubscriptBox["u", "2"], "\[Rule]", 
    SubscriptBox["v", "3"]}], ",", 
   RowBox[{
    SubscriptBox["u", "3"], "\[Rule]", 
    SubscriptBox["v", "6"]}], ",", 
   RowBox[{
    SubscriptBox["u", "4"], "\[Rule]", 
    SubscriptBox["v", "5"]}], ",", 
   RowBox[{
    SubscriptBox["u", "5"], "\[Rule]", 
    SubscriptBox["v", "1"]}], ",", 
   RowBox[{
    SubscriptBox["u", "6"], "\[Rule]", 
    SubscriptBox["v", "2"]}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["10.4 Connectivity", "Section",
 CellTags->"Section4"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides a number of functions related to connectivity of graphs."
}], "Text"],

Cell[TextData[{
 "The first such function that we consider is ",
 StyleBox[ButtonBox["ConnectedGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ConnectedGraphQ"], "FunctionLink"],
 ". This function takes one argument, the name of the graph, and returns true \
or false. As an example, consider the complete bipartite graph ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    RowBox[{"2", ",", "3"}]], TraditionalForm]]],
 " and its complement."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompleteGraph", "[", 
  RowBox[{"{", 
   RowBox[{"2", ",", "3"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 3, 6, 8, 10, 12}, {{3}, {4}, {5}, {3}, {4}, {5}, {1}, {2}, {
          1}, {2}, {1}, {2}}}, Pattern}]}, {
      GraphLayout -> {"MultipartiteLayout", "VertexPartition" -> {2, 3}}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0., -0.17950849718747378`}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$1"], 
       TagBox[
        DiskBox[{0., 0.17950849718747378`}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$2"], 
       TagBox[
        DiskBox[{1., -0.35901699437494755`}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$3"], 
       TagBox[
        DiskBox[{1., 0.}, 0.01273], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{1., 0.35901699437494755`}, 0.01273], "DynamicName", BoxID -> 
        "VertexID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.180000000000001, 
       352.8200000000001}, {-129.10720000000003`, 122.76872717684151`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConnectedGraphQ", "[", 
  RowBox[{"CompleteGraph", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphComplement", "[", 
  RowBox[{"CompleteGraph", "[", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 1, 2, 4, 6, 8}, {{2}, {1}, {4}, {5}, {3}, {5}, {3}, {4}}}, 
         Pattern}]}, {
      VertexCoordinates -> {{0.9510565162951535, 0.30901699437494745`}, {
        0.5877852522924732, -0.8090169943749473}, {-0.587785252292473, \
-0.8090169943749476}, {-0.9510565162951536, 
        0.30901699437494723`}, {-2.4492935982947064`*^-16, 1.}}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0.9510565162951535, 0.30901699437494745`}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0.5877852522924732, -0.8090169943749473}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{-0.587785252292473, -0.8090169943749476}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{-0.9510565162951536, 0.30901699437494723`}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{-2.4492935982947064`*^-16, 1.}, 0.021812234931106983`], 
        "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.179999999999982, 352.82}, {-168.10719999999998`, 
       162.04310466848676`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConnectedGraphQ", "[", 
  RowBox[{"GraphComplement", "[", 
   RowBox[{"CompleteGraph", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}], "]"}]], "Input"],

Cell[BoxData["False"], "Output"]
}, Open  ]],

Cell[TextData[{
 "When used with a directed graph, ",
 StyleBox[ButtonBox["ConnectedGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ConnectedGraphQ"], "FunctionLink"],
 " returns ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 " if the directed graph is strongly connected."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"stronglyConnectedEx", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"2", "\[Rule]", "3"}], ",", 
     RowBox[{"3", "\[Rule]", "4"}], ",", 
     RowBox[{"4", "\[Rule]", "1"}], ",", 
     RowBox[{"1", "\[Rule]", "5"}], ",", 
     RowBox[{"5", "\[Rule]", "2"}], ",", 
     RowBox[{"3", "\[Rule]", "5"}], ",", 
     RowBox[{"5", "\[Rule]", "4"}]}], "}"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 
      5}, {{{1, 2}, {2, 3}, {3, 4}, {4, 1}, {1, 5}, {5, 2}, {3, 5}, {5, 4}}, 
       Null}]], Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Arrowheads[0.04005097251311321], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$1", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}]]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0., 1.1537108639737284`}, 0.015417340259311824`], 
        "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0.004916287076213055, 0.}, 0.015417340259311824`], 
        "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{1.1607554929704147`, 0.0027887853451148414`}, 
         0.015417340259311824`], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{1.154988119841705, 1.1570175257891293`}, 
         0.015417340259311824`], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{0.5792897237044975, 0.5778516807252814}, 
         0.015417340259311824`], "DynamicName", BoxID -> 
        "VertexID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.1800000000000015`, 352.82}, {-175.1072, 
       170.4516791263811}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Applying ",
 StyleBox[ButtonBox["ConnectedGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ConnectedGraphQ"], "FunctionLink"],
 " reveals that the above graph is connected."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConnectedGraphQ", "[", "stronglyConnectedEx", "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The following example, while weakly connected, is not strongly connected \
and thus ",
 StyleBox[ButtonBox["ConnectedGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ConnectedGraphQ"], "FunctionLink"],
 " will return ",
 StyleBox[ButtonBox["False",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/False"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"weaklyConnectedEx", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", "\[Rule]", "2"}], ",", 
     RowBox[{"2", "\[Rule]", "1"}], ",", 
     RowBox[{"1", "\[Rule]", "3"}], ",", 
     RowBox[{"3", "\[Rule]", "4"}], ",", 
     RowBox[{"4", "\[Rule]", "5"}], ",", 
     RowBox[{"6", "\[Rule]", "8"}], ",", 
     RowBox[{"8", "\[Rule]", "9"}], ",", 
     RowBox[{"9", "\[Rule]", "7"}], ",", 
     RowBox[{"7", "\[Rule]", "6"}], ",", 
     RowBox[{"6", "\[Rule]", "5"}]}], "}"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{4, 2, 1, 3, 5, 6, 8, 9, 
      7}, {{{1, 2}, {2, 3}, {3, 4}, {4, 1}, {1, 5}, {6, 7}, {7, 8}, {8, 9}, {
       9, 6}, {6, 5}}, Null}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.02141326564986938], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$1", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}]]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{1.6267075319767295`, 0.3921723219111086}, 
         0.047727837353446295`], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0.7069903983693449, 0.7843695287371116}, 
         0.047727837353446295`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0., 0.3926757989121187}, 0.047727837353446295`], 
        "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{0.7072390316371968, 0.}, 0.047727837353446295`], 
        "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{2.928118570265649, 0.3921468659152118}, 
         0.047727837353446295`], "DynamicName", BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{4.229319840743651, 0.3923558385375609}, 
         0.047727837353446295`], "DynamicName", BoxID -> "VertexID$6"], 
       TagBox[
        DiskBox[{5.148893514966267, 0.7850029976131969}, 
         0.047727837353446295`], "DynamicName", BoxID -> "VertexID$7"], 
       TagBox[
        DiskBox[{5.855663518252539, 0.3921823793461117}, 
         0.047727837353446295`], "DynamicName", BoxID -> "VertexID$8"], 
       TagBox[
        DiskBox[{5.149307991705942, 0.000026629052002513642`}, 
         0.047727837353446295`], "DynamicName", BoxID -> 
        "VertexID$9"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.180000000000001, 
       352.81999999999994`}, {-29.107200000000013`, 23.881742918062663`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConnectedGraphQ", "[", "weaklyConnectedEx", "]"}]], "Input"],

Cell[BoxData["False"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["WeaklyConnectedGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WeaklyConnectedGraphQ"], "FunctionLink"],
 " function will determine whether a directed graph is weakly connected. A \
graph is weakly connected if it is connected as an undirected graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeaklyConnectedGraphQ", "[", "weaklyConnectedEx", "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " also has functions to extract the connected components of a graph that is \
not connected. The ",
 StyleBox[ButtonBox["ConnectedComponents",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ConnectedComponents"], "FunctionLink"],
 " function takes a graph as input and returns a list of lists of vertices. \
For directed graphs, ",
 StyleBox[ButtonBox["ConnectedComponents",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ConnectedComponents"], "FunctionLink"],
 " is used to determine the strongly connected components of the graph. "
}], "Text"],

Cell[TextData[{
 "As an example, consider the complement of the graph ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    RowBox[{"2", ",", "3"}]], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphComplement", "[", 
  RowBox[{
   RowBox[{"CompleteGraph", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "]"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 1, 2, 4, 6, 8}, {{2}, {1}, {4}, {5}, {3}, {5}, {3}, {4}}}, 
         Pattern}]}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{0.9510565162951535, 0.30901699437494745`}, {
        0.5877852522924732, -0.8090169943749473}, {-0.587785252292473, \
-0.8090169943749476}, {-0.9510565162951536, 
        0.30901699437494723`}, {-2.4492935982947064`*^-16, 1.}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9510565162951535, 0.30901699437494745`}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5877852522924732, -0.8090169943749473}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.587785252292473, -0.8090169943749476}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9510565162951536, 0.30901699437494723`}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{-2.4492935982947064`*^-16, 1.}, 0.021812234931106983`], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999994`, 
       350.83540146772174`}, {-170.10740146772284`, 154.31101834898473`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConnectedComponents", "[", 
  RowBox[{"GraphComplement", "[", 
   RowBox[{"CompleteGraph", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "This output indicates that the complement of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    RowBox[{"2", ",", "3"}]], TraditionalForm]]],
 " has two connected components, one with vertex set ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], TraditionalForm]]],
 " and the other with vertex set ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "5"}], "}"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "For directed graphs, ",
 StyleBox[ButtonBox["ConnectedComponents",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ConnectedComponents"], "FunctionLink"],
 " will produce the strongly connected components. The ",
 StyleBox[ButtonBox["WeaklyConnectedComponents",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WeaklyConnectedComponents"], "FunctionLink"],
 " function will output the weakly connected components."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConnectedComponents", "[", "weaklyConnectedEx", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "5", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2", ",", "1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "8", ",", "9", ",", "7"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeaklyConnectedComponents", "[", "weaklyConnectedEx", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
   "4", ",", "2", ",", "1", ",", "3", ",", "5", ",", "6", ",", "8", ",", "9", 
    ",", "7"}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coloring the Components", "Subsection",
 CellTags->"Section4a"],

Cell["\<\
Now we present a function that will color code the connected components in a \
graph. (This function will color up to 5 components before repeating colors.) \
\>", "Text"],

Cell[TextData[{
 "Note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " understands the symbols ",
 StyleBox[ButtonBox["Red",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Red"], "FunctionLink"],
 ", ",
 StyleBox[ButtonBox["Green",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Green"], "FunctionLink"],
 ", ",
 StyleBox[ButtonBox["Blue",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Blue"], "FunctionLink"],
 ", ",
 StyleBox[ButtonBox["Brown",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Brown"], "FunctionLink"],
 ", and ",
 StyleBox[ButtonBox["Gray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Gray"], "FunctionLink"],
 " as ",
 Cell[BoxData[
  FormBox[
   ButtonBox["Colors",
    BaseStyle->"Link",
    ButtonData->"paclet:guide/Colors"], TraditionalForm]]],
 ". Also note the use of ",
 StyleBox[ButtonBox["PropertyValue",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PropertyValue"], "FunctionLink"],
 " to set the ",
 StyleBox[ButtonBox["VertexStyle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexStyle"], "FunctionLink"],
 " property. We first saw ",
 StyleBox[ButtonBox["PropertyValue",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PropertyValue"], "FunctionLink"],
 " in the subsection on edge contraction in Section 10.2 of this manual. \
Finally, note the use of ",
 StyleBox[ButtonBox["Mod",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Mod"], "FunctionLink"],
 " with third argument 1, which causes the result of ",
 StyleBox[ButtonBox["Mod",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Mod"], "FunctionLink"],
 " to have minimum value 1. This allows us to cycle through the list of \
colors."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"highlightComponents", "[", "G_Graph", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"colorList", "=", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Green", ",", "Blue", ",", "Brown", ",", "Gray"}],
         "}"}]}], ",", "components", ",", "c", ",", "i", ",", "v", ",", 
      RowBox[{"H", "=", "G"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"components", "=", 
      RowBox[{"ConnectedComponents", "[", "G", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"c", "=", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", 
        RowBox[{"Length", "[", "components", "]"}]}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"c", "=", 
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"c", "+", "1"}], ",", "5", ",", "1"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"PropertyValue", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"H", ",", "v"}], "}"}], ",", "VertexStyle"}], "]"}], 
           "=", 
           RowBox[{"colorList", "[", 
            RowBox[{"[", "c", "]"}], "]"}]}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"v", ",", 
            RowBox[{"components", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "}"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", "H"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True],

Cell["We apply this function to the weakly connected graph above.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"highlightComponents", "[", "weaklyConnectedEx", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{4, 2, 1, 3, 5, 6, 8, 9, 
      7}, {{{1, 2}, {2, 3}, {3, 4}, {4, 1}, {1, 5}, {6, 7}, {7, 8}, {8, 9}, {
       9, 6}, {6, 5}}, Null}, {
      VertexStyle -> {
        2 -> RGBColor[0, 1, 0], 1 -> RGBColor[0, 1, 0], 8 -> 
         RGBColor[0, 0, 1], 7 -> RGBColor[0, 0, 1], 5 -> RGBColor[1, 0, 0], 6 -> 
         RGBColor[0, 0, 1], 4 -> RGBColor[0, 1, 0], 9 -> RGBColor[0, 0, 1], 3 -> 
         RGBColor[0, 1, 0]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.02141326564986938], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$1", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}]], 
       ArrowBox[
        LineBox[{
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}]]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        StyleBox[
         DiskBox[{1.6267075319767295`, 0.3921723219111086}, 
          0.047727837353446295`], 
         RGBColor[0, 1, 0], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$1"], 
       TagBox[
        StyleBox[
         DiskBox[{0.7069903983693449, 0.7843695287371116}, 
          0.047727837353446295`], 
         RGBColor[0, 1, 0], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$2"], 
       TagBox[
        StyleBox[
         DiskBox[{0., 0.3926757989121187}, 0.047727837353446295`], 
         RGBColor[0, 1, 0], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$3"], 
       TagBox[
        StyleBox[
         DiskBox[{0.7072390316371968, 0.}, 0.047727837353446295`], 
         RGBColor[0, 1, 0], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$4"], 
       TagBox[
        StyleBox[
         DiskBox[{2.928118570265649, 0.3921468659152118}, 
          0.047727837353446295`], 
         RGBColor[1, 0, 0], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$5"], 
       TagBox[
        StyleBox[
         DiskBox[{4.229319840743651, 0.3923558385375609}, 
          0.047727837353446295`], 
         RGBColor[0, 0, 1], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$6"], 
       TagBox[
        StyleBox[
         DiskBox[{5.148893514966267, 0.7850029976131969}, 
          0.047727837353446295`], 
         RGBColor[0, 0, 1], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$7"], 
       TagBox[
        StyleBox[
         DiskBox[{5.855663518252539, 0.3921823793461117}, 
          0.047727837353446295`], 
         RGBColor[0, 0, 1], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$8"], 
       TagBox[
        StyleBox[
         DiskBox[{5.149307991705942, 0.000026629052002513642`}, 
          0.047727837353446295`], 
         RGBColor[0, 0, 1], StripOnInput -> False], "DynamicName", BoxID -> 
        "VertexID$9"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.180000000000001, 
       352.81999999999994`}, {-29.107200000000013`, 23.881742918062663`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Counting Paths Between Vertices", "Subsection",
 CellTags->"Section4b"],

Cell[TextData[{
 "The last topic that we consider in this section is determining the number \
of paths between two vertices of a given length. As described in the \
textbook, if ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]]],
 " is the adjacency matrix for a graph (which may be undirected or directed \
and may include loops and multiple edges), then the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"i", ",", "j"}], ")"}], TraditionalForm]]],
 " entry of the matrix ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "r"], TraditionalForm]]],
 " is the number of paths of length ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]]],
 " from vertex ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 " to vertex ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "As an example, consider the ",
 StyleBox["stronglyConnectedEx", "Input"],
 " graph from above. We can obtain its adjacency matrix by applying the ",
 StyleBox[ButtonBox["AdjacencyMatrix",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AdjacencyMatrix"], "FunctionLink"],
 " function to the name of the graph. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"aMatrix", "=", 
   RowBox[{"AdjacencyMatrix", "[", "stronglyConnectedEx", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"aMatrix", "//", "MatrixForm"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1", "0", "0", "1"},
     {"0", "0", "1", "0", "0"},
     {"0", "0", "0", "1", "1"},
     {"1", "0", "0", "0", "0"},
     {"0", "1", "0", "1", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {5, 5}, 0, {
     1, {{0, 2, 3, 5, 6, 8}, {{2}, {5}, {3}, {4}, {5}, {1}, {2}, {4}}}, {1, 1,
       1, 1, 1, 1, 1, 1}}]]]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "You could use ",
 StyleBox[ButtonBox["Normal",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Normal"], "FunctionLink"],
 " to transform the ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 " object into a usual list of lists representation of the matrix. However, \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can compute more efficiently with the ",
 StyleBox[ButtonBox["SparseArray",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SparseArray"], "FunctionLink"],
 "."
}], "Text"],

Cell["Next, compute some powers of the adjacency matrix.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"MatrixForm", "[", 
    RowBox[{"MatrixPower", "[", 
     RowBox[{"aMatrix", ",", "i"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "2", ",", "7"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0", "1", "1", "1", "0"},
       {"0", "0", "0", "1", "1"},
       {"1", "1", "0", "1", "0"},
       {"0", "1", "0", "0", "1"},
       {"1", "0", "1", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {5, 5}, 0, {
       1, {{0, 3, 5, 8, 10, 12}, {{3}, {2}, {4}, {4}, {5}, {1}, {2}, {4}, {
         2}, {5}, {3}, {1}}}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}]]]], ",", 
   
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", "1", "1", "1"},
       {"1", "1", "0", "1", "0"},
       {"1", "1", "1", "0", "1"},
       {"0", "1", "1", "1", "0"},
       {"0", "1", "0", "1", "2"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {5, 5}, 0, {
       1, {{0, 4, 7, 11, 14, 17}, {{4}, {5}, {3}, {1}, {1}, {2}, {4}, {2}, {
         5}, {3}, {1}, {3}, {2}, {4}, {4}, {5}, {2}}}, {1, 1, 1, 1, 1, 1, 1, 
        1, 1, 1, 1, 1, 1, 1, 1, 2, 1}}]]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "2", "0", "2", "2"},
       {"1", "1", "1", "0", "1"},
       {"0", "2", "1", "2", "2"},
       {"1", "0", "1", "1", "1"},
       {"1", "2", "1", "2", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {5, 5}, 0, {
       1, {{0, 4, 8, 12, 16, 20}, {{1}, {2}, {4}, {5}, {2}, {5}, {3}, {1}, {
         3}, {2}, {4}, {5}, {4}, {5}, {3}, {1}, {1}, {2}, {4}, {3}}}, {1, 2, 
        2, 2, 1, 1, 1, 1, 1, 2, 2, 2, 1, 1, 1, 1, 1, 2, 2, 1}}]]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"2", "3", "2", "2", "1"},
       {"0", "2", "1", "2", "2"},
       {"2", "2", "2", "3", "1"},
       {"1", "2", "0", "2", "2"},
       {"2", "1", "2", "1", "2"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {5, 5}, 0, {
       1, {{0, 5, 9, 14, 18, 23}, {{2}, {5}, {3}, {1}, {4}, {3}, {2}, {4}, {
         5}, {4}, {5}, {3}, {1}, {2}, {1}, {2}, {4}, {5}, {2}, {5}, {3}, {
         1}, {4}}}, {3, 1, 2, 2, 2, 1, 2, 2, 2, 3, 1, 2, 2, 2, 1, 2, 2, 2, 1, 
        2, 2, 2, 1}}]]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"2", "3", "3", "3", "4"},
       {"2", "2", "2", "3", "1"},
       {"3", "3", "2", "3", "4"},
       {"2", "3", "2", "2", "1"},
       {"1", "4", "1", "4", "4"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {5, 5}, 0, {
       1, {{0, 5, 10, 15, 20, 25}, {{3}, {2}, {4}, {5}, {1}, {4}, {5}, {3}, {
         1}, {2}, {1}, {2}, {4}, {5}, {3}, {2}, {5}, {3}, {1}, {4}, {3}, {
         2}, {4}, {5}, {1}}}, {3, 3, 3, 4, 2, 3, 1, 2, 2, 2, 3, 3, 3, 4, 2, 3,
         1, 2, 2, 2, 1, 4, 4, 4, 1}}]]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"3", "6", "3", "7", "5"},
       {"3", "3", "2", "3", "4"},
       {"3", "7", "3", "6", "5"},
       {"2", "3", "3", "3", "4"},
       {"4", "5", "4", "5", "2"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {5, 5}, 0, {
       1, {{0, 5, 10, 15, 20, 25}, {{4}, {5}, {3}, {1}, {2}, {1}, {2}, {4}, {
         5}, {3}, {2}, {5}, {3}, {1}, {4}, {3}, {2}, {4}, {5}, {1}, {4}, {
         5}, {3}, {1}, {2}}}, {7, 5, 3, 3, 6, 3, 3, 3, 4, 2, 7, 5, 3, 3, 6, 3,
         3, 3, 4, 2, 5, 2, 4, 4, 5}}]]]]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that the ",
 StyleBox[ButtonBox["MatrixPower",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/MatrixPower"], "FunctionLink"],
 " function is used to compute powers of matrices. Using the ",
 StyleBox[ButtonBox["Power",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Power"], "FunctionLink"],
 " (",
 StyleBox["^", "Input"],
 ") operator on a matrix computes element-wise."
}], "Text"],

Cell[TextData[{
 "We see that there are 4 paths of length 6 from vertex 3 to vertex 5, since \
the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"3", ",", "5"}], ")"}], TraditionalForm]]],
 " entry in the 6th power of the adjacency matrix is 4. We also see that \
there are cycles of length 3 for every vertex and there are no cycles of \
length less than 3. Finally, we know that the shortest path from vertex 2 to \
vertex 1 is of length 3, since the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"2", ",", "1"}], ")"}], TraditionalForm]]],
 " entry is 0 for the first and second powers of the matrix."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["10.5 Euler and Hamilton Paths", "Section",
 CellTags->"Section5"],

Cell[TextData[{
 "In this section we will show how to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to solve two problems that seem closely related, but which are quite \
different in computational complexity. The two problems that will be analyzed \
are the problem of finding a simple circuit that contains every edge exactly \
once (an Euler circuit) and the problem of finding a simple circuit that \
contains every vertex exactly once (a Hamilton circuit). (Note that the \
textbook uses the term circuit while ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " uses the word cycle. These two terms are synonymous.)"
}], "Text"],

Cell[CellGroupData[{

Cell["Euler Circuits in Simple Graphs", "Subsection",
 CellTags->"Section5a"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " comes equipped with a function to determine if a given simple graph has an \
Euler circuit or not. This function, ",
 StyleBox[ButtonBox["EulerianGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EulerianGraphQ"], "FunctionLink"],
 ", takes one argument, a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object. As an example, we'll have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " check to see if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "5"], TraditionalForm]]],
 " is Eulerian, i.e., has an Euler circuit."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EulerianGraphQ", "[", 
  RowBox[{"CompleteGraph", "[", "5", "]"}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "To explicitly find an Euler circuit, we use the function ",
 StyleBox[ButtonBox["FindEulerianCycle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindEulerianCycle"], "FunctionLink"],
 ". The function accepts one or two arguments. The first argument must be a \
graph, and if this is the only argument, the function returns a list \
containing a single list of edges representing an Euler circuit. For example, \
the following identifies an Euler circuit on the complete graph ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "5"], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindEulerianCycle", "[", 
  RowBox[{"CompleteGraph", "[", "5", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1", "\[UndirectedEdge]", "5"}], ",", 
    RowBox[{"5", "\[UndirectedEdge]", "4"}], ",", 
    RowBox[{"4", "\[UndirectedEdge]", "3"}], ",", 
    RowBox[{"3", "\[UndirectedEdge]", "5"}], ",", 
    RowBox[{"5", "\[UndirectedEdge]", "2"}], ",", 
    RowBox[{"2", "\[UndirectedEdge]", "4"}], ",", 
    RowBox[{"4", "\[UndirectedEdge]", "1"}], ",", 
    RowBox[{"1", "\[UndirectedEdge]", "3"}], ",", 
    RowBox[{"3", "\[UndirectedEdge]", "2"}], ",", 
    RowBox[{"2", "\[UndirectedEdge]", "1"}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "If you provide ",
 StyleBox[ButtonBox["FindEulerianCycle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindEulerianCycle"], "FunctionLink"],
 " with a positive integer as a second argument, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will attempt to find more than one Euler circuit, with the integer serving \
as a maximum number of cycles to return, provided they exist. In this case, \
the output will be a list of lists of edges, with each sublist representing a \
distinct circuit."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindEulerianCycle", "[", 
  RowBox[{
   RowBox[{"CompleteGraph", "[", "5", "]"}], ",", "3"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "1"}], ",", 
     RowBox[{"1", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "1"}], ",", 
     RowBox[{"1", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "1"}], ",", 
     RowBox[{"1", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "1"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "With the symbol ",
 StyleBox[ButtonBox["All",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/All"], "FunctionLink"],
 " as the third argument, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will determine all of the Euler circuits. We see below that the complete \
graph on 5 vertices has 132 Euler circuits."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"FindEulerianCycle", "[", 
   RowBox[{
    RowBox[{"CompleteGraph", "[", "5", "]"}], ",", "All"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData["132"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Now we\[CloseCurlyQuote]ll have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " help us to visualize this path by creating an animation that successively \
highlights the edges in the path. To do this we will use the ",
 StyleBox[ButtonBox["Animate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Animate"], "FunctionLink"],
 " function. The ",
 StyleBox[ButtonBox["Animate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Animate"], "FunctionLink"],
 " function takes two arguments, similar to ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 ". The first argument is a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expression, typically one that generates an image and which is dependent \
on a variable. The second argument is a list describing the range of the \
variable. The structure of this list is similar to the second argument in a \
",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 ". "
}], "Text"],

Cell[TextData[{
 "We will also be making use of two options. Setting the ",
 StyleBox[ButtonBox["AnimationRunning",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AnimationRunning"], "FunctionLink"],
 " option to ",
 StyleBox[ButtonBox["False",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/False"], "FunctionLink"],
 " will prevent the animation from beginning until you explicitly click on \
the play button. Without this option, the animation would run as soon as ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has finished generating it. Setting the ",
 StyleBox[ButtonBox["AnimationRepetitions",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AnimationRepetitions"], "FunctionLink"],
 " option to 1 will cause the animation to stop once it has played through. \
This option defaults to ",
 StyleBox[ButtonBox["Infinity",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Infinity"], "FunctionLink"],
 ", meaning it will automatically restart every time it reaches the end."
}], "Text"],

Cell[TextData[{
 "To create the animation, we need a graph and a circuit. We will use ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "5"], TraditionalForm]]],
 " as the graph and we store the circuit as ",
 StyleBox["exampleCircuit", "Input"],
 ". Note that we apply ",
 StyleBox[ButtonBox["First",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/First"], "FunctionLink"],
 " since ",
 StyleBox[ButtonBox["FindEulerianCycle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindEulerianCycle"], "FunctionLink"],
 " returns a list of circuits and we want to access the first element of that \
list."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exampleCircuit", "=", 
  RowBox[{"First", "[", 
   RowBox[{"FindEulerianCycle", "[", 
    RowBox[{"CompleteGraph", "[", "5", "]"}], "]"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "\[UndirectedEdge]", "5"}], ",", 
   RowBox[{"5", "\[UndirectedEdge]", "4"}], ",", 
   RowBox[{"4", "\[UndirectedEdge]", "3"}], ",", 
   RowBox[{"3", "\[UndirectedEdge]", "5"}], ",", 
   RowBox[{"5", "\[UndirectedEdge]", "2"}], ",", 
   RowBox[{"2", "\[UndirectedEdge]", "4"}], ",", 
   RowBox[{"4", "\[UndirectedEdge]", "1"}], ",", 
   RowBox[{"1", "\[UndirectedEdge]", "3"}], ",", 
   RowBox[{"3", "\[UndirectedEdge]", "2"}], ",", 
   RowBox[{"2", "\[UndirectedEdge]", "1"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To display the path, we will apply the ",
 StyleBox[ButtonBox["HighlightGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HighlightGraph"], "FunctionLink"],
 " function. This function was first described in Section 10.2 in the \
subsection on bipartite graphs. It takes two arguments: a graph and a list of \
either vertices or edges."
}], "Text"],

Cell[TextData[{
 "To draw the successive stages in the circuit, we will apply ",
 StyleBox[ButtonBox["HighlightGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HighlightGraph"], "FunctionLink"],
 " to the graph and to a sublist of ",
 StyleBox["exampleCircuit", "Input"],
 ". We will obtain the sublist by applying ",
 StyleBox[ButtonBox["Part",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Part"], "FunctionLink"],
 " (",
 StyleBox["[[\[Ellipsis]]]", "Input"],
 ") to a ",
 StyleBox[ButtonBox["Span",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Span"], "FunctionLink"],
 " (",
 StyleBox[";;", "Input"],
 ") from 1 to the current stage. For example, to display the path after three \
steps, we enter the following."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{
   RowBox[{"CompleteGraph", "[", "5", "]"}], ",", 
   RowBox[{"exampleCircuit", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "3"}], "]"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 4, 8, 12, 16, 20}, {{2}, {3}, {4}, {5}, {1}, {3}, {4}, {5}, {
          1}, {2}, {4}, {5}, {1}, {2}, {3}, {5}, {1}, {2}, {3}, {4}}}, 
         Pattern}]}, {GraphHighlight -> {
         UndirectedEdge[4, 3], 
         UndirectedEdge[5, 4], 
         UndirectedEdge[1, 5]}, GraphLayout -> "CircularEmbedding"}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$2", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$3", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0.5877852522924738, -0.8090169943749481}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
        "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18000000000001, 352.82}, {-168.10719999999998`, 
       162.04310466848688`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell["\<\
Also note that the span from 1 to 0 will result in the empty list and thus \
nothing highlighted.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exampleCircuit", "[", 
  RowBox[{"[", 
   RowBox[{"1", ";;", "0"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{
   RowBox[{"CompleteGraph", "[", "5", "]"}], ",", 
   RowBox[{"exampleCircuit", "[", 
    RowBox[{"[", 
     RowBox[{"1", ";;", "0"}], "]"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 4, 8, 12, 16, 20}, {{2}, {3}, {4}, {5}, {1}, {3}, {4}, {5}, {
          1}, {2}, {4}, {5}, {1}, {2}, {3}, {5}, {1}, {2}, {3}, {4}}}, 
         Pattern}]}, {GraphLayout -> "CircularEmbedding"}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{0.5877852522924738, -0.8090169943749481}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
         0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
        "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.18000000000001, 352.82}, {-168.10719999999998`, 
       162.04310466848688`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We produce the animation using ",
 StyleBox[ButtonBox["HighlightGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HighlightGraph"], "FunctionLink"],
 " as above, with the second argument to the ",
 StyleBox[ButtonBox["Span",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Span"], "FunctionLink"],
 " (",
 StyleBox[";;", "Input"],
 ") as a variable. In the second argument of ",
 StyleBox[ButtonBox["Animate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Animate"], "FunctionLink"],
 ", this variable will be set to run from 0 to the ",
 StyleBox[ButtonBox["Length",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Length"], "FunctionLink"],
 " of the path. Note that, unlike ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 ", the variables in an ",
 StyleBox[ButtonBox["Animate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Animate"], "FunctionLink"],
 " are not assumed to be restricted to integers, so we must specify a step \
value of 1 in the variable specification."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"HighlightGraph", "[", 
    RowBox[{
     RowBox[{"CompleteGraph", "[", "5", "]"}], ",", 
     RowBox[{"exampleCircuit", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "i"}], "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "0", ",", 
     RowBox[{"Length", "[", "exampleCircuit", "]"}], ",", "1"}], "}"}], ",", 
   RowBox[{"AnimationRunning", "\[Rule]", "False"}], ",", 
   RowBox[{"AnimationRepetitions", "\[Rule]", "1"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`i$$], 0, 10, 1}}, Typeset`size$$ = {
    360., {169., 174.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i$1492$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`i$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`i$$, $CellContext`i$1492$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> HighlightGraph[
        CompleteGraph[5], 
        Part[$CellContext`exampleCircuit, 
         Span[1, $CellContext`i$$]]], 
      "Specifications" :> {{$CellContext`i$$, 0, 10, 1, AnimationRunning -> 
         False, AnimationRepetitions -> 1, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{403., {206., 211.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We now turn this into a function. The only difference between the ",
 StyleBox["animatePath", "Input"],
 " function below and the example from above is that we replace the variable \
in the loop specification with the list ",
 StyleBox["{i,0,\"step\"}", "Input"],
 ". This syntax gives the variable ",
 StyleBox["i", "Input"],
 " the initial value 0 and labels it as \[OpenCurlyDoubleQuote]step\
\[CloseCurlyDoubleQuote] in the animation controller. Also note that we use a \
",
 StyleBox[ButtonBox["BlankNullSequence",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/BlankNullSequence"], "FunctionLink"],
 " (",
 StyleBox["___", "Input"],
 ") to allow the ",
 StyleBox["animatePath", "Input"],
 " function to take 0 or more arguments after the required graph and path \
arguments. We use this to pass options to the ",
 StyleBox[ButtonBox["HighlightGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HighlightGraph"], "FunctionLink"],
 " function."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"animatePath", "[", 
   RowBox[{"g_Graph", ",", "p_List", ",", "opts___"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"i", ",", "len"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"len", "=", 
      RowBox[{"Length", "[", "p", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Animate", "[", 
      RowBox[{
       RowBox[{"HighlightGraph", "[", 
        RowBox[{"g", ",", 
         RowBox[{"p", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "i"}], "]"}], "]"}], ",", "opts"}], "]"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "\"\<step\>\""}], "}"}], ",", "0", ",", 
         "len", ",", "1"}], "}"}], ",", 
       RowBox[{"AnimationRunning", "\[Rule]", "False"}], ",", 
       RowBox[{"AnimationRepetitions", "\[Rule]", "1"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True],

Cell["\<\
To use this function, we just pass it an Eulerian graph, a circuit, and any \
options for drawing the graph.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"animatePath", "[", 
  RowBox[{
   RowBox[{"CompleteGraph", "[", "7", "]"}], ",", 
   RowBox[{"First", "[", 
    RowBox[{"FindEulerianCycle", "[", 
     RowBox[{"CompleteGraph", "[", "7", "]"}], "]"}], "]"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i$1526$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i$1526$$], 0, "step"}, 0, 21, 1}}, Typeset`size$$ = {
    360., {173., 178.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i$1526$1527$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`i$1526$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`i$1526$$, $CellContext`i$1526$1527$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> HighlightGraph[
        Graph[{1, 2, 3, 4, 5, 6, 7}, {Null, 
          SparseArray[
          Automatic, {7, 7}, 0, {
           1, {{0, 6, 12, 18, 24, 30, 36, 42}, {{2}, {3}, {4}, {5}, {6}, {
             7}, {1}, {3}, {4}, {5}, {6}, {7}, {1}, {2}, {4}, {5}, {6}, {7}, {
             1}, {2}, {3}, {5}, {6}, {7}, {1}, {2}, {3}, {4}, {6}, {7}, {1}, {
             2}, {3}, {4}, {5}, {7}, {1}, {2}, {3}, {4}, {5}, {6}}}, 
            Pattern}]}, {GraphLayout -> "CircularEmbedding"}], 
        Part[{
          UndirectedEdge[1, 7], 
          UndirectedEdge[7, 6], 
          UndirectedEdge[6, 5], 
          UndirectedEdge[5, 7], 
          UndirectedEdge[7, 4], 
          UndirectedEdge[4, 6], 
          UndirectedEdge[6, 3], 
          UndirectedEdge[3, 5], 
          UndirectedEdge[5, 4], 
          UndirectedEdge[4, 3], 
          UndirectedEdge[3, 7], 
          UndirectedEdge[7, 2], 
          UndirectedEdge[2, 6], 
          UndirectedEdge[6, 1], 
          UndirectedEdge[1, 5], 
          UndirectedEdge[5, 2], 
          UndirectedEdge[2, 4], 
          UndirectedEdge[4, 1], 
          UndirectedEdge[1, 3], 
          UndirectedEdge[3, 2], 
          UndirectedEdge[2, 1]}, 
         Span[1, $CellContext`i$1526$$]], VertexLabels -> "Name", 
        ImagePadding -> 10], 
      "Specifications" :> {{{$CellContext`i$1526$$, 0, "step"}, 0, 21, 1, 
         AnimationRunning -> False, AnimationRepetitions -> 1, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{403., {210., 215.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"]
}, Open  ]],

Cell["\<\
You can see the Euler circuit traced out by clicking on the play button.\
\>", "Text"],

Cell["\<\
Note that while our examples have all been undirected, the functions \
described here also apply to directed graphs.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Euler Circuits in Multigraphs", "Subsection",
 CellTags->"Section5b"],

Cell[TextData[{
 "As usual, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s built-in function does not apply to pseudographs. We will examine the \
problem of finding Euler circuits in undirected multigraphs. We know, from \
Theorem 1 of Section 10.5, that a connected multigraph with at least two \
vertices has an Euler circuit if and only if the degree of every vertex is \
even. It is easy to see that Theorem 1 extends to pseudographs as well. Using \
this fact, we can write a simple function for determining whether or not an \
undirected pseudograph has an Euler circuit. Note that, as we have done \
before, we input the undirected pseudograph as a list of rules, but the \
function assumes that the graph being modeled is undirected."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eulerianPseudographQ", "[", 
   RowBox[{"edgeList", ":", 
    RowBox[{"{", "___Rule", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"v", ",", "G"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"G", "=", 
      RowBox[{"Graph", "[", 
       RowBox[{
        RowBox[{"DeleteDuplicates", "[", 
         RowBox[{"Sort", "/@", "edgeList"}], "]"}], ",", 
        RowBox[{"DirectedEdges", "\[Rule]", "False"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Catch", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"!", 
           RowBox[{"ConnectedGraphQ", "[", "G", "]"}]}], "||", 
          RowBox[{
           RowBox[{"Length", "[", 
            RowBox[{"VertexList", "[", "G", "]"}], "]"}], "<", "2"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Throw", "[", "False", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"OddQ", "[", 
            RowBox[{"undirectedDegree", "[", 
             RowBox[{"edgeList", ",", "v"}], "]"}], "]"}], ",", 
           RowBox[{"Throw", "[", "False", "]"}]}], "]"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", 
           RowBox[{"VertexList", "[", "G", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Throw", "[", "True", "]"}]}], "\[IndentingNewLine]", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True],

Cell[TextData[{
 "We begin the ",
 StyleBox["eulerianPseudographQ", "Input"],
 " function by forming an undirected ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object. The purpose of this is to allow us to use some built-in functions \
rather than creating them from scratch. The ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object is obtained from the input pseudograph as follows. We ",
 StyleBox[ButtonBox["Map",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Map"], "FunctionLink"],
 " (",
 StyleBox["/@", "Input"],
 ") the ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " function over the ",
 StyleBox["edgeList", "Input"],
 " of the input graph. The ",
 StyleBox[ButtonBox["Map",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Map"], "FunctionLink"],
 " (",
 StyleBox["/@", "Input"],
 ") causes the ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " function to be applied to the elements of ",
 StyleBox["edgeList", "Input"],
 ", rather than the list itself. That is, ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " will be applied to the individual rules that describe the edges of the \
graph, which causes the ",
 StyleBox[ButtonBox["Rule",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rule"], "FunctionLink"],
 " (",
 StyleBox["->", "Input"],
 ") to point from lesser to greater, as illustrated below. This forces a \
canonical representation of each edge. Since the graph is undirected, this \
allows ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to recognize ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "\[Rule]", "2"}], TraditionalForm]]],
 " as the same as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Rule]", "1"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{"2", "\[Rule]", "1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"1", "\[Rule]", "2"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "After the edges are put in canonical form with ",
 Cell[BoxData[
  RowBox[{"Sort", "/@", "edgeList"}]], "myCode"],
 ", we apply ",
 StyleBox[ButtonBox["DeleteDuplicates",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DeleteDuplicates"], "FunctionLink"],
 ". This results in the edge set of a simple graph but such that every pair \
of vertices that were connected in the pseudograph are still connected. We \
then use the resulting list as the argument to ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 ", with the ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " option set to ",
 StyleBox[ButtonBox["False",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/False"], "FunctionLink"],
 ". Note that if we had not mapped ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " onto the original edge list, we would risk an error. For example, if the \
input had included both ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "\[Rule]", "2"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Rule]", "1"}], TraditionalForm]]],
 ", when ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " applied ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " with ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " false, it would then identify those as the same edge and identify the \
graph as having multiple edges. For a directed version of this function, ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " would be true, and you would not map ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " over the edge list."
}], "Text"],

Cell[TextData[{
 "All of the tests are contained in ",
 StyleBox[ButtonBox["Catch",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Catch"], "FunctionLink"],
 ". If any of the conditions fail, they will ",
 StyleBox[ButtonBox["Throw",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Throw"], "FunctionLink"],
 " ",
 StyleBox[ButtonBox["False",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/False"], "FunctionLink"],
 ". Otherwise, if the graph passes all of the hurdles, ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 " will be thrown at the end of the block. The first test is to ensure that \
the graph is connected and that it has at least 2 vertices, which are \
conditions required for Theorem 1 to apply. This is where the creation of the \
",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object is useful, as it allows us to apply the built-in functions ",
 StyleBox[ButtonBox["ConnectedGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ConnectedGraphQ"], "FunctionLink"],
 " and ",
 StyleBox[ButtonBox["VertexList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexList"], "FunctionLink"],
 " rather than create such functions for pseudographs. The second ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " is contained within a ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop to test the degree of each vertex. We apply the ",
 StyleBox["undirectedDegree", "Input"],
 " function, written in Section 10.2, and the Boolean function ",
 StyleBox[ButtonBox["OddQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/OddQ"], "FunctionLink"],
 "."
}], "Text"],

Cell["\<\
We can use this function to solve the Bridges of K\[ODoubleDot]nigsberg \
problem. First we create a representation of the town and its bridges as a \
graph (this replicates Figure 2 in Section 10.5). Then we apply the test.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"konigsbergEdges", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\"\<A\>\"", "\[Rule]", "\"\<B\>\""}], ",", 
    RowBox[{"\"\<A\>\"", "\[Rule]", "\"\<B\>\""}], ",", 
    RowBox[{"\"\<A\>\"", "\[Rule]", "\"\<C\>\""}], ",", 
    RowBox[{"\"\<A\>\"", "\[Rule]", "\"\<C\>\""}], ",", 
    RowBox[{"\"\<A\>\"", "\[Rule]", "\"\<D\>\""}], ",", 
    RowBox[{"\"\<B\>\"", "\[Rule]", "\"\<D\>\""}], ",", 
    RowBox[{"\"\<C\>\"", "\[Rule]", "\"\<D\>\""}]}], "}"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"A\"\>", "\[Rule]", "\<\"B\"\>"}], ",", 
   RowBox[{"\<\"A\"\>", "\[Rule]", "\<\"B\"\>"}], ",", 
   RowBox[{"\<\"A\"\>", "\[Rule]", "\<\"C\"\>"}], ",", 
   RowBox[{"\<\"A\"\>", "\[Rule]", "\<\"C\"\>"}], ",", 
   RowBox[{"\<\"A\"\>", "\[Rule]", "\<\"D\"\>"}], ",", 
   RowBox[{"\<\"B\"\>", "\[Rule]", "\<\"D\"\>"}], ",", 
   RowBox[{"\<\"C\"\>", "\[Rule]", "\<\"D\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"konigsbergEdges", ",", 
   RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
   RowBox[{"VertexCoordinateRules", "\[Rule]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<A\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], ",", 
      RowBox[{"\"\<B\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"\"\<C\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2"}], "}"}]}], ",", 
      RowBox[{"\"\<D\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJxl0l1Ik1EYB/A3A69CKEJBkUr6EPTCj5g0tP/QZTeBHyBqIOqceSM4FbaL
CgaiztCa0EUqyUTnR10IJqETPSqamlasQulGYkxbU0SnF6J7xTZen9jjHw6H
c3g4z/ODc0NXk18ZJkmS9t8K7KHZxbmr0GhC63YxrbmZmF3SCa/pqbpwdBsa
tdSwY7Th43ubweTcgjVTdeEDepE+3LXk3vbC4KqIvmyxY2y9dWcz3Atpsrkj
L2cA36/UH81f+4vc5tK5jdeDyHpmrfic5oE5646lqmgIDteIOz3nD2wdgQxB
9ySQTTqnBvOD6hvUnaqmcic0ynuuiKna1evfqF/faGqkx7yMMmWeiMaVB3r3
AszKvHJm+6/qR3NIUjxX855nxDmmYVa8L4K748wvmF8wv2B+wfyC+QXzC+YX
zC+YXzC/YH7B/IL5BfML5hfcf0k7q/tp3yP/7XfDD7VRPvLr41O62lp85O+3
jlta/T6a543xU1isYZ/8v2fSvka798ljf9nfVl50QF7nSiD/z3eD/mOqL6st
ruseOCb/rfuLyRsxfupX3XJPdr3yk7+0JttUf1Emf8/aF32dUSb/ekHu2IRH
Jv/hRMbbhMcn9P+ZH8wP5gfzg/nB/GB+MD+YH8wP5gfzg/nB/GB+nPlPAdgE
95Y=
    "], {
     {RGBColor[0.5, 0., 0.], 
      LineBox[{{1, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
        2}, {1, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 
        36, 2}, {1, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
        51, 52, 3}, {1, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 
        66, 67, 68, 3}, {1, 4}, {2, 4}, {3, 4}}]}, {InsetBox[
       FrameBox["\<\"A\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox["\<\"B\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox["\<\"C\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox["\<\"D\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 1.}, {0., 0.}, {0., 2.}, {1., 1.}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eulerianPseudographQ", "[", "konigsbergEdges", "]"}]], "Input"],

Cell[BoxData["False"], "Output"]
}, Open  ]],

Cell["\<\
Now that we have a test that tells us if a circuit exists, we will implement \
Algorithm 1 from Section 10.5 in order to find an Euler circuit, if it \
exists. The following algorithm will find an Euler circuit in a multigraph. \
It could also be applied to a pseudograph without generating an error, but it \
will not include loops in the circuit.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"findEulerianCycleMultigraph", "[", 
   RowBox[{"edgeList", ":", 
    RowBox[{"{", "___Rule", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "H", ",", "circuit", ",", "subC", ",", "i", ",", "n", ",", "v", ",", 
      "insertPoint", ",", "w", ",", "buildingSub", ",", "oldC"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"eulerianPseudographQ", "[", "edgeList", "]"}]}], ",", 
       RowBox[{"Return", "[", "$Failed", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"circuit", "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"H", "=", "edgeList"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"H", "\[NotEqual]", 
        RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"find", " ", "a", " ", "starting", " ", "point"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"circuit", "\[Equal]", 
           RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"subC", "=", 
            RowBox[{"{", 
             RowBox[{"H", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "}"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"H", "=", 
            RowBox[{"Delete", "[", 
             RowBox[{"H", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"insertPoint", "=", "0"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"For", "[", 
           RowBox[{
            RowBox[{"i", "=", "1"}], ",", 
            RowBox[{"i", "\[LessEqual]", 
             RowBox[{"Length", "[", "circuit", "]"}]}], ",", 
            RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"v", "=", 
              RowBox[{"circuit", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"n", "=", 
              RowBox[{"neighbors", "[", 
               RowBox[{"H", ",", "v"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"n", "\[NotEqual]", 
                RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"w", "=", 
                 RowBox[{"n", "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"subC", "=", 
                 RowBox[{"{", 
                  RowBox[{"v", "\[Rule]", "w"}], "}"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"insertPoint", "=", "i"}], ";", "\[IndentingNewLine]", 
                RowBox[{"H", "=", 
                 RowBox[{"DeleteCases", "[", 
                  RowBox[{"H", ",", 
                   RowBox[{
                    RowBox[{"Rule", "[", 
                    RowBox[{"v", ",", "w"}], "]"}], "|", 
                    RowBox[{"Rule", "[", 
                    RowBox[{"w", ",", "v"}], "]"}]}], ",", 
                   RowBox[{"{", "1", "}"}], ",", "1"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"Break", "[", "]"}]}]}], "\[IndentingNewLine]", 
              "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"build", " ", "a", " ", "subcircuit"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"buildingSub", "=", "True"}], ";", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{"buildingSub", "&&", 
           RowBox[{"H", "\[NotEqual]", 
            RowBox[{"{", "}"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"v", "=", 
            RowBox[{"subC", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "2"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"w", "=", 
            RowBox[{"First", "[", 
             RowBox[{"neighbors", "[", 
              RowBox[{"H", ",", "v"}], "]"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"H", "=", 
            RowBox[{"DeleteCases", "[", 
             RowBox[{"H", ",", 
              RowBox[{
               RowBox[{"Rule", "[", 
                RowBox[{"v", ",", "w"}], "]"}], "|", 
               RowBox[{"Rule", "[", 
                RowBox[{"w", ",", "v"}], "]"}]}], ",", 
              RowBox[{"{", "1", "}"}], ",", "1"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"subC", ",", 
             RowBox[{"v", "\[Rule]", "w"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"w", "\[Equal]", 
              RowBox[{"subC", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
             RowBox[{"buildingSub", "=", "False"}]}], "]"}]}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "splice", " ", "the", " ", "subcircuit", " ", "into", " ", "the", 
          " ", "main", " ", "circuit"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"circuit", "\[Equal]", 
           RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"circuit", "=", "subC"}], ",", "\[IndentingNewLine]", 
          RowBox[{"circuit", "=", 
           RowBox[{"Flatten", "[", 
            RowBox[{"Insert", "[", 
             RowBox[{"circuit", ",", "subC", ",", 
              RowBox[{"insertPoint", "+", "1"}]}], "]"}], "]"}]}]}], 
         "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "circuit"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[TextData[{
 "The function begins with a use of ",
 StyleBox["eulerianPseudographQ", "Input"],
 " in order to avoid searching for a circuit that cannot exist. It then \
assigns to the symbol ",
 StyleBox["H", "Input"],
 " a copy of the graph. It is this copy that is used throughout the rest of \
the function, rather than the input that was passed to the algorithm. The \
benefit of using a copy is that the function will be able to manipulate it as \
the algorithm proceeds, e.g., by deleting edges of ",
 StyleBox["H", "Input"],
 " once they are included in the circuit so that those edges are not reused."
}], "Text"],

Cell["\<\
Recall the description of Algorithm 1 in Section 10.5. There are two key \
ideas at the heart of this algorithm. The first is that, for a graph whose \
vertices all have even degree, if you pick any vertex to start at and follow \
edges at random but without repetition, you will definitely return to the \
original vertex and create a circuit. The second key idea is that (for a \
connected graph), if your circuit does not include all of the edges of the \
graph, then some vertex used in the existing circuit can be made the starting \
point for a new subcircuit. This subcircuit can then be spliced into the main \
circuit. This will eventually use all the edges and the result will be a \
Euler circuit.\
\>", "Text"],

Cell[TextData[{
 "The symbol ",
 StyleBox["circuit", "Input"],
 " will hold the main circuit that, at the end of the function, is output to \
the user. The circuit will be stored as a list of the edges through which the \
circuit passes and is initialized to the empty list. The main ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop consists of three parts: (1) determining the starting point for the \
subcircuit (named ",
 StyleBox["subC", "Input"],
 "); (2) building the subcircuit; and (3) splicing the subcircuit into the \
main circuit."
}], "Text"],

Cell[TextData[{
 "The first step, finding the starting point for the subcircuit, depends on \
the state of the main circuit. If ",
 StyleBox["circuit", "Input"],
 " is the empty list (i.e., this is the first pass through the main loop), \
then the starting point is the first edge in the graph. If the main circuit \
is not empty, then the else clause looks at the vertices in the main circuit \
to find one that has neighbors (since edges are deleted from ",
 StyleBox["H", "Input"],
 " as they are added to the circuit, only vertices that are an endpoint of an \
unused edge have neighbors). The first vertex that has a neighbor is used as \
the starting point for the subcircuit. The ",
 StyleBox["insertPoint", "Input"],
 " variable is used to keep track of the index, relative to ",
 StyleBox["circuit", "Input"],
 ", of the starting vertex for the subcircuit. This is used when the \
subcircuit is spliced into the main circuit."
}], "Text"],

Cell[TextData[{
 "The second step is to build ",
 StyleBox["subC", "Input"],
 ". The ",
 StyleBox["buildingSub", "Input"],
 " symbol is used to control the ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop. It is initialized to true and is set to false once ",
 StyleBox["subC", "Input"],
 " has returned to its starting vertex and is thus a circuit. The variable ",
 StyleBox["v", "Input"],
 " is set to the last vertex currently included as part of the subcircuit and \
",
 StyleBox["w", "Input"],
 " represents a neighbor of ",
 StyleBox["v", "Input"],
 ". To remove the edge between ",
 StyleBox["v", "Input"],
 " and ",
 StyleBox["w", "Input"],
 " from ",
 StyleBox["H", "Input"],
 ", we use ",
 StyleBox[ButtonBox["DeleteCases",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DeleteCases"], "FunctionLink"],
 ". The first argument is the list to delete from. The second argument is a \
pattern, in this case using ",
 StyleBox[ButtonBox["Alternatives",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Alternatives"], "FunctionLink"],
 " (",
 StyleBox["|", "Input"],
 ") to allow for either order of the vertices in the edge being deleted. If \
this function were to apply to a directed graph, the order would be \
important, but here we need to allow for the fact that the circuit may follow \
edges in either direction. The third argument is an optional level \
specification, with ",
 StyleBox["{1}", "Input"],
 " indicating that only the first level is to be matched, that is, only \
members of the list and not substructures are considered. The final argument, \
which is also optional, places a limit on the number of matches to delete. \
With ",
 StyleBox["1", "Input"],
 " in the final position, the function will only delete the first edge it \
finds, rather than all of them. Note that ",
 StyleBox["{1}", "Input"],
 " is the default level specification for this function, but it must be \
included in order to use the fourth argument."
}], "Text"],

Cell[TextData[{
 "After deleting the edge from ",
 StyleBox["H", "Input"],
 ", the newest vertex is compared with the starting vertex to determine if \
the circuit has been closed. If the new vertex closes the circuit, then the \
",
 StyleBox["buildingSub", "Input"],
 " variable is set to false, which causes the loop to terminate. Otherwise, \
the ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop continues building the subcircuit."
}], "Text"],

Cell[TextData[{
 "The third step, once the subcircuit has been built, is to splice it into \
the main circuit. If ",
 StyleBox["circuit", "Input"],
 " is empty, it is merely set to ",
 StyleBox["subC", "Input"],
 ". Otherwise, ",
 StyleBox[ButtonBox["Insert",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Insert"], "FunctionLink"],
 " is used to add the subcircuit. ",
 StyleBox[ButtonBox["Insert",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Insert"], "FunctionLink"],
 " takes a list as the first argument and adds the expression given as the \
second argument in the position specified by the third argument. The elements \
previously in that position and later and pushed down to make room. We give \
the third argument as ",
 Cell[BoxData[
  RowBox[{"insertPoint", "+", "1"}]], "myCode"],
 " to insert the sublist between the edges at position ",
 StyleBox["insertPoint", "Input"],
 " and position ",
 Cell[BoxData[
  RowBox[{"insertPoint", "+", "1"}]], "myCode"],
 "."
}], "Text"],

Cell[TextData[{
 "The main ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop continues until all the edges of the graph have been included in the \
circuit, making circuit an Euler circuit for the graph. As an example, \
consider Exercise 5 from Section 10.5."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exercise5Edges", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
    RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
    RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
    RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
    RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
    RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
    RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
    RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
    RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
    RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
    RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<e\>\""}]}], "}"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"d\"\>", "\[Rule]", "\<\"e\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphPlot", "[", 
  RowBox[{"exercise5Edges", ",", 
   RowBox[{"VertexLabeling", "\[Rule]", "True"}], ",", 
   RowBox[{"VertexCoordinateRules", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2"}], "}"}]}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"2", ",", ".5"}], "}"}]}], ",", 
      RowBox[{"\"\<d\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[GraphicsComplexBox[CompressedData["
1:eJxd0n0s1HEcB/Aj/FHpQZN1PUylB08rD0Ohtzw1W1tSCilUylNxLJqtSDOX
nat0EZWUCGVsNqvQT2WlQs1TT0x3XPN0x/3uasv9flfuOlrf9/bdd9+Hfb/f
12fftUcTg6INORyO30zT9kS8/nZT+H88G3L+G/6fn0KLl5Wd/+Fi/Gz0vG0b
poHXds5FeWop+oMDHzeOsLji7WJQjzKUfOw4npzKIklyjLuUX47wRP+0lHks
OM05RXv3PEDcpW2s5DKDwJyIVqmoEut2tDlIVzLI9NnEPxlShcO80OSSB2qU
FmlTBQcnbf6NO9u1Uc3tvyesyIsKUcFLf97Ac9dO7rBy7r6C1FeGq5OUiNS/
p+zKE76AoZGpf2/UZsebeZdobNV7rKprd/lazKzrvfN9XxztKVfM+inCTxF+
ivBThJ8i/BThpwg/Rfgpwk8RforwU4SfIvwU4acIPzXrP5MiXcLboIHJuiiH
sa5vUO331QxWsMiqyIjoXSyGSNN2I8WahXvrmvj8YDG6B/sd99UwyAhalrbg
vhipcd0N5Y4M2qbtRzepxTBuaSi++kSN+DcKXnuYBIE9bj0e3mokcK3Mv76Q
QMdsn4aLzj+EmBPaqFCsq8MoRIrsyd+0EpvZvl8WZmNo8dno+vqCEnV+Wb0F
+WO4dzCyadBMiVumd4dk3HFwDQJ9EypobHcojaarxxGyx/690INGespT5zTv
CXhUleXF9CrgHmT5Ybd4Arnq2L4VPAVURf3xO3NkSDMqsP4u1MDsxHrRs7MS
tB4ITy600eBtzeCW+jVDqKzr2sp7yUIg8HvHbx6CVFPbeC2URUdnRLFp8DCO
VN7xsZQxiKGPrDKTDgNNn9vczjMIfnrOJvaUFHGL0pdwTBkMGFqbjMikKNQ5
Z+qjc3+Hs64OP/T/fwJ1tq9tXzarcEP6dczKU4ZpBESf9lehyGWR0Klchtzr
dgFhHUp4GHct/2Qkh53l+o5HQUpk10zwVYfkiDNwPSnoo/HWXSw6VS3HwoeN
BpahNLJCM0ttpuTIFXAnhV8UYAZKOs3tJ/EH9UEPow==
    "], {
     {RGBColor[0.5, 0., 0.], 
      LineBox[{{1, 2}, {1, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
         20, 21, 3}, {1, 3}, {1, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 
        33, 34, 35, 36, 37, 3}, {2, 4}, {2, 5}, {2, 3}, {4, 38, 39, 40, 41, 
        42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 5}, {4, 54, 55, 56, 
        57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 5}, {4, 3}, {5, 
        3}}]}, {InsetBox[
       FrameBox["\<\"a\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 1], InsetBox[
       FrameBox["\<\"b\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 2], InsetBox[
       FrameBox["\<\"e\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 3], InsetBox[
       FrameBox["\<\"c\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 4], InsetBox[
       FrameBox["\<\"d\"\>",
        Background->RGBColor[1, 1, 0.8],
        FrameStyle->RGBColor[0.94, 0.85, 0.36],
        StripOnInput->False], 5]}}],
   Annotation[#, 
    VertexCoordinateRules -> {{0., 2.}, {1., 2.}, {0., 1.}, {2., 0.5}, {1., 
     1.}}]& ],
  AspectRatio->Automatic,
  FrameTicks->None,
  PlotRange->All,
  PlotRangePadding->Scaled[0.1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exercise5EulerPath", "=", 
  RowBox[{
  "findEulerianCycleMultigraph", "[", "exercise5Edges", "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"d\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"e\"\>", "\[Rule]", "\<\"a\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"e\"\>", "\[Rule]", "\<\"c\"\>"}], ",", 
   RowBox[{"\<\"c\"\>", "\[Rule]", "\<\"d\"\>"}], ",", 
   RowBox[{"\<\"d\"\>", "\[Rule]", "\<\"b\"\>"}], ",", 
   RowBox[{"\<\"b\"\>", "\[Rule]", "\<\"e\"\>"}], ",", 
   RowBox[{"\<\"e\"\>", "\[Rule]", "\<\"a\"\>"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that the edge between ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 " is traversed three times: twice in about the middle of the circuit \
immediately in succession, and once as the last edge in the cycle. This is \
consistent with there being three edges between ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hamilton Circuits", "Subsection",
 CellTags->"Section5c"],

Cell[TextData[{
 "Turning our attention to Hamilton circuits, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides the function ",
 StyleBox[ButtonBox["HamiltonianGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HamiltonianGraphQ"], "FunctionLink"],
 " for determining whether or not the graph contains a Hamilton circuit. This \
command, like ",
 StyleBox[ButtonBox["EulerianGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EulerianGraphQ"], "FunctionLink"],
 ", accepts a graph as the sole argument. It returns true or false depending \
on whether the graph has a Hamilton circuit."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hcGraphExample", "=", 
  RowBox[{"HypercubeGraph", "[", "3", "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 3, 6, 9, 12, 15, 18, 21, 24}, {{2}, {3}, {5}, {1}, {4}, {6}, {
          1}, {4}, {7}, {2}, {3}, {8}, {1}, {6}, {7}, {2}, {5}, {8}, {3}, {
          5}, {8}, {4}, {6}, {7}}}, Pattern}]}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0.6411318907234969, 1.6256350616332038`}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{1.5431761475992014`, 1.6258514889129208`}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{1.3641521541128723`, 0.8124188351574709}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{2.186420636755495, 0.814439144539747}, 0.02410631722965237], 
        "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{0., 0.8116524116085829}, 0.02410631722965237], "DynamicName",
         BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{0.8207122623609914, 0.8136876580070856}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$6"], 
       TagBox[
        DiskBox[{0.6431241846256299, 0.}, 0.02410631722965237], "DynamicName",
         BoxID -> "VertexID$7"], 
       TagBox[
        DiskBox[{1.5449243126722068`, 0.0005338415834358345}, 
         0.02410631722965237], "DynamicName", BoxID -> 
        "VertexID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.179999999999999, 352.82}, {-133.10719999999998`, 
       127.0780990872907}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HamiltonianGraphQ", "[", "hcGraphExample", "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["FindHamiltonianCycle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindHamiltonianCycle"], "FunctionLink"],
 " function, similar to ",
 StyleBox[ButtonBox["FindEulerianCycle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindEulerianCycle"], "FunctionLink"],
 ", accepts a graph as the argument and returns a list containing a list \
containing a Hamiltonian circuit. The optional second argument can be used to \
find more than one cycle."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindHamiltonianCycle", "[", "hcGraphExample", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1", "\[UndirectedEdge]", "2"}], ",", 
    RowBox[{"2", "\[UndirectedEdge]", "4"}], ",", 
    RowBox[{"4", "\[UndirectedEdge]", "8"}], ",", 
    RowBox[{"8", "\[UndirectedEdge]", "6"}], ",", 
    RowBox[{"6", "\[UndirectedEdge]", "5"}], ",", 
    RowBox[{"5", "\[UndirectedEdge]", "7"}], ",", 
    RowBox[{"7", "\[UndirectedEdge]", "3"}], ",", 
    RowBox[{"3", "\[UndirectedEdge]", "1"}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindHamiltonianCycle", "[", 
  RowBox[{"hcGraphExample", ",", "All"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "7"}], ",", 
     RowBox[{"7", "\[UndirectedEdge]", "8"}], ",", 
     RowBox[{"8", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "6"}], ",", 
     RowBox[{"6", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "6"}], ",", 
     RowBox[{"6", "\[UndirectedEdge]", "8"}], ",", 
     RowBox[{"8", "\[UndirectedEdge]", "7"}], ",", 
     RowBox[{"7", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "6"}], ",", 
     RowBox[{"6", "\[UndirectedEdge]", "8"}], ",", 
     RowBox[{"8", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "7"}], ",", 
     RowBox[{"7", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "7"}], ",", 
     RowBox[{"7", "\[UndirectedEdge]", "8"}], ",", 
     RowBox[{"8", "\[UndirectedEdge]", "6"}], ",", 
     RowBox[{"6", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "6"}], ",", 
     RowBox[{"6", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "7"}], ",", 
     RowBox[{"7", "\[UndirectedEdge]", "8"}], ",", 
     RowBox[{"8", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[UndirectedEdge]", "2"}], ",", 
     RowBox[{"2", "\[UndirectedEdge]", "4"}], ",", 
     RowBox[{"4", "\[UndirectedEdge]", "8"}], ",", 
     RowBox[{"8", "\[UndirectedEdge]", "6"}], ",", 
     RowBox[{"6", "\[UndirectedEdge]", "5"}], ",", 
     RowBox[{"5", "\[UndirectedEdge]", "7"}], ",", 
     RowBox[{"7", "\[UndirectedEdge]", "3"}], ",", 
     RowBox[{"3", "\[UndirectedEdge]", "1"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hcGraphExampleCircuit", "=", 
  RowBox[{"First", "[", 
   RowBox[{"FindHamiltonianCycle", "[", "hcGraphExample", "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "\[UndirectedEdge]", "2"}], ",", 
   RowBox[{"2", "\[UndirectedEdge]", "4"}], ",", 
   RowBox[{"4", "\[UndirectedEdge]", "8"}], ",", 
   RowBox[{"8", "\[UndirectedEdge]", "6"}], ",", 
   RowBox[{"6", "\[UndirectedEdge]", "5"}], ",", 
   RowBox[{"5", "\[UndirectedEdge]", "7"}], ",", 
   RowBox[{"7", "\[UndirectedEdge]", "3"}], ",", 
   RowBox[{"3", "\[UndirectedEdge]", "1"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We can use ",
 StyleBox[ButtonBox["HighlightGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HighlightGraph"], "FunctionLink"],
 " to illustrate the path statically."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"hcGraphExample", ",", "hcGraphExampleCircuit"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 3, 6, 9, 12, 15, 18, 21, 24}, {{2}, {3}, {5}, {1}, {4}, {6}, {
          1}, {4}, {7}, {2}, {3}, {8}, {1}, {6}, {7}, {2}, {5}, {8}, {3}, {
          5}, {8}, {4}, {6}, {7}}}, Pattern}]}, {GraphHighlight -> {
         UndirectedEdge[1, 2], 
         UndirectedEdge[2, 4], 
         UndirectedEdge[7, 3], 
         UndirectedEdge[3, 1], 
         UndirectedEdge[6, 5], 
         UndirectedEdge[8, 6], 
         UndirectedEdge[4, 8], 
         UndirectedEdge[5, 7]}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$1", Automatic, Center], 
         DynamicLocation["VertexID$5", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$2", Automatic, Center], 
         DynamicLocation["VertexID$6", Automatic, Center]}], 
       LineBox[{
         DynamicLocation["VertexID$3", Automatic, Center], 
         DynamicLocation["VertexID$4", Automatic, Center]}], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       StyleBox[
        LineBox[{
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}], 
        Directive[
         Hue[1, 1, 0.7], 
         Opacity[1]], StripOnInput -> False], 
       LineBox[{
         DynamicLocation["VertexID$7", Automatic, Center], 
         DynamicLocation["VertexID$8", Automatic, Center]}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{0.6411318907234969, 1.6256350616332038`}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{1.5431761475992014`, 1.6258514889129208`}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{1.3641521541128723`, 0.8124188351574709}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{2.186420636755495, 0.814439144539747}, 0.02410631722965237], 
        "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{0., 0.8116524116085829}, 0.02410631722965237], "DynamicName",
         BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{0.8207122623609914, 0.8136876580070856}, 
         0.02410631722965237], "DynamicName", BoxID -> "VertexID$6"], 
       TagBox[
        DiskBox[{0.6431241846256299, 0.}, 0.02410631722965237], "DynamicName",
         BoxID -> "VertexID$7"], 
       TagBox[
        DiskBox[{1.5449243126722068`, 0.0005338415834358345}, 
         0.02410631722965237], "DynamicName", BoxID -> 
        "VertexID$8"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.179999999999999, 352.82}, {-133.10719999999998`, 
       127.0780990872907}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Also, our animation function ",
 StyleBox["animatePath", "Input"],
 ", created above, works equally well here."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"animatePath", "[", 
  RowBox[{"hcGraphExample", ",", "hcGraphExampleCircuit"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i$1626$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i$1626$$], 0, "step"}, 0, 8, 1}}, Typeset`size$$ = {
    360., {134., 139.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i$1626$1627$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`i$1626$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`i$1626$$, $CellContext`i$1626$1627$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> HighlightGraph[
        Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {Null, 
          SparseArray[
          Automatic, {8, 8}, 0, {
           1, {{0, 3, 6, 9, 12, 15, 18, 21, 24}, {{2}, {3}, {5}, {1}, {4}, {
             6}, {1}, {4}, {7}, {2}, {3}, {8}, {1}, {6}, {7}, {2}, {5}, {8}, {
             3}, {5}, {8}, {4}, {6}, {7}}}, Pattern}]}], 
        Part[{
          UndirectedEdge[1, 2], 
          UndirectedEdge[2, 4], 
          UndirectedEdge[4, 8], 
          UndirectedEdge[8, 6], 
          UndirectedEdge[6, 5], 
          UndirectedEdge[5, 7], 
          UndirectedEdge[7, 3], 
          UndirectedEdge[3, 1]}, 
         Span[1, $CellContext`i$1626$$]]], 
      "Specifications" :> {{{$CellContext`i$1626$$, 0, "step"}, 0, 8, 1, 
         AnimationRunning -> False, AnimationRepetitions -> 1, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{403., {171., 176.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"]
}, Open  ]],

Cell["\<\
Note that a pseudograph is Hamiltonian if and only if its underlying simple \
graph is Hamiltonian, so there is no need for us to extend the built-in \
functions to pseudographs.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["10.6 Shortest-Path Problems", "Section",
 CellTags->"Section6"],

Cell["\<\
Among the most common problems in graph theory are shortest path problems. \
Generally, in shortest path problems, we wish to determine a path between two \
vertices of a weighted graph that is minimal in terms of the total weight of \
the edges in the path.\
\>", "Text"],

Cell[TextData[{
 "To define a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object with weighted edges, you use the ",
 StyleBox[ButtonBox["EdgeWeight",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeWeight"], "FunctionLink"],
 " option. The value associated with the option is the list of the weights of \
each edge. The weights must appear in the same order as they are displayed in \
the output by ",
 StyleBox[ButtonBox["EdgeList",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeList"], "FunctionLink"],
 ". For graphs you define by listing the edges, this is identical to the \
order you give in the definition."
}], "Text"],

Cell["\<\
We reproduce Exercise 2 from Section 10.6 of the textbook to use as an \
example. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exercise2", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\"", ",", 
      "\"\<e\>\"", ",", "\"\<z\>\""}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
      RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
      RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<z\>\""}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<z\>\""}]}], "}"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
    RowBox[{"EdgeWeight", "->", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "3", ",", "5", ",", "2", ",", "5", ",", "1", ",", "2", ",", 
       "4"}], "}"}]}], ",", 
    RowBox[{"VertexCoordinates", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", ".5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", ".5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "5"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "e", "z"}, {
      Null, {{1, 2}, {1, 3}, {2, 4}, {2, 5}, {3, 5}, {4, 5}, {4, 6}, {5, 
       6}}}, {EdgeWeight -> {2, 3, 5, 2, 5, 1, 2, 4}, ImagePadding -> 5, 
       VertexCoordinates -> {{0, 0.5}, {1, 1}, {1, 0}, {2, 1}, {2, 0}, {
         3, 0.5}}, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{11.000000000000004`, 
       354.73473109407513`}, {-73.01473109407456, 57.14653101154374}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A second approach to setting edge weights is by using the ",
 StyleBox[ButtonBox["EdgeWeight",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeWeight"], "FunctionLink"],
 " property. Rather than listing all of the edges and then listing the \
weights separately using the option as shown above, we can wrap the edge \
definitions in the ",
 StyleBox[ButtonBox["Property",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Property"], "FunctionLink"],
 " wrapper, setting the edge weights at the same time the edges are described."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\"", ",", 
     "\"\<e\>\"", ",", "\"\<z\>\""}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Property", "[", 
      RowBox[{
       RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
       RowBox[{"EdgeWeight", "\[Rule]", "2"}]}], "]"}], ",", 
     RowBox[{"Property", "[", 
      RowBox[{
       RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       RowBox[{"EdgeWeight", "\[Rule]", "3"}]}], "]"}], ",", 
     RowBox[{"Property", "[", 
      RowBox[{
       RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
       RowBox[{"EdgeWeight", "\[Rule]", "5"}]}], "]"}], ",", 
     RowBox[{"Property", "[", 
      RowBox[{
       RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
       RowBox[{"EdgeWeight", "\[Rule]", "2"}]}], "]"}], ",", 
     RowBox[{"Property", "[", 
      RowBox[{
       RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
       RowBox[{"EdgeWeight", "\[Rule]", "5"}]}], "]"}], ",", 
     RowBox[{"Property", "[", 
      RowBox[{
       RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
       RowBox[{"EdgeWeight", "\[Rule]", "1"}]}], "]"}], ",", 
     RowBox[{"Property", "[", 
      RowBox[{
       RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<z\>\""}], ",", 
       RowBox[{"EdgeWeight", "\[Rule]", "2"}]}], "]"}], ",", 
     RowBox[{"Property", "[", 
      RowBox[{
       RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<z\>\""}], ",", 
       RowBox[{"EdgeWeight", "\[Rule]", "4"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
   RowBox[{"VertexCoordinates", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", ".5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", ".5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "e", "z"}, {
      Null, {{1, 2}, {1, 3}, {2, 4}, {2, 5}, {3, 5}, {4, 5}, {4, 6}, {5, 
       6}}}, {EdgeWeight -> {2, 3, 5, 2, 5, 1, 2, 4}, ImagePadding -> 5, 
       VertexCoordinates -> {{0, 0.5}, {1, 1}, {1, 0}, {2, 1}, {2, 0}, {
         3, 0.5}}, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{11.000000000000004`, 
       354.73473109407513`}, {-73.01473109407445, 57.14653101154374}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "You can also define a weighted graph using the ",
 StyleBox[ButtonBox["WeightedAdjacencyGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WeightedAdjacencyGraph"], "FunctionLink"],
 " function and an adjacency matrix. Unlike with ",
 StyleBox[ButtonBox["AdjacencyGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AdjacencyGraph"], "FunctionLink"],
 ", the adjacency matrix must use ",
 StyleBox[ButtonBox["Infinity",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Infinity"], "FunctionLink"],
 ", or \[Infinity] (\[EscapeKey]inf\[EscapeKey]) to indicate that there is no \
edge between the corresponding vertices. In the example below, we give the \
list of vertices as the first argument, otherwise ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will automatically use positive integers to name the vertices. Note that \
",
 StyleBox[ButtonBox["WeightedAdjacencyMatrix",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WeightedAdjacencyMatrix"], "FunctionLink"],
 " applied to a weighted graph returns the adjacency matrix with weights."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"exercise2matrix", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\[Infinity]", ",", "2", ",", "3", ",", "\[Infinity]", ",", 
       "\[Infinity]", ",", "\[Infinity]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "\[Infinity]", ",", "\[Infinity]", ",", "5", ",", "2", ",", 
       "\[Infinity]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "\[Infinity]", ",", "\[Infinity]", ",", "\[Infinity]", ",", 
       "5", ",", "\[Infinity]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\[Infinity]", ",", "5", ",", "\[Infinity]", ",", "\[Infinity]", ",", 
       "1", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\[Infinity]", ",", "2", ",", "5", ",", "1", ",", "\[Infinity]", ",", 
       "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\[Infinity]", ",", "\[Infinity]", ",", "\[Infinity]", ",", "2", ",", 
       "4", ",", "\[Infinity]"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"exercise2matrix", "//", "MatrixForm"}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\[Infinity]", "2", "3", "\[Infinity]", "\[Infinity]", "\[Infinity]"},
     {"2", "\[Infinity]", "\[Infinity]", "5", "2", "\[Infinity]"},
     {"3", "\[Infinity]", "\[Infinity]", "\[Infinity]", "5", "\[Infinity]"},
     {"\[Infinity]", "5", "\[Infinity]", "\[Infinity]", "1", "2"},
     {"\[Infinity]", "2", "5", "1", "\[Infinity]", "4"},
     {"\[Infinity]", "\[Infinity]", "\[Infinity]", "2", "4", "\[Infinity]"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WeightedAdjacencyGraph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\"", ",", 
     "\"\<e\>\"", ",", "\"\<z\>\""}], "}"}], ",", "exercise2matrix", ",", 
   RowBox[{"VertexCoordinates", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", ".5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", ".5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "5"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "e", "z"}, {Null, 
       SparseArray[
       Automatic, {6, 6}, 0, {
        1, {{0, 2, 5, 7, 10, 14, 16}, {{2}, {3}, {1}, {4}, {5}, {1}, {5}, {
          2}, {5}, {6}, {2}, {3}, {4}, {6}, {4}, {5}}}, Pattern}]}, {
      EdgeWeight -> {2, 3, 5, 2, 5, 1, 2, 4}, ImagePadding -> 5, 
       VertexCoordinates -> {{0, 0.5}, {1, 1}, {1, 0}, {2, 1}, {2, 0}, {
         3, 0.5}}, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{11.000000000000004`, 
       354.73473109407513`}, {-73.01473109407445, 57.14653101154374}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Observe that the edge weights are not automatically displayed. We can \
display them with ",
 StyleBox[ButtonBox["EdgeLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeLabels"], "FunctionLink"],
 ", but unlike ",
 StyleBox[ButtonBox["VertexLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexLabels"], "FunctionLink"],
 ", there is no simple value, like ",
 StyleBox["\[OpenCurlyDoubleQuote]Name\[CloseCurlyDoubleQuote]", "Input"],
 ", that will cause the weights to appear. Rather, we must set each edge\
\[CloseCurlyQuote]s label individually. This is illustrated below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\""}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
     RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
     RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<a\>\""}]}], "}"}], ",", 
   RowBox[{"EdgeWeight", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
   RowBox[{"ImagePadding", "\[Rule]", "10"}], ",", 
   RowBox[{"EdgeLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"\"\<a\>\"", "\[DirectedEdge]", "\"\<b\>\""}], "\[Rule]", 
       "1"}], ",", 
      RowBox[{
       RowBox[{"\"\<b\>\"", "\[DirectedEdge]", "\"\<c\>\""}], "\[Rule]", 
       "2"}], ",", 
      RowBox[{
       RowBox[{"\"\<c\>\"", "\[DirectedEdge]", "\"\<a\>\""}], "\[Rule]", 
       "3"}]}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c"}, {{{1, 2}, {2, 3}, {3, 1}}, Null}, {
      EdgeLabels -> {
        DirectedEdge["c", "a"] -> 3, DirectedEdge["b", "c"] -> 2, 
         DirectedEdge["a", "b"] -> 1}, EdgeWeight -> {1, 2, 3}, ImagePadding -> 
       10, VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Arrowheads[0.03555748430834104], 
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         ArrowBox[
          LineBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          LineBox[{
            DynamicLocation["VertexID$2", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         ArrowBox[
          LineBox[{
            DynamicLocation["VertexID$3", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]], 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox["3", TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
           0.020399597244776385`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.8660254037844389, -0.5000000000000012}, 
           0.020399597244776385`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1.8369701987210297`*^-16, 1.}, 0.020399597244776385`], 
          "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.385786437626845`, 
       351.22127884808106`}, {-157.49327884808085`, 141.86348606963318`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that, even in a directed graph, rules cannot be used to describe edges \
within the ",
 StyleBox[ButtonBox["EdgeLabels",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeLabels"], "FunctionLink"],
 " value. Rather the symbols \[DirectedEdge] (\[EscapeKey]de\[EscapeKey]) or \
\[UndirectedEdge] (\[EscapeKey]ue\[EscapeKey]) must be used."
}], "Text"],

Cell[TextData[{
 "For graphs of any size, needing to assign the edge weights for the ",
 StyleBox[ButtonBox["EdgeWeight",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeWeight"], "FunctionLink"],
 " option can be cumbersome. For convenience, we create the following \
function, which modifies a given graph by setting the ",
 StyleBox[ButtonBox["EdgeWeight",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeWeight"], "FunctionLink"],
 " property to be the edge weight."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"addWeightLabels", "[", "G_Graph", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"E", ",", "W", ",", "H", ",", "i"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"H", "=", "G"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"PropertyValue", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"H", ",", "e"}], "}"}], ",", "EdgeLabels"}], "]"}], "=", 
        RowBox[{"PropertyValue", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"H", ",", "e"}], "}"}], ",", "EdgeWeight"}], "]"}]}], 
       "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"e", ",", 
         RowBox[{"EdgeList", "[", "H", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "H"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 InitializationCell->True],

Cell["\<\
This can be applied to an existing graph to display the labels once.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"addWeightLabels", "[", "exercise2", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "e", "z"}, {
      Null, {{1, 2}, {1, 3}, {2, 4}, {2, 5}, {3, 5}, {4, 5}, {4, 6}, {5, 
       6}}}, {EdgeLabels -> {
        UndirectedEdge["b", "d"] -> 5, UndirectedEdge["d", "z"] -> 2, 
         UndirectedEdge["a", "b"] -> 2, UndirectedEdge["c", "e"] -> 5, 
         UndirectedEdge["d", "e"] -> 1, UndirectedEdge["e", "z"] -> 4, 
         UndirectedEdge["b", "e"] -> 2, UndirectedEdge["a", "c"] -> 3}, 
       EdgeWeight -> {2, 3, 5, 2, 5, 1, 2, 4}, ImagePadding -> 5, 
       VertexCoordinates -> {{0, 0.5}, {1, 1}, {1, 0}, {2, 1}, {2, 0}, {
         3, 0.5}}, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox["3", TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox["5", TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$3", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox["5", TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox["4", TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{10.585786437626897`, 
       355.14894465644824`}, {-73.42894465644756, 59.24084631525946}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell["\<\
Or it can be applied at the time the graph is created to make the labels \
permanent.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exercise2", "=", 
  RowBox[{
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\"", ",", 
       "\"\<e\>\"", ",", "\"\<z\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
       RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
       RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
       RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
       RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
       RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
       RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<z\>\""}], ",", 
       RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<z\>\""}]}], "}"}], ",", 
     RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
     RowBox[{"EdgeWeight", "->", 
      RowBox[{"{", 
       RowBox[{
       "2", ",", "3", ",", "5", ",", "2", ",", "5", ",", "1", ",", "2", ",", 
        "4"}], "}"}]}], ",", 
     RowBox[{"VertexCoordinates", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", ".5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"2", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", ".5"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
     RowBox[{"ImagePadding", "\[Rule]", "5"}]}], "]"}], "//", 
   "addWeightLabels"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "e", "z"}, {
      Null, {{1, 2}, {1, 3}, {2, 4}, {2, 5}, {3, 5}, {4, 5}, {4, 6}, {5, 
       6}}}, {EdgeLabels -> {
        UndirectedEdge["b", "d"] -> 5, UndirectedEdge["d", "z"] -> 2, 
         UndirectedEdge["a", "b"] -> 2, UndirectedEdge["c", "e"] -> 5, 
         UndirectedEdge["d", "e"] -> 1, UndirectedEdge["e", "z"] -> 4, 
         UndirectedEdge["b", "e"] -> 2, UndirectedEdge["a", "c"] -> 3}, 
       EdgeWeight -> {2, 3, 5, 2, 5, 1, 2, 4}, ImagePadding -> 5, 
       VertexCoordinates -> {{0, 0.5}, {1, 1}, {1, 0}, {2, 1}, {2, 0}, {
         3, 0.5}}, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$2", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox["3", TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox["5", TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$3", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox["5", TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$4", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox["4", TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.5}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{10.585786437626897`, 
       355.14894465644824`}, {-73.42894465644756, 59.24084631525946}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Now we will make use of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s implementation of Dijkstra's algorithm to compute the shortest path \
between ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 ". To do this, we simply call the ",
 StyleBox[ButtonBox["FindShortestPath",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindShortestPath"], "FunctionLink"],
 " function with three arguments: the graph and the names of the starting and \
ending vertices. The output will be a list of vertices beginning with the \
starting vertex and ending with the final vertex through which the path \
runs."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindShortestPath", "[", 
  RowBox[{"exercise2", ",", "\"\<a\>\"", ",", "\"\<z\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"e\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"z\"\>"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["PathGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PathGraph"], "FunctionLink"],
 " function can be use to help visualize this path. ",
 StyleBox[ButtonBox["PathGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PathGraph"], "FunctionLink"],
 " accepts a list of vertices as input and produces the graph obtained by \
connecting successive vertices with an edge. By default, the graph produced \
is undirected. To obtain a directed path, assign the ",
 StyleBox[ButtonBox["DirectedEdges",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DirectedEdges"], "FunctionLink"],
 " option to ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 ". Here, we will display the path in the graph by applying ",
 StyleBox[ButtonBox["HighlightGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/HighlightGraph"], "FunctionLink"],
 ", using ",
 StyleBox[ButtonBox["PathGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PathGraph"], "FunctionLink"],
 " in the second argument."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HighlightGraph", "[", 
  RowBox[{"exercise2", ",", 
   RowBox[{"PathGraph", "@", 
    RowBox[{"FindShortestPath", "[", 
     RowBox[{"exercise2", ",", "\"\<a\>\"", ",", "\"\<z\>\""}], "]"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "e", "z"}, {
      Null, {{1, 2}, {1, 3}, {2, 4}, {2, 5}, {3, 5}, {4, 5}, {4, 6}, {5, 
       6}}}, {EdgeLabels -> {
        UndirectedEdge["b", "d"] -> 5, UndirectedEdge["d", "z"] -> 2, 
         UndirectedEdge["a", "b"] -> 2, UndirectedEdge["c", "e"] -> 5, 
         UndirectedEdge["d", "e"] -> 1, UndirectedEdge["e", "z"] -> 4, 
         UndirectedEdge["b", "e"] -> 2, UndirectedEdge["a", "c"] -> 3}, 
       EdgeWeight -> {2, 3, 5, 2, 5, 1, 2, 4}, GraphHighlight -> {"e", 
         UndirectedEdge["d", "e"], "z", "b", 
         UndirectedEdge["d", "z"], 
         UndirectedEdge["a", "b"], "a", 
         UndirectedEdge["b", "e"], "d"}, ImagePadding -> 5, 
       VertexCoordinates -> {{0, 0.5}, {1, 1}, {1, 0}, {2, 1}, {2, 0}, {
         3, 0.5}}, VertexLabels -> {"Name"}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], {
        TagBox[
         StyleBox[
          LineBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}], 
          Directive[
           Hue[1, 1, 0.7], 
           Opacity[1]], StripOnInput -> False], "DynamicName", BoxID -> 
         "EdgeLabelID$1"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$1", Automatic, Center], 
           DynamicLocation["VertexID$3", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox["3", TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$2", Automatic, Center], 
           DynamicLocation["VertexID$4", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox["5", TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         StyleBox[
          LineBox[{
            DynamicLocation["VertexID$2", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}], 
          Directive[
           Hue[1, 1, 0.7], 
           Opacity[1]], StripOnInput -> False], "DynamicName", BoxID -> 
         "EdgeLabelID$4"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$3", Automatic, Center], 
           DynamicLocation["VertexID$5", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox["5", TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         StyleBox[
          LineBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}], 
          Directive[
           Hue[1, 1, 0.7], 
           Opacity[1]], StripOnInput -> False], "DynamicName", BoxID -> 
         "EdgeLabelID$6"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         StyleBox[
          LineBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$6", Automatic, Center]}], 
          Directive[
           Hue[1, 1, 0.7], 
           Opacity[1]], StripOnInput -> False], "DynamicName", BoxID -> 
         "EdgeLabelID$7"], 
        InsetBox[
         FormBox["2", TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[
         LineBox[{
           DynamicLocation["VertexID$5", Automatic, Center], 
           DynamicLocation["VertexID$6", Automatic, Center]}], "DynamicName", 
         BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox["4", TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.5}, 0.030239520958083826`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 1.}, 0.030239520958083826`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 1.}, 0.030239520958083826`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 0.}, 0.030239520958083826`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{3., 0.5}, 0.030239520958083826`], 
           Directive[
            Hue[1, 1, 0.7], 
            EdgeForm[{
              Hue[1, 1, 0.7], 
              Opacity[1]}]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"z\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{10.585786437626897`, 
       355.14894465644824`}, {-73.42894465644835, 59.24084631525906}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->5]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The length of the shortest path can be determined with the ",
 StyleBox[ButtonBox["GraphDistance",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphDistance"], "FunctionLink"],
 " function and the same arguments."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphDistance", "[", 
  RowBox[{"exercise2", ",", "\"\<a\>\"", ",", "\"\<z\>\""}], "]"}]], "Input"],

Cell[BoxData["7.`"], "Output"]
}, Open  ]],

Cell[TextData[{
 "If the final argument, the destination vertex, is omitted from ",
 StyleBox[ButtonBox["GraphDistance",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphDistance"], "FunctionLink"],
 ", the result will be a list of the lengths of the shortest paths to each \
vertex of the graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphDistance", "[", 
  RowBox[{"exercise2", ",", "\"\<a\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "2.`", ",", "3.`", ",", "5.`", ",", "4.`", ",", "7.`"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "To determine the shortest path from every vertex to every other vertex, use \
the ",
 StyleBox[ButtonBox["GraphDistanceMatrix",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphDistanceMatrix"], "FunctionLink"],
 " function. Algorithm 2 in the Exercises of Section 10.6 describes the \
Floyd-Warshall algorithm (also known as simply the Floyd algorithm), which is \
one method for computing this matrix."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GraphDistanceMatrix", "[", "exercise2", "]"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.`", "2.`", "3.`", "5.`", "4.`", "7.`"},
     {"2.`", "0.`", "5.`", "3.`", "2.`", "5.`"},
     {"3.`", "5.`", "0.`", "6.`", "5.`", "8.`"},
     {"5.`", "3.`", "6.`", "0.`", "1.`", "2.`"},
     {"4.`", "2.`", "5.`", "1.`", "0.`", "3.`"},
     {"7.`", "5.`", "8.`", "2.`", "3.`", "0.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["10.7 Planar Graphs", "Section",
 CellTags->"Section7"],

Cell[TextData[{
 "This section explains how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be used to explore the question of whether a graph is planar by",
 " ",
 "manipulating graphs in order to produce homeomorphic graphs and applying \
Kuratowski's Theorem. We consider only undirected simple graphs in this \
section. The question of planarity for a directed graph can be answered by \
considering the underlying undirected graph, which can be obtained by \
applying the function ",
 StyleBox[ButtonBox["UndirectedGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/UndirectedGraph"], "FunctionLink"],
 "."
}], "Text"],

Cell[TextData[{
 "Before looking at how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can help you manipulate graphs to apply Kuratowski\[CloseCurlyQuote]s \
Theorem manually, note that the function ",
 StyleBox[ButtonBox["PlanarGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PlanarGraphQ"], "FunctionLink"],
 ", applied to a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object, will determine whether or not the graph is planar."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlanarGraphQ", "[", 
  RowBox[{"HypercubeGraph", "[", "3", "]"}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlanarGraphQ", "[", 
  RowBox[{"CompleteGraph", "[", "5", "]"}], "]"}]], "Input"],

Cell[BoxData["False"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Elementary Subdivisions, Smoothing, and Homeomorphic Graphs", \
"Subsection",
 CellTags->"Section7a"],

Cell[TextData[{
 "Recall that an elementary subdivision refers to the process of modifying a \
graph by removing an edge ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"u", ",", "v"}], "}"}], TraditionalForm]]],
 " and replacing it with a vertex ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " and new edges ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"u", ",", "w"}], "}"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"w", ",", "v"}], "}"}], TraditionalForm]]],
 ". Effectively, this splits the original edge into two by inserting a vertex \
in the middle of it. It is not difficult to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to perform an elementary subdivision. We will use a cycle graph as an \
example."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subdivideExample", "=", 
  RowBox[{"CycleGraph", "[", 
   RowBox[{"5", ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 2, 4, 6, 8, 10}, {{2}, {5}, {1}, {3}, {2}, {4}, {3}, {5}, {
          1}, {4}}}, Pattern}]}, {
      GraphLayout -> "CircularEmbedding", ImagePadding -> 10, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5877852522924738, -0.8090169943749481}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999994`, 
       350.8354014677217}, {-170.10740146772108`, 154.3110183489848}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We will subdivide the edge ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], TraditionalForm]]],
 ". To do this, we first need to introduce a vertex. We will give this vertex \
the name \[OpenCurlyDoubleQuote]1-2\[CloseCurlyDoubleQuote]. We apply ",
 StyleBox[ButtonBox["ToString",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ToString"], "FunctionLink"],
 " to the integers to create strings and combine them and the hyphen with the \
",
 StyleBox[ButtonBox["StringJoin",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/StringJoin"], "FunctionLink"],
 " (",
 StyleBox["<>", "Input"],
 ") operator. We use the ",
 StyleBox[ButtonBox["VertexAdd",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexAdd"], "FunctionLink"],
 " function to add the vertex to the graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"subdivideExampleB", "=", 
  RowBox[{"VertexAdd", "[", 
   RowBox[{"subdivideExample", ",", 
    RowBox[{
     RowBox[{"ToString", "[", "1", "]"}], "<>", "\"\<-\>\"", "<>", 
     RowBox[{"ToString", "[", "2", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, "1-2"}, {Null, 
       SparseArray[
       Automatic, {6, 6}, 0, {
        1, {{0, 2, 4, 6, 8, 10, 10}, {{2}, {5}, {1}, {3}, {2}, {4}, {3}, {
          5}, {1}, {4}}}, Pattern}]}, {
      GraphLayout -> "CircularEmbedding", ImagePadding -> 10, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.23195562668532854`, -0.9229386323103799}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5952268906880097, -2.040972621060275}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.770797395272956, -2.040972621060276}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{2.1340686592756355`, -0.9229386323103819}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.1830121429804816`, -0.2319556266853282}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.23195562668532846`, -2.5048838744309334`}, 
           0.02478814347755698], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["\"1-2\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.8, 350.69289964032333`}, {-208.96489964032355`, 
       192.94303744196327`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has moved the original vertices. We can put them back in place by using ",
 StyleBox[ButtonBox["PropertyValue",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PropertyValue"], "FunctionLink"],
 " to assign the ",
 StyleBox[ButtonBox["VertexCoordinates",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/VertexCoordinates"], "FunctionLink"],
 " property in the new graph to the position in the old."
}], "Text"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PropertyValue", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"subdivideExampleB", ",", "v"}], "}"}], ",", 
      "VertexCoordinates"}], "]"}], "=", 
    RowBox[{"PropertyValue", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"subdivideExample", ",", "v"}], "}"}], ",", 
      "VertexCoordinates"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"VertexList", "[", "subdivideExample", "]"}]}], "}"}]}], 
  "]"}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData["subdivideExampleB"], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, "1-2"}, {Null, 
       SparseArray[
       Automatic, {6, 6}, 0, {
        1, {{0, 2, 4, 6, 8, 10, 10}, {{2}, {5}, {1}, {3}, {2}, {4}, {3}, {
          5}, {1}, {4}}}, Pattern}]}, {
      GraphLayout -> "CircularEmbedding", ImagePadding -> 10, 
       VertexCoordinates -> {{-0.9510565162951538, 
        0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
        0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
        0.30901699437494634`}, {-7.044813998280222*^-16, 1.}, {
        0.23195562668532846`, -2.5048838744309334`}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
           0.033753937858755134`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
           0.033753937858755134`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5877852522924738, -0.8090169943749481}, 
           0.033753937858755134`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
           0.033753937858755134`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{-7.044813998280222*^-16, 1.}, 0.033753937858755134`], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.23195562668532846`, -2.5048838744309334`}, 
           0.033753937858755134`], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["\"1-2\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{13.630264353388572`, 
       244.47448671959245`}, {-216.14647962430024`, 200.55494622074707`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Now we place the new vertex along the edge which is to be deleted. This is \
done by using ",
 StyleBox[ButtonBox["PropertyValue",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PropertyValue"], "FunctionLink"],
 " and averaging the positions of the existing vertices."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PropertyValue", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"subdivideExampleB", ",", "\"\<1-2\>\""}], "}"}], ",", 
    "VertexCoordinates"}], "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"PropertyValue", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"subdivideExample", ",", "1"}], "}"}], ",", 
       "VertexCoordinates"}], "]"}], "+", 
     RowBox[{"PropertyValue", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"subdivideExample", ",", "2"}], "}"}], ",", 
       "VertexCoordinates"}], "]"}]}], ")"}], "/", "2"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.7694208842938132`"}], ",", 
   RowBox[{"-", "0.2499999999999992`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["subdivideExampleB"], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, "1-2"}, {Null, 
       SparseArray[
       Automatic, {6, 6}, 0, {
        1, {{0, 2, 4, 6, 8, 10, 10}, {{2}, {5}, {1}, {3}, {2}, {4}, {3}, {
          5}, {1}, {4}}}, Pattern}]}, {
      GraphLayout -> "CircularEmbedding", ImagePadding -> 10, 
       VertexCoordinates -> {{-0.9510565162951538, 
        0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
        0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
        0.30901699437494634`}, {-7.044813998280222*^-16, 
        1.}, {-0.7694208842938132, -0.2499999999999992}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5877852522924738, -0.8090169943749481}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.7694208842938132, -0.2499999999999992}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["\"1-2\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999994`, 
       350.8354014677217}, {-170.10740146772108`, 154.3110183489848}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Now we simply remove the original edge with ",
 StyleBox[ButtonBox["EdgeDelete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeDelete"], "FunctionLink"],
 " and add the new ones with ",
 StyleBox[ButtonBox["EdgeAdd",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeAdd"], "FunctionLink"],
 ". Recall that the second argument of ",
 StyleBox[ButtonBox["EdgeDelete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EdgeDelete"], "FunctionLink"],
 " must be given using the special symbols \[UndirectedEdge] (\[EscapeKey]ue\
\[EscapeKey]) or \[DirectedEdge] (\[EscapeKey]de\[EscapeKey]), not as a ",
 StyleBox[ButtonBox["Rule",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Rule"], "FunctionLink"],
 " (",
 StyleBox["->", "Input"],
 "). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"subdivideExampleB", "=", 
   RowBox[{"EdgeDelete", "[", 
    RowBox[{"subdivideExampleB", ",", 
     RowBox[{"1", "\[UndirectedEdge]", "2"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"subdivideExampleB", "=", 
   RowBox[{"EdgeAdd", "[", 
    RowBox[{"subdivideExampleB", ",", 
     RowBox[{"1", "\[Rule]", "\"\<1-2\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"subdivideExampleB", "=", 
  RowBox[{"EdgeAdd", "[", 
   RowBox[{"subdivideExampleB", ",", 
    RowBox[{"2", "\[Rule]", "\"\<1-2\>\""}]}], "]"}]}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, "1-2"}, {Null, 
       SparseArray[
       Automatic, {6, 6}, 0, {
        1, {{0, 2, 4, 6, 8, 10, 12}, {{5}, {6}, {3}, {6}, {2}, {4}, {3}, {
          5}, {1}, {4}, {1}, {2}}}, Pattern}]}, {
      GraphLayout -> "CircularEmbedding", ImagePadding -> 10, 
       VertexCoordinates -> {{-0.9510565162951538, 
        0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
        0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
        0.30901699437494634`}, {-7.044813998280222*^-16, 
        1.}, {-0.7694208842938132, -0.2499999999999992}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5877852522924738, -0.8090169943749481}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.7694208842938132, -0.2499999999999992}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["\"1-2\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999994`, 
       350.8354014677217}, {-170.10740146772048`, 154.31101834898476`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell["Based on this example, we create the following function.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"subdivideGraph", "::", "nonedge"}], "=", 
   "\"\<Second argument must be an edge in the graph.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"subdivideGraph", "[", 
    RowBox[{"G_Graph", ",", 
     RowBox[{"E_Rule", "|", "E_UndirectedEdge"}]}], "]"}], "/;", 
   RowBox[{"UndirectedGraphQ", "[", "G", "]"}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"H", ",", "e", ",", "newV", ",", "v"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "E", "]"}], "===", "Rule"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"e", "=", 
        RowBox[{"UndirectedEdge", "@@", "E"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"e", "=", "E"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"EdgeQ", "[", 
         RowBox[{"G", ",", "e"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"subdivideGraph", "::", "nonedge"}], "]"}], ";", 
        RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"newV", "=", 
      RowBox[{
       RowBox[{"ToString", "[", 
        RowBox[{"e", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "<>", "\"\<-\>\"", "<>", 
       RowBox[{"ToString", "[", 
        RowBox[{"e", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"H", "=", 
      RowBox[{"VertexAdd", "[", 
       RowBox[{"G", ",", "newV"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"PropertyValue", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"H", ",", "v"}], "}"}], ",", "VertexCoordinates"}], "]"}], 
        "=", 
        RowBox[{"PropertyValue", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"G", ",", "v"}], "}"}], ",", "VertexCoordinates"}], 
         "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"v", ",", 
         RowBox[{"VertexList", "[", "G", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"PropertyValue", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"H", ",", "newV"}], "}"}], ",", "VertexCoordinates"}], "]"}],
       "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"PropertyValue", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"H", ",", 
             RowBox[{"e", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           "VertexCoordinates"}], "]"}], "+", 
         RowBox[{"PropertyValue", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"H", ",", 
             RowBox[{"e", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
           "VertexCoordinates"}], "]"}]}], ")"}], "/", "2"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"H", "=", 
      RowBox[{"EdgeDelete", "[", 
       RowBox[{"H", ",", "e"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"H", "=", 
      RowBox[{"EdgeAdd", "[", 
       RowBox[{"H", ",", 
        RowBox[{
         RowBox[{"e", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "newV"}]}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"H", "=", 
      RowBox[{"EdgeAdd", "[", 
       RowBox[{"H", ",", 
        RowBox[{"newV", "\[Rule]", 
         RowBox[{"e", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "H"}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",\

 InitializationCell->True],

Cell[TextData[{
 "The inverse operation of elementary subdivision is referred to as \
smoothing. To be precise, let ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " be a vertex of degree 2 with neighbors ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " and such that ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["w", TraditionalForm]]],
 " are not adjacent. We smooth the vertex ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " by deleting ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " and the edges incident to it and adding the edge ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"u", ",", "w"}], "}"}], TraditionalForm]]],
 ". Below we have created a function to implement smoothing. "
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"smoothGraph", "::", "vertx"}], "=", 
   "\"\<Cannot smooth this vertex.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"smoothGraph", "[", 
    RowBox[{"G_Graph", ",", "v_"}], "]"}], "/;", 
   RowBox[{"UndirectedGraphQ", "[", "G", "]"}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"N", ",", "H", ",", "e"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"N", "=", 
      RowBox[{"AdjacencyList", "[", 
       RowBox[{"G", ",", "v"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "N", "]"}], "\[NotEqual]", "2"}], "||", 
        RowBox[{"EdgeQ", "[", 
         RowBox[{"G", ",", 
          RowBox[{"UndirectedEdge", "[", 
           RowBox[{
            RowBox[{"N", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"N", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"smoothGraph", "::", "vertx"}], "]"}], ";", 
        RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"H", "=", 
      RowBox[{"VertexDelete", "[", 
       RowBox[{"G", ",", "v"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"e", "=", 
      RowBox[{"UndirectedEdge", "[", 
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"N", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"H", "=", 
      RowBox[{"EdgeAdd", "[", 
       RowBox[{"H", ",", "e"}], "]"}]}], ";", "\[IndentingNewLine]", "H"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True],

Cell["\<\
As an example, we can smooth the vertex \[OpenCurlyDoubleQuote]1-2\
\[CloseCurlyDoubleQuote] added above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"smoothGraph", "[", 
  RowBox[{"subdivideExampleB", ",", "\"\<1-2\>\""}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, 
       SparseArray[
       Automatic, {5, 5}, 0, {
        1, {{0, 2, 4, 6, 8, 10}, {{5}, {2}, {3}, {1}, {2}, {4}, {3}, {5}, {
          1}, {4}}}, Pattern}]}, {
      GraphLayout -> "CircularEmbedding", ImagePadding -> 10, 
       VertexCoordinates -> {{-0.9510565162951538, 
        0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
        0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
        0.30901699437494634`}, {-7.044813998280222*^-16, 1.}}, 
       VertexLabels -> {"Name", "1-2" -> None}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5877852522924738, -0.8090169943749481}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
           0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999994`, 
       350.8354014677217}, {-170.10740146772218`, 154.31101834898476`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "The textbook defines graphs to be homeomorphic if they can be obtained from \
the same graph from a sequence of elementary subdivisions. It is clear that \
if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["G", "1"], ",", 
    SubscriptBox["G", "2"], ",", 
    SubscriptBox["G", "3"], ",", "\[Ellipsis]", ",", 
    SubscriptBox["G", "n"]}], TraditionalForm]]],
 " is a sequence of graphs, each of which can be obtained from the previous \
by an elementary subdivision, then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["G", "n"], ",", "\[Ellipsis]", ",", 
    SubscriptBox["G", "3"], ",", 
    SubscriptBox["G", "2"], ",", 
    SubscriptBox["G", "1"]}], TraditionalForm]]],
 " is a sequence of graphs, each of which can be obtained from the previous \
by a smoothing. So we can say that two graphs are homeomorphic if one can be \
transformed into the other by a sequence of elementary subdivisions and \
smoothings."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Applying Kuratowski\[CloseCurlyQuote]s Theorem", "Subsection",
 CellTags->"Section7b"],

Cell[TextData[{
 "Recall that Kuratowski's Theorem asserts that a graph is nonplanar if and \
only if it contains a subgraph homeomorphic to either ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    RowBox[{"3", ",", "3"}]], TraditionalForm]]],
 " or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", "5"], TraditionalForm]]],
 ". Using the functions above and those for creating subgraphs, we can use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to manipulate a graph and confirm that it is nonplanar using Kuratowski's \
Theorem. We will illustrate this with the Petersen graph."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"petersen", "=", 
  RowBox[{"PetersenGraph", "[", 
   RowBox[{"5", ",", "2", ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10}, {
      Null, {{1, 3}, {1, 4}, {1, 6}, {2, 4}, {2, 5}, {2, 7}, {3, 5}, {3, 8}, {
       4, 9}, {5, 10}, {6, 7}, {6, 10}, {7, 8}, {8, 9}, {9, 10}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{0.9510565162951535, 0.30901699437494745`}, {
        0.5877852522924732, -0.8090169943749473}, {-0.587785252292473, \
-0.8090169943749476}, {-0.9510565162951536, 
        0.30901699437494723`}, {-2.4492935982947064`*^-16, 1.}, {
        1.902113032590307, 0.6180339887498949}, {
        1.1755705045849465`, -1.6180339887498947`}, {-1.175570504584946, \
-1.6180339887498951`}, {-1.9021130325903073`, 
        0.6180339887498945}, {-4.898587196589413*^-16, 2.}}, 
       VertexLabels -> {"Name"}}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9510565162951535, 0.30901699437494745`}, 
           0.03574187784409402], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5877852522924732, -0.8090169943749473}, 
           0.03574187784409402], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.587785252292473, -0.8090169943749476}, 
           0.03574187784409402], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9510565162951536, 0.30901699437494723`}, 
           0.03574187784409402], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{-2.4492935982947064`*^-16, 1.}, 0.03574187784409402], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.902113032590307, 0.6180339887498949}, 
           0.03574187784409402], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.1755705045849465`, -1.6180339887498947`}, 
           0.03574187784409402], "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-1.175570504584946, -1.6180339887498951`}, 
           0.03574187784409402], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-1.9021130325903073`, 0.6180339887498945}, 
           0.03574187784409402], "DynamicName", BoxID -> "VertexID$9"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          DiskBox[{-4.898587196589413*^-16, 2.}, 0.03574187784409402], 
          "DynamicName", BoxID -> "VertexID$10"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.800000000000011`, 
       351.02547836505175`}, {-170.29747836505152`, 154.24749331713286`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell["\<\
First, we form the subgraph of the Petersen graph obtained by removing vertex \
2 and the three edges incident to it.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"petersen1", "=", 
  RowBox[{"VertexDelete", "[", 
   RowBox[{"petersen", ",", "6"}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 7, 8, 9, 10}, {
      Null, {{1, 3}, {1, 4}, {2, 4}, {2, 5}, {2, 6}, {3, 5}, {3, 7}, {4, 8}, {
       5, 9}, {6, 7}, {7, 8}, {8, 9}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{0.9510565162951535, 0.30901699437494745`}, {
        0.5877852522924732, -0.8090169943749473}, {-0.587785252292473, \
-0.8090169943749476}, {-0.9510565162951536, 
        0.30901699437494723`}, {-2.4492935982947064`*^-16, 1.}, {
        1.1755705045849465`, -1.6180339887498947`}, {-1.175570504584946, \
-1.6180339887498951`}, {-1.9021130325903073`, 
        0.6180339887498945}, {-4.898587196589413*^-16, 2.}}, 
       VertexLabels -> {"Name", 6 -> None}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.9510565162951535, 0.30901699437494745`}, 
           0.034513449892797546`], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5877852522924732, -0.8090169943749473}, 
           0.034513449892797546`], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.587785252292473, -0.8090169943749476}, 
           0.034513449892797546`], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9510565162951536, 0.30901699437494723`}, 
           0.034513449892797546`], "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{-2.4492935982947064`*^-16, 1.}, 0.034513449892797546`], 
          "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{1.1755705045849465`, -1.6180339887498947`}, 
           0.034513449892797546`], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-1.175570504584946, -1.6180339887498951`}, 
           0.034513449892797546`], "DynamicName", BoxID -> "VertexID$7"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-1.9021130325903073`, 0.6180339887498945}, 
           0.034513449892797546`], "DynamicName", BoxID -> "VertexID$8"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          DiskBox[{-4.898587196589413*^-16, 2.}, 0.034513449892797546`], 
          "DynamicName", BoxID -> "VertexID$9"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999947`, 
       350.8585521591683}, {-206.1305521591692, 189.97713160179586`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell["\<\
Now we notice that there are three vertices that are smoothable: 1, 7, and \
10. That is to say, those three vertices have degree 2 and their neighbors \
are not adjacent. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"petersen2", "=", 
   RowBox[{"smoothGraph", "[", 
    RowBox[{"petersen1", ",", "1"}], "]"}]}], ";", 
  RowBox[{"petersen3", "=", 
   RowBox[{"smoothGraph", "[", 
    RowBox[{"petersen2", ",", "7"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"petersen4", "=", 
  RowBox[{"smoothGraph", "[", 
   RowBox[{"petersen3", ",", "10"}], "]"}]}]}], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{2, 3, 4, 5, 8, 9}, {
      Null, {{1, 3}, {1, 4}, {2, 4}, {2, 5}, {3, 6}, {5, 6}, {2, 3}, {1, 5}, {
       4, 6}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{
        0.5877852522924732, -0.8090169943749473}, {-0.587785252292473, \
-0.8090169943749476}, {-0.9510565162951536, 
        0.30901699437494723`}, {-2.4492935982947064`*^-16, 
        1.}, {-1.175570504584946, -1.6180339887498951`}, \
{-1.9021130325903073`, 0.6180339887498945}}, 
       VertexLabels -> {
        "Name", 6 -> None, 1 -> None, 10 -> None, 7 -> None}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          
          DiskBox[{0.5877852522924732, -0.8090169943749473}, 
           0.02743621557726529], "DynamicName", BoxID -> "VertexID$1"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.587785252292473, -0.8090169943749476}, 
           0.02743621557726529], "DynamicName", BoxID -> "VertexID$2"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-0.9510565162951536, 0.30901699437494723`}, 
           0.02743621557726529], "DynamicName", BoxID -> "VertexID$3"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{-2.4492935982947064`*^-16, 1.}, 0.02743621557726529], 
          "DynamicName", BoxID -> "VertexID$4"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-1.175570504584946, -1.6180339887498951`}, 
           0.02743621557726529], "DynamicName", BoxID -> "VertexID$5"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          
          DiskBox[{-1.9021130325903073`, 0.6180339887498945}, 
           0.02743621557726529], "DynamicName", BoxID -> "VertexID$6"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.79999999999999, 
       350.87640028074725`}, {-186.148400280747, 170.36307349351824`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[TextData[{
 "We now observe that this graph has 6 vertices, each of which has degree 3, \
just like ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    RowBox[{"3", ",", "3"}]], TraditionalForm]]],
 ". So there is a definite possibility that this graph is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    RowBox[{"3", ",", "3"}]], TraditionalForm]]],
 ". We have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " confirm that is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    RowBox[{"3", ",", "3"}]], TraditionalForm]]],
 " with ",
 StyleBox[ButtonBox["IsomorphicGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsomorphicGraphQ"], "FunctionLink"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IsomorphicGraphQ", "[", 
  RowBox[{"petersen4", ",", 
   RowBox[{"CompleteGraph", "[", 
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]],

Cell[TextData[{
 "This demonstrates that the Petersen graph has a subgraph that is \
homeomorphic to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["K", 
    RowBox[{"3", ",", "3"}]], TraditionalForm]]],
 " and hence is nonplanar."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["10.8 Graph Coloring", "Section",
 CellTags->"Section8"],

Cell["\<\
In this section we consider the problem of how to properly color a graph; \
that is, how to assign to each vertex of a graph a color such that no vertex \
has the same color as any of its neighbors. \
\>", "Text"],

Cell["\<\
It is worth noting that, in terms of computational complexity, Hamilton \
circuits and graph coloring are equivalently difficult problems.\
\>", "Text"],

Cell[CellGroupData[{

Cell["A Greedy Coloring Algorithm", "Subsection",
 CellTags->"Section8a"],

Cell["\<\
We will create a function based on the algorithm described in the preface to \
Exercise 29 in Section 10.8 of the text. It can be shown that this algorithm \
will color a graph using at most one more color than the maximal degree of \
the graph. It is considered a greedy algorithm because it makes optimal \
choices at each step but never reconsiders its choices. That is to say, it \
does the best it can at every step but never backtracks to make improvements. \
Greedy algorithms often lead to good, but non-optimal, solutions.\
\>", "Text"],

Cell["\<\
The algorithm proceeds as follows. First, the vertices are sorted in order of \
descending degree. The first color is assigned to the first vertex in the \
list. Also assign color 1 to the first vertex in the list not adjacent to \
vertex 1, to the next vertex not adjacent to those already colored, etc. Then \
move on to the second color. The first uncolored vertex in the list is \
assigned color 2, as are vertices further down the list not adjacent to ones \
previously assigned the second color. This continues until all of the \
vertices have been given a color.\
\>", "Text"],

Cell[TextData[{
 "Our first step in implementing this function will be to sort the list of \
vertices in decreasing order of degree. For this, we will make use of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s very flexible ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " function. With no additional instructions, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will sort a list of numbers in increasing numerical order and a list of \
strings in lexicographical order. But the ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " function takes an optional argument that allows us to specify the way in \
which the list is sorted. Specifically, ",
 StyleBox[ButtonBox["Sort",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sort"], "FunctionLink"],
 " takes as an argument a Boolean-valued function on two arguments and \
returns true if the first argument precedes the second."
}], "Text"],

Cell[TextData[{
 "For our graph coloring procedure, we will create a helper function that \
takes a ",
 StyleBox[ButtonBox["Graph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Graph"], "FunctionLink"],
 " object and returns the sorted list of vertices."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sortVertices", "[", "G_Graph", "]"}], ":=", 
  RowBox[{"Sort", "[", 
   RowBox[{
    RowBox[{"VertexList", "[", "G", "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"VertexDegree", "[", 
       RowBox[{"G", ",", "#1"}], "]"}], "\[GreaterEqual]", 
      RowBox[{"VertexDegree", "[", 
       RowBox[{"G", ",", "#2"}], "]"}]}], "&"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell["\<\
In order for our algorithm to color the vertices of a graph, we need to \
decide on what colors to use. We define a list of colors globally.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"colorList", "=", 
  RowBox[{"{", 
   RowBox[{
   "Red", ",", "Green", ",", "Blue", ",", "Magenta", ",", "Orange", ",", 
    "Pink", ",", "Purple", ",", "Cyan", ",", "Brown", ",", "Black"}], 
   "}"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"RGBColor", "[", 
    RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0", ",", "1", ",", "0"}], "]"}], ",", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"1", ",", "0", ",", "1"}], "]"}], ",", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], ",", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"1", ",", "0.5`", ",", "0.5`"}], "]"}], ",", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.5`", ",", "0", ",", "0.5`"}], "]"}], ",", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0", ",", "1", ",", "1"}], "]"}], ",", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.6`", ",", "0.4`", ",", "0.2`"}], "]"}], ",", 
   RowBox[{"GrayLevel", "[", "0", "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["Now we will implement the greedy coloring algorithm.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"greedyColorer", "::", "colorx"}], "=", 
   "\"\<Insufficiently many colors.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"greedyColorer", "[", "G_Graph", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H", "=", "G"}], ",", "V", ",", "currentColor", ",", 
      "excludeSet", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"V", "=", 
      RowBox[{"sortVertices", "[", "H", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"currentColor", "=", "1"}], ",", 
       RowBox[{"currentColor", "\[LessEqual]", 
        RowBox[{"Length", "[", "colorList", "]"}]}], ",", 
       RowBox[{"currentColor", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"PropertyValue", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"H", ",", 
             RowBox[{"V", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "VertexStyle"}], 
          "]"}], "=", 
         RowBox[{"colorList", "[", 
          RowBox[{"[", "currentColor", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"excludeSet", "=", 
         RowBox[{"VertexList", "[", 
          RowBox[{"NeighborhoodGraph", "[", 
           RowBox[{"H", ",", 
            RowBox[{"V", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"V", "=", 
         RowBox[{"Delete", "[", 
          RowBox[{"V", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"i", "=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{"i", "\[LessEqual]", 
           RowBox[{"Length", "[", "V", "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"!", 
             RowBox[{"MemberQ", "[", 
              RowBox[{"excludeSet", ",", 
               RowBox[{"V", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"PropertyValue", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"H", ",", 
                  RowBox[{"V", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
                "VertexStyle"}], "]"}], "=", 
              RowBox[{"colorList", "[", 
               RowBox[{"[", "currentColor", "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"excludeSet", "=", 
              RowBox[{"Union", "[", 
               RowBox[{"excludeSet", ",", 
                RowBox[{"VertexList", "[", 
                 RowBox[{"NeighborhoodGraph", "[", 
                  RowBox[{"H", ",", 
                   RowBox[{"V", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"V", "=", 
              RowBox[{"Delete", "[", 
               RowBox[{"V", ",", "i"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
            RowBox[{"i", "++"}]}], "\[IndentingNewLine]", "]"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"V", "\[Equal]", 
           RowBox[{"{", "}"}]}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"V", "\[NotEqual]", 
        RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"greedyColorer", "::", "colorx"}], "]"}], ";", 
        RowBox[{"Return", "[", "$Failed", "]"}]}], ",", "\[IndentingNewLine]",
        "H"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True],

Cell[TextData[{
 "Note that the list ",
 StyleBox["V", "Input"],
 ", which is initialized to the list of vertices, sorted in decreasing order \
of degree, is used to track which vertices still need to be assigned a color. \
When a vertex has been assigned a color, it is deleted from the list ",
 StyleBox["V", "Input"],
 " using ",
 StyleBox[ButtonBox["Delete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Delete"], "FunctionLink"],
 ". The ",
 StyleBox[ButtonBox["Delete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Delete"], "FunctionLink"],
 " function removes from the list in the first argument the element at the \
position specified by the second argument."
}], "Text"],

Cell[TextData[{
 "The ",
 StyleBox["excludeSet", "Input"],
 " variable is used to store all vertices which cannot be assigned the \
current color. Each time a vertex is assigned a color, it and all of its \
neighbors are added to the ",
 StyleBox["excludeSet", "Input"],
 ". As the function looks down the list of vertices that still need to have a \
color assigned, it checks to see if they are in this set."
}], "Text"],

Cell[TextData[{
 "The index ",
 StyleBox["i", "Input"],
 ", which controls the ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop, is incremented in the else clause of the ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement that tests to see if a vertex can be assigned the color. If the \
vertex at index ",
 StyleBox["i", "Input"],
 " is assigned the color, then it is removed from the list ",
 StyleBox["V", "Input"],
 ", and thus the index ",
 StyleBox["i", "Input"],
 " refers to a different vertex (the vertex previously in position ",
 Cell[BoxData[
  FormBox[
   RowBox[{"i", "+", "1"}], TraditionalForm]]],
 ")."
}], "Text"],

Cell["As an example, we solve Exercise 29 of Section 10.8.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"exercise29", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\"", ",", 
      "\"\<e\>\"", ",", "\"\<f\>\"", ",", "\"\<g\>\"", ",", "\"\<h\>\"", ",", 
      "\"\<i\>\"", ",", "\"\<j\>\""}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<b\>\""}], ",", 
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<d\>\""}], ",", 
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
      RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<h\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<c\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
      RowBox[{"\"\<b\>\"", "\[Rule]", "\"\<f\>\""}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<e\>\""}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<f\>\""}], ",", 
      RowBox[{"\"\<c\>\"", "\[Rule]", "\"\<h\>\""}], ",", 
      RowBox[{"\"\<d\>\"", "\[Rule]", "\"\<g\>\""}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<g\>\""}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<h\>\""}], ",", 
      RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<i\>\""}], ",", 
      RowBox[{"\"\<f\>\"", "\[Rule]", "\"\<i\>\""}], ",", 
      RowBox[{"\"\<f\>\"", "\[Rule]", "\"\<j\>\""}], ",", 
      RowBox[{"\"\<h\>\"", "\[Rule]", "\"\<i\>\""}], ",", 
      RowBox[{"\"\<i\>\"", "\[Rule]", "\"\<j\>\""}]}], "}"}], ",", 
    RowBox[{"DirectedEdges", "\[Rule]", "False"}], ",", 
    RowBox[{"VertexCoordinates", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "0"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
    RowBox[{"ImagePadding", "\[Rule]", "10"}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "e", "f", "g", "h", "i", "j"}, {
      Null, {{1, 2}, {1, 4}, {1, 5}, {1, 8}, {2, 3}, {2, 5}, {2, 6}, {3, 5}, {
       3, 6}, {3, 8}, {4, 7}, {5, 7}, {5, 8}, {5, 9}, {6, 9}, {6, 10}, {8, 
       9}, {9, 10}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{0, 2}, {1, 2}, {2, 2}, {0, 1}, {1, 1}, {2, 1}, {
        0, 0}, {1, 0}, {2, 0}, {3, 0}}, VertexLabels -> {"Name"}}]], 
    Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          DiskBox[{0., 2.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 2.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 2.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"f\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          DiskBox[{0., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["\"g\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          DiskBox[{1., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["\"h\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          DiskBox[{2., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["\"i\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          DiskBox[{3., 0.}, 0.030239520958083826`], "DynamicName", BoxID -> 
          "VertexID$10"], 
         InsetBox[
          FormBox["\"j\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       348.96251325656397`}, {-125.23451325656406`, 108.2780293484641}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"greedyColorer", "[", "exercise29", "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{"a", "b", "c", "d", "e", "f", "g", "h", "i", "j"}, {
      Null, {{1, 2}, {1, 4}, {1, 5}, {1, 8}, {2, 3}, {2, 5}, {2, 6}, {3, 5}, {
       3, 6}, {3, 8}, {4, 7}, {5, 7}, {5, 8}, {5, 9}, {6, 9}, {6, 10}, {8, 
       9}, {9, 10}}}, {
      ImagePadding -> 10, 
       VertexCoordinates -> {{0, 2}, {1, 2}, {2, 2}, {0, 1}, {1, 1}, {2, 1}, {
        0, 0}, {1, 0}, {2, 0}, {3, 0}}, VertexLabels -> {"Name"}, 
       VertexStyle -> {
        "a" -> RGBColor[0, 1, 0], "h" -> RGBColor[0, 0, 1], "i" -> 
         RGBColor[0, 1, 0], "f" -> RGBColor[1, 0, 0], "b" -> 
         RGBColor[0, 0, 1], "j" -> RGBColor[0, 0, 1], "e" -> 
         RGBColor[1, 0, 0], "g" -> RGBColor[0, 1, 0], "c" -> 
         RGBColor[0, 1, 0], "d" -> RGBColor[1, 0, 0]}}]], Typeset`boxes, 
    Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 2.}, 0.030239520958083826`], 
           RGBColor[0, 1, 0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["\"a\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 2.}, 0.030239520958083826`], 
           RGBColor[0, 0, 1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["\"b\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 2.}, 0.030239520958083826`], 
           RGBColor[0, 1, 0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["\"c\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 1.}, 0.030239520958083826`], 
           RGBColor[1, 0, 0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["\"d\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 1.}, 0.030239520958083826`], 
           RGBColor[1, 0, 0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["\"e\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 1.}, 0.030239520958083826`], 
           RGBColor[1, 0, 0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["\"f\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.}, 0.030239520958083826`], 
           RGBColor[0, 1, 0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["\"g\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1., 0.}, 0.030239520958083826`], 
           RGBColor[0, 0, 1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["\"h\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2., 0.}, 0.030239520958083826`], 
           RGBColor[0, 1, 0], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["\"i\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{3., 0.}, 0.030239520958083826`], 
           RGBColor[0, 0, 1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$10"], 
         InsetBox[
          FormBox["\"j\"", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{15.799999999999997`, 
       348.96251325656397`}, {-125.23451325656406`, 108.2780293484641}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImagePadding->10]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Solutions to Computer Projects and Computations and Explorations\
\>", "Section",
 CellTags->"Solutions"],

Cell[CellGroupData[{

Cell["Computations and Explorations 1", "Subsection",
 CellTags->"SolutionsCE1"],

Cell["Display all simple graphs with four vertices.", "Problem"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " To solve this problem, we will generate all possible edge sets and then \
construct the graphs based on these edge sets. The possible edge sets are all \
of the subsets of the set of all possible edges, which we obtain from the \
complete graph on the vertices. We will generalize the question and have our \
function create all the simple graphs on ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"allGraphs", "[", "n_Integer", "]"}], "/;", 
   RowBox[{"n", ">", "0"}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"cg", ",", "v", ",", 
      RowBox[{"A", "=", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"V", "=", 
       RowBox[{"Range", "[", "n", "]"}]}], ",", "powerE", ",", "vCoords", ",",
       "E"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"cg", "=", 
      RowBox[{"CompleteGraph", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"powerE", "=", 
      RowBox[{"Subsets", "[", 
       RowBox[{"EdgeList", "[", "cg", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vCoords", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"PropertyValue", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"cg", ",", "v"}], "}"}], ",", "VertexCoordinates"}], "]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"Range", "[", "n", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"AppendTo", "[", 
        RowBox[{"A", ",", 
         RowBox[{"Graph", "[", 
          RowBox[{"V", ",", "E", ",", 
           RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
           RowBox[{"ImagePadding", "\[Rule]", "10"}], ",", 
           RowBox[{"VertexCoordinates", "\[Rule]", "vCoords"}]}], "]"}]}], 
        "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"E", ",", "powerE"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "A"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 InitializationCell->True],

Cell[TextData[{
 "Recall that the complete graph on ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices has ",
 Cell[BoxData[
  FormBox[
   RowBox[{"C", "(", 
    RowBox[{"n", ",", "2"}], ")"}], TraditionalForm]]],
 " edges, so there are ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", 
    RowBox[{"C", "(", 
     RowBox[{"n", ",", "2"}], ")"}]], TraditionalForm]]],
 " graphs on ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices. So on 4 vertices, there are 64 graphs. For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", " ", "=", " ", "3"}], TraditionalForm]]],
 ", there are only 8 graphs, which is more manageable."
}], "Text"],

Cell[TextData[{
 "We use the ",
 StyleBox[ButtonBox["Partition",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Partition"], "FunctionLink"],
 " function to break the list of all graphs into triples and then apply ",
 StyleBox[ButtonBox["Grid",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Grid"], "FunctionLink"],
 " with the ",
 StyleBox[ButtonBox["Frame",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Frame"], "FunctionLink"],
 " option in order to display the results in a useful way."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"allGraphs", "[", "3", "]"}], ",", "3"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3}, {}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.8660254037844384, -0.4999999999999994}, {
            0.8660254037844389, -0.5000000000000012}, {
            1.8369701987210297`*^-16, 1.}}, VertexLabels -> {"Name"}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[{
             TagBox[
              
              DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$1"], 
             
             InsetBox[
              FormBox["1", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$1"], 
           TagBox[{
             TagBox[
              
              DiskBox[{0.8660254037844389, -0.5000000000000012}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$2"], 
             
             InsetBox[
              FormBox["2", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$2"], 
           TagBox[{
             TagBox[
              DiskBox[{1.8369701987210297`*^-16, 1.}, 0.020399597244776385`], 
              "DynamicName", BoxID -> "VertexID$3"], 
             InsetBox[
              FormBox["3", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$3"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.199999999999985`, 
           174.989440195079}, {-82.11744019507914, 65.5670819295514}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10], 
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3}, {Null, {{1, 2}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.8660254037844384, -0.4999999999999994}, {
            0.8660254037844389, -0.5000000000000012}, {
            1.8369701987210297`*^-16, 1.}}, VertexLabels -> {"Name"}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{
             DynamicLocation["VertexID$1", Automatic, Center], 
             DynamicLocation["VertexID$2", Automatic, Center]}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[{
             TagBox[
              
              DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$1"], 
             
             InsetBox[
              FormBox["1", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$1"], 
           TagBox[{
             TagBox[
              
              DiskBox[{0.8660254037844389, -0.5000000000000012}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$2"], 
             
             InsetBox[
              FormBox["2", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$2"], 
           TagBox[{
             TagBox[
              DiskBox[{1.8369701987210297`*^-16, 1.}, 0.020399597244776385`], 
              "DynamicName", BoxID -> "VertexID$3"], 
             InsetBox[
              FormBox["3", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$3"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.199999999999985`, 
           174.98944019507894`}, {-82.11744019507914, 65.5670819295514}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10], 
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3}, {Null, {{1, 3}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.8660254037844384, -0.4999999999999994}, {
            0.8660254037844389, -0.5000000000000012}, {
            1.8369701987210297`*^-16, 1.}}, VertexLabels -> {"Name"}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{
             DynamicLocation["VertexID$1", Automatic, Center], 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[{
             TagBox[
              
              DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$1"], 
             
             InsetBox[
              FormBox["1", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$1"], 
           TagBox[{
             TagBox[
              
              DiskBox[{0.8660254037844389, -0.5000000000000012}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$2"], 
             
             InsetBox[
              FormBox["2", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$2"], 
           TagBox[{
             TagBox[
              DiskBox[{1.8369701987210297`*^-16, 1.}, 0.020399597244776385`], 
              "DynamicName", BoxID -> "VertexID$3"], 
             InsetBox[
              FormBox["3", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$3"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.199999999999985`, 
           174.98944019507903`}, {-82.11744019507914, 65.5670819295514}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10]},
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3}, {Null, {{2, 3}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.8660254037844384, -0.4999999999999994}, {
            0.8660254037844389, -0.5000000000000012}, {
            1.8369701987210297`*^-16, 1.}}, VertexLabels -> {"Name"}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{
             DynamicLocation["VertexID$2", Automatic, Center], 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[{
             TagBox[
              
              DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$1"], 
             
             InsetBox[
              FormBox["1", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$1"], 
           TagBox[{
             TagBox[
              
              DiskBox[{0.8660254037844389, -0.5000000000000012}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$2"], 
             
             InsetBox[
              FormBox["2", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$2"], 
           TagBox[{
             TagBox[
              DiskBox[{1.8369701987210297`*^-16, 1.}, 0.020399597244776385`], 
              "DynamicName", BoxID -> "VertexID$3"], 
             InsetBox[
              FormBox["3", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$3"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.199999999999985`, 
           174.989440195079}, {-82.11744019507887, 65.56708192955142}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10], 
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3}, {Null, {{1, 2}, {1, 3}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.8660254037844384, -0.4999999999999994}, {
            0.8660254037844389, -0.5000000000000012}, {
            1.8369701987210297`*^-16, 1.}}, VertexLabels -> {"Name"}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{{
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$2", Automatic, Center]}, {
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$3", Automatic, Center]}}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[{
             TagBox[
              
              DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$1"], 
             
             InsetBox[
              FormBox["1", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$1"], 
           TagBox[{
             TagBox[
              
              DiskBox[{0.8660254037844389, -0.5000000000000012}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$2"], 
             
             InsetBox[
              FormBox["2", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$2"], 
           TagBox[{
             TagBox[
              DiskBox[{1.8369701987210297`*^-16, 1.}, 0.020399597244776385`], 
              "DynamicName", BoxID -> "VertexID$3"], 
             InsetBox[
              FormBox["3", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$3"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.199999999999985`, 
           174.98944019507894`}, {-82.11744019507887, 65.56708192955142}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10], 
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3}, {Null, {{1, 2}, {2, 3}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.8660254037844384, -0.4999999999999994}, {
            0.8660254037844389, -0.5000000000000012}, {
            1.8369701987210297`*^-16, 1.}}, VertexLabels -> {"Name"}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{{
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$2", Automatic, Center]}, {
              DynamicLocation["VertexID$2", Automatic, Center], 
              DynamicLocation["VertexID$3", Automatic, Center]}}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[{
             TagBox[
              
              DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$1"], 
             
             InsetBox[
              FormBox["1", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$1"], 
           TagBox[{
             TagBox[
              
              DiskBox[{0.8660254037844389, -0.5000000000000012}, 
               0.020399597244776385`], "DynamicName", BoxID -> "VertexID$2"], 
             
             InsetBox[
              FormBox["2", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$2"], 
           TagBox[{
             TagBox[
              DiskBox[{1.8369701987210297`*^-16, 1.}, 0.020399597244776385`], 
              "DynamicName", BoxID -> "VertexID$3"], 
             InsetBox[
              FormBox["3", TraditionalForm], 
              Offset[{2, 2}, 
               DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
              ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
            BoxID -> "VertexLabelID$3"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.199999999999985`, 
           174.98944019507903`}, {-82.11744019507887, 65.56708192955142}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Computations and Explorations 2", "Subsection",
 CellTags->"SolutionsCE2"],

Cell["\<\
Display a full set of nonisomorphic simple graphs with six vertices.\
\>", "Problem"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " The solution to this exercise is very similar to the previous question. \
The only difference is that, once the list of graphs is generated, we remove \
those that are isomorphic to others by applying ",
 StyleBox[ButtonBox["DeleteDuplicates",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DeleteDuplicates"], "FunctionLink"],
 " with second argument ",
 StyleBox[ButtonBox["IsomorphicGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsomorphicGraphQ"], "FunctionLink"],
 ". This uses ",
 StyleBox[ButtonBox["IsomorphicGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsomorphicGraphQ"], "FunctionLink"],
 " to determine whether two elements are to be considered duplicates or not."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"nonIsoGraphs", "[", "n_Integer", "]"}], "/;", 
   RowBox[{"n", ">", "0"}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A", "=", 
       RowBox[{"{", "}"}]}], ",", "cg", ",", "v", ",", 
      RowBox[{"V", "=", 
       RowBox[{"Range", "[", "n", "]"}]}], ",", "powerE", ",", "vCoords", ",",
       "E", ",", "i", ",", "G", ",", "j"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"cg", "=", 
      RowBox[{"CompleteGraph", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"powerE", "=", 
      RowBox[{"Subsets", "[", 
       RowBox[{"EdgeList", "[", "cg", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vCoords", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"PropertyValue", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"cg", ",", "v"}], "}"}], ",", "VertexCoordinates"}], "]"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"v", ",", 
          RowBox[{"Range", "[", "n", "]"}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"AppendTo", "[", 
        RowBox[{"A", ",", 
         RowBox[{"Graph", "[", 
          RowBox[{"V", ",", "E", ",", 
           RowBox[{"ImagePadding", "\[Rule]", "10"}], ",", 
           RowBox[{"VertexCoordinates", "\[Rule]", "vCoords"}]}], "]"}]}], 
        "]"}], "\[IndentingNewLine]", ",", 
       RowBox[{"{", 
        RowBox[{"E", ",", "powerE"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"DeleteDuplicates", "[", 
      RowBox[{"A", ",", "IsomorphicGraphQ"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True],

Cell["\<\
We apply this to five vertices, since six takes a bit more time to compute.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nonIso5", "=", 
   RowBox[{"nonIsoGraphs", "[", "5", "]"}]}], ";"}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "nonIso5", "]"}]], "Input"],

Cell[BoxData["34"], "Output"]
}, Open  ]],

Cell["\<\
We see that there are 34 nonisomorphic graphs on 5 vertices. Here are the \
first eight.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"nonIso5", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "8"}], "]"}], "]"}], ",", "3"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5}, {}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.9510565162951538, 
            0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
            0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
            0.30901699437494634`}, {-7.044813998280222*^-16, 1.}}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[
            
            DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
           TagBox[
            
            DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
           TagBox[
            
            DiskBox[{0.5877852522924738, -0.8090169943749481}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
           TagBox[
            
            DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
           TagBox[
            DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
            "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.200000000000005`, 167.8}, {-75.928, 
           72.32283216422812}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10], 
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5}, {Null, {{1, 2}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.9510565162951538, 
            0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
            0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
            0.30901699437494634`}, {-7.044813998280222*^-16, 1.}}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{
             DynamicLocation["VertexID$1", Automatic, Center], 
             DynamicLocation["VertexID$2", Automatic, Center]}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[
            
            DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
           TagBox[
            
            DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
           TagBox[
            
            DiskBox[{0.5877852522924738, -0.8090169943749481}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
           TagBox[
            
            DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
           TagBox[
            DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
            "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.200000000000005`, 167.8}, {-75.928, 
           72.32283216422812}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10], 
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5}, {Null, {{1, 2}, {1, 3}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.9510565162951538, 
            0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
            0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
            0.30901699437494634`}, {-7.044813998280222*^-16, 1.}}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{{
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$2", Automatic, Center]}, {
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$3", Automatic, Center]}}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[
            
            DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
           TagBox[
            
            DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
           TagBox[
            
            DiskBox[{0.5877852522924738, -0.8090169943749481}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
           TagBox[
            
            DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
           TagBox[
            DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
            "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.200000000000005`, 167.8}, {-75.928, 
           72.32283216422812}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10]},
    {
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5}, {Null, {{1, 2}, {3, 4}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.9510565162951538, 
            0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
            0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
            0.30901699437494634`}, {-7.044813998280222*^-16, 1.}}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{{
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$2", Automatic, Center]}, {
              DynamicLocation["VertexID$3", Automatic, Center], 
              DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[
            
            DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
           TagBox[
            
            DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
           TagBox[
            
            DiskBox[{0.5877852522924738, -0.8090169943749481}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
           TagBox[
            
            DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
           TagBox[
            DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
            "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.200000000000005`, 167.8}, {-75.928, 
           72.32283216422812}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10], 
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5}, {Null, {{1, 2}, {1, 3}, {1, 4}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.9510565162951538, 
            0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
            0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
            0.30901699437494634`}, {-7.044813998280222*^-16, 1.}}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{{
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$2", Automatic, Center]}, {
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$3", Automatic, Center]}, {
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$4", Automatic, Center]}}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[
            
            DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
           TagBox[
            
            DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
           TagBox[
            
            DiskBox[{0.5877852522924738, -0.8090169943749481}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
           TagBox[
            
            DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
           TagBox[
            DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
            "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.200000000000005`, 167.8}, {-75.928, 
           72.32283216422812}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10], 
     GraphicsBox[
      NamespaceBox["NetworkGraphics",
       DynamicModuleBox[{Typeset`graph = HoldComplete[
         Graph[{1, 2, 3, 4, 5}, {Null, {{1, 2}, {1, 3}, {2, 3}}}, {
          ImagePadding -> 10, 
           VertexCoordinates -> {{-0.9510565162951538, 
            0.3090169943749484}, {-0.5877852522924726, -0.8090169943749468}, {
            0.5877852522924738, -0.8090169943749481}, {0.9510565162951533, 
            0.30901699437494634`}, {-7.044813998280222*^-16, 1.}}}]], 
        Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
           Directive[
            Opacity[0.7], 
            Hue[0.6, 0.7, 0.5]], 
           LineBox[{{
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$2", Automatic, Center]}, {
              DynamicLocation["VertexID$1", Automatic, Center], 
              DynamicLocation["VertexID$3", Automatic, Center]}, {
              DynamicLocation["VertexID$2", Automatic, Center], 
              DynamicLocation["VertexID$3", Automatic, Center]}}]}, {
           Directive[
            Hue[0.6, 0.2, 0.8], 
            EdgeForm[
             Directive[
              GrayLevel[0], 
              Opacity[0.7]]]], 
           TagBox[
            
            DiskBox[{-0.9510565162951538, 0.3090169943749484}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$1"], 
           TagBox[
            
            DiskBox[{-0.5877852522924726, -0.8090169943749468}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$2"], 
           TagBox[
            
            DiskBox[{0.5877852522924738, -0.8090169943749481}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$3"], 
           TagBox[
            
            DiskBox[{0.9510565162951533, 0.30901699437494634`}, 
             0.021812234931106983`], "DynamicName", BoxID -> "VertexID$4"], 
           TagBox[
            DiskBox[{-7.044813998280222*^-16, 1.}, 0.021812234931106983`], 
            "DynamicName", BoxID -> "VertexID$5"]}}], $CellContext`flag}, 
        TagBox[
         DynamicBox[GraphComputation`NetworkGraphicsBox[
          3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
          CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
           SynchronousUpdating -> False, 
           TrackedSymbols :> {$CellContext`flag}},
          
          ImageSizeCache->{{12.200000000000005`, 167.8}, {-75.928, 
           72.32283216422812}}],
         MouseAppearanceTag["NetworkGraphics"]],
        AllowKernelInitialization->False,
        UnsavedVariables:>{$CellContext`flag}]],
      DefaultBaseStyle->{
       "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
        Hue[0.8, 1., 0.6]},
      FrameTicks->None,
      ImagePadding->10]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Computations and Explorations 9", "Subsection",
 CellTags->"SolutionsCE9"],

Cell["\<\
Generate at random simple graphs with 10 vertices. Stop when you have \
constructed one with an Euler circuit. Display an Euler circuit in this graph.\
\>", "Problem"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " To generate the random graphs, we will use the ",
 StyleBox[ButtonBox["RandomGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RandomGraph"], "FunctionLink"],
 " function. By passing this function a list containing a number of vertices \
and a number of edges, it produces a graph with that number of vertices and \
edges. To display a random graph on 10 vertices and 15 edges, we enter the \
following."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomGraph", "[", 
  RowBox[{"{", 
   RowBox[{"10", ",", "15"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10}, {Null, 
       SparseArray[
       Automatic, {10, 10}, 0, {
        1, {{0, 4, 6, 9, 12, 16, 18, 19, 21, 25, 30}, {{5}, {6}, {9}, {10}, {
          5}, {9}, {4}, {6}, {8}, {3}, {8}, {10}, {1}, {2}, {9}, {10}, {1}, {
          3}, {10}, {3}, {4}, {1}, {2}, {5}, {10}, {1}, {4}, {5}, {7}, {9}}}, 
         Pattern}]}]], Typeset`boxes, Typeset`boxes$s2d = GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$9", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{1.7063396559326893`, 0.4391656540641528}, 
         0.038138236250704505`], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{0., 0.6023702050420664}, 0.038138236250704505`], 
        "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{3.708522809602342, 0.5438238196407208}, 
         0.038138236250704505`], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{3.164985216322668, 1.273199508133036}, 
         0.038138236250704505`], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{0.8440875674393473, 0.9932317797864253}, 
         0.038138236250704505`], "DynamicName", BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{2.8173034497713543`, 0.}, 0.038138236250704505`], 
        "DynamicName", BoxID -> "VertexID$6"], 
       TagBox[
        DiskBox[{1.5626878508771038`, 2.4451186049731444`}, 
         0.038138236250704505`], "DynamicName", BoxID -> "VertexID$7"], 
       TagBox[
        DiskBox[{4.17921031249247, 1.2114553350265804`}, 
         0.038138236250704505`], "DynamicName", BoxID -> "VertexID$8"], 
       TagBox[
        DiskBox[{0.9065820000531011, 0.5274851597694081}, 
         0.038138236250704505`], "DynamicName", BoxID -> "VertexID$9"], 
       TagBox[
        DiskBox[{1.755075887653217, 1.3135782410951953`}, 
         0.038138236250704505`], "DynamicName", BoxID -> 
        "VertexID$10"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.1800000000000015`, 352.82}, {-106.1072, 
       100.09355150158873`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 "Alternately, the argument to ",
 StyleBox[ButtonBox["RandomGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RandomGraph"], "FunctionLink"],
 " can be a graph distribution, which is a probability distribution on the \
sample space consisting of graphs. There are six built-in graph \
distributions. We will use the ",
 StyleBox[ButtonBox["BernoulliGraphDistribution",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/BernoulliGraphDistribution"], "FunctionLink"],
 ", which allows you to specify a number of vertices and a probability. The \
probability indicates the independent probability that an edge will appear \
between any two vertices. It accepts two arguments, the number of vertices \
and the probability. The following constructs a random graph with 10 vertices \
and with each edge as likely to appear as not."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomGraph", "[", 
  RowBox[{"BernoulliGraphDistribution", "[", 
   RowBox[{"10", ",", ".5"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10}, {
      Null, SparseArray[
       Automatic, {10, 10}, 0, {
        1, {{0, 6, 10, 12, 14, 15, 17, 18, 19, 19, 19}, {{2}, {3}, {4}, {5}, {
          8}, {10}, {4}, {5}, {6}, {10}, {6}, {9}, {8}, {10}, {10}, {7}, {
          10}, {8}, {10}}}, {1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
         1, 1, 1}}]}]], Typeset`boxes, Typeset`boxes$s2d = 
    GraphicsGroupBox[{{
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       LineBox[{{
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$2", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$3", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$1", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$4", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$5", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$2", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$6", Automatic, Center]}, {
          DynamicLocation["VertexID$3", Automatic, Center], 
          DynamicLocation["VertexID$9", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$4", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$5", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$7", Automatic, Center]}, {
          DynamicLocation["VertexID$6", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}, {
          DynamicLocation["VertexID$7", Automatic, Center], 
          DynamicLocation["VertexID$8", Automatic, Center]}, {
          DynamicLocation["VertexID$8", Automatic, Center], 
          DynamicLocation["VertexID$10", Automatic, Center]}}]}, {
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[
        DiskBox[{2.6030650496608034`, 0.942288790308188}, 
         0.03546943201558453], "DynamicName", BoxID -> "VertexID$1"], 
       TagBox[
        DiskBox[{3.0605941538635433`, 0.6134492371579503}, 
         0.03546943201558453], "DynamicName", BoxID -> "VertexID$2"], 
       TagBox[
        DiskBox[{1.2399735469181077`, 1.1471377210626392`}, 
         0.03546943201558453], "DynamicName", BoxID -> "VertexID$3"], 
       TagBox[
        DiskBox[{3.762586933753324, 1.1325289861425092`}, 
         0.03546943201558453], "DynamicName", BoxID -> "VertexID$4"], 
       TagBox[
        DiskBox[{3.1009599114385242`, 0.}, 0.03546943201558453], 
        "DynamicName", BoxID -> "VertexID$5"], 
       TagBox[
        DiskBox[{2.2700622723380945`, 1.6281641877412603`}, 
         0.03546943201558453], "DynamicName", BoxID -> "VertexID$6"], 
       TagBox[
        DiskBox[{2.6900745637061814`, 2.7168838607309445`}, 
         0.03546943201558453], "DynamicName", BoxID -> "VertexID$7"], 
       TagBox[
        DiskBox[{3.309828836015046, 1.922678570606581}, 0.03546943201558453], 
        "DynamicName", BoxID -> "VertexID$8"], 
       TagBox[
        DiskBox[{0., 1.0490957394007645`}, 0.03546943201558453], 
        "DynamicName", BoxID -> "VertexID$9"], 
       TagBox[
        DiskBox[{3.1690423419141354`, 1.1228836544727854`}, 
         0.03546943201558453], "DynamicName", BoxID -> 
        "VertexID$10"]}}], $CellContext`flag}, 
    TagBox[
     DynamicBox[GraphComputation`NetworkGraphicsBox[
      3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
      CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
       SynchronousUpdating -> False, TrackedSymbols :> {$CellContext`flag}},
      ImageSizeCache->{{6.1800000000000015`, 
       352.8199999999999}, {-129.10720000000003`, 123.52244866893196`}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False,
    UnsavedVariables:>{$CellContext`flag}]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox[ButtonBox["RandomGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RandomGraph"], "FunctionLink"],
 " also accepts an optional second argument, a positive integer, causing it \
to produce a list of that many random graphs."
}], "Text"],

Cell[TextData[{
 "Recall the description of the ",
 StyleBox[ButtonBox["EulerianGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EulerianGraphQ"], "FunctionLink"],
 " function. When this function is given a graph, it returns true or false \
depending on the existence of an Euler circuit."
}], "Text"],

Cell[TextData[{
 "To satisfy the requirements of this problem, we use ",
 StyleBox[ButtonBox["RandomGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RandomGraph"], "FunctionLink"],
 " to generate a random graph ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 ". Then we test it for an Euler circuit using ",
 StyleBox[ButtonBox["EulerianGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/EulerianGraphQ"], "FunctionLink"],
 ". As long as the randomly generated graph does not have an Euler circuit, \
we continue generating new random graphs. We display the path using ",
 StyleBox[ButtonBox["FindEulerianCycle",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FindEulerianCycle"], "FunctionLink"],
 " and the ",
 StyleBox["animatePath", "Input"],
 " function we created in Section 10.5."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"generateEulerian", "[", "n_Integer", "]"}], "/;", 
   RowBox[{"n", ">", "0"}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"G", ",", "path"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"EulerianGraphQ", "[", "G", "]"}]}], ",", 
       RowBox[{"G", "=", 
        RowBox[{"RandomGraph", "[", 
         RowBox[{"BernoulliGraphDistribution", "[", 
          RowBox[{"n", ",", ".5"}], "]"}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"animatePath", "[", 
      RowBox[{"G", ",", 
       RowBox[{"First", "[", 
        RowBox[{"FindEulerianCycle", "[", "G", "]"}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"generateEulerian", "[", "10", "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i$1896$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i$1896$$], 0, "step"}, 0, 22, 1}}, Typeset`size$$ = {
    360., {100., 105.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i$1896$1897$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`i$1896$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`i$1896$$, $CellContext`i$1896$1897$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> HighlightGraph[
        Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10}, {
         Null, SparseArray[
          Automatic, {10, 10}, 0, {
           1, {{0, 4, 9, 12, 14, 15, 17, 19, 21, 22, 22}, {{2}, {5}, {9}, {
             10}, {3}, {5}, {6}, {7}, {8}, {5}, {6}, {8}, {9}, {10}, {7}, {
             8}, {10}, {8}, {10}, {9}, {10}, {10}}}, {1, 1, 1, 1, 1, 1, 1, 1, 
            1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1}}]}], 
        Part[{
          UndirectedEdge[1, 10], 
          UndirectedEdge[10, 9], 
          UndirectedEdge[9, 8], 
          UndirectedEdge[8, 10], 
          UndirectedEdge[10, 7], 
          UndirectedEdge[7, 8], 
          UndirectedEdge[8, 6], 
          UndirectedEdge[6, 3], 
          UndirectedEdge[3, 8], 
          UndirectedEdge[8, 2], 
          UndirectedEdge[2, 7], 
          UndirectedEdge[7, 5], 
          UndirectedEdge[5, 2], 
          UndirectedEdge[2, 6], 
          UndirectedEdge[6, 10], 
          UndirectedEdge[10, 4], 
          UndirectedEdge[4, 9], 
          UndirectedEdge[9, 1], 
          UndirectedEdge[1, 5], 
          UndirectedEdge[5, 3], 
          UndirectedEdge[3, 2], 
          UndirectedEdge[2, 1]}, 
         Span[1, $CellContext`i$1896$$]]], 
      "Specifications" :> {{{$CellContext`i$1896$$, 0, "step"}, 0, 22, 1, 
         AnimationRunning -> False, AnimationRepetitions -> 1, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{403., {137., 142.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Computations and Explorations 13", "Subsection",
 CellTags->"SolutionsCE13"],

Cell[TextData[{
 "Estimate the probability that a randomly generated simple graph with ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices is connected for each possible integer ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " not exceeding ten by generating a set of random simple graphs and \
determining whether each is connected."
}], "Problem"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " To solve this problem we will create a function that generates a number of \
random graphs of the specified size and counts the number that are connected. \
We use the ",
 StyleBox[ButtonBox["RandomGraph",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/RandomGraph"], "FunctionLink"],
 " function to create the random graphs and the ",
 StyleBox[ButtonBox["ConnectedGraphQ",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ConnectedGraphQ"], "FunctionLink"],
 " function to test them for connectivity."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"connectedProbability", "[", 
    RowBox[{"n_Integer", ",", "max_Integer"}], "]"}], "/;", 
   RowBox[{
    RowBox[{"n", ">", "0"}], "&&", 
    RowBox[{"max", ">", "0"}]}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"G", ",", "i", ",", 
      RowBox[{"count", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "max"}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"G", "=", 
         RowBox[{"RandomGraph", "[", 
          RowBox[{"BernoulliGraphDistribution", "[", 
           RowBox[{"n", ",", ".5"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"ConnectedGraphQ", "[", "G", "]"}], ",", 
          RowBox[{"count", "++"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"count", "/", "max"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"connectedProbability", "[", 
    RowBox[{"i", ",", "100"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   FractionBox["2", "5"], ",", 
   FractionBox["39", "100"], ",", 
   FractionBox["51", "100"], ",", 
   FractionBox["67", "100"], ",", 
   FractionBox["79", "100"], ",", 
   FractionBox["87", "100"], ",", 
   FractionBox["24", "25"], ",", 
   FractionBox["49", "50"], ",", "1"}], "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "Section",
 CellTags->"Exercises"],

Cell[CellGroupData[{

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function to find ",
 StyleBox["all",
  FontSlant->"Italic"],
 " maximal matchings for a bipartite graph."
}], "Item1Exercise"],

Cell[TextData[{
 "Write ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions for calculating the adjacency and incidence matrices for a \
\:fffcpseudograph."
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function for creating a pseudograph from an incidence matrix."
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function to find all of the minimal edge cuts of a given graph."
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function to count the number of Hamilton circuits in a simple graph."
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function to determine whether a mixed graph (with directed edges, multiple \
edges, and loops) has an Euler circuit and, if so, to find such a circuit."
}], "Item1Exercise"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to construct all regular graphs of degree ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ", given a positive integer ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ". (Regular is defined in the Exercises for Section 10.2.)"
}], "Item1Exercise"],

Cell[TextData[{
 "For vertices ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " in a simple, undirected and connected graph ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 ", the local vertex connectivity ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Kappa]", "(", 
    RowBox[{"u", ",", "v"}], ")"}], TraditionalForm]]],
 " is defined to be the minimum number of vertices that must be removed so \
that there is no path between vertex ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " and vertex ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 ". Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function that calculates the local vertex connectivity of a graph and a \
pair of its vertices."
}], "Item1Exercise"],

Cell[TextData[{
 "For vertices ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " in a simple, undirected and connected graph ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]]],
 ", the local edge connectivity ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Lambda]", "(", 
    RowBox[{"u", ",", "v"}], ")"}], TraditionalForm]]],
 " is defined to be the minimum number of edges that must be removed so that \
there is no path between vertex ",
 Cell[BoxData[
  FormBox["u", TraditionalForm]]],
 " and vertex ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 ". Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function that calculates the local edge connectivity of a graph and a pair \
of its vertices."
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function that computes the thickness of a nonplanar simple graph (see the \
Exercises in Section 10.7 for a definition of thickness)."
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function for finding an orientation of a simple graph. (An orientation of \
a graph is defined in the Supplementary Exercises of Chapter 10.)"
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function for finding the bandwidth of a simple graph. (The bandwidth of a \
graph is defined in the Supplementary Exercises of Chapter 10.)"
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function for finding the radius and diameter of a simple graph. (The \
radius and diameter of a graph are defined in the Supplementary Exercises of \
Chapter 10.)"
}], "Item1Exercise"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find the minimum number of queens controlling an ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Times]", "n"}], TraditionalForm]]],
 " chessboard for as many values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " as you can. Make use of the concept of a dominating set, described in the \
Supplementary Exercises of Chapter 10."
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function for finding all self-complementary graphs on ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " vertices. (A self-complementary graph is a graph which is isomorphic to \
its own complement.) Use your function to display the self-complementary \
graphs for as large a ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " as possible."
}], "Item1Exercise"],

Cell[TextData[{
 "Write a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function that finds a total coloring for a graph. A total coloring of a \
graph is an assignment of a color to each vertex and each edge such that: (a) \
no pair of adjacent vertices have the same color; (b) no two edges with a \
common endpoint have the same color; and (c) no edge has the same color as \
either of its endpoints."
}], "Item1Exercise"],

Cell[TextData[{
 "A sequence of positive integers is called ",
 StyleBox["graphic",
  FontSlant->"Italic"],
 " if there is a simple graph that has this sequence as its degree sequence. \
In this context, the degree sequence of a graph is the nondecreasing sequence \
made up of the degrees of the vertices of the graph. Develop a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function for determining whether a sequence of positive integers is \
graphic and, if it is, to construct a graph with this degree sequence."
}], "Item1Exercise"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{725, 850},
WindowMargins->{{26, Automatic}, {Automatic, 27}},
DockedCells->Cell[
  BoxData[
   TagBox[
    GridBox[{{"\"Exploring Discrete Mathematics with Mathematica\"", 
       ActionMenuBox[
       "\"Navigation\"", {
        "\"CloseAll\"" :> Module[{$CellContext`DJSection$}, SelectionMove[
             SelectedNotebook[], All, Notebook]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; 
           Do[NotebookLocate[$CellContext`DJSection$]; FrontEndExecute[
               FrontEndToken["OpenCloseGroup"]], {$CellContext`DJSection$, {
              "Section1a", "Section1b", "Section1c", "Section2a", "Section2b",
                "Section2c", "Section2d", "Section2e", "Section2f", 
               "Section2g", "Section2h", "Section2i", "Section2j", 
               "Section3a", "Section3b", "Section3c", "Section3d", 
               "Section4a", "Section4b", "Section5a", "Section5b", 
               "Section5c", "Section7a", "Section7b", "Section8a", 
               "SolutionsCE1", "SolutionsCE13", "SolutionsCE2", 
               "SolutionsCE9", "Section1", "Section2", "Section3", "Section4",
                "Section5", "Section6", "Section7", "Section8", "Solutions", 
               "Exercises"}}]; SelectionMove[
             SelectedNotebook[], Before, Notebook]], "\"Section1\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Section1"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section2\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Section2"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section3\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Section3"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section4\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Section4"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section5\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Section5"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section6\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Section6"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section7\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Section7"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section8\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Section8"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Solutions\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Solutions"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Exercises\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Section6", "Section7", "Section8", "Solutions", 
                "Exercises"}}] NotebookLocate["Exercises"]; FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Open All\"" :> 
         Module[{$CellContext`DJSection$}, 
           Do[NotebookLocate[$CellContext`DJSection$]; FrontEndExecute[
               FrontEndToken[
               "SelectionOpenAllGroups"]], {$CellContext`DJSection$, {
              "Exercises", "Section1", "Section1a", "Section1b", "Section1c", 
               "Section2", "Section2a", "Section2b", "Section2c", "Section2d",
                "Section2e", "Section2f", "Section2g", "Section2h", 
               "Section2i", "Section2j", "Section3", "Section3a", "Section3b",
                "Section3c", "Section3d", "Section4", "Section4a", 
               "Section4b", "Section5", "Section5a", "Section5b", "Section5c",
                "Section6", "Section7", "Section7a", "Section7b", "Section8", 
               "Section8a", "Solutions", "SolutionsCE1", "SolutionsCE13", 
               "SolutionsCE2", "SolutionsCE9"}}] SelectionMove[
             SelectedNotebook[], Before, Notebook]]}]}}, 
     GridBoxAlignment -> {
      "Columns" -> {Left, Baseline}, "Rows" -> {Right, Baseline}}, AutoDelete -> 
     False, GridBoxItemSize -> {"Columns" -> {
         Scaled[0.8], 
         Scaled[0.2]}}], "Grid"]], "DockedCell", FontFamily -> "Times"],
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
Magnification->1,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Book"}, "Textbook.nb", CharacterEncoding -> 
       "UTF-8"]]], 
   Cell[
    StyleData[All, "Printout"], PageWidth -> PaperWidth, 
    CellHorizontalScrolling -> True, 
    CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
    ShowAutoStyles -> False, 
    AutoStyleOptions -> {"HighlightMisspelledWords" -> False}, ScriptMinSize -> 
    9, MenuSortingValue -> 1500, 
    PrivateFontOptions -> {"FontType" -> "Outline"}, Magnification -> 1], 
   Cell[
    StyleData["Title"], Editable -> False, ShowCellBracket -> Automatic, 
    CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
    DefaultNewInlineCellStyle -> {}, LanguageCategory -> "NaturalLanguage", 
    FontFamily -> "Helvetica", FontSize -> 25, FontWeight -> "Bold", 
    FontColor -> GrayLevel[0.137255]], 
   Cell[
    StyleData["BookChapterTitle", StyleDefinitions -> StyleData["Title"]], 
    CellFrame -> {{0, 0}, {1, 1}}, CellDingbat -> Cell[
      BoxData[
       GraphicsBox[{{
          RGBColor[0.09375, 0.570313, 0.816406], 
          RectangleBox[{0, 0}]}, {
          GrayLevel[1], FontSize -> 35, FontWeight -> Bold, FontFamily -> 
          "Helvetica", 
          InsetBox[
           CounterBox["ChapterNumber"], {0.5, 0.45}, {Center, Center}]}}, 
        ImageSize -> {70, 70}]], "Output"], CellMargins -> {{75, 0}, {20, 5}},
     CellFrameColor -> GrayLevel[1]], 
   Cell[
    StyleData["DockedCell"], CellMargins -> {{0, 12}, {0, 0}}, 
    CellGroupingRules -> "TitleGrouping", 
    ConversionRules :> {"TeX" -> {"\n\\chapter{", "}"}}, 
    TaggingRules :> {"CounterSettings" -> {"CounterTarget" -> "CellGroup"}}, 
    PageBreakAbove -> False, PageBreakBelow -> False, LineSpacing -> {1, 2}, 
    MenuSortingValue -> 1105, FontFamily -> "Helvetica", FontSize -> 20, 
    FontWeight -> "Bold", Background -> 
    RGBColor[0.09375, 0.570313, 0.816406]], 
   Cell[
    StyleData["FunctionLink"], ConversionRules :> {"TeX" -> {{"", 
         $CellContext`ExportAsHyperRef[], ""}, {"", Automatic, ""}}}, 
    MenuSortingValue -> 1105, ButtonStyleMenuListing -> None, FontFamily -> 
    "Courier", FontVariations -> {"Underline" -> True}, FontColor -> 
    RGBColor[0, 0, 1], 
    ButtonBoxOptions -> {Active -> True, ButtonFunction :> (FrontEndExecute[{
         FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> ButtonData}], 
   Cell[
    StyleData["Problem"], CellMargins -> {{40, 12}, {15, 15}}, 
    CellGroupingRules -> {"GroupTogetherNestedGrouping", 15010}, 
    ConversionRules :> {
     "TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, ""}}}, 
    TaggingRules :> {
     "ExtraConversionRules" -> {"General" -> {"RestartList" -> False}}}], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item1Exercise"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Exercise"], "."}], CellSize -> {30, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{50, 12}, {3, 5}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterIncrements -> "Item1Exercise", 
       CounterAssignments -> {{"Item2Exercise", 0}}, MenuSortingValue -> 
       4100], 
      Cell[
       StyleData["Item1Exercise", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Exercise"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{35, 12}, {3, 5}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ExerciseContinuation"], CellMargins -> {{50, 12}, {1, 3}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, MenuSortingValue -> 4101], 
      Cell[
       StyleData["ExerciseContinuation", "Printout"], 
       CellMargins -> {{35, 12}, {1, 3}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item2Exercise"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item2Exercise"], "."}], CellSize -> {32, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{75, 12}, {1, 2}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17100}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterIncrements -> "Item2Exercise", MenuSortingValue -> 4200, 
       CounterBoxOptions -> {CounterFunction :> (Part[
           CharacterRange["a", "z"], #]& )}], 
      Cell[
       StyleData["Item2Exercise", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item2Exercise"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{50, 12}, {1, 2}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterBoxOptions -> {CounterFunction :> (Part[
           CharacterRange["a", "z"], #]& )}]}, Open]], 
   Cell[
    StyleData["ExerciseEquation"], CellMargins -> {{36, 12}, {7, 7}}, 
    CellGroupingRules -> {"GroupTogetherNestedGrouping", 17200}, 
    CellHorizontalScrolling -> True, 
    CellFrameLabels -> {{None, None}, {None, None}}, DefaultFormatType -> 
    TraditionalForm, InputAutoReplacements -> {}, TextAlignment -> Center, 
    MenuSortingValue -> 4300, 
    ButtonBoxOptions -> {Appearance -> {Automatic, None}}], 
   Cell[
    StyleData["myCode"], CellMargins -> {{66, 10}, {5, 10}}, 
    StyleKeyMapping -> {"=" -> "WolframAlphaShort"}, Evaluatable -> False, 
    CellGroupingRules -> "InputGrouping", TextClipboardType -> "InputText", 
    PageBreakWithin -> False, GroupPageBreakWithin -> False, 
    DefaultFormatType -> DefaultInputFormatType, ContextMenu -> 
    FEPrivate`FrontEndResource["ContextMenus", "myCode"], ShowAutoStyles -> 
    True, "TwoByteSyntaxCharacterAutoReplacement" -> True, 
    HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"}, 
    AutoItalicWords -> {}, LanguageCategory -> "Mathematica", FormatType -> 
    InputForm, NumberMarks -> True, 
    LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> "Code", 
    MenuSortingValue -> 1495, MenuCommandKey -> "8", FontWeight -> 
    "Bold", $CellContext`StripStyleOnPaste -> 
    True, $CellContext`AutoQuoteCharacters -> {}, \
$CellContext`PasteAutoQuoteCharacters -> {}], 
   Cell[
    StyleData["CodeVar"], DefaultFormatType -> DefaultInputFormatType, 
    LineBreakWithin -> False, MenuSortingValue -> 10000, FontWeight -> "Bold",
     FontSlant -> "Italic", FontColor -> GrayLevel[0.4]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Section"], CellFrame -> {{6, 0}, {0, 1}}, ShowCellBracket -> 
       Automatic, CellMargins -> {{12, 12}, {3, 24}}, 
       CellGroupingRules -> {"SectionGrouping", 30}, 
       ConversionRules :> {
        "TeX" -> {"\n\\section{", "}"}, 
         "HTML" -> {"<h3 class=\"Section\">", "</h3>"}}, 
       TaggingRules :> {
        "CounterSettings" -> {
          "CounterFormat" -> {"BookChapterNumber", ".", "Section"}, 
           "CounterTarget" -> "Cell", "XRefPrefix" -> "Section"}}, 
       PageBreakBelow -> False, CellFrameMargins -> {{8, 8}, {4, 6}}, 
       CellFrameColor -> RGBColor[0.09375, 0.570313, 0.816406], TabSpacings -> 
       2.1, CounterIncrements -> {
        "Section", "SectionHeader", "SubsectionHeader", "SubsubsectionHeader",
          "SubsubsubsectionHeader"}, FontFamily -> "Helvetica", FontSize -> 
       16, FontWeight -> "Bold", Background -> GrayLevel[0.999985]], 
      Cell[
       StyleData["Section", "Printout"], CellFrame -> {{4, 0}, {0, 0.5}}, 
       CellMargins -> {{2, 2}, {3, 21}}, PageBreakBelow -> False, 
       CellFrameMargins -> {{6, 6}, {3, 5}}, CellFrameColor -> 
       RGBColor[0.09375, 0.570313, 0.816406]], 
      Cell[
       StyleData["Section", "DoubleSpacedPrintout"], 
       CellFrame -> {{4, 0}, {0, 0.5}}, CellMargins -> {{2, 2}, {3, 21}}, 
       PageBreakBelow -> False, CellFrameMargins -> {{6, 6}, {3, 5}}, 
       CellFrameColor -> RGBColor[0.09375, 0.570313, 0.816406], FontSize -> 
       14]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsection"], CellDingbat -> None, 
       CellMargins -> {{12, 12}, {0, 6}}, 
       CellElementSpacings -> {"ClosedGroupTopMargin" -> 12}, 
       CellGroupingRules -> {"SectionGrouping", 50}, 
       ConversionRules :> {
        "TeX" -> {"\n\\subsubsection{", "}"}, 
         "HTML" -> {"<h5 class=\"Subsubsection\">", "</h5>"}}, PageBreakBelow -> 
       False, CellFrameLabelMargins -> 4, 
       CounterIncrements -> {
        "Subsubsection", "SubsubsectionHeader", "SubsubsubsectionHeader"}, 
       FontFamily -> "Helvetica", FontSize -> 11, FontWeight -> "Bold", 
       FontSlant -> "Italic"], 
      Cell[
       StyleData["Subsubsection", "Printout"], PageBreakBelow -> False, 
       FontFamily -> "Helvetica", FontSize -> 11, FontWeight -> "Bold", 
       FontSlant -> "Italic"]}, Open]], 
   Cell[
    StyleData["Equation"], CellMargins -> {{26, 10}, {7, 7}}, 
    ConversionRules :> {
     "HTML" -> {{"", ""}, {"<p class=\"Equation\">", "</p>"}}}, 
    CellHorizontalScrolling -> True, DefaultFormatType -> TraditionalForm, 
    InputAutoReplacements -> {}, TextAlignment -> Center, CounterIncrements -> 
    "Equation", ButtonBoxOptions -> {Appearance -> {Automatic, None}}], 
   Cell[
    StyleData["Subsubsubsection"], CellDingbat -> None, 
    CellMargins -> {{12, 12}, {0, 6}}, 
    CellGroupingRules -> {"SectionGrouping", 60}, 
    ConversionRules :> {
     "TeX" -> {"\n\\subsubsubsection{", "}"}, 
      "HTML" -> {"<h6 class=\"Subsubsubsection\">", "</h6>"}}, PageBreakBelow -> 
    False, CellFrameLabelMargins -> 4, 
    CounterIncrements -> {"Subsubsubsection", "SubsubsubsectionHeader"}, 
    FontFamily -> "Helvetica", FontSize -> 11, FontSlant -> "Italic"]}, 
  Visible -> False, FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, 2013)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Section1"->{
  Cell[2163, 66, 70, 1, 55, "Section",
   CellTags->"Section1"]},
 "Section1a"->{
  Cell[31218, 858, 129, 4, 33, "Subsection",
   CellTags->"Section1a"]},
 "Section1b"->{
  Cell[75484, 1988, 62, 1, 26, "Subsection",
   CellTags->"Section1b"]},
 "Section1c"->{
  Cell[102052, 2657, 113, 4, 27, "Subsection",
   CellTags->"Section1c"]},
 "Section2"->{
  Cell[154022, 3923, 92, 1, 35, "Section",
   CellTags->"Section2"]},
 "Section2a"->{
  Cell[154627, 3944, 52, 1, 32, "Subsection",
   CellTags->"Section2a"]},
 "Section2b"->{
  Cell[174235, 4495, 72, 1, 26, "Subsection",
   CellTags->"Section2b"]},
 "Section2c"->{
  Cell[187385, 4816, 56, 1, 26, "Subsection",
   CellTags->"Section2c"]},
 "Section2d"->{
  Cell[209450, 5358, 62, 1, 26, "Subsection",
   CellTags->"Section2d"]},
 "Section2e"->{
  Cell[263674, 6765, 76, 1, 26, "Subsection",
   CellTags->"Section2e"]},
 "Section2f"->{
  Cell[283032, 7282, 77, 1, 26, "Subsection",
   CellTags->"Section2f"]},
 "Section2g"->{
  Cell[330078, 8454, 98, 2, 26, "Subsection",
   PageBreakWithin->False,
   CellTags->"Section2g"]},
 "Section2h"->{
  Cell[344576, 8865, 96, 2, 26, "Subsection",
   PageBreakWithin->False,
   CellTags->"Section2h"]},
 "Section2i"->{
  Cell[355304, 9125, 62, 1, 26, "Subsection",
   CellTags->"Section2i"]},
 "Section2j"->{
  Cell[378382, 9739, 78, 1, 26, "Subsection",
   CellTags->"Section2j"]},
 "Section3"->{
  Cell[442534, 11232, 88, 1, 35, "Section",
   CellTags->"Section3"]},
 "Section3a"->{
  Cell[442911, 11244, 64, 1, 32, "Subsection",
   CellTags->"Section3a"]},
 "Section3b"->{
  Cell[456350, 11633, 61, 1, 26, "Subsection",
   CellTags->"Section3b"]},
 "Section3c"->{
  Cell[478977, 12348, 64, 1, 26, "Subsection",
   CellTags->"Section3c"]},
 "Section3d"->{
  Cell[494523, 12799, 67, 1, 26, "Subsection",
   CellTags->"Section3d"]},
 "Section4"->{
  Cell[518072, 13453, 59, 1, 35, "Section",
   CellTags->"Section4"]},
 "Section4a"->{
  Cell[542704, 14141, 69, 1, 32, "Subsection",
   CellTags->"Section4a"]},
 "Section4b"->{
  Cell[551719, 14391, 77, 1, 26, "Subsection",
   CellTags->"Section4b"]},
 "Section5"->{
  Cell[562147, 14696, 71, 1, 35, "Section",
   CellTags->"Section5"]},
 "Section5a"->{
  Cell[562896, 14716, 77, 1, 32, "Subsection",
   CellTags->"Section5a"]},
 "Section5b"->{
  Cell[590411, 15453, 75, 1, 26, "Subsection",
   CellTags->"Section5b"]},
 "Section5c"->{
  Cell[622699, 16294, 63, 1, 26, "Subsection",
   CellTags->"Section5c"]},
 "Section6"->{
  Cell[641209, 16768, 69, 1, 35, "Section",
   CellTags->"Section6"]},
 "Section7"->{
  Cell[704098, 18380, 60, 1, 35, "Section",
   CellTags->"Section7"]},
 "Section7a"->{
  Cell[705704, 18436, 107, 2, 32, "Subsection",
   CellTags->"Section7a"]},
 "Section7b"->{
  Cell[748308, 19554, 92, 1, 26, "Subsection",
   CellTags->"Section7b"]},
 "Section8"->{
  Cell[772393, 20144, 61, 1, 35, "Section",
   CellTags->"Section8"]},
 "Section8a"->{
  Cell[772870, 20160, 73, 1, 32, "Subsection",
   CellTags->"Section8a"]},
 "Solutions"->{
  Cell[802489, 20874, 115, 3, 35, "Section",
   CellTags->"Solutions"]},
 "SolutionsCE1"->{
  Cell[802629, 20881, 80, 1, 32, "Subsection",
   CellTags->"SolutionsCE1"]},
 "SolutionsCE2"->{
  Cell[825336, 21444, 80, 1, 26, "Subsection",
   CellTags->"SolutionsCE2"]},
 "SolutionsCE9"->{
  Cell[844845, 21925, 80, 1, 26, "Subsection",
   CellTags->"SolutionsCE9"]},
 "SolutionsCE13"->{
  Cell[862213, 22325, 82, 1, 26, "Subsection",
   CellTags->"SolutionsCE13"]},
 "Exercises"->{
  Cell[865042, 22416, 52, 1, 35, "Section",
   CellTags->"Exercises"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Section1", 890590, 22983},
 {"Section1a", 890672, 22986},
 {"Section1b", 890761, 22989},
 {"Section1c", 890850, 22992},
 {"Section2", 890940, 22995},
 {"Section2a", 891026, 22998},
 {"Section2b", 891116, 23001},
 {"Section2c", 891206, 23004},
 {"Section2d", 891296, 23007},
 {"Section2e", 891386, 23010},
 {"Section2f", 891476, 23013},
 {"Section2g", 891566, 23016},
 {"Section2h", 891683, 23020},
 {"Section2i", 891800, 23024},
 {"Section2j", 891890, 23027},
 {"Section3", 891979, 23030},
 {"Section3a", 892066, 23033},
 {"Section3b", 892157, 23036},
 {"Section3c", 892248, 23039},
 {"Section3d", 892339, 23042},
 {"Section4", 892429, 23045},
 {"Section4a", 892516, 23048},
 {"Section4b", 892607, 23051},
 {"Section5", 892697, 23054},
 {"Section5a", 892784, 23057},
 {"Section5b", 892875, 23060},
 {"Section5c", 892966, 23063},
 {"Section6", 893056, 23066},
 {"Section7", 893142, 23069},
 {"Section7a", 893229, 23072},
 {"Section7b", 893321, 23075},
 {"Section8", 893411, 23078},
 {"Section8a", 893498, 23081},
 {"Solutions", 893589, 23084},
 {"SolutionsCE1", 893681, 23087},
 {"SolutionsCE2", 893778, 23090},
 {"SolutionsCE9", 893875, 23093},
 {"SolutionsCE13", 893973, 23096},
 {"Exercises", 894068, 23099}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 80, 1, 96, "BookChapterTitle",
 CounterAssignments->{{"ChapterNumber", 10}}],
Cell[CellGroupData[{
Cell[684, 27, 31, 0, 55, "Section"],
Cell[718, 29, 390, 12, 35, "Text"],
Cell[1111, 43, 1015, 18, 110, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2163, 66, 70, 1, 55, "Section",
 CellTags->"Section1"],
Cell[2236, 69, 561, 14, 50, "Text"],
Cell[2800, 85, 919, 24, 64, "Text"],
Cell[CellGroupData[{
Cell[3744, 113, 85, 2, 28, "Input"],
Cell[3832, 117, 210, 8, 39, "Output"]
}, Open  ]],
Cell[4057, 128, 1358, 38, 80, "Text"],
Cell[5418, 168, 606, 15, 52, "Text"],
Cell[6027, 185, 131, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[6183, 192, 387, 10, 29, "Input",
 InitializationCell->True],
Cell[6573, 204, 2933, 64, 447, "Output"]
}, Open  ]],
Cell[9521, 271, 328, 10, 21, "Text"],
Cell[CellGroupData[{
Cell[9874, 285, 454, 11, 29, "Input",
 InitializationCell->True],
Cell[10331, 298, 2184, 49, 178, "Output"]
}, Open  ]],
Cell[12530, 350, 351, 10, 36, "Text"],
Cell[CellGroupData[{
Cell[12906, 364, 356, 8, 29, "Input"],
Cell[13265, 374, 2184, 49, 178, "Output"]
}, Open  ]],
Cell[15464, 426, 1048, 26, 68, "Text"],
Cell[16515, 454, 348, 8, 36, "Text"],
Cell[CellGroupData[{
Cell[16888, 466, 413, 11, 29, "Input"],
Cell[17304, 479, 2400, 52, 447, "Output"]
}, Open  ]],
Cell[19719, 534, 452, 14, 21, "Text"],
Cell[CellGroupData[{
Cell[20196, 552, 71, 1, 28, "Input"],
Cell[20270, 555, 128, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20435, 563, 69, 1, 29, "Input"],
Cell[20507, 566, 317, 6, 28, "Output"]
}, Open  ]],
Cell[20839, 575, 992, 27, 53, "Text"],
Cell[CellGroupData[{
Cell[21856, 606, 100, 2, 29, "Input"],
Cell[21959, 610, 574, 16, 56, "Output"]
}, Open  ]],
Cell[22548, 629, 245, 7, 21, "Text"],
Cell[CellGroupData[{
Cell[22818, 640, 77, 1, 29, "Input"],
Cell[22898, 643, 309, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23244, 654, 111, 3, 29, "Input"],
Cell[23358, 659, 566, 16, 56, "Output"]
}, Open  ]],
Cell[23939, 678, 319, 8, 36, "Text"],
Cell[CellGroupData[{
Cell[24283, 690, 1376, 34, 77, "Input",
 InitializationCell->True],
Cell[25662, 726, 5519, 127, 298, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31218, 858, 129, 4, 33, "Subsection",
 CellTags->"Section1a"],
Cell[31350, 864, 484, 12, 37, "Text"],
Cell[31837, 878, 551, 13, 52, "Text"],
Cell[CellGroupData[{
Cell[32413, 895, 450, 10, 45, "Input"],
Cell[32866, 907, 3416, 79, 178, "Output"]
}, Open  ]],
Cell[36297, 989, 1460, 36, 101, "Text"],
Cell[CellGroupData[{
Cell[37782, 1029, 501, 11, 45, "Input"],
Cell[38286, 1042, 3471, 80, 183, "Output"]
}, Open  ]],
Cell[41772, 1125, 445, 9, 51, "Text"],
Cell[CellGroupData[{
Cell[42242, 1138, 631, 15, 45, "Input"],
Cell[42876, 1155, 2882, 65, 183, "Output"]
}, Open  ]],
Cell[45773, 1223, 321, 7, 36, "Text"],
Cell[CellGroupData[{
Cell[46119, 1234, 499, 11, 45, "Input"],
Cell[46621, 1247, 3639, 86, 183, "Output"]
}, Open  ]],
Cell[50275, 1336, 435, 9, 37, "Text"],
Cell[CellGroupData[{
Cell[50735, 1349, 579, 14, 45, "Input"],
Cell[51317, 1365, 2622, 62, 178, "Output"]
}, Open  ]],
Cell[53954, 1430, 1120, 28, 68, "Text"],
Cell[CellGroupData[{
Cell[55099, 1462, 730, 18, 45, "Input"],
Cell[55832, 1482, 3211, 76, 178, "Output"]
}, Open  ]],
Cell[59058, 1561, 535, 16, 51, "Text"],
Cell[CellGroupData[{
Cell[59618, 1581, 504, 11, 45, "Input"],
Cell[60125, 1594, 3446, 79, 189, "Output"]
}, Open  ]],
Cell[63586, 1676, 829, 21, 52, "Text"],
Cell[CellGroupData[{
Cell[64440, 1701, 560, 13, 45, "Input"],
Cell[65003, 1716, 3158, 82, 178, "Output"]
}, Open  ]],
Cell[68176, 1801, 1786, 47, 100, "Text"],
Cell[CellGroupData[{
Cell[69987, 1852, 970, 26, 61, "Input"],
Cell[70960, 1880, 3319, 76, 374, "Output"]
}, Open  ]],
Cell[74294, 1959, 1153, 24, 115, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[75484, 1988, 62, 1, 26, "Subsection",
 CellTags->"Section1b"],
Cell[75549, 1991, 939, 23, 67, "Text"],
Cell[76491, 2016, 91, 2, 20, "Text"],
Cell[CellGroupData[{
Cell[76607, 2022, 633, 14, 45, "Input",
 InitializationCell->True],
Cell[77243, 2038, 3593, 83, 204, "Output"]
}, Open  ]],
Cell[80851, 2124, 196, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[81072, 2134, 228, 6, 29, "Input",
 InitializationCell->True],
Cell[81303, 2142, 4591, 107, 243, "Output"]
}, Open  ]],
Cell[85909, 2252, 255, 7, 35, "Text"],
Cell[CellGroupData[{
Cell[86189, 2263, 372, 10, 29, "Input",
 InitializationCell->True],
Cell[86564, 2275, 4929, 111, 298, "Output"]
}, Open  ]],
Cell[91508, 2389, 284, 5, 35, "Text"],
Cell[CellGroupData[{
Cell[91817, 2398, 224, 6, 29, "Input",
 InitializationCell->True],
Cell[92044, 2406, 4778, 109, 325, "Output"]
}, Open  ]],
Cell[96837, 2518, 117, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[96979, 2525, 173, 4, 29, "Input",
 InitializationCell->True],
Cell[97155, 2531, 4088, 94, 361, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101280, 2630, 76, 1, 29, "Input"],
Cell[101359, 2633, 147, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101543, 2641, 74, 1, 29, "Input"],
Cell[101620, 2644, 383, 7, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[102052, 2657, 113, 4, 27, "Subsection",
 CellTags->"Section1c"],
Cell[102168, 2663, 284, 7, 36, "Text"],
Cell[102455, 2672, 544, 13, 45, "Input",
 InitializationCell->True],
Cell[103002, 2687, 169, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[103196, 2697, 71, 1, 29, "Input"],
Cell[103270, 2700, 366, 8, 24, "Message"],
Cell[103639, 2710, 485, 10, 29, "Output"]
}, Open  ]],
Cell[104139, 2723, 559, 12, 51, "Text"],
Cell[104701, 2737, 494, 14, 36, "Text"],
Cell[105198, 2753, 740, 19, 37, "Text"],
Cell[105941, 2774, 240, 8, 21, "Text"],
Cell[CellGroupData[{
Cell[106206, 2786, 75, 1, 29, "Input"],
Cell[106284, 2789, 2885, 63, 375, "Output"]
}, Open  ]],
Cell[109184, 2855, 857, 24, 53, "Text"],
Cell[CellGroupData[{
Cell[110066, 2883, 143, 3, 29, "Input"],
Cell[110212, 2888, 2998, 65, 375, "Output"]
}, Open  ]],
Cell[113225, 2956, 1310, 34, 69, "Text"],
Cell[114538, 2992, 798, 24, 37, "Text"],
Cell[CellGroupData[{
Cell[115361, 3020, 70, 1, 29, "Input"],
Cell[115434, 3023, 1089, 35, 200, "Output"]
}, Open  ]],
Cell[116538, 3061, 909, 24, 53, "Text"],
Cell[CellGroupData[{
Cell[117472, 3089, 137, 3, 29, "Input"],
Cell[117612, 3094, 2196, 54, 309, "Output"]
}, Open  ]],
Cell[119823, 3151, 545, 12, 52, "Text"],
Cell[CellGroupData[{
Cell[120393, 3167, 857, 17, 45, "Input",
 InitializationCell->True],
Cell[121253, 3186, 781, 15, 28, "Output"]
}, Open  ]],
Cell[122049, 3204, 616, 18, 37, "Text"],
Cell[CellGroupData[{
Cell[122690, 3226, 143, 3, 29, "Input"],
Cell[122836, 3231, 6169, 120, 229, "Output"]
}, Open  ]],
Cell[129020, 3354, 631, 16, 51, "Text"],
Cell[CellGroupData[{
Cell[129676, 3374, 197, 4, 29, "Input"],
Cell[129876, 3380, 6169, 120, 209, "Output"]
}, Open  ]],
Cell[136060, 3503, 856, 21, 67, "Text"],
Cell[CellGroupData[{
Cell[136941, 3528, 253, 5, 45, "Input"],
Cell[137197, 3535, 6242, 114, 209, "Output"]
}, Open  ]],
Cell[143454, 3652, 265, 5, 35, "Text"],
Cell[CellGroupData[{
Cell[143744, 3661, 316, 9, 29, "Input"],
Cell[144063, 3672, 1425, 41, 374, "Output"]
}, Open  ]],
Cell[145503, 3716, 490, 14, 36, "Text"],
Cell[145996, 3732, 1497, 40, 99, "Text"],
Cell[CellGroupData[{
Cell[147518, 3776, 886, 23, 76, "Input"],
Cell[148407, 3801, 4754, 90, 215, "Output"]
}, Open  ]],
Cell[153176, 3894, 797, 23, 53, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[154022, 3923, 92, 1, 35, "Section",
 CellTags->"Section2"],
Cell[154117, 3926, 485, 14, 50, "Text"],
Cell[CellGroupData[{
Cell[154627, 3944, 52, 1, 32, "Subsection",
 CellTags->"Section2a"],
Cell[154682, 3947, 869, 27, 52, "Text"],
Cell[CellGroupData[{
Cell[155576, 3978, 35, 0, 28, "Input"],
Cell[155614, 3980, 5519, 127, 298, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161170, 4112, 104, 2, 29, "Input"],
Cell[161277, 4116, 28, 0, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161342, 4121, 104, 2, 29, "Input"],
Cell[161449, 4125, 28, 0, 28, "Output"]
}, Open  ]],
Cell[161492, 4128, 902, 26, 67, "Text"],
Cell[CellGroupData[{
Cell[162419, 4158, 106, 2, 29, "Input"],
Cell[162528, 4162, 28, 0, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162593, 4167, 107, 2, 29, "Input"],
Cell[162703, 4171, 28, 0, 28, "Output"]
}, Open  ]],
Cell[162746, 4174, 396, 9, 36, "Text"],
Cell[CellGroupData[{
Cell[163167, 4187, 71, 1, 28, "Input"],
Cell[163241, 4190, 147, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163425, 4198, 73, 1, 29, "Input"],
Cell[163501, 4201, 103, 2, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163641, 4208, 75, 1, 29, "Input"],
Cell[163719, 4211, 103, 2, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163859, 4218, 76, 1, 29, "Input"],
Cell[163938, 4221, 103, 2, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[164078, 4228, 47, 0, 18, "Subsubsection"],
Cell[164128, 4230, 320, 7, 35, "Text"],
Cell[164451, 4239, 609, 13, 51, "Text"],
Cell[165063, 4254, 892, 19, 45, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[165980, 4277, 775, 21, 60, "Input"],
Cell[166758, 4300, 3618, 70, 238, "Output"]
}, Open  ]],
Cell[170391, 4373, 768, 19, 53, "Text"],
Cell[171162, 4394, 377, 6, 50, "Text"],
Cell[171542, 4402, 1375, 33, 99, "Text"],
Cell[172920, 4437, 344, 13, 21, "Text"],
Cell[CellGroupData[{
Cell[173289, 4454, 136, 3, 29, "Input"],
Cell[173428, 4459, 28, 0, 28, "Output"]
}, Open  ]],
Cell[173471, 4462, 73, 0, 20, "Text"],
Cell[173547, 4464, 317, 9, 29, "Input",
 InitializationCell->True],
Cell[173867, 4475, 138, 5, 20, "Text"],
Cell[CellGroupData[{
Cell[174030, 4484, 113, 2, 29, "Input"],
Cell[174146, 4488, 28, 0, 28, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[174235, 4495, 72, 1, 26, "Subsection",
 CellTags->"Section2b"],
Cell[174310, 4498, 257, 6, 35, "Text"],
Cell[174570, 4506, 852, 25, 66, "Text"],
Cell[CellGroupData[{
Cell[175447, 4535, 66, 1, 29, "Input"],
Cell[175516, 4538, 3323, 68, 358, "Output"]
}, Open  ]],
Cell[178854, 4609, 279, 10, 21, "Text"],
Cell[CellGroupData[{
Cell[179158, 4623, 63, 1, 29, "Input"],
Cell[179224, 4626, 3818, 78, 369, "Output"]
}, Open  ]],
Cell[183057, 4707, 737, 24, 51, "Text"],
Cell[CellGroupData[{
Cell[183819, 4735, 63, 1, 29, "Input"],
Cell[183885, 4738, 3451, 72, 358, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[187385, 4816, 56, 1, 26, "Subsection",
 CellTags->"Section2c"],
Cell[187444, 4819, 913, 27, 66, "Text"],
Cell[CellGroupData[{
Cell[188382, 4850, 67, 1, 29, "Input"],
Cell[188452, 4853, 3984, 82, 288, "Output"]
}, Open  ]],
Cell[192451, 4938, 578, 17, 37, "Text"],
Cell[CellGroupData[{
Cell[193054, 4959, 194, 4, 29, "Input"],
Cell[193251, 4965, 6447, 145, 293, "Output"]
}, Open  ]],
Cell[199713, 5113, 502, 10, 52, "Text"],
Cell[200218, 5125, 826, 18, 67, "Text"],
Cell[201047, 5145, 238, 7, 21, "Text"],
Cell[CellGroupData[{
Cell[201310, 5156, 265, 8, 29, "Input"],
Cell[201578, 5166, 453, 10, 28, "Output"]
}, Open  ]],
Cell[202046, 5179, 269, 7, 21, "Text"],
Cell[CellGroupData[{
Cell[202340, 5190, 445, 12, 45, "Input"],
Cell[202788, 5204, 6613, 148, 293, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[209450, 5358, 62, 1, 26, "Subsection",
 CellTags->"Section2d"],
Cell[209515, 5361, 698, 20, 50, "Text"],
Cell[210216, 5383, 1193, 44, 54, "Text"],
Cell[CellGroupData[{
Cell[211434, 5431, 113, 3, 29, "Input"],
Cell[211550, 5436, 3722, 78, 296, "Output"]
}, Open  ]],
Cell[215287, 5517, 582, 15, 51, "Text"],
Cell[CellGroupData[{
Cell[215894, 5536, 706, 21, 61, "Input"],
Cell[216603, 5559, 6314, 141, 301, "Output"]
}, Open  ]],
Cell[222932, 5703, 402, 11, 35, "Text"],
Cell[CellGroupData[{
Cell[223359, 5718, 123, 3, 29, "Input"],
Cell[223485, 5723, 5995, 116, 271, "Output"]
}, Open  ]],
Cell[229495, 5842, 472, 12, 37, "Text"],
Cell[CellGroupData[{
Cell[229992, 5858, 109, 2, 29, "Input"],
Cell[230104, 5862, 31, 0, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230172, 5867, 47, 0, 18, "Subsubsection"],
Cell[230222, 5869, 594, 10, 66, "Text"],
Cell[230819, 5881, 449, 11, 36, "Text"],
Cell[CellGroupData[{
Cell[231293, 5896, 460, 11, 45, "Input"],
Cell[231756, 5909, 3853, 94, 374, "Output"]
}, Open  ]],
Cell[235624, 6006, 699, 16, 52, "Text"],
Cell[CellGroupData[{
Cell[236348, 6026, 658, 19, 61, "Input"],
Cell[237009, 6047, 1444, 29, 375, "Output"]
}, Open  ]],
Cell[238468, 6079, 1392, 36, 101, "Text"],
Cell[239863, 6117, 546, 14, 37, "Text"],
Cell[CellGroupData[{
Cell[240434, 6135, 829, 23, 77, "Input"],
Cell[241266, 6160, 1419, 29, 375, "Output"]
}, Open  ]],
Cell[242700, 6192, 360, 8, 36, "Text"],
Cell[CellGroupData[{
Cell[243085, 6204, 210, 8, 16, "Item1Numbered"],
Cell[243298, 6214, 184, 8, 16, "Item1Numbered"],
Cell[243485, 6224, 401, 14, 29, "Item1Numbered"],
Cell[243889, 6240, 227, 8, 16, "Item1Numbered"],
Cell[244119, 6250, 588, 16, 42, "Item1Numbered"]
}, Open  ]],
Cell[244722, 6269, 467, 12, 37, "Text"],
Cell[245192, 6283, 1719, 43, 117, "Text"],
Cell[CellGroupData[{
Cell[246936, 6330, 40, 0, 29, "Input"],
Cell[246979, 6332, 781, 15, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[247797, 6352, 252, 7, 30, "Input"],
Cell[248052, 6361, 333, 7, 28, "Output"]
}, Open  ]],
Cell[248400, 6371, 904, 15, 81, "Text"],
Cell[CellGroupData[{
Cell[249329, 6390, 292, 9, 30, "Input"],
Cell[249624, 6401, 147, 3, 28, "Output"]
}, Open  ]],
Cell[249786, 6407, 268, 7, 36, "Text"],
Cell[250057, 6416, 581, 19, 46, "Input",
 InitializationCell->True],
Cell[250641, 6437, 117, 4, 21, "Text"],
Cell[250761, 6443, 4537, 119, 354, "Input",
 InitializationCell->True],
Cell[255301, 6564, 96, 2, 20, "Text"],
Cell[CellGroupData[{
Cell[255422, 6570, 79, 1, 29, "Input"],
Cell[255504, 6573, 32, 0, 28, "Output"]
}, Open  ]],
Cell[255551, 6576, 179, 3, 35, "Text"],
Cell[CellGroupData[{
Cell[255755, 6583, 79, 1, 29, "Input"],
Cell[255837, 6586, 3135, 57, 375, "Output"]
}, Open  ]],
Cell[258987, 6646, 978, 27, 52, "Text"],
Cell[CellGroupData[{
Cell[259990, 6677, 215, 5, 29, "Input"],
Cell[260208, 6684, 2675, 51, 291, "Output"]
}, Open  ]],
Cell[262898, 6738, 302, 8, 36, "Text"],
Cell[263203, 6748, 422, 11, 61, "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[263674, 6765, 76, 1, 26, "Subsection",
 CellTags->"Section2e"],
Cell[263753, 6768, 331, 7, 35, "Text"],
Cell[CellGroupData[{
Cell[264109, 6779, 651, 13, 45, "Input",
 InitializationCell->True],
Cell[264763, 6794, 579, 11, 29, "Output"]
}, Open  ]],
Cell[265357, 6808, 614, 14, 52, "Text"],
Cell[CellGroupData[{
Cell[265996, 6826, 287, 7, 29, "Input",
 InitializationCell->True],
Cell[266286, 6835, 215, 4, 29, "Output"]
}, Open  ]],
Cell[266516, 6842, 528, 16, 37, "Text"],
Cell[CellGroupData[{
Cell[267069, 6862, 490, 16, 29, "Input",
 InitializationCell->True],
Cell[267562, 6880, 525, 18, 28, "Output"]
}, Open  ]],
Cell[268102, 6901, 40, 0, 20, "Text"],
Cell[CellGroupData[{
Cell[268167, 6905, 360, 7, 45, "Input",
 InitializationCell->True],
Cell[268530, 6914, 5964, 141, 155, "Output"]
}, Open  ]],
Cell[274509, 7058, 424, 10, 36, "Text"],
Cell[CellGroupData[{
Cell[274958, 7072, 149, 3, 29, "Input",
 InitializationCell->True],
Cell[275110, 7077, 319, 6, 29, "Output"]
}, Open  ]],
Cell[275444, 7086, 185, 4, 35, "Text"],
Cell[275632, 7092, 631, 15, 52, "Text"],
Cell[CellGroupData[{
Cell[276288, 7111, 114, 2, 29, "Input"],
Cell[276405, 7115, 6578, 161, 155, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[283032, 7282, 77, 1, 26, "Subsection",
 CellTags->"Section2f"],
Cell[283112, 7285, 632, 18, 37, "Text"],
Cell[283747, 7305, 134, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[283906, 7312, 251, 6, 29, "Input",
 InitializationCell->True],
Cell[284160, 7320, 6450, 145, 293, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290647, 7470, 465, 12, 45, "Input",
 InitializationCell->True],
Cell[291115, 7484, 3506, 81, 374, "Output"]
}, Open  ]],
Cell[294636, 7568, 464, 9, 51, "Text"],
Cell[CellGroupData[{
Cell[295125, 7581, 1113, 27, 61, "Input",
 InitializationCell->True],
Cell[296241, 7610, 8926, 197, 336, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305204, 7812, 362, 9, 45, "Input",
 InitializationCell->True],
Cell[305569, 7823, 4629, 107, 424, "Output"]
}, Open  ]],
Cell[310213, 7933, 317, 8, 36, "Text"],
Cell[CellGroupData[{
Cell[310555, 7945, 101, 2, 29, "Input"],
Cell[310659, 7949, 7964, 202, 293, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[318660, 8156, 101, 2, 29, "Input"],
Cell[318764, 8160, 11265, 288, 336, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[330078, 8454, 98, 2, 26, "Subsection",
 PageBreakWithin->False,
 CellTags->"Section2g"],
Cell[330179, 8458, 920, 23, 67, "Text",
 PageBreakAbove->False,
 PageBreakWithin->False],
Cell[331102, 8483, 148, 4, 29, "Input",
 InitializationCell->True],
Cell[331253, 8489, 183, 5, 28, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[331461, 8498, 228, 4, 45, "Input"],
Cell[331692, 8504, 6451, 169, 359, "Output"]
}, Open  ]],
Cell[338158, 8676, 369, 10, 36, "Text"],
Cell[338530, 8688, 148, 4, 29, "Input",
 InitializationCell->True],
Cell[338681, 8694, 415, 13, 29, "Input",
 InitializationCell->True],
Cell[339099, 8709, 197, 6, 29, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[339321, 8719, 114, 2, 29, "Input"],
Cell[339438, 8723, 5089, 136, 358, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[344576, 8865, 96, 2, 26, "Subsection",
 PageBreakWithin->False,
 CellTags->"Section2h"],
Cell[344675, 8869, 336, 9, 36, "Text",
 PageBreakAbove->False,
 PageBreakWithin->False],
Cell[CellGroupData[{
Cell[345036, 8882, 270, 7, 29, "Input"],
Cell[345309, 8891, 5375, 122, 436, "Output"]
}, Open  ]],
Cell[350699, 9016, 395, 10, 36, "Text"],
Cell[CellGroupData[{
Cell[351119, 9030, 402, 11, 29, "Input"],
Cell[351524, 9043, 3731, 76, 426, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[355304, 9125, 62, 1, 26, "Subsection",
 CellTags->"Section2i"],
Cell[355369, 9128, 863, 32, 50, "Text"],
Cell[CellGroupData[{
Cell[356257, 9164, 1498, 42, 93, "Input",
 InitializationCell->True],
Cell[357758, 9208, 5489, 131, 155, "Output"]
}, Open  ]],
Cell[363262, 9342, 230, 6, 21, "Text"],
Cell[363495, 9350, 983, 24, 68, "Text"],
Cell[364481, 9376, 1248, 25, 99, "Text"],
Cell[365732, 9403, 69, 0, 20, "Text"],
Cell[365804, 9405, 746, 16, 67, "Text"],
Cell[366553, 9423, 836, 20, 66, "Text"],
Cell[367392, 9445, 551, 13, 52, "Text"],
Cell[367946, 9460, 391, 9, 36, "Text"],
Cell[368340, 9471, 37, 0, 20, "Text"],
Cell[368380, 9473, 4899, 135, 397, "Input",
 InitializationCell->True],
Cell[373282, 9610, 98, 4, 21, "Text"],
Cell[CellGroupData[{
Cell[373405, 9618, 136, 3, 29, "Input"],
Cell[373544, 9623, 4789, 110, 155, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[378382, 9739, 78, 1, 26, "Subsection",
 CellTags->"Section2j"],
Cell[378463, 9742, 171, 3, 35, "Text"],
Cell[378637, 9747, 250, 4, 35, "Text"],
Cell[CellGroupData[{
Cell[378912, 9755, 92, 2, 29, "Input",
 InitializationCell->True],
Cell[379007, 9759, 8926, 197, 336, "Output"]
}, Open  ]],
Cell[387948, 9959, 1185, 28, 83, "Text"],
Cell[CellGroupData[{
Cell[389158, 9991, 506, 14, 61, "Input",
 InitializationCell->True],
Cell[389667, 10007, 6010, 130, 424, "Output"]
}, Open  ]],
Cell[395692, 10140, 498, 11, 37, "Text"],
Cell[396193, 10153, 296, 7, 36, "Text"],
Cell[CellGroupData[{
Cell[396514, 10164, 288, 6, 45, "Input",
 InitializationCell->True],
Cell[396805, 10172, 10170, 218, 332, "Output"]
}, Open  ]],
Cell[406990, 10393, 560, 15, 52, "Text"],
Cell[407553, 10410, 545, 18, 61, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[408123, 10432, 38, 0, 29, "Input"],
Cell[408164, 10434, 10726, 226, 336, "Output"]
}, Open  ]],
Cell[418905, 10663, 1254, 42, 69, "Text"],
Cell[CellGroupData[{
Cell[420184, 10709, 190, 4, 29, "Input"],
Cell[420377, 10715, 6756, 150, 366, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[427170, 10870, 302, 7, 45, "Input",
 InitializationCell->True],
Cell[427475, 10879, 7045, 153, 374, "Output"]
}, Open  ]],
Cell[434535, 11035, 172, 6, 20, "Text"],
Cell[434710, 11043, 588, 19, 61, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[435323, 11066, 43, 0, 29, "Input"],
Cell[435369, 11068, 7104, 157, 366, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[442534, 11232, 88, 1, 35, "Section",
 CellTags->"Section3"],
Cell[442625, 11235, 261, 5, 35, "Text"],
Cell[CellGroupData[{
Cell[442911, 11244, 64, 1, 32, "Subsection",
 CellTags->"Section3a"],
Cell[442978, 11247, 811, 28, 36, "Text"],
Cell[443792, 11277, 72, 0, 20, "Text"],
Cell[CellGroupData[{
Cell[443889, 11281, 540, 15, 45, "Input",
 InitializationCell->True],
Cell[444432, 11298, 659, 19, 88, "Output"]
}, Open  ]],
Cell[445106, 11320, 423, 11, 37, "Text"],
Cell[445532, 11333, 201, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[445758, 11343, 77, 1, 29, "Input"],
Cell[445838, 11346, 2274, 51, 374, "Output"]
}, Open  ]],
Cell[448127, 11400, 376, 8, 36, "Text"],
Cell[CellGroupData[{
Cell[448528, 11412, 325, 8, 45, "Input"],
Cell[448856, 11422, 3530, 81, 374, "Output"]
}, Open  ]],
Cell[452401, 11506, 146, 3, 20, "Text"],
Cell[452550, 11511, 993, 27, 69, "Text"],
Cell[CellGroupData[{
Cell[453568, 11542, 169, 4, 29, "Input",
 InitializationCell->True],
Cell[453740, 11548, 350, 12, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[454127, 11565, 72, 1, 29, "Input"],
Cell[454202, 11568, 1140, 28, 136, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[455379, 11601, 68, 1, 29, "Input"],
Cell[455450, 11604, 851, 23, 44, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[456350, 11633, 61, 1, 26, "Subsection",
 CellTags->"Section3b"],
Cell[456414, 11636, 137, 3, 20, "Text"],
Cell[456554, 11641, 358, 8, 36, "Text"],
Cell[CellGroupData[{
Cell[456937, 11653, 127, 3, 29, "Input"],
Cell[457067, 11658, 83, 2, 28, "Output"]
}, Open  ]],
Cell[457165, 11663, 156, 3, 20, "Text"],
Cell[457324, 11668, 339, 10, 29, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[457688, 11682, 103, 2, 29, "Input"],
Cell[457794, 11686, 570, 17, 28, "Output"]
}, Open  ]],
Cell[458379, 11706, 1129, 27, 96, "Text"],
Cell[459511, 11735, 553, 11, 50, "Text"],
Cell[460067, 11748, 1269, 38, 68, "Text"],
Cell[CellGroupData[{
Cell[461361, 11790, 503, 16, 29, "Input"],
Cell[461867, 11808, 749, 22, 88, "Output"]
}, Open  ]],
Cell[462631, 11833, 581, 12, 51, "Text"],
Cell[463215, 11847, 281, 6, 36, "Text"],
Cell[463499, 11855, 353, 10, 36, "Text"],
Cell[CellGroupData[{
Cell[463877, 11869, 192, 6, 29, "Input"],
Cell[464072, 11877, 189, 6, 28, "Output"]
}, Open  ]],
Cell[464276, 11886, 763, 17, 67, "Text"],
Cell[CellGroupData[{
Cell[465064, 11907, 172, 5, 29, "Input"],
Cell[465239, 11914, 347, 11, 28, "Output"]
}, Open  ]],
Cell[465601, 11928, 782, 17, 66, "Text"],
Cell[CellGroupData[{
Cell[466408, 11949, 264, 8, 29, "Input"],
Cell[466675, 11959, 268, 9, 33, "Output"]
}, Open  ]],
Cell[466958, 11971, 376, 8, 36, "Text"],
Cell[CellGroupData[{
Cell[467359, 11983, 285, 9, 29, "Input"],
Cell[467647, 11994, 756, 26, 28, "Output"]
}, Open  ]],
Cell[468418, 12023, 717, 19, 66, "Text"],
Cell[469138, 12044, 697, 19, 51, "Text"],
Cell[CellGroupData[{
Cell[469860, 12067, 466, 16, 29, "Input"],
Cell[CellGroupData[{
Cell[470351, 12087, 72, 2, 21, "Print"],
Cell[470426, 12091, 72, 2, 21, "Print"],
Cell[470501, 12095, 72, 2, 21, "Print"],
Cell[470576, 12099, 72, 2, 21, "Print"],
Cell[470651, 12103, 72, 2, 21, "Print"]
}, Open  ]]
}, Open  ]],
Cell[470750, 12109, 671, 20, 37, "Text"],
Cell[CellGroupData[{
Cell[471446, 12133, 527, 16, 61, "Input"],
Cell[471976, 12151, 508, 17, 28, "Output"]
}, Open  ]],
Cell[472499, 12171, 512, 15, 37, "Text"],
Cell[473014, 12188, 1081, 31, 93, "Input",
 InitializationCell->True],
Cell[474098, 12221, 44, 0, 20, "Text"],
Cell[CellGroupData[{
Cell[474167, 12225, 596, 17, 45, "Input",
 InitializationCell->True],
Cell[474766, 12244, 4162, 98, 124, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[478977, 12348, 64, 1, 26, "Subsection",
 CellTags->"Section3c"],
Cell[479044, 12351, 720, 27, 35, "Text"],
Cell[479767, 12380, 537, 14, 51, "Text"],
Cell[CellGroupData[{
Cell[480329, 12398, 648, 19, 45, "Input",
 InitializationCell->True],
Cell[480980, 12419, 567, 17, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[481584, 12441, 708, 19, 45, "Input",
 InitializationCell->True],
Cell[482295, 12462, 4077, 95, 215, "Output"]
}, Open  ]],
Cell[486387, 12560, 704, 19, 37, "Text"],
Cell[CellGroupData[{
Cell[487116, 12583, 120, 3, 29, "Input"],
Cell[487239, 12588, 910, 24, 104, "Output"]
}, Open  ]],
Cell[488164, 12615, 638, 21, 36, "Text"],
Cell[CellGroupData[{
Cell[488827, 12640, 915, 25, 61, "Input",
 InitializationCell->True],
Cell[489745, 12667, 3619, 88, 374, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[493401, 12760, 121, 3, 28, "Input"],
Cell[493525, 12765, 949, 28, 88, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[494523, 12799, 67, 1, 26, "Subsection",
 CellTags->"Section3d"],
Cell[494593, 12802, 291, 5, 35, "Text"],
Cell[494887, 12809, 578, 9, 80, "Text"],
Cell[495468, 12820, 1133, 30, 82, "Text"],
Cell[496604, 12852, 230, 4, 35, "Text"],
Cell[496837, 12858, 3246, 80, 426, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[500108, 12942, 124, 2, 29, "Input"],
Cell[CellGroupData[{
Cell[500257, 12948, 64, 0, 21, "Print"],
Cell[500324, 12950, 61, 0, 22, "Print"],
Cell[500388, 12952, 69, 0, 21, "Print"],
Cell[500460, 12954, 64, 0, 22, "Print"],
Cell[500527, 12956, 64, 0, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[500640, 12962, 170, 4, 29, "Input"],
Cell[500813, 12968, 63, 0, 22, "Print"]
}, Open  ]],
Cell[500891, 12971, 777, 21, 52, "Text"],
Cell[CellGroupData[{
Cell[501693, 12996, 171, 4, 29, "Input"],
Cell[501867, 13002, 31, 0, 28, "Output"]
}, Open  ]],
Cell[501913, 13005, 1011, 26, 68, "Text"],
Cell[502927, 13033, 112, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[503064, 13040, 1762, 53, 77, "Input",
 InitializationCell->True],
Cell[504829, 13095, 5028, 119, 268, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[509894, 13219, 1764, 53, 77, "Input",
 InitializationCell->True],
Cell[511661, 13274, 5031, 119, 268, "Output"]
}, Open  ]],
Cell[516707, 13396, 210, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[516942, 13406, 108, 2, 29, "Input"],
Cell[517053, 13410, 31, 0, 28, "Output"]
}, Open  ]],
Cell[517099, 13413, 191, 5, 21, "Text"],
Cell[CellGroupData[{
Cell[517315, 13422, 112, 2, 29, "Input"],
Cell[517430, 13426, 581, 20, 29, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[518072, 13453, 59, 1, 35, "Section",
 CellTags->"Section4"],
Cell[518134, 13456, 146, 4, 20, "Text"],
Cell[518283, 13462, 466, 12, 39, "Text"],
Cell[CellGroupData[{
Cell[518774, 13478, 113, 3, 29, "Input"],
Cell[518890, 13483, 2663, 59, 280, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[521590, 13547, 157, 4, 29, "Input"],
Cell[521750, 13553, 31, 0, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[521818, 13558, 157, 4, 29, "Input"],
Cell[521978, 13564, 2731, 59, 358, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[524746, 13628, 202, 5, 29, "Input"],
Cell[524951, 13635, 32, 0, 28, "Output"]
}, Open  ]],
Cell[524998, 13638, 350, 10, 21, "Text"],
Cell[CellGroupData[{
Cell[525373, 13652, 491, 13, 29, "Input",
 InitializationCell->True],
Cell[525867, 13667, 3180, 77, 373, "Output"]
}, Open  ]],
Cell[529062, 13747, 210, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[529297, 13757, 86, 1, 29, "Input"],
Cell[529386, 13760, 31, 0, 28, "Output"]
}, Open  ]],
Cell[529432, 13763, 363, 11, 21, "Text"],
Cell[CellGroupData[{
Cell[529820, 13778, 573, 15, 45, "Input",
 InitializationCell->True],
Cell[530396, 13795, 4139, 98, 81, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[534572, 13898, 84, 1, 29, "Input"],
Cell[534659, 13901, 32, 0, 28, "Output"]
}, Open  ]],
Cell[534706, 13904, 317, 7, 36, "Text"],
Cell[CellGroupData[{
Cell[535048, 13915, 90, 1, 29, "Input"],
Cell[535141, 13918, 31, 0, 28, "Output"]
}, Open  ]],
Cell[535187, 13921, 613, 14, 52, "Text"],
Cell[535803, 13937, 187, 7, 23, "Text"],
Cell[CellGroupData[{
Cell[536015, 13948, 287, 7, 29, "Input"],
Cell[536305, 13957, 4322, 101, 359, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[540664, 14063, 206, 5, 29, "Input"],
Cell[540873, 14070, 181, 6, 28, "Output"]
}, Open  ]],
Cell[541069, 14079, 480, 17, 38, "Text"],
Cell[541552, 14098, 441, 10, 37, "Text"],
Cell[CellGroupData[{
Cell[542018, 14112, 88, 1, 29, "Input"],
Cell[542109, 14115, 245, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[542391, 14127, 97, 2, 29, "Input"],
Cell[542491, 14131, 176, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[542704, 14141, 69, 1, 32, "Subsection",
 CellTags->"Section4a"],
Cell[542776, 14144, 181, 3, 35, "Text"],
Cell[542960, 14149, 1658, 53, 68, "Text"],
Cell[544621, 14204, 1726, 45, 187, "Input",
 InitializationCell->True],
Cell[546350, 14251, 75, 0, 20, "Text"],
Cell[CellGroupData[{
Cell[546450, 14255, 88, 1, 29, "Input"],
Cell[546541, 14258, 5129, 127, 81, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[551719, 14391, 77, 1, 26, "Subsection",
 CellTags->"Section4b"],
Cell[551799, 14394, 803, 26, 50, "Text"],
Cell[552605, 14422, 340, 8, 37, "Text"],
Cell[CellGroupData[{
Cell[552970, 14434, 232, 6, 45, "Input",
 InitializationCell->True],
Cell[553205, 14442, 851, 24, 104, "Output"]
}, Open  ]],
Cell[554071, 14469, 580, 18, 37, "Text"],
Cell[554654, 14489, 66, 0, 20, "Text"],
Cell[CellGroupData[{
Cell[554745, 14493, 250, 7, 28, "Input"],
Cell[554998, 14502, 6035, 155, 183, "Output"]
}, Open  ]],
Cell[561048, 14660, 407, 12, 36, "Text"],
Cell[561458, 14674, 640, 16, 50, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[562147, 14696, 71, 1, 35, "Section",
 CellTags->"Section5"],
Cell[562221, 14699, 650, 13, 65, "Text"],
Cell[CellGroupData[{
Cell[562896, 14716, 77, 1, 32, "Subsection",
 CellTags->"Section5a"],
Cell[562976, 14719, 676, 20, 51, "Text"],
Cell[CellGroupData[{
Cell[563677, 14743, 107, 2, 29, "Input"],
Cell[563787, 14747, 31, 0, 28, "Output"]
}, Open  ]],
Cell[563833, 14750, 589, 13, 51, "Text"],
Cell[CellGroupData[{
Cell[564447, 14767, 110, 2, 29, "Input"],
Cell[564560, 14771, 587, 13, 28, "Output"]
}, Open  ]],
Cell[565162, 14787, 531, 12, 51, "Text"],
Cell[CellGroupData[{
Cell[565718, 14803, 134, 3, 29, "Input"],
Cell[565855, 14808, 1730, 38, 59, "Output"]
}, Open  ]],
Cell[567600, 14849, 347, 10, 36, "Text"],
Cell[CellGroupData[{
Cell[567972, 14863, 174, 5, 29, "Input"],
Cell[568149, 14870, 30, 0, 28, "Output"]
}, Open  ]],
Cell[568194, 14873, 1059, 28, 67, "Text"],
Cell[569256, 14903, 996, 23, 68, "Text"],
Cell[570255, 14928, 611, 17, 37, "Text"],
Cell[CellGroupData[{
Cell[570891, 14949, 208, 5, 29, "Input",
 InitializationCell->True],
Cell[571102, 14956, 553, 12, 28, "Output"]
}, Open  ]],
Cell[571670, 14971, 370, 8, 36, "Text"],
Cell[572043, 14981, 738, 21, 52, "Text"],
Cell[CellGroupData[{
Cell[572806, 15006, 225, 6, 29, "Input"],
Cell[573034, 15014, 3906, 92, 358, "Output"]
}, Open  ]],
Cell[576955, 15109, 121, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[577101, 15116, 115, 3, 29, "Input"],
Cell[577219, 15121, 45, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[577301, 15127, 225, 6, 29, "Input"],
Cell[577529, 15135, 3323, 68, 358, "Output"]
}, Open  ]],
Cell[580867, 15206, 1068, 29, 53, "Text"],
Cell[CellGroupData[{
Cell[581960, 15239, 529, 13, 61, "Input"],
Cell[582492, 15254, 1939, 40, 434, "Output"]
}, Open  ]],
Cell[584446, 15297, 982, 24, 84, "Text"],
Cell[585431, 15323, 995, 27, 93, "Input",
 InitializationCell->True],
Cell[586429, 15352, 132, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[586586, 15359, 364, 8, 45, "Input"],
Cell[586953, 15369, 3167, 69, 442, "Output"]
}, Open  ]],
Cell[590135, 15441, 96, 2, 20, "Text"],
Cell[590234, 15445, 140, 3, 20, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[590411, 15453, 75, 1, 26, "Subsection",
 CellTags->"Section5b"],
Cell[590489, 15456, 765, 13, 95, "Text"],
Cell[591257, 15471, 1668, 45, 170, "Input",
 InitializationCell->True],
Cell[592928, 15518, 1980, 61, 100, "Text"],
Cell[CellGroupData[{
Cell[594933, 15583, 86, 2, 28, "Input"],
Cell[595022, 15587, 56, 1, 28, "Output"]
}, Open  ]],
Cell[595093, 15591, 2002, 56, 101, "Text"],
Cell[597098, 15649, 1794, 47, 101, "Text"],
Cell[598895, 15698, 248, 4, 35, "Text"],
Cell[CellGroupData[{
Cell[599168, 15706, 516, 11, 45, "Input",
 InitializationCell->True],
Cell[599687, 15719, 445, 9, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[600169, 15733, 691, 18, 45, "Input"],
Cell[600863, 15753, 2005, 43, 447, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[602905, 15801, 87, 1, 29, "Input"],
Cell[602995, 15804, 32, 0, 28, "Output"]
}, Open  ]],
Cell[603042, 15807, 372, 6, 50, "Text"],
Cell[603417, 15815, 6178, 146, 638, "Input",
 InitializationCell->True],
Cell[609598, 15963, 625, 12, 68, "Text"],
Cell[610226, 15977, 732, 11, 80, "Text"],
Cell[610961, 15990, 619, 14, 68, "Text"],
Cell[611583, 16006, 947, 17, 98, "Text"],
Cell[612533, 16025, 2025, 51, 162, "Text"],
Cell[614561, 16078, 510, 13, 53, "Text"],
Cell[615074, 16093, 991, 26, 85, "Text"],
Cell[616068, 16121, 335, 8, 36, "Text"],
Cell[CellGroupData[{
Cell[616428, 16133, 743, 15, 45, "Input",
 InitializationCell->True],
Cell[617174, 16150, 669, 13, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[617880, 16168, 776, 21, 60, "Input"],
Cell[618659, 16191, 2632, 55, 279, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[621328, 16251, 163, 4, 29, "Input",
 InitializationCell->True],
Cell[621494, 16257, 669, 13, 28, "Output"]
}, Open  ]],
Cell[622178, 16273, 484, 16, 35, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[622699, 16294, 63, 1, 26, "Subsection",
 CellTags->"Section5c"],
Cell[622765, 16297, 621, 15, 52, "Text"],
Cell[CellGroupData[{
Cell[623411, 16316, 130, 3, 29, "Input",
 InitializationCell->True],
Cell[623544, 16321, 3984, 82, 288, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[627565, 16408, 83, 1, 29, "Input"],
Cell[627651, 16411, 31, 0, 28, "Output"]
}, Open  ]],
Cell[627697, 16414, 503, 12, 36, "Text"],
Cell[CellGroupData[{
Cell[628225, 16430, 86, 1, 29, "Input"],
Cell[628314, 16433, 485, 11, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[628836, 16449, 111, 2, 29, "Input"],
Cell[628950, 16453, 2783, 62, 104, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[631770, 16520, 193, 5, 29, "Input",
 InitializationCell->True],
Cell[631966, 16527, 453, 10, 28, "Output"]
}, Open  ]],
Cell[632434, 16540, 202, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[632661, 16550, 123, 2, 29, "Input"],
Cell[632787, 16554, 5319, 133, 288, "Output"]
}, Open  ]],
Cell[638121, 16690, 141, 4, 21, "Text"],
Cell[CellGroupData[{
Cell[638287, 16698, 120, 2, 29, "Input"],
Cell[638410, 16702, 2533, 53, 364, "Output"]
}, Open  ]],
Cell[640958, 16758, 202, 4, 35, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[641209, 16768, 69, 1, 35, "Section",
 CellTags->"Section6"],
Cell[641281, 16771, 282, 5, 35, "Text"],
Cell[641566, 16778, 699, 17, 52, "Text"],
Cell[642268, 16797, 106, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[642399, 16804, 1634, 41, 93, "Input",
 InitializationCell->True],
Cell[644036, 16847, 4843, 109, 155, "Output"]
}, Open  ]],
Cell[648894, 16959, 560, 12, 52, "Text"],
Cell[CellGroupData[{
Cell[649479, 16975, 2250, 58, 141, "Input"],
Cell[651732, 17035, 4843, 109, 155, "Output"]
}, Open  ]],
Cell[656590, 17147, 1085, 24, 83, "Text"],
Cell[CellGroupData[{
Cell[657700, 17175, 1124, 31, 59, "Input",
 InitializationCell->True],
Cell[658827, 17208, 973, 21, 120, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[659837, 17234, 852, 23, 61, "Input"],
Cell[660692, 17259, 4964, 112, 155, "Output"]
}, Open  ]],
Cell[665671, 17374, 623, 14, 52, "Text"],
Cell[CellGroupData[{
Cell[666319, 17392, 998, 26, 61, "Input"],
Cell[667320, 17420, 4036, 98, 332, "Output"]
}, Open  ]],
Cell[671371, 17521, 374, 8, 36, "Text"],
Cell[671748, 17531, 488, 11, 37, "Text"],
Cell[672239, 17544, 955, 27, 123, "Input",
 InitializationCell->True],
Cell[673197, 17573, 92, 2, 20, "Text"],
Cell[CellGroupData[{
Cell[673314, 17579, 76, 1, 29, "Input"],
Cell[673393, 17582, 7455, 177, 155, "Output"]
}, Open  ]],
Cell[680863, 17762, 109, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[680997, 17769, 1715, 43, 109, "Input",
 InitializationCell->True],
Cell[682715, 17814, 7455, 177, 155, "Output"]
}, Open  ]],
Cell[690185, 17994, 700, 19, 66, "Text"],
Cell[CellGroupData[{
Cell[690910, 18017, 126, 2, 28, "Input"],
Cell[691039, 18021, 147, 3, 28, "Output"]
}, Open  ]],
Cell[691201, 18027, 1089, 28, 68, "Text"],
Cell[CellGroupData[{
Cell[692315, 18059, 238, 6, 29, "Input"],
Cell[692556, 18067, 9024, 227, 155, "Output"]
}, Open  ]],
Cell[701595, 18297, 246, 6, 21, "Text"],
Cell[CellGroupData[{
Cell[701866, 18307, 123, 2, 29, "Input"],
Cell[701992, 18311, 30, 0, 28, "Output"]
}, Open  ]],
Cell[702037, 18314, 312, 7, 36, "Text"],
Cell[CellGroupData[{
Cell[702374, 18325, 105, 2, 29, "Input"],
Cell[702482, 18329, 126, 3, 28, "Output"]
}, Open  ]],
Cell[702623, 18335, 437, 9, 51, "Text"],
Cell[CellGroupData[{
Cell[703085, 18348, 116, 3, 29, "Input"],
Cell[703204, 18353, 845, 21, 120, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[704098, 18380, 60, 1, 35, "Section",
 CellTags->"Section7"],
Cell[704161, 18383, 638, 15, 66, "Text"],
Cell[704802, 18400, 523, 14, 36, "Text"],
Cell[CellGroupData[{
Cell[705350, 18418, 106, 2, 29, "Input"],
Cell[705459, 18422, 31, 0, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[705527, 18427, 105, 2, 29, "Input"],
Cell[705635, 18431, 32, 0, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[705704, 18436, 107, 2, 32, "Subsection",
 CellTags->"Section7a"],
Cell[705814, 18440, 814, 26, 50, "Text"],
Cell[CellGroupData[{
Cell[706653, 18470, 258, 6, 29, "Input",
 InitializationCell->True],
Cell[706914, 18478, 4228, 99, 359, "Output"]
}, Open  ]],
Cell[711157, 18580, 830, 23, 52, "Text"],
Cell[CellGroupData[{
Cell[712012, 18607, 288, 7, 29, "Input",
 InitializationCell->True],
Cell[712303, 18616, 4697, 111, 436, "Output"]
}, Open  ]],
Cell[717015, 18730, 491, 13, 37, "Text"],
Cell[717509, 18745, 559, 18, 61, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[718093, 18767, 43, 0, 29, "Input"],
Cell[718139, 18769, 5019, 115, 447, "Output"]
}, Open  ]],
Cell[723173, 18887, 299, 7, 36, "Text"],
Cell[CellGroupData[{
Cell[723497, 18898, 615, 19, 61, "Input"],
Cell[724115, 18919, 147, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[724299, 18928, 43, 0, 29, "Input"],
Cell[724345, 18930, 5011, 115, 359, "Output"]
}, Open  ]],
Cell[729371, 19048, 773, 21, 37, "Text"],
Cell[CellGroupData[{
Cell[730169, 19073, 622, 17, 61, "Input",
 InitializationCell->True],
Cell[730794, 19092, 5147, 117, 359, "Output"]
}, Open  ]],
Cell[735956, 19212, 72, 0, 20, "Text"],
Cell[736031, 19214, 3768, 108, 346, "Input",
 InitializationCell->True],
Cell[739802, 19324, 845, 29, 50, "Text"],
Cell[740650, 19355, 1854, 51, 172, "Input",
 InitializationCell->True],
Cell[742507, 19408, 129, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[742661, 19415, 113, 2, 29, "Input"],
Cell[742777, 19419, 4508, 103, 359, "Output"]
}, Open  ]],
Cell[747300, 19525, 971, 24, 80, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[748308, 19554, 92, 1, 26, "Subsection",
 CellTags->"Section7b"],
Cell[748403, 19557, 607, 16, 53, "Text"],
Cell[CellGroupData[{
Cell[749035, 19577, 263, 6, 29, "Input",
 InitializationCell->True],
Cell[749301, 19585, 8138, 179, 359, "Output"]
}, Open  ]],
Cell[757454, 19767, 141, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[757620, 19774, 154, 4, 29, "Input",
 InitializationCell->True],
Cell[757777, 19780, 7260, 161, 431, "Output"]
}, Open  ]],
Cell[765052, 19944, 196, 4, 35, "Text"],
Cell[CellGroupData[{
Cell[765273, 19952, 418, 11, 45, "Input",
 InitializationCell->True],
Cell[765694, 19965, 5428, 123, 391, "Output"]
}, Open  ]],
Cell[771137, 20091, 700, 25, 42, "Text"],
Cell[CellGroupData[{
Cell[771862, 20120, 192, 5, 29, "Input"],
Cell[772057, 20127, 31, 0, 28, "Output"]
}, Open  ]],
Cell[772103, 20130, 241, 8, 23, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[772393, 20144, 61, 1, 35, "Section",
 CellTags->"Section8"],
Cell[772457, 20147, 223, 4, 35, "Text"],
Cell[772683, 20153, 162, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[772870, 20160, 73, 1, 32, "Subsection",
 CellTags->"Section8a"],
Cell[772946, 20163, 555, 8, 65, "Text"],
Cell[773504, 20173, 593, 9, 65, "Text"],
Cell[774100, 20184, 1019, 24, 83, "Text"],
Cell[775122, 20210, 268, 7, 21, "Text"],
Cell[775393, 20219, 420, 12, 45, "Input",
 InitializationCell->True],
Cell[775816, 20233, 164, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[776005, 20240, 263, 7, 29, "Input",
 InitializationCell->True],
Cell[776271, 20249, 853, 21, 60, "Output"]
}, Open  ]],
Cell[777139, 20273, 68, 0, 20, "Text"],
Cell[777210, 20275, 3991, 98, 357, "Input",
 InitializationCell->True],
Cell[781204, 20375, 684, 17, 52, "Text"],
Cell[781891, 20394, 421, 9, 52, "Text"],
Cell[782315, 20405, 755, 23, 52, "Text"],
Cell[783073, 20430, 68, 0, 20, "Text"],
Cell[CellGroupData[{
Cell[783166, 20434, 2398, 55, 109, "Input",
 InitializationCell->True],
Cell[785567, 20491, 7826, 171, 268, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[793430, 20667, 75, 1, 29, "Input"],
Cell[793508, 20670, 8920, 197, 268, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[802489, 20874, 115, 3, 35, "Section",
 CellTags->"Solutions"],
Cell[CellGroupData[{
Cell[802629, 20881, 80, 1, 32, "Subsection",
 CellTags->"SolutionsCE1"],
Cell[802712, 20884, 64, 0, 42, "Problem"],
Cell[802779, 20886, 494, 11, 50, "Text"],
Cell[803276, 20899, 1713, 48, 172, "Input",
 InitializationCell->True],
Cell[804992, 20949, 661, 23, 38, "Text"],
Cell[805656, 20974, 505, 14, 36, "Text"],
Cell[CellGroupData[{
Cell[806186, 20992, 217, 6, 29, "Input"],
Cell[806406, 21000, 18881, 438, 351, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[825336, 21444, 80, 1, 26, "Subsection",
 CellTags->"SolutionsCE2"],
Cell[825419, 21447, 95, 2, 42, "Problem"],
Cell[825517, 21451, 775, 18, 52, "Text"],
Cell[826295, 21471, 1766, 49, 157, "Input",
 InitializationCell->True],
Cell[828064, 21522, 99, 2, 20, "Text"],
Cell[828166, 21526, 140, 4, 29, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[828331, 21534, 65, 1, 29, "Input"],
Cell[828399, 21537, 29, 0, 28, "Output"]
}, Open  ]],
Cell[828443, 21540, 112, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[828580, 21547, 271, 8, 28, "Input"],
Cell[828854, 21557, 15942, 362, 375, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[844845, 21925, 80, 1, 26, "Subsection",
 CellTags->"SolutionsCE9"],
Cell[844928, 21928, 177, 3, 55, "Problem"],
Cell[845108, 21933, 487, 11, 51, "Text"],
Cell[CellGroupData[{
Cell[845620, 21948, 113, 3, 29, "Input"],
Cell[845736, 21953, 4717, 94, 234, "Output"]
}, Open  ]],
Cell[850468, 22050, 856, 16, 82, "Text"],
Cell[CellGroupData[{
Cell[851349, 22070, 143, 3, 29, "Input"],
Cell[851495, 22075, 5226, 103, 280, "Output"]
}, Open  ]],
Cell[856736, 22181, 266, 6, 21, "Text"],
Cell[857005, 22189, 308, 7, 36, "Text"],
Cell[857316, 22198, 816, 20, 53, "Text"],
Cell[858135, 22220, 843, 24, 77, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[859003, 22248, 70, 1, 29, "Input"],
Cell[859076, 22251, 3088, 68, 296, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[862213, 22325, 82, 1, 26, "Subsection",
 CellTags->"SolutionsCE13"],
Cell[862298, 22328, 369, 9, 55, "Problem"],
Cell[862670, 22339, 579, 14, 51, "Text"],
Cell[863252, 22355, 1147, 32, 138, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[864424, 22391, 206, 6, 29, "Input"],
Cell[864633, 22399, 348, 10, 47, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[865042, 22416, 52, 1, 35, "Section",
 CellTags->"Exercises"],
Cell[CellGroupData[{
Cell[865119, 22421, 207, 8, 20, "Item1Exercise"],
Cell[865329, 22431, 190, 6, 20, "Item1Exercise"],
Cell[865522, 22439, 164, 5, 20, "Item1Exercise"],
Cell[865689, 22446, 166, 5, 20, "Item1Exercise"],
Cell[865858, 22453, 171, 5, 20, "Item1Exercise"],
Cell[866032, 22460, 254, 6, 33, "Item1Exercise"],
Cell[866289, 22468, 335, 11, 33, "Item1Exercise"],
Cell[866627, 22481, 810, 27, 46, "Item1Exercise"],
Cell[867440, 22510, 804, 27, 46, "Item1Exercise"],
Cell[868247, 22539, 236, 6, 33, "Item1Exercise"],
Cell[868486, 22547, 244, 6, 33, "Item1Exercise"],
Cell[868733, 22555, 242, 6, 33, "Item1Exercise"],
Cell[868978, 22563, 265, 7, 33, "Item1Exercise"],
Cell[869246, 22572, 441, 13, 33, "Item1Exercise"],
Cell[869690, 22587, 452, 13, 46, "Item1Exercise"],
Cell[870145, 22602, 434, 9, 46, "Item1Exercise"],
Cell[870582, 22613, 547, 11, 59, "Item1Exercise"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
